// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dcore_python.h"

// main header
#include "qt3dcore_qabstractskeleton_wrapper.h"

// Wrappers providing overrides
#include "qt3dcore_qnode_wrapper.h"

// Argument includes
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractSkeletonWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QAbstractSkeletonWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QNodeWrapper::sbk_o_childEvent("QAbstractSkeleton", funcName, gil, pyOverride, event);
}

void QAbstractSkeletonWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QNodeWrapper::sbk_o_connectNotify("QAbstractSkeleton", funcName, gil, pyOverride, signal);
}

void QAbstractSkeletonWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QNodeWrapper::sbk_o_customEvent("QAbstractSkeleton", funcName, gil, pyOverride, event);
}

void QAbstractSkeletonWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QNodeWrapper::sbk_o_connectNotify("QAbstractSkeleton", funcName, gil, pyOverride, signal);
}

bool QAbstractSkeletonWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QNodeWrapper::sbk_o_event("QAbstractSkeleton", funcName, gil, pyOverride, event);
}

bool QAbstractSkeletonWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QNodeWrapper::sbk_o_eventFilter("QAbstractSkeleton", funcName, gil, pyOverride, watched, event);
}

void QAbstractSkeletonWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QNodeWrapper::sbk_o_timerEvent("QAbstractSkeleton", funcName, gil, pyOverride, event);
}

const QMetaObject *QAbstractSkeletonWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DCore::QAbstractSkeleton::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstractSkeletonWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DCore::QAbstractSkeleton::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstractSkeletonWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstractSkeletonWrapper *>(this));
    return Qt3DCore::QAbstractSkeleton::qt_metacast(_clname);
}

QAbstractSkeletonWrapper::~QAbstractSkeletonWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_Qt3DCore_QAbstractSkeleton_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QAbstractSkeleton");
    return -1;
}

static PyObject *Sbk_Qt3DCore_QAbstractSkeletonFunc_jointCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAbstractSkeleton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAbstractSkeleton_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // jointCount()const
        int cppResult = const_cast<const ::Qt3DCore::QAbstractSkeleton *>(cppSelf)->jointCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Qt3DCore_QAbstractSkeleton_PropertyStrings[] = {
    "jointCount:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DCore_QAbstractSkeleton_methods[] = {
    {"jointCount", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAbstractSkeletonFunc_jointCount), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DCore_QAbstractSkeleton_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DCore::QAbstractSkeleton *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAbstractSkeleton_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractSkeletonWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DCore_QAbstractSkeleton_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DCore_QAbstractSkeleton_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DCore_QAbstractSkeleton_Type = nullptr;
static PyTypeObject *Sbk_Qt3DCore_QAbstractSkeleton_TypeF(void)
{
    return _Sbk_Qt3DCore_QAbstractSkeleton_Type;
}

static PyType_Slot Sbk_Qt3DCore_QAbstractSkeleton_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DCore_QAbstractSkeleton_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DCore_QAbstractSkeleton_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DCore_QAbstractSkeleton_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DCore_QAbstractSkeleton_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DCore_QAbstractSkeleton_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DCore_QAbstractSkeleton_spec = {
    "2:PySide6.Qt3DCore.Qt3DCore.QAbstractSkeleton",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DCore_QAbstractSkeleton_slots
};

} //extern "C"

static void *Sbk_Qt3DCore_QAbstractSkeleton_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DCore::QAbstractSkeleton *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractSkeleton_PythonToCpp_QAbstractSkeleton_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DCore_QAbstractSkeleton_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractSkeleton_PythonToCpp_QAbstractSkeleton_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DCore_QAbstractSkeleton_TypeF()))
        return QAbstractSkeleton_PythonToCpp_QAbstractSkeleton_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractSkeleton_PTR_CppToPython_QAbstractSkeleton(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DCore::QAbstractSkeleton *>(const_cast<void *>(cppIn)), Sbk_Qt3DCore_QAbstractSkeleton_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DCore_QAbstractSkeleton_SignatureStrings[] = {
    "PySide6.Qt3DCore.Qt3DCore.QAbstractSkeleton.jointCount(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DCore_QAbstractSkeleton_SignatureByteSize = 63;
static constexpr uint8_t Qt3DCore_QAbstractSkeleton_SignatureBytes[63] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x31, 0x76, 0x71, 0xce,
    0x2f, 0x4a, 0x45, 0x62, 0x38, 0x26, 0x15, 0x97, 0x14, 0x25, 0x26, 0x97, 0x04, 0x67, 0xa7, 0xe6,
    0xa4, 0x96, 0xe4, 0xe7, 0xe9, 0x65, 0xe5, 0x67, 0xe6, 0x95, 0x38, 0xe7, 0x97, 0xe6, 0x95, 0x68,
    0x14, 0xa7, 0xe6, 0xa4, 0x69, 0xea, 0xda, 0x01, 0xf9, 0x5c, 0x00, 0x0b, 0x3d, 0x17, 0x79
};
#endif

PyTypeObject *init_Qt3DCore_QAbstractSkeleton(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAbstractSkeleton_IDX].type != nullptr)
        return SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAbstractSkeleton_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DCore_QAbstractSkeleton_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]))));

    _Sbk_Qt3DCore_QAbstractSkeleton_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QAbstractSkeleton",
        "Qt3DCore::QAbstractSkeleton*",
        &Sbk_Qt3DCore_QAbstractSkeleton_spec,
        &Shiboken::callCppDestructor< Qt3DCore::QAbstractSkeleton >,
        Sbk_Qt3DCore_QAbstractSkeleton_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DCore_QAbstractSkeleton_TypeF(); // references _Sbk_Qt3DCore_QAbstractSkeleton_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DCore_QAbstractSkeleton_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DCore_QAbstractSkeleton_SignatureBytes, Qt3DCore_QAbstractSkeleton_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DCore_QAbstractSkeleton_PropertyStrings);
    SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAbstractSkeleton_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractSkeleton_PythonToCpp_QAbstractSkeleton_PTR,
        is_QAbstractSkeleton_PythonToCpp_QAbstractSkeleton_PTR_Convertible,
        QAbstractSkeleton_PTR_CppToPython_QAbstractSkeleton);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QAbstractSkeleton");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QAbstractSkeleton*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QAbstractSkeleton&");
    Shiboken::Conversions::registerConverterAlias(converter, "QAbstractSkeleton");
    Shiboken::Conversions::registerConverterAlias(converter, "QAbstractSkeleton*");
    Shiboken::Conversions::registerConverterAlias(converter, "QAbstractSkeleton&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DCore::QAbstractSkeleton).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractSkeletonWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DCore_QAbstractSkeleton_TypeF(), &Sbk_Qt3DCore_QAbstractSkeleton_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Qt3DCore::QAbstractSkeleton::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DCore::QAbstractSkeleton::staticMetaObject, sizeof(QAbstractSkeletonWrapper));

    return pyType;
}
