// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dextras_python.h"

// main header
#include "qt3dextras_qorbitcameracontroller_wrapper.h"

// Wrappers providing overrides
#include "qt3dextras_qt3dwindow_wrapper.h"

// Argument includes
#include <Qt3DCore/qnode.h>
#include <Qt3DExtras/qabstractcameracontroller.h>
#include <QtGui/qvectornd.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DExtras;

// Native ---------------------------------------------------------

void QOrbitCameraControllerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QOrbitCameraControllerWrapper::QOrbitCameraControllerWrapper(::Qt3DCore::QNode * parent) : Qt3DExtras::QOrbitCameraController(parent)
{
}

void QOrbitCameraControllerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    Qt3DWindowWrapper::sbk_o_childEvent("QOrbitCameraController", funcName, gil, pyOverride, event);
}

void QOrbitCameraControllerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    Qt3DWindowWrapper::sbk_o_connectNotify("QOrbitCameraController", funcName, gil, pyOverride, signal);
}

void QOrbitCameraControllerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    Qt3DWindowWrapper::sbk_o_customEvent("QOrbitCameraController", funcName, gil, pyOverride, event);
}

void QOrbitCameraControllerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    Qt3DWindowWrapper::sbk_o_connectNotify("QOrbitCameraController", funcName, gil, pyOverride, signal);
}

bool QOrbitCameraControllerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return Qt3DWindowWrapper::sbk_o_event("QOrbitCameraController", funcName, gil, pyOverride, event);
}

bool QOrbitCameraControllerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return Qt3DWindowWrapper::sbk_o_eventFilter("QOrbitCameraController", funcName, gil, pyOverride, watched, event);
}

void QOrbitCameraControllerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    Qt3DWindowWrapper::sbk_o_timerEvent("QOrbitCameraController", funcName, gil, pyOverride, event);
}

const QMetaObject *QOrbitCameraControllerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DExtras::QOrbitCameraController::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QOrbitCameraControllerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DExtras::QOrbitCameraController::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QOrbitCameraControllerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QOrbitCameraControllerWrapper *>(this));
    return Qt3DExtras::QOrbitCameraController::qt_metacast(_clname);
}

QOrbitCameraControllerWrapper::~QOrbitCameraControllerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DExtras_QOrbitCameraController_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DExtras::QOrbitCameraController >()))
        return -1;

    QOrbitCameraControllerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QOrbitCameraController", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOrbitCameraController::QOrbitCameraController(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QOrbitCameraController(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QOrbitCameraController(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QOrbitCameraController(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QOrbitCameraControllerWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QOrbitCameraControllerWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DExtras::QOrbitCameraController >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DExtras_QOrbitCameraControllerFunc_inversePan(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inversePan()const
        bool cppResult = const_cast<const ::Qt3DExtras::QOrbitCameraController *>(cppSelf)->inversePan();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DExtras_QOrbitCameraControllerFunc_inverseTilt(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inverseTilt()const
        bool cppResult = const_cast<const ::Qt3DExtras::QOrbitCameraController *>(cppSelf)->inverseTilt();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DExtras_QOrbitCameraControllerFunc_inverseXTranslate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inverseXTranslate()const
        bool cppResult = const_cast<const ::Qt3DExtras::QOrbitCameraController *>(cppSelf)->inverseXTranslate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DExtras_QOrbitCameraControllerFunc_inverseYTranslate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // inverseYTranslate()const
        bool cppResult = const_cast<const ::Qt3DExtras::QOrbitCameraController *>(cppSelf)->inverseYTranslate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DExtras_QOrbitCameraControllerFunc_setInversePan(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOrbitCameraController::setInversePan(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setInversePan(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInversePan", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInversePan(bool)
            cppSelf->setInversePan(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DExtras_QOrbitCameraControllerFunc_setInverseTilt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOrbitCameraController::setInverseTilt(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setInverseTilt(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInverseTilt", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInverseTilt(bool)
            cppSelf->setInverseTilt(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DExtras_QOrbitCameraControllerFunc_setInverseXTranslate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOrbitCameraController::setInverseXTranslate(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setInverseXTranslate(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInverseXTranslate", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInverseXTranslate(bool)
            cppSelf->setInverseXTranslate(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DExtras_QOrbitCameraControllerFunc_setInverseYTranslate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOrbitCameraController::setInverseYTranslate(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setInverseYTranslate(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInverseYTranslate", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInverseYTranslate(bool)
            cppSelf->setInverseYTranslate(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DExtras_QOrbitCameraControllerFunc_setUpVector(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOrbitCameraController::setUpVector(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setUpVector(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUpVector", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUpVector(QVector3D)
            cppSelf->setUpVector(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DExtras_QOrbitCameraControllerFunc_setZoomInLimit(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOrbitCameraController::setZoomInLimit(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setZoomInLimit(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setZoomInLimit", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZoomInLimit(float)
            cppSelf->setZoomInLimit(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DExtras_QOrbitCameraControllerFunc_setZoomTranslateViewCenter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOrbitCameraController::setZoomTranslateViewCenter(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setZoomTranslateViewCenter(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setZoomTranslateViewCenter", errInfo, SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZoomTranslateViewCenter(bool)
            cppSelf->setZoomTranslateViewCenter(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DExtras_QOrbitCameraControllerFunc_upVector(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // upVector()const
        QVector3D cppResult = const_cast<const ::Qt3DExtras::QOrbitCameraController *>(cppSelf)->upVector();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DExtras_QOrbitCameraControllerFunc_zoomInLimit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // zoomInLimit()const
        float cppResult = const_cast<const ::Qt3DExtras::QOrbitCameraController *>(cppSelf)->zoomInLimit();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DExtras_QOrbitCameraControllerFunc_zoomTranslateViewCenter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // zoomTranslateViewCenter()const
        bool cppResult = const_cast<const ::Qt3DExtras::QOrbitCameraController *>(cppSelf)->zoomTranslateViewCenter();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Qt3DExtras_QOrbitCameraController_PropertyStrings[] = {
    "inversePan::",
    "inverseTilt::",
    "inverseXTranslate::",
    "inverseYTranslate::",
    "upVector::",
    "zoomInLimit::",
    "zoomTranslateViewCenter::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DExtras_QOrbitCameraController_methods[] = {
    {"inversePan", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QOrbitCameraControllerFunc_inversePan), METH_NOARGS, nullptr},
    {"inverseTilt", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QOrbitCameraControllerFunc_inverseTilt), METH_NOARGS, nullptr},
    {"inverseXTranslate", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QOrbitCameraControllerFunc_inverseXTranslate), METH_NOARGS, nullptr},
    {"inverseYTranslate", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QOrbitCameraControllerFunc_inverseYTranslate), METH_NOARGS, nullptr},
    {"setInversePan", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QOrbitCameraControllerFunc_setInversePan), METH_O, nullptr},
    {"setInverseTilt", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QOrbitCameraControllerFunc_setInverseTilt), METH_O, nullptr},
    {"setInverseXTranslate", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QOrbitCameraControllerFunc_setInverseXTranslate), METH_O, nullptr},
    {"setInverseYTranslate", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QOrbitCameraControllerFunc_setInverseYTranslate), METH_O, nullptr},
    {"setUpVector", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QOrbitCameraControllerFunc_setUpVector), METH_O, nullptr},
    {"setZoomInLimit", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QOrbitCameraControllerFunc_setZoomInLimit), METH_O, nullptr},
    {"setZoomTranslateViewCenter", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QOrbitCameraControllerFunc_setZoomTranslateViewCenter), METH_O, nullptr},
    {"upVector", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QOrbitCameraControllerFunc_upVector), METH_NOARGS, nullptr},
    {"zoomInLimit", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QOrbitCameraControllerFunc_zoomInLimit), METH_NOARGS, nullptr},
    {"zoomTranslateViewCenter", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtras_QOrbitCameraControllerFunc_zoomTranslateViewCenter), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DExtras_QOrbitCameraController_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DExtras::QOrbitCameraController *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QOrbitCameraControllerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DExtras_QOrbitCameraController_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DExtras_QOrbitCameraController_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DExtras_QOrbitCameraController_Type = nullptr;
static PyTypeObject *Sbk_Qt3DExtras_QOrbitCameraController_TypeF(void)
{
    return _Sbk_Qt3DExtras_QOrbitCameraController_Type;
}

static PyType_Slot Sbk_Qt3DExtras_QOrbitCameraController_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DExtras_QOrbitCameraController_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DExtras_QOrbitCameraController_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DExtras_QOrbitCameraController_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DExtras_QOrbitCameraController_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DExtras_QOrbitCameraController_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DExtras_QOrbitCameraController_spec = {
    "2:PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DExtras_QOrbitCameraController_slots
};

} //extern "C"

static void *Sbk_Qt3DExtras_QOrbitCameraController_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DExtras::QOrbitCameraController *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOrbitCameraController_PythonToCpp_QOrbitCameraController_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DExtras_QOrbitCameraController_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOrbitCameraController_PythonToCpp_QOrbitCameraController_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DExtras_QOrbitCameraController_TypeF()))
        return QOrbitCameraController_PythonToCpp_QOrbitCameraController_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOrbitCameraController_PTR_CppToPython_QOrbitCameraController(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DExtras::QOrbitCameraController *>(const_cast<void *>(cppIn)), Sbk_Qt3DExtras_QOrbitCameraController_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DExtras_QOrbitCameraController_SignatureStrings[] = {
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,zoomInLimit:float=None,upVector:QVector3D=None,inverseXTranslate:bool=None,inverseYTranslate:bool=None,inversePan:bool=None,inverseTilt:bool=None,zoomTranslateViewCenter:bool=None)",
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController.inversePan(self)->bool",
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController.inverseTilt(self)->bool",
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController.inverseXTranslate(self)->bool",
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController.inverseYTranslate(self)->bool",
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController.setInversePan(self,isInverse:bool)",
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController.setInverseTilt(self,isInverse:bool)",
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController.setInverseXTranslate(self,isInverse:bool)",
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController.setInverseYTranslate(self,isInverse:bool)",
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController.setUpVector(self,upVector:PySide6.QtGui.QVector3D)",
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController.setZoomInLimit(self,zoomInLimit:float)",
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController.setZoomTranslateViewCenter(self,isTranslate:bool)",
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController.upVector(self)->PySide6.QtGui.QVector3D",
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController.zoomInLimit(self)->float",
    "PySide6.Qt3DExtras.Qt3DExtras.QOrbitCameraController.zoomTranslateViewCenter(self)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DExtras_QOrbitCameraController_SignatureByteSize = 301;
static constexpr uint8_t Qt3DExtras_QOrbitCameraController_SignatureBytes[301] = {
    0x78, 0xda, 0xb5, 0x94, 0x4b, 0x6f, 0x83, 0x30, 0x0c, 0x80, 0xef, 0xfb, 0x25, 0x63, 0x62, 0x5c,
    0x2a, 0xf5, 0x80, 0xd4, 0x5d, 0xe8, 0x34, 0x55, 0xab, 0x5a, 0xaa, 0x75, 0xd5, 0xd8, 0x2d, 0x1d,
    0xae, 0x14, 0x29, 0xc4, 0xc8, 0x31, 0xeb, 0xe8, 0xaf, 0x1f, 0x8f, 0x96, 0x47, 0x1f, 0x3b, 0x00,
    0x3b, 0x25, 0x72, 0xd0, 0x67, 0xe7, 0x23, 0xb6, 0x9f, 0xbe, 0xc9, 0x10, 0xc6, 0xce, 0x8a, 0x47,
    0xd3, 0xe7, 0x1f, 0x26, 0x61, 0x5a, 0xdb, 0x25, 0x6d, 0x25, 0x7b, 0x22, 0x02, 0x12, 0x1e, 0x6a,
    0x26, 0x54, 0x0a, 0xe8, 0xde, 0x80, 0xda, 0xd9, 0xb1, 0x20, 0xd0, 0xec, 0xfa, 0x0d, 0x80, 0x87,
    0x04, 0x8d, 0xcd, 0x02, 0x43, 0x98, 0xe8, 0x44, 0xa9, 0x98, 0xc9, 0x7e, 0x70, 0x5f, 0x21, 0xdd,
    0x23, 0x85, 0x4b, 0xad, 0xd2, 0xc9, 0x02, 0x35, 0xd8, 0x07, 0xc4, 0x68, 0xa6, 0xe7, 0x32, 0x92,
    0xec, 0xee, 0x14, 0x0a, 0x2e, 0xc3, 0x49, 0xbc, 0x81, 0x2f, 0x46, 0x72, 0x57, 0xe5, 0x3a, 0x9a,
    0x96, 0x71, 0xa9, 0xbf, 0x81, 0x0c, 0x7c, 0xac, 0x49, 0x68, 0xa3, 0x04, 0x83, 0xbb, 0x45, 0x54,
    0xad, 0xb3, 0xe0, 0x8f, 0x33, 0x5f, 0xe8, 0xcb, 0xe0, 0x5a, 0x2a, 0x6e, 0x44, 0xf3, 0x8a, 0x2a,
    0xc4, 0x46, 0xc2, 0xde, 0xcb, 0xae, 0x08, 0x54, 0x7f, 0x61, 0xdd, 0xf9, 0x1d, 0x84, 0x39, 0x75,
    0x09, 0x85, 0x3b, 0xeb, 0xf1, 0x29, 0x27, 0xf6, 0x62, 0xe5, 0x95, 0x0f, 0x06, 0xab, 0x9d, 0x0e,
    0x86, 0x0c, 0x06, 0x44, 0x1a, 0xe0, 0x59, 0xdb, 0xa0, 0x2d, 0xcd, 0x31, 0x52, 0xfc, 0x1b, 0xab,
    0x2f, 0xb7, 0xb2, 0x39, 0x34, 0xf8, 0xcc, 0xec, 0xd0, 0xf8, 0xe0, 0x9f, 0xf0, 0xef, 0xc7, 0x1e,
    0x2c, 0xa9, 0x55, 0x47, 0xd6, 0xb8, 0x97, 0x44, 0x3a, 0x55, 0x7f, 0x76, 0xcf, 0xf3, 0x59, 0x8f,
    0x80, 0x32, 0xd5, 0xc5, 0x4c, 0xe8, 0xc7, 0xbe, 0xd2, 0xcc, 0x27, 0x51, 0xed, 0x51, 0xd1, 0x31,
    0x4d, 0xd2, 0xf4, 0x94, 0xbd, 0xf1, 0x1b, 0x82, 0xba, 0xc1, 0x0f, 0x67, 0x72, 0x32, 0x7e, 0xa1,
    0xa4, 0x3b, 0xed, 0x96, 0x8e, 0x53, 0x77, 0xfe, 0x02, 0x66, 0x0c, 0x3b, 0x86
};
#endif

PyTypeObject *init_Qt3DExtras_QOrbitCameraController(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX].type != nullptr)
        return SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DExtras_QOrbitCameraController_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QAbstractCameraController_IDX]))));

    _Sbk_Qt3DExtras_QOrbitCameraController_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QOrbitCameraController",
        "Qt3DExtras::QOrbitCameraController*",
        &Sbk_Qt3DExtras_QOrbitCameraController_spec,
        &Shiboken::callCppDestructor< Qt3DExtras::QOrbitCameraController >,
        Sbk_Qt3DExtras_QOrbitCameraController_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DExtras_QOrbitCameraController_TypeF(); // references _Sbk_Qt3DExtras_QOrbitCameraController_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DExtras_QOrbitCameraController_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DExtras_QOrbitCameraController_SignatureBytes, Qt3DExtras_QOrbitCameraController_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DExtras_QOrbitCameraController_PropertyStrings);
    SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtras_QOrbitCameraController_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOrbitCameraController_PythonToCpp_QOrbitCameraController_PTR,
        is_QOrbitCameraController_PythonToCpp_QOrbitCameraController_PTR_Convertible,
        QOrbitCameraController_PTR_CppToPython_QOrbitCameraController);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DExtras::QOrbitCameraController");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DExtras::QOrbitCameraController*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DExtras::QOrbitCameraController&");
    Shiboken::Conversions::registerConverterAlias(converter, "QOrbitCameraController");
    Shiboken::Conversions::registerConverterAlias(converter, "QOrbitCameraController*");
    Shiboken::Conversions::registerConverterAlias(converter, "QOrbitCameraController&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DExtras::QOrbitCameraController).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QOrbitCameraControllerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DExtras_QOrbitCameraController_TypeF(), &Sbk_Qt3DExtras_QOrbitCameraController_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Qt3DExtras::QOrbitCameraController::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DExtras::QOrbitCameraController::staticMetaObject, sizeof(QOrbitCameraControllerWrapper));

    return pyType;
}
