// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dinput_python.h"

// main header
#include "qt3dinput_qabstractphysicaldevice_wrapper.h"

// Wrappers providing overrides
#include "qt3dinput_qabstractphysicaldevice_wrapper.h"
#include "qt3dinput_qwheelevent_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <Qt3DCore/qnode.h>
#include <Qt3DInput/qaxissetting.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DInput;

// Native ---------------------------------------------------------

void QAbstractPhysicalDeviceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractPhysicalDeviceWrapper::QAbstractPhysicalDeviceWrapper(::Qt3DCore::QNode * parent) : Qt3DInput::QAbstractPhysicalDevice(parent)
{
}

int QAbstractPhysicalDeviceWrapper::axisCount() const
{
    static const char *funcName = "axisCount";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::Qt3DInput::QAbstractPhysicalDevice::axisCount();
    }
    return sbk_o_axisCount("QAbstractPhysicalDevice", funcName, gil, pyOverride);
}

int QAbstractPhysicalDeviceWrapper::sbk_o_axisCount(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QAbstractPhysicalDeviceWrapper::axisIdentifier(const ::QString & name) const
{
    static const char *funcName = "axisIdentifier";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::Qt3DInput::QAbstractPhysicalDevice::axisIdentifier(name);
    }
    return sbk_o_axisIdentifier("QAbstractPhysicalDevice", funcName, gil, pyOverride, name);
}

int QAbstractPhysicalDeviceWrapper::sbk_o_axisIdentifier(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & name)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QStringList QAbstractPhysicalDeviceWrapper::axisNames() const
{
    static const char *funcName = "axisNames";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::Qt3DInput::QAbstractPhysicalDevice::axisNames();
    }
    return sbk_o_axisNames("QAbstractPhysicalDevice", funcName, gil, pyOverride);
}

::QStringList QAbstractPhysicalDeviceWrapper::sbk_o_axisNames(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QStringList();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QStringList", Py_TYPE(pyResult)->tp_name);
        return ::QStringList();
    }
    ::QStringList cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QAbstractPhysicalDeviceWrapper::buttonCount() const
{
    static const char *funcName = "buttonCount";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::Qt3DInput::QAbstractPhysicalDevice::buttonCount();
    }
    return QAbstractPhysicalDeviceWrapper::sbk_o_axisCount("QAbstractPhysicalDevice", funcName, gil, pyOverride);
}

int QAbstractPhysicalDeviceWrapper::buttonIdentifier(const ::QString & name) const
{
    static const char *funcName = "buttonIdentifier";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::Qt3DInput::QAbstractPhysicalDevice::buttonIdentifier(name);
    }
    return QAbstractPhysicalDeviceWrapper::sbk_o_axisIdentifier("QAbstractPhysicalDevice", funcName, gil, pyOverride, name);
}

::QStringList QAbstractPhysicalDeviceWrapper::buttonNames() const
{
    static const char *funcName = "buttonNames";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::Qt3DInput::QAbstractPhysicalDevice::buttonNames();
    }
    return QAbstractPhysicalDeviceWrapper::sbk_o_axisNames("QAbstractPhysicalDevice", funcName, gil, pyOverride);
}

void QAbstractPhysicalDeviceWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWheelEventWrapper::sbk_o_childEvent("QAbstractPhysicalDevice", funcName, gil, pyOverride, event);
}

void QAbstractPhysicalDeviceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWheelEventWrapper::sbk_o_connectNotify("QAbstractPhysicalDevice", funcName, gil, pyOverride, signal);
}

void QAbstractPhysicalDeviceWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWheelEventWrapper::sbk_o_customEvent("QAbstractPhysicalDevice", funcName, gil, pyOverride, event);
}

void QAbstractPhysicalDeviceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWheelEventWrapper::sbk_o_connectNotify("QAbstractPhysicalDevice", funcName, gil, pyOverride, signal);
}

bool QAbstractPhysicalDeviceWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QWheelEventWrapper::sbk_o_event("QAbstractPhysicalDevice", funcName, gil, pyOverride, event);
}

bool QAbstractPhysicalDeviceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWheelEventWrapper::sbk_o_eventFilter("QAbstractPhysicalDevice", funcName, gil, pyOverride, watched, event);
}

void QAbstractPhysicalDeviceWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWheelEventWrapper::sbk_o_timerEvent("QAbstractPhysicalDevice", funcName, gil, pyOverride, event);
}

const QMetaObject *QAbstractPhysicalDeviceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DInput::QAbstractPhysicalDevice::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstractPhysicalDeviceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DInput::QAbstractPhysicalDevice::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstractPhysicalDeviceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstractPhysicalDeviceWrapper *>(this));
    return Qt3DInput::QAbstractPhysicalDevice::qt_metacast(_clname);
}

QAbstractPhysicalDeviceWrapper::~QAbstractPhysicalDeviceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DInput_QAbstractPhysicalDevice_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DInput::QAbstractPhysicalDevice >()))
        return -1;

    QAbstractPhysicalDeviceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QAbstractPhysicalDevice", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAbstractPhysicalDevice::QAbstractPhysicalDevice(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QAbstractPhysicalDevice(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QAbstractPhysicalDevice(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractPhysicalDevice(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QAbstractPhysicalDeviceWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QAbstractPhysicalDeviceWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DInput::QAbstractPhysicalDevice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_addAxisSetting(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QAbstractPhysicalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractPhysicalDevice::addAxisSetting(Qt3DInput::QAxisSetting*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAxisSetting_IDX]), (pyArg)))) {
        overloadId = 0; // addAxisSetting(Qt3DInput::QAxisSetting*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addAxisSetting", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DInput::QAxisSetting *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addAxisSetting(Qt3DInput::QAxisSetting*)
            cppSelf->addAxisSetting(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_axisCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QAbstractPhysicalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axisCount()const
        int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Qt3DInput::QAbstractPhysicalDevice *>(cppSelf)->::Qt3DInput::QAbstractPhysicalDevice::axisCount()
            : const_cast<const ::Qt3DInput::QAbstractPhysicalDevice *>(cppSelf)->axisCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_axisIdentifier(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QAbstractPhysicalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractPhysicalDevice::axisIdentifier(QString)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // axisIdentifier(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "axisIdentifier", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // axisIdentifier(QString)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Qt3DInput::QAbstractPhysicalDevice *>(cppSelf)->::Qt3DInput::QAbstractPhysicalDevice::axisIdentifier(cppArg0)
                : const_cast<const ::Qt3DInput::QAbstractPhysicalDevice *>(cppSelf)->axisIdentifier(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_axisNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QAbstractPhysicalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axisNames()const
        QStringList cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Qt3DInput::QAbstractPhysicalDevice *>(cppSelf)->::Qt3DInput::QAbstractPhysicalDevice::axisNames()
            : const_cast<const ::Qt3DInput::QAbstractPhysicalDevice *>(cppSelf)->axisNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_axisSettings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QAbstractPhysicalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // axisSettings()const
        QList<Qt3DInput::QAxisSetting*> cppResult = const_cast<const ::Qt3DInput::QAbstractPhysicalDevice *>(cppSelf)->axisSettings();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_Qt3DInputTypeConverters[SBK_Qt3DInput_QList_Qt3DInput_QAxisSettingPTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_buttonCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QAbstractPhysicalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // buttonCount()const
        int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Qt3DInput::QAbstractPhysicalDevice *>(cppSelf)->::Qt3DInput::QAbstractPhysicalDevice::buttonCount()
            : const_cast<const ::Qt3DInput::QAbstractPhysicalDevice *>(cppSelf)->buttonCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_buttonIdentifier(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QAbstractPhysicalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractPhysicalDevice::buttonIdentifier(QString)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // buttonIdentifier(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "buttonIdentifier", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // buttonIdentifier(QString)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Qt3DInput::QAbstractPhysicalDevice *>(cppSelf)->::Qt3DInput::QAbstractPhysicalDevice::buttonIdentifier(cppArg0)
                : const_cast<const ::Qt3DInput::QAbstractPhysicalDevice *>(cppSelf)->buttonIdentifier(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_buttonNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QAbstractPhysicalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // buttonNames()const
        QStringList cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Qt3DInput::QAbstractPhysicalDevice *>(cppSelf)->::Qt3DInput::QAbstractPhysicalDevice::buttonNames()
            : const_cast<const ::Qt3DInput::QAbstractPhysicalDevice *>(cppSelf)->buttonNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_removeAxisSetting(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QAbstractPhysicalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractPhysicalDevice::removeAxisSetting(Qt3DInput::QAxisSetting*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAxisSetting_IDX]), (pyArg)))) {
        overloadId = 0; // removeAxisSetting(Qt3DInput::QAxisSetting*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAxisSetting", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DInput::QAxisSetting *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAxisSetting(Qt3DInput::QAxisSetting*)
            cppSelf->removeAxisSetting(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_Qt3DInput_QAbstractPhysicalDevice_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DInput_QAbstractPhysicalDevice_methods[] = {
    {"addAxisSetting", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_addAxisSetting), METH_O, nullptr},
    {"axisCount", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_axisCount), METH_NOARGS, nullptr},
    {"axisIdentifier", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_axisIdentifier), METH_O, nullptr},
    {"axisNames", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_axisNames), METH_NOARGS, nullptr},
    {"axisSettings", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_axisSettings), METH_NOARGS, nullptr},
    {"buttonCount", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_buttonCount), METH_NOARGS, nullptr},
    {"buttonIdentifier", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_buttonIdentifier), METH_O, nullptr},
    {"buttonNames", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_buttonNames), METH_NOARGS, nullptr},
    {"removeAxisSetting", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QAbstractPhysicalDeviceFunc_removeAxisSetting), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DInput_QAbstractPhysicalDevice_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DInput::QAbstractPhysicalDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractPhysicalDeviceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DInput_QAbstractPhysicalDevice_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DInput_QAbstractPhysicalDevice_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DInput_QAbstractPhysicalDevice_Type = nullptr;
static PyTypeObject *Sbk_Qt3DInput_QAbstractPhysicalDevice_TypeF(void)
{
    return _Sbk_Qt3DInput_QAbstractPhysicalDevice_Type;
}

static PyType_Slot Sbk_Qt3DInput_QAbstractPhysicalDevice_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DInput_QAbstractPhysicalDevice_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DInput_QAbstractPhysicalDevice_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DInput_QAbstractPhysicalDevice_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DInput_QAbstractPhysicalDevice_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DInput_QAbstractPhysicalDevice_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DInput_QAbstractPhysicalDevice_spec = {
    "2:PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DInput_QAbstractPhysicalDevice_slots
};

} //extern "C"

static void *Sbk_Qt3DInput_QAbstractPhysicalDevice_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DInput::QAbstractPhysicalDevice *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractPhysicalDevice_PythonToCpp_QAbstractPhysicalDevice_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DInput_QAbstractPhysicalDevice_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractPhysicalDevice_PythonToCpp_QAbstractPhysicalDevice_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DInput_QAbstractPhysicalDevice_TypeF()))
        return QAbstractPhysicalDevice_PythonToCpp_QAbstractPhysicalDevice_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractPhysicalDevice_PTR_CppToPython_QAbstractPhysicalDevice(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DInput::QAbstractPhysicalDevice *>(const_cast<void *>(cppIn)), Sbk_Qt3DInput_QAbstractPhysicalDevice_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DInput_QAbstractPhysicalDevice_SignatureStrings[] = {
    "PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr)",
    "PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice.addAxisSetting(self,axisSetting:PySide6.Qt3DInput.Qt3DInput.QAxisSetting)",
    "PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice.axisCount(self)->int",
    "PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice.axisIdentifier(self,name:QString)->int",
    "PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice.axisNames(self)->QStringList",
    "PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice.axisSettings(self)->QList[PySide6.Qt3DInput.Qt3DInput.QAxisSetting]",
    "PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice.buttonCount(self)->int",
    "PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice.buttonIdentifier(self,name:QString)->int",
    "PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice.buttonNames(self)->QStringList",
    "PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice.removeAxisSetting(self,axisSetting:PySide6.Qt3DInput.Qt3DInput.QAxisSetting)",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DInput_QAbstractPhysicalDevice_SignatureByteSize = 204;
static constexpr uint8_t Qt3DInput_QAbstractPhysicalDevice_SignatureBytes[204] = {
    0x78, 0xda, 0xb5, 0x92, 0xc1, 0x0a, 0x82, 0x40, 0x10, 0x86, 0xef, 0x3d, 0x49, 0x42, 0x79, 0x09,
    0x3a, 0x08, 0x05, 0xa2, 0x17, 0x21, 0x44, 0xf1, 0x18, 0x1d, 0x56, 0x77, 0xac, 0x81, 0x75, 0x57,
    0x76, 0x47, 0xc9, 0xb7, 0x4f, 0xd3, 0xd0, 0x53, 0x94, 0xd9, 0x6d, 0x18, 0x66, 0xbf, 0x7f, 0xe6,
    0x63, 0xa3, 0x26, 0x41, 0x0e, 0x7b, 0x3b, 0xa6, 0x9d, 0x1f, 0xc8, 0xb2, 0xa2, 0x69, 0xe5, 0xa6,
    0x86, 0x34, 0xcb, 0x28, 0xba, 0x35, 0x06, 0x33, 0x26, 0x7c, 0xa8, 0x31, 0x83, 0xb5, 0x01, 0x91,
    0x6f, 0x4a, 0xa6, 0x41, 0x92, 0x13, 0x4d, 0xde, 0x7b, 0x4a, 0xc3, 0xa4, 0x08, 0x15, 0x87, 0x83,
    0xac, 0x84, 0x28, 0x49, 0x5b, 0xab, 0xe8, 0xfb, 0x20, 0x9b, 0x71, 0xee, 0xde, 0xd1, 0x24, 0x40,
    0x84, 0xf2, 0xda, 0xe7, 0xb2, 0xb1, 0xe1, 0xbc, 0x67, 0x8e, 0x83, 0x33, 0xd3, 0x5b, 0x80, 0xa7,
    0x2a, 0x49, 0xcf, 0x60, 0x6b, 0x7b, 0x44, 0x49, 0xb3, 0x41, 0x01, 0x6f, 0x6d, 0x61, 0x8e, 0xa0,
    0xfb, 0x33, 0x24, 0x2b, 0xc0, 0x89, 0x13, 0xd2, 0xdd, 0x7a, 0xbf, 0xa1, 0xc3, 0x16, 0x65, 0x5e,
    0x3b, 0x0e, 0xc8, 0x13, 0x9a, 0xf9, 0xc0, 0xc1, 0xda, 0xc8, 0xec, 0x68, 0xe7, 0x4f, 0x65, 0x5f,
    0x66, 0xe5, 0xa6, 0x15, 0x91, 0x92, 0x8b, 0xe8, 0xee, 0x51, 0x7f, 0x12, 0xde, 0xc3, 0x17, 0x55,
    0xae, 0xa1, 0x50, 0x35, 0x2c, 0xf4, 0xd1, 0x1f, 0x94, 0xf5, 0x62, 0xa7
};
#endif

PyTypeObject *init_Qt3DInput_QAbstractPhysicalDevice(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX].type != nullptr)
        return SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DInput_QAbstractPhysicalDevice_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]))));

    _Sbk_Qt3DInput_QAbstractPhysicalDevice_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QAbstractPhysicalDevice",
        "Qt3DInput::QAbstractPhysicalDevice*",
        &Sbk_Qt3DInput_QAbstractPhysicalDevice_spec,
        &Shiboken::callCppDestructor< Qt3DInput::QAbstractPhysicalDevice >,
        Sbk_Qt3DInput_QAbstractPhysicalDevice_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DInput_QAbstractPhysicalDevice_TypeF(); // references _Sbk_Qt3DInput_QAbstractPhysicalDevice_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DInput_QAbstractPhysicalDevice_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DInput_QAbstractPhysicalDevice_SignatureBytes, Qt3DInput_QAbstractPhysicalDevice_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DInput_QAbstractPhysicalDevice_PropertyStrings);
    SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractPhysicalDevice_PythonToCpp_QAbstractPhysicalDevice_PTR,
        is_QAbstractPhysicalDevice_PythonToCpp_QAbstractPhysicalDevice_PTR_Convertible,
        QAbstractPhysicalDevice_PTR_CppToPython_QAbstractPhysicalDevice);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QAbstractPhysicalDevice");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QAbstractPhysicalDevice*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QAbstractPhysicalDevice&");
    Shiboken::Conversions::registerConverterAlias(converter, "QAbstractPhysicalDevice");
    Shiboken::Conversions::registerConverterAlias(converter, "QAbstractPhysicalDevice*");
    Shiboken::Conversions::registerConverterAlias(converter, "QAbstractPhysicalDevice&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DInput::QAbstractPhysicalDevice).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractPhysicalDeviceWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DInput_QAbstractPhysicalDevice_TypeF(), &Sbk_Qt3DInput_QAbstractPhysicalDevice_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DInput::QAbstractPhysicalDevice::staticMetaObject, sizeof(QAbstractPhysicalDeviceWrapper));

    return pyType;
}
