// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dinput_python.h"

// main header
#include "qt3dinput_qactioninput_wrapper.h"

// Wrappers providing overrides
#include "qt3dinput_qwheelevent_wrapper.h"

// Argument includes
#include <QList>
#include <Qt3DCore/qnode.h>
#include <Qt3DInput/qabstractphysicaldevice.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DInput;

// Native ---------------------------------------------------------

void QActionInputWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QActionInputWrapper::QActionInputWrapper(::Qt3DCore::QNode * parent) : Qt3DInput::QActionInput(parent)
{
}

void QActionInputWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWheelEventWrapper::sbk_o_childEvent("QActionInput", funcName, gil, pyOverride, event);
}

void QActionInputWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWheelEventWrapper::sbk_o_connectNotify("QActionInput", funcName, gil, pyOverride, signal);
}

void QActionInputWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWheelEventWrapper::sbk_o_customEvent("QActionInput", funcName, gil, pyOverride, event);
}

void QActionInputWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWheelEventWrapper::sbk_o_connectNotify("QActionInput", funcName, gil, pyOverride, signal);
}

bool QActionInputWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QWheelEventWrapper::sbk_o_event("QActionInput", funcName, gil, pyOverride, event);
}

bool QActionInputWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWheelEventWrapper::sbk_o_eventFilter("QActionInput", funcName, gil, pyOverride, watched, event);
}

void QActionInputWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWheelEventWrapper::sbk_o_timerEvent("QActionInput", funcName, gil, pyOverride, event);
}

const QMetaObject *QActionInputWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DInput::QActionInput::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QActionInputWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DInput::QActionInput::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QActionInputWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QActionInputWrapper *>(this));
    return Qt3DInput::QActionInput::qt_metacast(_clname);
}

QActionInputWrapper::~QActionInputWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DInput_QActionInput_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DInput::QActionInput >()))
        return -1;

    QActionInputWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QActionInput", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QActionInput::QActionInput(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QActionInput(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QActionInput(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QActionInput(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QActionInputWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QActionInputWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DInput::QActionInput >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DInput_QActionInputFunc_buttons(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QActionInput *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // buttons()const
        QList<int> cppResult = const_cast<const ::Qt3DInput::QActionInput *>(cppSelf)->buttons();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_Qt3DInputTypeConverters[SBK_Qt3DInput_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DInput_QActionInputFunc_setButtons(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QActionInput *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QActionInput::setButtons(QList<int>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_Qt3DInputTypeConverters[SBK_Qt3DInput_QList_int_IDX], (pyArg)))) {
        overloadId = 0; // setButtons(QList<int>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setButtons", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX]);

    // Call function/method
    {
        ::QList<int> cppArg0_local;
        ::QList<int> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setButtons(QList<int>)
            cppSelf->setButtons(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DInput_QActionInputFunc_setSourceDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QActionInput *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QActionInput::setSourceDevice(Qt3DInput::QAbstractPhysicalDevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]), (pyArg)))) {
        overloadId = 0; // setSourceDevice(Qt3DInput::QAbstractPhysicalDevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSourceDevice", errInfo, SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DInput::QAbstractPhysicalDevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSourceDevice(Qt3DInput::QAbstractPhysicalDevice*)
            cppSelf->setSourceDevice(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DInput_QActionInputFunc_sourceDevice(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DInput::QActionInput *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sourceDevice()const
        Qt3DInput::QAbstractPhysicalDevice * cppResult = const_cast<const ::Qt3DInput::QActionInput *>(cppSelf)->sourceDevice();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractPhysicalDevice_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Qt3DInput_QActionInput_PropertyStrings[] = {
    "buttons::",
    "sourceDevice::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DInput_QActionInput_methods[] = {
    {"buttons", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QActionInputFunc_buttons), METH_NOARGS, nullptr},
    {"setButtons", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QActionInputFunc_setButtons), METH_O, nullptr},
    {"setSourceDevice", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QActionInputFunc_setSourceDevice), METH_O, nullptr},
    {"sourceDevice", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QActionInputFunc_sourceDevice), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DInput_QActionInput_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DInput::QActionInput *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QActionInputWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DInput_QActionInput_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DInput_QActionInput_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DInput_QActionInput_Type = nullptr;
static PyTypeObject *Sbk_Qt3DInput_QActionInput_TypeF(void)
{
    return _Sbk_Qt3DInput_QActionInput_Type;
}

static PyType_Slot Sbk_Qt3DInput_QActionInput_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DInput_QActionInput_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DInput_QActionInput_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DInput_QActionInput_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DInput_QActionInput_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DInput_QActionInput_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DInput_QActionInput_spec = {
    "2:PySide6.Qt3DInput.Qt3DInput.QActionInput",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DInput_QActionInput_slots
};

} //extern "C"

static void *Sbk_Qt3DInput_QActionInput_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DInput::QActionInput *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QActionInput_PythonToCpp_QActionInput_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DInput_QActionInput_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QActionInput_PythonToCpp_QActionInput_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DInput_QActionInput_TypeF()))
        return QActionInput_PythonToCpp_QActionInput_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QActionInput_PTR_CppToPython_QActionInput(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DInput::QActionInput *>(const_cast<void *>(cppIn)), Sbk_Qt3DInput_QActionInput_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DInput_QActionInput_SignatureStrings[] = {
    "PySide6.Qt3DInput.Qt3DInput.QActionInput(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr,*:KeywordOnly=None,sourceDevice:Qt3DInput.QAbstractPhysicalDevice=None,buttons:QList[int]=None)",
    "PySide6.Qt3DInput.Qt3DInput.QActionInput.buttons(self)->QList[int]",
    "PySide6.Qt3DInput.Qt3DInput.QActionInput.setButtons(self,buttons:QList[int])",
    "PySide6.Qt3DInput.Qt3DInput.QActionInput.setSourceDevice(self,sourceDevice:PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice)",
    "PySide6.Qt3DInput.Qt3DInput.QActionInput.sourceDevice(self)->PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DInput_QActionInput_SignatureByteSize = 190;
static constexpr uint8_t Qt3DInput_QActionInput_SignatureBytes[190] = {
    0x78, 0xda, 0x9d, 0x90, 0x41, 0x0b, 0xc2, 0x30, 0x0c, 0x85, 0xef, 0xfb, 0x25, 0x4e, 0xa6, 0x17,
    0xc1, 0x43, 0x61, 0x82, 0xba, 0x8b, 0x28, 0xb3, 0x63, 0x47, 0xf1, 0xb0, 0x75, 0x11, 0x0b, 0x25,
    0x1d, 0x6d, 0xaa, 0xec, 0xdf, 0x2b, 0x9b, 0x60, 0x95, 0x21, 0x9b, 0xb7, 0x24, 0x24, 0xdf, 0x7b,
    0x79, 0xbc, 0xc9, 0x65, 0x05, 0xcb, 0x79, 0x46, 0x8b, 0x64, 0x87, 0xb5, 0x23, 0xbf, 0x5a, 0x0b,
    0x92, 0x1a, 0xdb, 0x66, 0x62, 0x41, 0x5d, 0xa2, 0xba, 0x30, 0x80, 0xc4, 0xb8, 0x77, 0xb4, 0xd5,
    0x06, 0xbc, 0x22, 0xd5, 0x15, 0xc4, 0xe8, 0x94, 0xaa, 0xc9, 0x44, 0x53, 0xb6, 0x87, 0xe6, 0xae,
    0x4d, 0x75, 0x44, 0xd5, 0xc4, 0xa9, 0x46, 0x88, 0xac, 0x76, 0x46, 0x40, 0x02, 0x37, 0x29, 0x80,
    0xf9, 0x52, 0xa5, 0x25, 0x53, 0x08, 0xe2, 0xd7, 0xc6, 0x4a, 0x51, 0xa8, 0x6e, 0xa3, 0xbb, 0x29,
    0x1d, 0x91, 0x46, 0xcb, 0xb2, 0x83, 0xb4, 0x74, 0x92, 0x48, 0xe7, 0x76, 0x1e, 0x06, 0x7c, 0xa0,
    0xf9, 0xf9, 0x8b, 0xd0, 0x3e, 0x11, 0xce, 0x56, 0x6f, 0xd0, 0x70, 0x84, 0x05, 0xda, 0x78, 0x94,
    0x1e, 0x53, 0xe1, 0x28, 0x58, 0xee, 0x05, 0xd1, 0x11, 0x3f, 0xa2, 0xf9, 0x8d, 0xea, 0x0d, 0x6b,
    0x8c, 0xfe, 0xb7, 0xf8, 0x33, 0x94, 0x3f, 0x14, 0x83, 0x07, 0xe2, 0xeb, 0xd0, 0x48
};
#endif

PyTypeObject *init_Qt3DInput_QActionInput(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX].type != nullptr)
        return SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DInput_QActionInput_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QAbstractActionInput_IDX]))));

    _Sbk_Qt3DInput_QActionInput_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QActionInput",
        "Qt3DInput::QActionInput*",
        &Sbk_Qt3DInput_QActionInput_spec,
        &Shiboken::callCppDestructor< Qt3DInput::QActionInput >,
        Sbk_Qt3DInput_QActionInput_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DInput_QActionInput_TypeF(); // references _Sbk_Qt3DInput_QActionInput_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DInput_QActionInput_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DInput_QActionInput_SignatureBytes, Qt3DInput_QActionInput_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DInput_QActionInput_PropertyStrings);
    SbkPySide6_Qt3DInputTypeStructs[SBK_Qt3DInput_QActionInput_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QActionInput_PythonToCpp_QActionInput_PTR,
        is_QActionInput_PythonToCpp_QActionInput_PTR_Convertible,
        QActionInput_PTR_CppToPython_QActionInput);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QActionInput");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QActionInput*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QActionInput&");
    Shiboken::Conversions::registerConverterAlias(converter, "QActionInput");
    Shiboken::Conversions::registerConverterAlias(converter, "QActionInput*");
    Shiboken::Conversions::registerConverterAlias(converter, "QActionInput&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DInput::QActionInput).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QActionInputWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DInput_QActionInput_TypeF(), &Sbk_Qt3DInput_QActionInput_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Qt3DInput::QActionInput::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DInput::QActionInput::staticMetaObject, sizeof(QActionInputWrapper));

    return pyType;
}
