// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qrendercapturereply_wrapper.h"

// Wrappers providing overrides
#include "qt3drender_qtexturewrapmode_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qimage.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QRenderCaptureReplyWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QRenderCaptureReplyWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QTextureWrapModeWrapper::sbk_o_childEvent("QRenderCaptureReply", funcName, gil, pyOverride, event);
}

void QRenderCaptureReplyWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QTextureWrapModeWrapper::sbk_o_connectNotify("QRenderCaptureReply", funcName, gil, pyOverride, signal);
}

void QRenderCaptureReplyWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QTextureWrapModeWrapper::sbk_o_customEvent("QRenderCaptureReply", funcName, gil, pyOverride, event);
}

void QRenderCaptureReplyWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QTextureWrapModeWrapper::sbk_o_connectNotify("QRenderCaptureReply", funcName, gil, pyOverride, signal);
}

bool QRenderCaptureReplyWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QTextureWrapModeWrapper::sbk_o_event("QRenderCaptureReply", funcName, gil, pyOverride, event);
}

bool QRenderCaptureReplyWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QTextureWrapModeWrapper::sbk_o_eventFilter("QRenderCaptureReply", funcName, gil, pyOverride, watched, event);
}

void QRenderCaptureReplyWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QTextureWrapModeWrapper::sbk_o_timerEvent("QRenderCaptureReply", funcName, gil, pyOverride, event);
}

const QMetaObject *QRenderCaptureReplyWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QRenderCaptureReply::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QRenderCaptureReplyWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QRenderCaptureReply::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QRenderCaptureReplyWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QRenderCaptureReplyWrapper *>(this));
    return Qt3DRender::QRenderCaptureReply::qt_metacast(_clname);
}

QRenderCaptureReplyWrapper::~QRenderCaptureReplyWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_Qt3DRender_QRenderCaptureReply_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QRenderCaptureReply");
    return -1;
}

static PyObject *Sbk_Qt3DRender_QRenderCaptureReplyFunc_captureId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCaptureReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCaptureReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QRenderCaptureReply", "captureId() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // captureId()const
        int cppResult = const_cast<const ::Qt3DRender::QRenderCaptureReply *>(cppSelf)->captureId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DRender_QRenderCaptureReplyFunc_image(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCaptureReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCaptureReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // image()const
        QImage cppResult = const_cast<const ::Qt3DRender::QRenderCaptureReply *>(cppSelf)->image();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DRender_QRenderCaptureReplyFunc_isComplete(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCaptureReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCaptureReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isComplete()const
        bool cppResult = const_cast<const ::Qt3DRender::QRenderCaptureReply *>(cppSelf)->isComplete();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DRender_QRenderCaptureReplyFunc_saveImage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderCaptureReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCaptureReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRenderCaptureReply::saveImage(QString)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // saveImage(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "saveImage", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCaptureReply_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // saveImage(QString)const
            bool cppResult = const_cast<const ::Qt3DRender::QRenderCaptureReply *>(cppSelf)->saveImage(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Qt3DRender_QRenderCaptureReply_PropertyStrings[] = {
    "captureId:",
    "complete:isComplete",
    "image:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QRenderCaptureReply_methods[] = {
    {"captureId", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCaptureReplyFunc_captureId), METH_NOARGS, nullptr},
    {"image", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCaptureReplyFunc_image), METH_NOARGS, nullptr},
    {"isComplete", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCaptureReplyFunc_isComplete), METH_NOARGS, nullptr},
    {"saveImage", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderCaptureReplyFunc_saveImage), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QRenderCaptureReply_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QRenderCaptureReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCaptureReply_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRenderCaptureReplyWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DRender_QRenderCaptureReply_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QRenderCaptureReply_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QRenderCaptureReply_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QRenderCaptureReply_TypeF(void)
{
    return _Sbk_Qt3DRender_QRenderCaptureReply_Type;
}

static PyType_Slot Sbk_Qt3DRender_QRenderCaptureReply_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderCaptureReply_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderCaptureReply_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderCaptureReply_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderCaptureReply_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderCaptureReply_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QRenderCaptureReply_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QRenderCaptureReply",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QRenderCaptureReply_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QRenderCaptureReply_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QRenderCaptureReply *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRenderCaptureReply_PythonToCpp_QRenderCaptureReply_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QRenderCaptureReply_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRenderCaptureReply_PythonToCpp_QRenderCaptureReply_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QRenderCaptureReply_TypeF()))
        return QRenderCaptureReply_PythonToCpp_QRenderCaptureReply_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRenderCaptureReply_PTR_CppToPython_QRenderCaptureReply(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QRenderCaptureReply *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QRenderCaptureReply_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QRenderCaptureReply_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QRenderCaptureReply.captureId(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCaptureReply.image(self)->PySide6.QtGui.QImage",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCaptureReply.isComplete(self)->bool",
    "PySide6.Qt3DRender.Qt3DRender.QRenderCaptureReply.saveImage(self,fileName:QString)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QRenderCaptureReply_SignatureByteSize = 125;
static constexpr uint8_t Qt3DRender_QRenderCaptureReply_SignatureBytes[125] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x31, 0x76, 0x09, 0x4a,
    0xcd, 0x4b, 0x49, 0x2d, 0x42, 0x61, 0x42, 0x68, 0xe7, 0xc4, 0x82, 0x92, 0xd2, 0xa2, 0xd4, 0xa0,
    0xd4, 0x82, 0x9c, 0x4a, 0xbd, 0x64, 0x08, 0xc7, 0x33, 0x45, 0xa3, 0x38, 0x35, 0x27, 0x4d, 0x53,
    0xd7, 0x2e, 0x33, 0xaf, 0x84, 0x2b, 0x80, 0x64, 0x63, 0x32, 0x73, 0x13, 0xd3, 0x53, 0x61, 0x46,
    0x20, 0xb4, 0xbb, 0x97, 0x66, 0xea, 0x05, 0x7a, 0x82, 0xe4, 0xc8, 0x31, 0xb3, 0xd8, 0x39, 0x3f,
    0xb7, 0x20, 0x27, 0xb5, 0x04, 0x6e, 0x70, 0x52, 0x7e, 0x7e, 0x0e, 0x19, 0x06, 0x15, 0x27, 0x96,
    0xa5, 0x7a, 0xc2, 0x1d, 0xa8, 0x93, 0x96, 0x99, 0x93, 0xea, 0x97, 0x98, 0x9b, 0x6a, 0x15, 0x18,
    0x5c, 0x52, 0x94, 0x99, 0x97, 0x0e, 0x33, 0x18, 0x00, 0x0d, 0x6a, 0x71, 0x10
};
#endif

PyTypeObject *init_Qt3DRender_QRenderCaptureReply(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCaptureReply_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCaptureReply_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QRenderCaptureReply_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_Qt3DRender_QRenderCaptureReply_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QRenderCaptureReply",
        "Qt3DRender::QRenderCaptureReply*",
        &Sbk_Qt3DRender_QRenderCaptureReply_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QRenderCaptureReply >,
        Sbk_Qt3DRender_QRenderCaptureReply_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QRenderCaptureReply_TypeF(); // references _Sbk_Qt3DRender_QRenderCaptureReply_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QRenderCaptureReply_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QRenderCaptureReply_SignatureBytes, Qt3DRender_QRenderCaptureReply_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QRenderCaptureReply_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderCaptureReply_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRenderCaptureReply_PythonToCpp_QRenderCaptureReply_PTR,
        is_QRenderCaptureReply_PythonToCpp_QRenderCaptureReply_PTR_Convertible,
        QRenderCaptureReply_PTR_CppToPython_QRenderCaptureReply);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QRenderCaptureReply");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QRenderCaptureReply*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QRenderCaptureReply&");
    Shiboken::Conversions::registerConverterAlias(converter, "QRenderCaptureReply");
    Shiboken::Conversions::registerConverterAlias(converter, "QRenderCaptureReply*");
    Shiboken::Conversions::registerConverterAlias(converter, "QRenderCaptureReply&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QRenderCaptureReply).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRenderCaptureReplyWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QRenderCaptureReply_TypeF(), &Sbk_Qt3DRender_QRenderCaptureReply_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Qt3DRender::QRenderCaptureReply::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QRenderCaptureReply::staticMetaObject, sizeof(QRenderCaptureReplyWrapper));

    return pyType;
}
