// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qrenderstateset_wrapper.h"

// Wrappers providing overrides
#include "qt3drender_qtexturewrapmode_wrapper.h"

// Argument includes
#include <QList>
#include <Qt3DCore/qnode.h>
#include <Qt3DRender/qrenderstate.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QRenderStateSetWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QRenderStateSetWrapper::QRenderStateSetWrapper(::Qt3DCore::QNode * parent) : Qt3DRender::QRenderStateSet(parent)
{
}

void QRenderStateSetWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QTextureWrapModeWrapper::sbk_o_childEvent("QRenderStateSet", funcName, gil, pyOverride, event);
}

void QRenderStateSetWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QTextureWrapModeWrapper::sbk_o_connectNotify("QRenderStateSet", funcName, gil, pyOverride, signal);
}

void QRenderStateSetWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QTextureWrapModeWrapper::sbk_o_customEvent("QRenderStateSet", funcName, gil, pyOverride, event);
}

void QRenderStateSetWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QTextureWrapModeWrapper::sbk_o_connectNotify("QRenderStateSet", funcName, gil, pyOverride, signal);
}

bool QRenderStateSetWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QTextureWrapModeWrapper::sbk_o_event("QRenderStateSet", funcName, gil, pyOverride, event);
}

bool QRenderStateSetWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QTextureWrapModeWrapper::sbk_o_eventFilter("QRenderStateSet", funcName, gil, pyOverride, watched, event);
}

void QRenderStateSetWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QTextureWrapModeWrapper::sbk_o_timerEvent("QRenderStateSet", funcName, gil, pyOverride, event);
}

const QMetaObject *QRenderStateSetWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QRenderStateSet::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QRenderStateSetWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QRenderStateSet::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QRenderStateSetWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QRenderStateSetWrapper *>(this));
    return Qt3DRender::QRenderStateSet::qt_metacast(_clname);
}

QRenderStateSetWrapper::~QRenderStateSetWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_QRenderStateSet_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DRender::QRenderStateSet >()))
        return -1;

    QRenderStateSetWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QRenderStateSet", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRenderStateSet::QRenderStateSet(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QRenderStateSet(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QRenderStateSet(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderStateSet_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderStateSet_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderStateSet_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QRenderStateSet(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QRenderStateSetWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QRenderStateSetWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DRender::QRenderStateSet >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderStateSet_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderStateSet_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Qt3DRender_QRenderStateSetFunc_addRenderState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderStateSet *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderStateSet_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRenderStateSet::addRenderState(Qt3DRender::QRenderState*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderState_IDX]), (pyArg)))) {
        overloadId = 0; // addRenderState(Qt3DRender::QRenderState*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addRenderState", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderStateSet_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QRenderState *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addRenderState(Qt3DRender::QRenderState*)
            cppSelf->addRenderState(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DRender_QRenderStateSetFunc_removeRenderState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderStateSet *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderStateSet_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRenderStateSet::removeRenderState(Qt3DRender::QRenderState*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderState_IDX]), (pyArg)))) {
        overloadId = 0; // removeRenderState(Qt3DRender::QRenderState*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeRenderState", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderStateSet_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QRenderState *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeRenderState(Qt3DRender::QRenderState*)
            cppSelf->removeRenderState(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DRender_QRenderStateSetFunc_renderStates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QRenderStateSet *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderStateSet_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // renderStates()const
        QList<Qt3DRender::QRenderState*> cppResult = const_cast<const ::Qt3DRender::QRenderStateSet *>(cppSelf)->renderStates();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRenderStatePTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Qt3DRender_QRenderStateSet_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QRenderStateSet_methods[] = {
    {"addRenderState", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderStateSetFunc_addRenderState), METH_O, nullptr},
    {"removeRenderState", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderStateSetFunc_removeRenderState), METH_O, nullptr},
    {"renderStates", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QRenderStateSetFunc_renderStates), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QRenderStateSet_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QRenderStateSet *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderStateSet_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRenderStateSetWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DRender_QRenderStateSet_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QRenderStateSet_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QRenderStateSet_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QRenderStateSet_TypeF(void)
{
    return _Sbk_Qt3DRender_QRenderStateSet_Type;
}

static PyType_Slot Sbk_Qt3DRender_QRenderStateSet_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderStateSet_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderStateSet_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderStateSet_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderStateSet_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QRenderStateSet_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QRenderStateSet_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QRenderStateSet",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QRenderStateSet_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QRenderStateSet_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QRenderStateSet *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRenderStateSet_PythonToCpp_QRenderStateSet_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QRenderStateSet_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRenderStateSet_PythonToCpp_QRenderStateSet_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QRenderStateSet_TypeF()))
        return QRenderStateSet_PythonToCpp_QRenderStateSet_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRenderStateSet_PTR_CppToPython_QRenderStateSet(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QRenderStateSet *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QRenderStateSet_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QRenderStateSet_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QRenderStateSet(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr)",
    "PySide6.Qt3DRender.Qt3DRender.QRenderStateSet.addRenderState(self,state:PySide6.Qt3DRender.Qt3DRender.QRenderState)",
    "PySide6.Qt3DRender.Qt3DRender.QRenderStateSet.removeRenderState(self,state:PySide6.Qt3DRender.Qt3DRender.QRenderState)",
    "PySide6.Qt3DRender.Qt3DRender.QRenderStateSet.renderStates(self)->QList[PySide6.Qt3DRender.Qt3DRender.QRenderState]",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QRenderStateSet_SignatureByteSize = 121;
static constexpr uint8_t Qt3DRender_QRenderStateSet_SignatureBytes[121] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x31, 0x76, 0x09, 0x4a,
    0xcd, 0x4b, 0x49, 0x2d, 0x42, 0x61, 0x42, 0xe8, 0xe0, 0x92, 0xc4, 0x92, 0xd4, 0xe0, 0xd4, 0x12,
    0x8d, 0xe2, 0xd4, 0x9c, 0x34, 0x9d, 0x82, 0xc4, 0xa2, 0xd4, 0xbc, 0x12, 0xab, 0x00, 0x24, 0x9d,
    0xce, 0xf9, 0x45, 0xa9, 0x48, 0x0c, 0xbf, 0xfc, 0x94, 0x54, 0xdb, 0xbc, 0xd2, 0x9c, 0x9c, 0x82,
    0x92, 0x22, 0x4d, 0xae, 0x00, 0x52, 0xac, 0xd0, 0x4b, 0x4c, 0x49, 0x41, 0x12, 0x81, 0xd8, 0x58,
    0x0c, 0x62, 0x5a, 0x11, 0x6f, 0x0e, 0xa9, 0x76, 0x16, 0xa5, 0xe6, 0xe6, 0x97, 0xa5, 0x0e, 0x80,
    0xb5, 0x70, 0x6e, 0x31, 0xd8, 0x46, 0x4d, 0x5d, 0xbb, 0x40, 0x9f, 0xcc, 0xe2, 0x92, 0x68, 0xe2,
    0xcd, 0x89, 0xe5, 0x02, 0x00, 0x04, 0x7f, 0xa0, 0x4f
};
#endif

PyTypeObject *init_Qt3DRender_QRenderStateSet(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderStateSet_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderStateSet_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QRenderStateSet_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QFrameGraphNode_IDX]))));

    _Sbk_Qt3DRender_QRenderStateSet_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QRenderStateSet",
        "Qt3DRender::QRenderStateSet*",
        &Sbk_Qt3DRender_QRenderStateSet_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QRenderStateSet >,
        Sbk_Qt3DRender_QRenderStateSet_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QRenderStateSet_TypeF(); // references _Sbk_Qt3DRender_QRenderStateSet_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QRenderStateSet_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QRenderStateSet_SignatureBytes, Qt3DRender_QRenderStateSet_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QRenderStateSet_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderStateSet_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRenderStateSet_PythonToCpp_QRenderStateSet_PTR,
        is_QRenderStateSet_PythonToCpp_QRenderStateSet_PTR_Convertible,
        QRenderStateSet_PTR_CppToPython_QRenderStateSet);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QRenderStateSet");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QRenderStateSet*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QRenderStateSet&");
    Shiboken::Conversions::registerConverterAlias(converter, "QRenderStateSet");
    Shiboken::Conversions::registerConverterAlias(converter, "QRenderStateSet*");
    Shiboken::Conversions::registerConverterAlias(converter, "QRenderStateSet&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QRenderStateSet).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRenderStateSetWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QRenderStateSet_TypeF(), &Sbk_Qt3DRender_QRenderStateSet_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QRenderStateSet::staticMetaObject, sizeof(QRenderStateSetWrapper));

    return pyType;
}
