// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qstenciltestarguments_wrapper.h"

// Wrappers providing overrides
#include "qt3drender_qtexturewrapmode_wrapper.h"

// Argument includes
#include <Qt3DRender/qstenciltestarguments.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QStencilTestArgumentsWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QStencilTestArgumentsWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QTextureWrapModeWrapper::sbk_o_childEvent("QStencilTestArguments", funcName, gil, pyOverride, event);
}

void QStencilTestArgumentsWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QTextureWrapModeWrapper::sbk_o_connectNotify("QStencilTestArguments", funcName, gil, pyOverride, signal);
}

void QStencilTestArgumentsWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QTextureWrapModeWrapper::sbk_o_customEvent("QStencilTestArguments", funcName, gil, pyOverride, event);
}

void QStencilTestArgumentsWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QTextureWrapModeWrapper::sbk_o_connectNotify("QStencilTestArguments", funcName, gil, pyOverride, signal);
}

bool QStencilTestArgumentsWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QTextureWrapModeWrapper::sbk_o_event("QStencilTestArguments", funcName, gil, pyOverride, event);
}

bool QStencilTestArgumentsWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QTextureWrapModeWrapper::sbk_o_eventFilter("QStencilTestArguments", funcName, gil, pyOverride, watched, event);
}

void QStencilTestArgumentsWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QTextureWrapModeWrapper::sbk_o_timerEvent("QStencilTestArguments", funcName, gil, pyOverride, event);
}

const QMetaObject *QStencilTestArgumentsWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QStencilTestArguments::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QStencilTestArgumentsWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QStencilTestArguments::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QStencilTestArgumentsWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QStencilTestArgumentsWrapper *>(this));
    return Qt3DRender::QStencilTestArguments::qt_metacast(_clname);
}

QStencilTestArgumentsWrapper::~QStencilTestArgumentsWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_Qt3DRender_QStencilTestArguments_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QStencilTestArguments");
    return -1;
}

static PyObject *Sbk_Qt3DRender_QStencilTestArgumentsFunc_comparisonMask(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QStencilTestArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // comparisonMask()const
        uint cppResult = const_cast<const ::Qt3DRender::QStencilTestArguments *>(cppSelf)->comparisonMask();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DRender_QStencilTestArgumentsFunc_faceMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QStencilTestArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // faceMode()const
        Qt3DRender::QStencilTestArguments::StencilFaceMode cppResult = const_cast<const ::Qt3DRender::QStencilTestArguments *>(cppSelf)->faceMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_StencilFaceMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DRender_QStencilTestArgumentsFunc_referenceValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QStencilTestArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // referenceValue()const
        int cppResult = const_cast<const ::Qt3DRender::QStencilTestArguments *>(cppSelf)->referenceValue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Qt3DRender_QStencilTestArgumentsFunc_setComparisonMask(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QStencilTestArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStencilTestArguments::setComparisonMask(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // setComparisonMask(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setComparisonMask", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setComparisonMask(uint)
            cppSelf->setComparisonMask(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DRender_QStencilTestArgumentsFunc_setReferenceValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QStencilTestArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStencilTestArguments::setReferenceValue(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setReferenceValue(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReferenceValue", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReferenceValue(int)
            cppSelf->setReferenceValue(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DRender_QStencilTestArgumentsFunc_setStencilFunction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QStencilTestArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStencilTestArguments::setStencilFunction(Qt3DRender::QStencilTestArguments::StencilFunction)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_StencilFunction_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setStencilFunction(Qt3DRender::QStencilTestArguments::StencilFunction)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStencilFunction", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_IDX]);

    // Call function/method
    {
        ::Qt3DRender::QStencilTestArguments::StencilFunction cppArg0 = static_cast< ::Qt3DRender::QStencilTestArguments::StencilFunction>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStencilFunction(Qt3DRender::QStencilTestArguments::StencilFunction)
            cppSelf->setStencilFunction(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Qt3DRender_QStencilTestArgumentsFunc_stencilFunction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QStencilTestArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stencilFunction()const
        Qt3DRender::QStencilTestArguments::StencilFunction cppResult = const_cast<const ::Qt3DRender::QStencilTestArguments *>(cppSelf)->stencilFunction();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_StencilFunction_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Qt3DRender_QStencilTestArguments_PropertyStrings[] = {
    "comparisonMask::",
    "faceMode:",
    "referenceValue::",
    "stencilFunction::",
    nullptr // Sentinel
};

static const char *Sbk_Qt3DRender_QStencilTestArguments_EnumFlagInfo[] = {
    "StencilFaceMode:Enum",
    "StencilFunction:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QStencilTestArguments_methods[] = {
    {"comparisonMask", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QStencilTestArgumentsFunc_comparisonMask), METH_NOARGS, nullptr},
    {"faceMode", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QStencilTestArgumentsFunc_faceMode), METH_NOARGS, nullptr},
    {"referenceValue", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QStencilTestArgumentsFunc_referenceValue), METH_NOARGS, nullptr},
    {"setComparisonMask", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QStencilTestArgumentsFunc_setComparisonMask), METH_O, nullptr},
    {"setReferenceValue", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QStencilTestArgumentsFunc_setReferenceValue), METH_O, nullptr},
    {"setStencilFunction", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QStencilTestArgumentsFunc_setStencilFunction), METH_O, nullptr},
    {"stencilFunction", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QStencilTestArgumentsFunc_stencilFunction), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QStencilTestArguments_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QStencilTestArguments *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QStencilTestArgumentsWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DRender_QStencilTestArguments_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QStencilTestArguments_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QStencilTestArguments_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QStencilTestArguments_TypeF(void)
{
    return _Sbk_Qt3DRender_QStencilTestArguments_Type;
}

static PyType_Slot Sbk_Qt3DRender_QStencilTestArguments_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QStencilTestArguments_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QStencilTestArguments_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QStencilTestArguments_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QStencilTestArguments_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QStencilTestArguments_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QStencilTestArguments_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QStencilTestArguments_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QStencilTestArguments_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QStencilTestArguments *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Qt3DRender_QStencilTestArguments_StencilFaceMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QStencilTestArguments::StencilFaceMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QStencilTestArguments::StencilFaceMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QStencilTestArguments_StencilFaceMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_StencilFaceMode_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QStencilTestArguments_StencilFaceMode;
    return {};
}

static PyObject *Qt3DRender_QStencilTestArguments_StencilFaceMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QStencilTestArguments::StencilFaceMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QStencilTestArguments::StencilFaceMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_StencilFaceMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_Qt3DRender_QStencilTestArguments_StencilFunction(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QStencilTestArguments::StencilFunction>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QStencilTestArguments::StencilFunction *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DRender_QStencilTestArguments_StencilFunction_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_StencilFunction_IDX])))
        return Enum_PythonToCpp_Qt3DRender_QStencilTestArguments_StencilFunction;
    return {};
}

static PyObject *Qt3DRender_QStencilTestArguments_StencilFunction_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::Qt3DRender::QStencilTestArguments::StencilFunction>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Qt3DRender::QStencilTestArguments::StencilFunction *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_StencilFunction_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStencilTestArguments_PythonToCpp_QStencilTestArguments_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QStencilTestArguments_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStencilTestArguments_PythonToCpp_QStencilTestArguments_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QStencilTestArguments_TypeF()))
        return QStencilTestArguments_PythonToCpp_QStencilTestArguments_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStencilTestArguments_PTR_CppToPython_QStencilTestArguments(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QStencilTestArguments *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QStencilTestArguments_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QStencilTestArguments_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments.comparisonMask(self)->uint",
    "PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments.faceMode(self)->PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments.StencilFaceMode",
    "PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments.referenceValue(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments.setComparisonMask(self,comparisonMask:uint)",
    "PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments.setReferenceValue(self,referenceValue:int)",
    "PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments.setStencilFunction(self,stencilFunction:PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments.StencilFunction)",
    "PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments.stencilFunction(self)->PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments.StencilFunction",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QStencilTestArguments_SignatureByteSize = 171;
static constexpr uint8_t Qt3DRender_QStencilTestArguments_SignatureBytes[171] = {
    0x78, 0xda, 0xa5, 0x92, 0xb1, 0x0a, 0xc2, 0x30, 0x10, 0x86, 0xf7, 0x3e, 0x89, 0x85, 0xda, 0x45,
    0x70, 0xc8, 0x20, 0x88, 0xe2, 0x56, 0xa8, 0xad, 0xb8, 0x87, 0xe4, 0x2a, 0xc1, 0xf4, 0x22, 0xb9,
    0xcb, 0xe0, 0xdb, 0xab, 0x98, 0x0a, 0xa1, 0x4e, 0xe9, 0x76, 0xfc, 0xc3, 0xc7, 0x77, 0xff, 0x5d,
    0xfb, 0xec, 0x8d, 0x86, 0x6d, 0x7d, 0xe6, 0xcd, 0xb1, 0x03, 0xd4, 0xe0, 0x93, 0xb1, 0x67, 0x40,
    0x65, 0xec, 0x05, 0x88, 0xf7, 0xfe, 0x16, 0x46, 0x40, 0xa6, 0x5a, 0xb9, 0xf1, 0x21, 0xbd, 0x21,
    0x87, 0x8d, 0xa4, 0xfb, 0x8a, 0xc0, 0x0e, 0xe5, 0x7a, 0x17, 0x0c, 0x72, 0xd1, 0x66, 0xe0, 0x06,
    0xa9, 0xa0, 0x71, 0x1a, 0x26, 0x50, 0x0e, 0x23, 0x86, 0xa7, 0x88, 0xca, 0xf2, 0xf0, 0x30, 0x80,
    0x7f, 0xe7, 0x70, 0x95, 0x36, 0xfc, 0x6c, 0x72, 0xb7, 0x22, 0xe0, 0xc3, 0xbc, 0xa7, 0x2a, 0xed,
    0x4e, 0x7c, 0x4a, 0x2b, 0x73, 0xf9, 0xdd, 0x5c, 0xb8, 0x4a, 0x97, 0x10, 0x4b, 0xf0, 0x53, 0xa7,
    0x01, 0x15, 0x1b, 0x87, 0x5f, 0x3e, 0xa5, 0xa1, 0x58, 0x72, 0xac, 0xc8, 0xc8, 0x14, 0xfc, 0x63,
    0xb7, 0xf0, 0x79, 0x22, 0xaa, 0x78, 0x01, 0x84, 0x9a, 0x21, 0xf8
};
#endif

PyTypeObject *init_Qt3DRender_QStencilTestArguments(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QStencilTestArguments_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_Qt3DRender_QStencilTestArguments_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QStencilTestArguments",
        "Qt3DRender::QStencilTestArguments*",
        &Sbk_Qt3DRender_QStencilTestArguments_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QStencilTestArguments >,
        Sbk_Qt3DRender_QStencilTestArguments_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QStencilTestArguments_TypeF(); // references _Sbk_Qt3DRender_QStencilTestArguments_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QStencilTestArguments_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QStencilTestArguments_SignatureBytes, Qt3DRender_QStencilTestArguments_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QStencilTestArguments_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStencilTestArguments_PythonToCpp_QStencilTestArguments_PTR,
        is_QStencilTestArguments_PythonToCpp_QStencilTestArguments_PTR_Convertible,
        QStencilTestArguments_PTR_CppToPython_QStencilTestArguments);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QStencilTestArguments");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QStencilTestArguments*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QStencilTestArguments&");
    Shiboken::Conversions::registerConverterAlias(converter, "QStencilTestArguments");
    Shiboken::Conversions::registerConverterAlias(converter, "QStencilTestArguments*");
    Shiboken::Conversions::registerConverterAlias(converter, "QStencilTestArguments&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QStencilTestArguments).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QStencilTestArgumentsWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QStencilTestArguments_TypeF(), &Sbk_Qt3DRender_QStencilTestArguments_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DRender_QStencilTestArguments_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StencilFaceMode'.
    const char *StencilFaceMode_Initializer[] = {
        "Front",
        "Back",
        "FrontAndBack",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t StencilFaceMode_InitializerValues[] = {
        uint16_t(Qt3DRender::QStencilTestArguments::StencilFaceMode::Front),       //  0x0404  1028
        uint16_t(Qt3DRender::QStencilTestArguments::StencilFaceMode::Back),        //  0x0405  1029
        uint16_t(Qt3DRender::QStencilTestArguments::StencilFaceMode::FrontAndBack) //  0x0408  1032
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QStencilTestArguments_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments.StencilFaceMode",
        StencilFaceMode_Initializer, StencilFaceMode_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_StencilFaceMode_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QStencilTestArguments::StencilFaceMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QStencilTestArguments_StencilFaceMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QStencilTestArguments_StencilFaceMode,
            is_Enum_PythonToCpp_Qt3DRender_QStencilTestArguments_StencilFaceMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QStencilTestArguments::StencilFaceMode");
        Shiboken::Conversions::registerConverterAlias(converter, "QStencilTestArguments::StencilFaceMode");
        Shiboken::Conversions::registerConverterAlias(converter, "StencilFaceMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StencilFaceMode' enum.

    // Initialization of enum 'StencilFunction'.
    const char *StencilFunction_Initializer[] = {
        "Never",
        "Always",
        "Less",
        "LessOrEqual",
        "Equal",
        "GreaterOrEqual",
        "Greater",
        "NotEqual",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t StencilFunction_InitializerValues[] = {
        uint16_t(Qt3DRender::QStencilTestArguments::StencilFunction::Never),          //  0x0200  512
        uint16_t(Qt3DRender::QStencilTestArguments::StencilFunction::Always),         //  0x0207  519
        uint16_t(Qt3DRender::QStencilTestArguments::StencilFunction::Less),           //  0x0201  513
        uint16_t(Qt3DRender::QStencilTestArguments::StencilFunction::LessOrEqual),    //  0x0203  515
        uint16_t(Qt3DRender::QStencilTestArguments::StencilFunction::Equal),          //  0x0202  514
        uint16_t(Qt3DRender::QStencilTestArguments::StencilFunction::GreaterOrEqual), //  0x0206  518
        uint16_t(Qt3DRender::QStencilTestArguments::StencilFunction::Greater),        //  0x0204  516
        uint16_t(Qt3DRender::QStencilTestArguments::StencilFunction::NotEqual)        //  0x0205  517
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QStencilTestArguments_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments.StencilFunction",
        StencilFunction_Initializer, StencilFunction_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QStencilTestArguments_StencilFunction_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QStencilTestArguments::StencilFunction'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QStencilTestArguments_StencilFunction_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DRender_QStencilTestArguments_StencilFunction,
            is_Enum_PythonToCpp_Qt3DRender_QStencilTestArguments_StencilFunction_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QStencilTestArguments::StencilFunction");
        Shiboken::Conversions::registerConverterAlias(converter, "QStencilTestArguments::StencilFunction");
        Shiboken::Conversions::registerConverterAlias(converter, "StencilFunction");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StencilFunction' enum.

    PySide::Signal::registerSignals(pyType, &::Qt3DRender::QStencilTestArguments::staticMetaObject);
    qRegisterMetaType< ::Qt3DRender::QStencilTestArguments::StencilFaceMode >("QStencilTestArguments::StencilFaceMode");
    qRegisterMetaType< ::Qt3DRender::QStencilTestArguments::StencilFaceMode >("Qt3DRender::QStencilTestArguments::StencilFaceMode");
    qRegisterMetaType< ::Qt3DRender::QStencilTestArguments::StencilFunction >("QStencilTestArguments::StencilFunction");
    qRegisterMetaType< ::Qt3DRender::QStencilTestArguments::StencilFunction >("Qt3DRender::QStencilTestArguments::StencilFunction");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QStencilTestArguments::staticMetaObject, sizeof(QStencilTestArgumentsWrapper));

    return pyType;
}
