// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qtexture2dmultisamplearray_wrapper.h"

// Wrappers providing overrides
#include "qt3drender_qtexturewrapmode_wrapper.h"

// Argument includes
#include <Qt3DCore/qnode.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QTexture2DMultisampleArrayWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QTexture2DMultisampleArrayWrapper::QTexture2DMultisampleArrayWrapper(::Qt3DCore::QNode * parent) : Qt3DRender::QTexture2DMultisampleArray(parent)
{
}

void QTexture2DMultisampleArrayWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QTextureWrapModeWrapper::sbk_o_childEvent("QTexture2DMultisampleArray", funcName, gil, pyOverride, event);
}

void QTexture2DMultisampleArrayWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QTextureWrapModeWrapper::sbk_o_connectNotify("QTexture2DMultisampleArray", funcName, gil, pyOverride, signal);
}

void QTexture2DMultisampleArrayWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QTextureWrapModeWrapper::sbk_o_customEvent("QTexture2DMultisampleArray", funcName, gil, pyOverride, event);
}

void QTexture2DMultisampleArrayWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QTextureWrapModeWrapper::sbk_o_connectNotify("QTexture2DMultisampleArray", funcName, gil, pyOverride, signal);
}

bool QTexture2DMultisampleArrayWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QTextureWrapModeWrapper::sbk_o_event("QTexture2DMultisampleArray", funcName, gil, pyOverride, event);
}

bool QTexture2DMultisampleArrayWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QTextureWrapModeWrapper::sbk_o_eventFilter("QTexture2DMultisampleArray", funcName, gil, pyOverride, watched, event);
}

void QTexture2DMultisampleArrayWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QTextureWrapModeWrapper::sbk_o_timerEvent("QTexture2DMultisampleArray", funcName, gil, pyOverride, event);
}

const QMetaObject *QTexture2DMultisampleArrayWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QTexture2DMultisampleArray::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QTexture2DMultisampleArrayWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QTexture2DMultisampleArray::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QTexture2DMultisampleArrayWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QTexture2DMultisampleArrayWrapper *>(this));
    return Qt3DRender::QTexture2DMultisampleArray::qt_metacast(_clname);
}

QTexture2DMultisampleArrayWrapper::~QTexture2DMultisampleArrayWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_QTexture2DMultisampleArray_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DRender::QTexture2DMultisampleArray >()))
        return -1;

    QTexture2DMultisampleArrayWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QTexture2DMultisampleArray", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTexture2DMultisampleArray::QTexture2DMultisampleArray(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QTexture2DMultisampleArray(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QTexture2DMultisampleArray(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTexture2DMultisampleArray_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTexture2DMultisampleArray_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTexture2DMultisampleArray_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QTexture2DMultisampleArray(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QTexture2DMultisampleArrayWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QTexture2DMultisampleArrayWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DRender::QTexture2DMultisampleArray >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTexture2DMultisampleArray_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTexture2DMultisampleArray_IDX]);
    };


    return 1;
}


static const char *Sbk_Qt3DRender_QTexture2DMultisampleArray_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QTexture2DMultisampleArray_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QTexture2DMultisampleArray_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QTexture2DMultisampleArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTexture2DMultisampleArray_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QTexture2DMultisampleArrayWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DRender_QTexture2DMultisampleArray_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QTexture2DMultisampleArray_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QTexture2DMultisampleArray_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QTexture2DMultisampleArray_TypeF(void)
{
    return _Sbk_Qt3DRender_QTexture2DMultisampleArray_Type;
}

static PyType_Slot Sbk_Qt3DRender_QTexture2DMultisampleArray_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QTexture2DMultisampleArray_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QTexture2DMultisampleArray_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QTexture2DMultisampleArray_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QTexture2DMultisampleArray_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QTexture2DMultisampleArray_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QTexture2DMultisampleArray_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QTexture2DMultisampleArray",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QTexture2DMultisampleArray_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QTexture2DMultisampleArray_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QTexture2DMultisampleArray *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTexture2DMultisampleArray_PythonToCpp_QTexture2DMultisampleArray_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QTexture2DMultisampleArray_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTexture2DMultisampleArray_PythonToCpp_QTexture2DMultisampleArray_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QTexture2DMultisampleArray_TypeF()))
        return QTexture2DMultisampleArray_PythonToCpp_QTexture2DMultisampleArray_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTexture2DMultisampleArray_PTR_CppToPython_QTexture2DMultisampleArray(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QTexture2DMultisampleArray *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QTexture2DMultisampleArray_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Qt3DRender_QTexture2DMultisampleArray_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QTexture2DMultisampleArray(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr)",
    nullptr}; // Sentinel
#else
static constexpr size_t Qt3DRender_QTexture2DMultisampleArray_SignatureByteSize = 89;
static constexpr uint8_t Qt3DRender_QTexture2DMultisampleArray_SignatureBytes[89] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x31, 0x76, 0x09, 0x4a,
    0xcd, 0x4b, 0x49, 0x2d, 0x42, 0x61, 0x86, 0xa4, 0x56, 0x94, 0x94, 0x16, 0xa5, 0x1a, 0xb9, 0xf8,
    0x96, 0xe6, 0x94, 0x64, 0x16, 0x27, 0xe6, 0x16, 0xe4, 0xa4, 0x3a, 0x16, 0x15, 0x25, 0x56, 0x6a,
    0x14, 0xa7, 0xe6, 0xa4, 0xe9, 0x14, 0x24, 0x16, 0xa5, 0xe6, 0x95, 0x58, 0x05, 0x20, 0x19, 0xe2,
    0x9c, 0x5f, 0x94, 0x8a, 0xc4, 0xf0, 0xcb, 0x4f, 0x49, 0xb5, 0xcd, 0x2b, 0xcd, 0xc9, 0x29, 0x28,
    0x29, 0xd2, 0xe4, 0x02, 0x00, 0x8f, 0x64, 0x27, 0x3d
};
#endif

PyTypeObject *init_Qt3DRender_QTexture2DMultisampleArray(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTexture2DMultisampleArray_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTexture2DMultisampleArray_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QTexture2DMultisampleArray_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]))));

    _Sbk_Qt3DRender_QTexture2DMultisampleArray_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QTexture2DMultisampleArray",
        "Qt3DRender::QTexture2DMultisampleArray*",
        &Sbk_Qt3DRender_QTexture2DMultisampleArray_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QTexture2DMultisampleArray >,
        Sbk_Qt3DRender_QTexture2DMultisampleArray_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QTexture2DMultisampleArray_TypeF(); // references _Sbk_Qt3DRender_QTexture2DMultisampleArray_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Qt3DRender_QTexture2DMultisampleArray_SignatureStrings);
#else
    InitSignatureBytes(pyType, Qt3DRender_QTexture2DMultisampleArray_SignatureBytes, Qt3DRender_QTexture2DMultisampleArray_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QTexture2DMultisampleArray_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTexture2DMultisampleArray_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTexture2DMultisampleArray_PythonToCpp_QTexture2DMultisampleArray_PTR,
        is_QTexture2DMultisampleArray_PythonToCpp_QTexture2DMultisampleArray_PTR_Convertible,
        QTexture2DMultisampleArray_PTR_CppToPython_QTexture2DMultisampleArray);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QTexture2DMultisampleArray");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QTexture2DMultisampleArray*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QTexture2DMultisampleArray&");
    Shiboken::Conversions::registerConverterAlias(converter, "QTexture2DMultisampleArray");
    Shiboken::Conversions::registerConverterAlias(converter, "QTexture2DMultisampleArray*");
    Shiboken::Conversions::registerConverterAlias(converter, "QTexture2DMultisampleArray&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QTexture2DMultisampleArray).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QTexture2DMultisampleArrayWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QTexture2DMultisampleArray_TypeF(), &Sbk_Qt3DRender_QTexture2DMultisampleArray_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QTexture2DMultisampleArray::staticMetaObject, sizeof(QTexture2DMultisampleArrayWrapper));

    return pyType;
}
