// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qbluetoothsocket_wrapper.h"

// Wrappers providing overrides
#include "qbluetoothsocket_wrapper.h"
#include "qlowenergyservice_wrapper.h"

// Argument includes
#include <QString>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtBluetooth/qbluetoothserviceinfo.h>
#include <QtBluetooth/qbluetoothsocket.h>
#include <QtBluetooth/qbluetoothuuid.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QBluetoothSocketWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QBluetoothSocketWrapper::QBluetoothSocketWrapper(::QBluetoothServiceInfo::Protocol socketType, ::QObject * parent) : QBluetoothSocket(socketType, parent)
{
}

QBluetoothSocketWrapper::QBluetoothSocketWrapper(::QObject * parent) : QBluetoothSocket(parent)
{
}

bool QBluetoothSocketWrapper::atEnd() const
{
    static const char *funcName = "atEnd";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::atEnd();
    }
    return sbk_o_atEnd("QBluetoothSocket", funcName, gil, pyOverride);
}

bool QBluetoothSocketWrapper::sbk_o_atEnd(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QBluetoothSocketWrapper::bytesAvailable() const
{
    static const char *funcName = "bytesAvailable";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBluetoothSocket::bytesAvailable();
    }
    return sbk_o_bytesAvailable("QBluetoothSocket", funcName, gil, pyOverride);
}

qint64 QBluetoothSocketWrapper::sbk_o_bytesAvailable(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "qint64", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    qint64 cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QBluetoothSocketWrapper::bytesToWrite() const
{
    static const char *funcName = "bytesToWrite";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBluetoothSocket::bytesToWrite();
    }
    return QBluetoothSocketWrapper::sbk_o_bytesAvailable("QBluetoothSocket", funcName, gil, pyOverride);
}

bool QBluetoothSocketWrapper::canReadLine() const
{
    static const char *funcName = "canReadLine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBluetoothSocket::canReadLine();
    }
    return QBluetoothSocketWrapper::sbk_o_atEnd("QBluetoothSocket", funcName, gil, pyOverride);
}

void QBluetoothSocketWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QLowEnergyServiceWrapper::sbk_o_childEvent("QBluetoothSocket", funcName, gil, pyOverride, event);
}

void QBluetoothSocketWrapper::close()
{
    static const char *funcName = "close";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBluetoothSocket::close();
    }
    sbk_o_close("QBluetoothSocket", funcName, gil, pyOverride);
}

void QBluetoothSocketWrapper::sbk_o_close(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QBluetoothSocketWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QLowEnergyServiceWrapper::sbk_o_connectNotify("QBluetoothSocket", funcName, gil, pyOverride, signal);
}

void QBluetoothSocketWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QLowEnergyServiceWrapper::sbk_o_customEvent("QBluetoothSocket", funcName, gil, pyOverride, event);
}

void QBluetoothSocketWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QLowEnergyServiceWrapper::sbk_o_connectNotify("QBluetoothSocket", funcName, gil, pyOverride, signal);
}

bool QBluetoothSocketWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QLowEnergyServiceWrapper::sbk_o_event("QBluetoothSocket", funcName, gil, pyOverride, event);
}

bool QBluetoothSocketWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QLowEnergyServiceWrapper::sbk_o_eventFilter("QBluetoothSocket", funcName, gil, pyOverride, watched, event);
}

bool QBluetoothSocketWrapper::isSequential() const
{
    static const char *funcName = "isSequential";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBluetoothSocket::isSequential();
    }
    return QBluetoothSocketWrapper::sbk_o_atEnd("QBluetoothSocket", funcName, gil, pyOverride);
}

bool QBluetoothSocketWrapper::open(::QFlags<QIODeviceBase::OpenModeFlag> mode)
{
    static const char *funcName = "open";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::open(mode);
    }
    return sbk_o_open("QBluetoothSocket", funcName, gil, pyOverride, mode);
}

bool QBluetoothSocketWrapper::sbk_o_open(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<QIODeviceBase::OpenModeFlag> mode)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, &mode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, &mode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QBluetoothSocketWrapper::pos() const
{
    static const char *funcName = "pos";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::pos();
    }
    return QBluetoothSocketWrapper::sbk_o_bytesAvailable("QBluetoothSocket", funcName, gil, pyOverride);
}

qint64 QBluetoothSocketWrapper::readData(char * data, qint64 maxSize)
{
    static const char *funcName = "readData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBluetoothSocket::readData(data, maxSize);
    }
    return sbk_o_readData("QBluetoothSocket", funcName, gil, pyOverride, data, maxSize);
}

qint64 QBluetoothSocketWrapper::sbk_o_readData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, char * data, qint64 maxSize)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        maxSize
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }

    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    qint64 cppResult = 0;
    if (PyBytes_Check(pyResult.object())) {
        cppResult = PyBytes_Size(pyResult.object());
        memcpy(data, PyBytes_AsString(pyResult.object()), cppResult);
    } else if (Shiboken::String::check(pyResult.object())) {
        cppResult = Shiboken::String::len(pyResult.object());
        memcpy(data, Shiboken::String::toCString(pyResult.object()), cppResult);
    }
    // END of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    // ========================================================================
    // End of code injection

    return cppResult;
}

qint64 QBluetoothSocketWrapper::readLineData(char * data, qint64 maxlen)
{
    static const char *funcName = "readLineData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::readLineData(data, maxlen);
    }
    return sbk_o_readLineData("QBluetoothSocket", funcName, gil, pyOverride, data, maxlen);
}

qint64 QBluetoothSocketWrapper::sbk_o_readLineData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, char * data, qint64 maxlen)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        maxlen
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }

    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    qint64 cppResult = 0;
    if (PyBytes_Check(pyResult.object())) {
        cppResult = PyBytes_Size(pyResult.object());
        memcpy(data, PyBytes_AsString(pyResult.object()), cppResult);
    } else if (Shiboken::String::check(pyResult.object())) {
        cppResult = Shiboken::String::len(pyResult.object());
        memcpy(data, Shiboken::String::toCString(pyResult.object()), cppResult);
    }
    // END of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    // ========================================================================
    // End of code injection

    return cppResult;
}

bool QBluetoothSocketWrapper::reset()
{
    static const char *funcName = "reset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::reset();
    }
    return QBluetoothSocketWrapper::sbk_o_atEnd("QBluetoothSocket", funcName, gil, pyOverride);
}

bool QBluetoothSocketWrapper::seek(qint64 pos)
{
    static const char *funcName = "seek";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::seek(pos);
    }
    return sbk_o_seek("QBluetoothSocket", funcName, gil, pyOverride, pos);
}

bool QBluetoothSocketWrapper::sbk_o_seek(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, qint64 pos)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &pos)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        pos
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QBluetoothSocketWrapper::size() const
{
    static const char *funcName = "size";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::size();
    }
    return QBluetoothSocketWrapper::sbk_o_bytesAvailable("QBluetoothSocket", funcName, gil, pyOverride);
}

qint64 QBluetoothSocketWrapper::skipData(qint64 maxSize)
{
    static const char *funcName = "skipData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::skipData(maxSize);
    }
    return sbk_o_skipData("QBluetoothSocket", funcName, gil, pyOverride, maxSize);
}

qint64 QBluetoothSocketWrapper::sbk_o_skipData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, qint64 maxSize)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &maxSize)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        maxSize
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "qint64", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    qint64 cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QBluetoothSocketWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QLowEnergyServiceWrapper::sbk_o_timerEvent("QBluetoothSocket", funcName, gil, pyOverride, event);
}

bool QBluetoothSocketWrapper::waitForBytesWritten(int msecs)
{
    static const char *funcName = "waitForBytesWritten";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::waitForBytesWritten(msecs);
    }
    return sbk_o_waitForBytesWritten("QBluetoothSocket", funcName, gil, pyOverride, msecs);
}

bool QBluetoothSocketWrapper::sbk_o_waitForBytesWritten(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int msecs)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &msecs)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        msecs
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QBluetoothSocketWrapper::waitForReadyRead(int msecs)
{
    static const char *funcName = "waitForReadyRead";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::waitForReadyRead(msecs);
    }
    return sbk_o_waitForReadyRead("QBluetoothSocket", funcName, gil, pyOverride, msecs);
}

bool QBluetoothSocketWrapper::sbk_o_waitForReadyRead(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int msecs)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &msecs)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        msecs
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QBluetoothSocketWrapper::writeData(const char * data, qint64 maxSize)
{
    static const char *funcName = "writeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBluetoothSocket::writeData(data, maxSize);
    }
    return sbk_o_writeData("QBluetoothSocket", funcName, gil, pyOverride, data, maxSize);
}

qint64 QBluetoothSocketWrapper::sbk_o_writeData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const char * data, qint64 maxSize)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), data),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &maxSize)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NL)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), data),
        maxSize
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "qint64", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    qint64 cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

const QMetaObject *QBluetoothSocketWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QBluetoothSocket::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QBluetoothSocketWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QBluetoothSocket::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QBluetoothSocketWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QBluetoothSocketWrapper *>(this));
    return QBluetoothSocket::qt_metacast(_clname);
}

QBluetoothSocketWrapper::~QBluetoothSocketWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBluetoothSocket_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBluetoothSocket >()))
        return -1;

    QBluetoothSocketWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QBluetoothSocket", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBluetoothSocket::QBluetoothSocket(QBluetoothServiceInfo::Protocol,QObject*=)
    // 1: QBluetoothSocket::QBluetoothSocket(QObject*=)
    if (numArgs == 0) {
        overloadId = 1; // QBluetoothSocket(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QBluetoothSocket(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Protocol_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QBluetoothSocket(QBluetoothServiceInfo::Protocol,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QBluetoothSocket(QBluetoothServiceInfo::Protocol,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QBluetoothSocket(QBluetoothServiceInfo::Protocol socketType, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);
                }
            }
            ::QBluetoothServiceInfo::Protocol cppArg0{QBluetoothServiceInfo::UnknownProtocol};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothSocket(QBluetoothServiceInfo::Protocol,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QBluetoothSocketWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QBluetoothSocketWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 1: // QBluetoothSocket(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothSocket(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QBluetoothSocketWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QBluetoothSocketWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QBluetoothSocket >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QBluetoothSocketFunc_abort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // abort()
        cppSelf->abort();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBluetoothSocketFunc_bytesAvailable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bytesAvailable()const
        qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QBluetoothSocket *>(cppSelf)->::QBluetoothSocket::bytesAvailable()
            : const_cast<const ::QBluetoothSocket *>(cppSelf)->bytesAvailable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_bytesToWrite(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bytesToWrite()const
        qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QBluetoothSocket *>(cppSelf)->::QBluetoothSocket::bytesToWrite()
            : const_cast<const ::QBluetoothSocket *>(cppSelf)->bytesToWrite();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_canReadLine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // canReadLine()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QBluetoothSocket *>(cppSelf)->::QBluetoothSocket::canReadLine()
            : const_cast<const ::QBluetoothSocket *>(cppSelf)->canReadLine();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QBluetoothSocket::close()
            : cppSelf->close();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBluetoothSocketFunc_connectToService(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "connectToService", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:connectToService", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBluetoothSocket::connectToService(QBluetoothAddress,QBluetoothUuid::ServiceClassUuid,QFlags<QIODeviceBase::OpenModeFlag>=)
    // 1: QBluetoothSocket::connectToService(QBluetoothAddress,QBluetoothUuid,QFlags<QIODeviceBase::OpenModeFlag>=)
    // 2: QBluetoothSocket::connectToService(QBluetoothAddress,quint16,QFlags<QIODeviceBase::OpenModeFlag>=)
    // 3: QBluetoothSocket::connectToService(QBluetoothServiceInfo,QFlags<QIODeviceBase::OpenModeFlag>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // connectToService(QBluetoothServiceInfo,QFlags<QIODeviceBase::OpenModeFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 3; // connectToService(QBluetoothServiceInfo,QFlags<QIODeviceBase::OpenModeFlag>)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_ServiceClassUuid_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // connectToService(QBluetoothAddress,QBluetoothUuid::ServiceClassUuid,QFlags<QIODeviceBase::OpenModeFlag>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 0; // connectToService(QBluetoothAddress,QBluetoothUuid::ServiceClassUuid,QFlags<QIODeviceBase::OpenModeFlag>)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // connectToService(QBluetoothAddress,QBluetoothUuid,QFlags<QIODeviceBase::OpenModeFlag>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 1; // connectToService(QBluetoothAddress,QBluetoothUuid,QFlags<QIODeviceBase::OpenModeFlag>)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // connectToService(QBluetoothAddress,quint16,QFlags<QIODeviceBase::OpenModeFlag>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 2; // connectToService(QBluetoothAddress,quint16,QFlags<QIODeviceBase::OpenModeFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "connectToService", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // connectToService(const QBluetoothAddress &address, QBluetoothUuid::ServiceClassUuid uuid, QFlags<QIODeviceBase::OpenModeFlag> mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"mode", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "connectToService", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QBluetoothAddress cppArg0_local;
            ::QBluetoothAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QBluetoothUuid::ServiceClassUuid cppArg1 = static_cast< ::QBluetoothUuid::ServiceClassUuid>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QIODeviceBase::OpenModeFlag> cppArg2(QIODeviceBase::OpenModeFlag::ReadWrite);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connectToService(QBluetoothAddress,QBluetoothUuid::ServiceClassUuid,QFlags<QIODeviceBase::OpenModeFlag>)
                cppSelf->connectToService(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // connectToService(const QBluetoothAddress &address, const QBluetoothUuid &uuid, QFlags<QIODeviceBase::OpenModeFlag> openMode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"openMode", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "connectToService", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QBluetoothAddress cppArg0_local;
            ::QBluetoothAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QBluetoothUuid cppArg1_local;
            ::QBluetoothUuid *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QFlags<QIODeviceBase::OpenModeFlag> cppArg2(QIODeviceBase::OpenModeFlag::ReadWrite);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connectToService(QBluetoothAddress,QBluetoothUuid,QFlags<QIODeviceBase::OpenModeFlag>)
                cppSelf->connectToService(*cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 2: // connectToService(const QBluetoothAddress &address, quint16 port, QFlags<QIODeviceBase::OpenModeFlag> openMode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"openMode", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "connectToService", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QBluetoothAddress cppArg0_local;
            ::QBluetoothAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            quint16 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QIODeviceBase::OpenModeFlag> cppArg2(QIODeviceBase::OpenModeFlag::ReadWrite);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connectToService(QBluetoothAddress,quint16,QFlags<QIODeviceBase::OpenModeFlag>)
                cppSelf->connectToService(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 3: // connectToService(const QBluetoothServiceInfo &service, QFlags<QIODeviceBase::OpenModeFlag> openMode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"openMode", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "connectToService", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QBluetoothServiceInfo cppArg0_local;
            ::QBluetoothServiceInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QFlags<QIODeviceBase::OpenModeFlag> cppArg1(QIODeviceBase::OpenModeFlag::ReadWrite);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connectToService(QBluetoothServiceInfo,QFlags<QIODeviceBase::OpenModeFlag>)
                cppSelf->connectToService(*cppArg0, cppArg1);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBluetoothSocketFunc_disconnectFromService(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // disconnectFromService()
        cppSelf->disconnectFromService();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBluetoothSocketFunc_doDeviceDiscovery(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "doDeviceDiscovery", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBluetoothSocket::doDeviceDiscovery(QBluetoothServiceInfo,QFlags<QIODeviceBase::OpenModeFlag>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
        overloadId = 0; // doDeviceDiscovery(QBluetoothServiceInfo,QFlags<QIODeviceBase::OpenModeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "doDeviceDiscovery", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QBluetoothServiceInfo cppArg0_local;
        ::QBluetoothServiceInfo *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QFlags<QIODeviceBase::OpenModeFlag> cppArg1 = QFlags<QIODeviceBase::OpenModeFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // doDeviceDiscovery(QBluetoothServiceInfo,QFlags<QIODeviceBase::OpenModeFlag>)
            cppSelf->doDeviceDiscovery(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBluetoothSocketFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QBluetoothSocket::SocketError cppResult = const_cast<const ::QBluetoothSocket *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_SocketError_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QBluetoothSocket *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_isSequential(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSequential()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QBluetoothSocket *>(cppSelf)->::QBluetoothSocket::isSequential()
            : const_cast<const ::QBluetoothSocket *>(cppSelf)->isSequential();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_localAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localAddress()const
        QBluetoothAddress cppResult = const_cast<const ::QBluetoothSocket *>(cppSelf)->localAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_localName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localName()const
        QString cppResult = const_cast<const ::QBluetoothSocket *>(cppSelf)->localName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_localPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localPort()const
        quint16 cppResult = const_cast<const ::QBluetoothSocket *>(cppSelf)->localPort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_peerAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // peerAddress()const
        QBluetoothAddress cppResult = const_cast<const ::QBluetoothSocket *>(cppSelf)->peerAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_peerName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // peerName()const
        QString cppResult = const_cast<const ::QBluetoothSocket *>(cppSelf)->peerName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_peerPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // peerPort()const
        quint16 cppResult = const_cast<const ::QBluetoothSocket *>(cppSelf)->peerPort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_preferredSecurityFlags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // preferredSecurityFlags()const
        QFlags<QBluetooth::Security> cppResult = const_cast<const ::QBluetoothSocket *>(cppSelf)->preferredSecurityFlags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetooth_Security_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_readData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QIODevice::readData(char*,qint64)->PyObject
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // readData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "readData", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readData(char*,qint64)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            QByteArray ba(1 + qsizetype(cppArg0), char(0));
            Py_BEGIN_ALLOW_THREADS
            (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QBluetoothSocket::readData(ba.data(), qint64(cppArg0)) : cppSelf->readData(ba.data(), qint64(cppArg0)));
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::String::fromCString(ba.constData());
            // END of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_setPreferredSecurityFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothSocket::setPreferredSecurityFlags(QFlags<QBluetooth::Security>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetooth_Security_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setPreferredSecurityFlags(QFlags<QBluetooth::Security>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPreferredSecurityFlags", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);

    // Call function/method
    {
        ::QFlags<QBluetooth::Security> cppArg0 = QFlags<QBluetooth::Security>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPreferredSecurityFlags(QFlags<QBluetooth::Security>)
            cppSelf->setPreferredSecurityFlags(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBluetoothSocketFunc_setSocketDescriptor(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setSocketDescriptor", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:setSocketDescriptor", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBluetoothSocket::setSocketDescriptor(int,QBluetoothServiceInfo::Protocol,QBluetoothSocket::SocketState=,QFlags<QIODeviceBase::OpenModeFlag>=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Protocol_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setSocketDescriptor(int,QBluetoothServiceInfo::Protocol,QBluetoothSocket::SocketState,QFlags<QIODeviceBase::OpenModeFlag>)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_SocketState_IDX])))->converter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // setSocketDescriptor(int,QBluetoothServiceInfo::Protocol,QBluetoothSocket::SocketState,QFlags<QIODeviceBase::OpenModeFlag>)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[3])))) {
                overloadId = 0; // setSocketDescriptor(int,QBluetoothServiceInfo::Protocol,QBluetoothSocket::SocketState,QFlags<QIODeviceBase::OpenModeFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSocketDescriptor", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"socketState", 2}, {"openMode", 3}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_SocketState_IDX])))->converter, (pyArgs[2]))))
                || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[3]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setSocketDescriptor", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QBluetoothServiceInfo::Protocol cppArg1{QBluetoothServiceInfo::UnknownProtocol};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QBluetoothSocket::SocketState cppArg2(QBluetoothSocket::SocketState::ConnectedState);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QFlags<QIODeviceBase::OpenModeFlag> cppArg3(QIODeviceBase::OpenModeFlag::ReadWrite);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSocketDescriptor(int,QBluetoothServiceInfo::Protocol,QBluetoothSocket::SocketState,QFlags<QIODeviceBase::OpenModeFlag>)
            bool cppResult = cppSelf->setSocketDescriptor(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_setSocketError(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothSocket::setSocketError(QBluetoothSocket::SocketError)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_SocketError_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSocketError(QBluetoothSocket::SocketError)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSocketError", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);

    // Call function/method
    {
        ::QBluetoothSocket::SocketError cppArg0{QBluetoothSocket::SocketError::NoSocketError};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSocketError(QBluetoothSocket::SocketError)
            cppSelf->setSocketError(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBluetoothSocketFunc_setSocketState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothSocket::setSocketState(QBluetoothSocket::SocketState)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_SocketState_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSocketState(QBluetoothSocket::SocketState)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSocketState", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);

    // Call function/method
    {
        ::QBluetoothSocket::SocketState cppArg0{QBluetoothSocket::SocketState::UnconnectedState};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSocketState(QBluetoothSocket::SocketState)
            cppSelf->setSocketState(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBluetoothSocketFunc_socketDescriptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // socketDescriptor()const
        int cppResult = const_cast<const ::QBluetoothSocket *>(cppSelf)->socketDescriptor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_socketType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // socketType()const
        QBluetoothServiceInfo::Protocol cppResult = const_cast<const ::QBluetoothSocket *>(cppSelf)->socketType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_Protocol_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QBluetoothSocket::SocketState cppResult = const_cast<const ::QBluetoothSocket *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_SocketState_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBluetoothSocketFunc_writeData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QIODevice::writeData(const char*,qint64)->qint64
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
        overloadId = 0; // writeData(const char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeData", errInfo, SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qint64 cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeData(const char*,qint64)
            qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QBluetoothSocket::writeData(cppArg0, cppArg1)
                : cppSelf->writeData(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QBluetoothSocket_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QBluetoothSocket_EnumFlagInfo[] = {
    "SocketError:Enum",
    "SocketState:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBluetoothSocket_methods[] = {
    {"abort", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_abort), METH_NOARGS, nullptr},
    {"bytesAvailable", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_bytesAvailable), METH_NOARGS, nullptr},
    {"bytesToWrite", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_bytesToWrite), METH_NOARGS, nullptr},
    {"canReadLine", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_canReadLine), METH_NOARGS, nullptr},
    {"close", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_close), METH_NOARGS, nullptr},
    {"connectToService", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_connectToService), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"disconnectFromService", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_disconnectFromService), METH_NOARGS, nullptr},
    {"doDeviceDiscovery", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_doDeviceDiscovery), METH_VARARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_errorString), METH_NOARGS, nullptr},
    {"isSequential", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_isSequential), METH_NOARGS, nullptr},
    {"localAddress", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_localAddress), METH_NOARGS, nullptr},
    {"localName", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_localName), METH_NOARGS, nullptr},
    {"localPort", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_localPort), METH_NOARGS, nullptr},
    {"peerAddress", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_peerAddress), METH_NOARGS, nullptr},
    {"peerName", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_peerName), METH_NOARGS, nullptr},
    {"peerPort", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_peerPort), METH_NOARGS, nullptr},
    {"preferredSecurityFlags", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_preferredSecurityFlags), METH_NOARGS, nullptr},
    {"readData", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_readData), METH_O, nullptr},
    {"setPreferredSecurityFlags", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_setPreferredSecurityFlags), METH_O, nullptr},
    {"setSocketDescriptor", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_setSocketDescriptor), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setSocketError", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_setSocketError), METH_O, nullptr},
    {"setSocketState", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_setSocketState), METH_O, nullptr},
    {"socketDescriptor", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_socketDescriptor), METH_NOARGS, nullptr},
    {"socketType", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_socketType), METH_NOARGS, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_state), METH_NOARGS, nullptr},
    {"writeData", reinterpret_cast<PyCFunction>(Sbk_QBluetoothSocketFunc_writeData), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QBluetoothSocket_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QBluetoothSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QBluetoothSocketWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QBluetoothSocket_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBluetoothSocket_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QBluetoothSocketSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QBluetoothSocket *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]))
        return static_cast< ::QIODevice *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_IDX]))
        return static_cast< ::QIODeviceBase *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBluetoothSocket_Type = nullptr;
static PyTypeObject *Sbk_QBluetoothSocket_TypeF(void)
{
    return _Sbk_QBluetoothSocket_Type;
}

static PyType_Slot Sbk_QBluetoothSocket_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QBluetoothSocket_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBluetoothSocket_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBluetoothSocket_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBluetoothSocket_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBluetoothSocket_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBluetoothSocket_spec = {
    "2:PySide6.QtBluetooth.QBluetoothSocket",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBluetoothSocket_slots
};

} //extern "C"

static void *Sbk_QBluetoothSocket_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QBluetoothSocket *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QBluetoothSocket_SocketState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothSocket::SocketState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothSocket::SocketState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBluetoothSocket_SocketState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_SocketState_IDX])))
        return Enum_PythonToCpp_QBluetoothSocket_SocketState;
    return {};
}

static PyObject *QBluetoothSocket_SocketState_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBluetoothSocket::SocketState>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBluetoothSocket::SocketState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_SocketState_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QBluetoothSocket_SocketError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothSocket::SocketError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothSocket::SocketError *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QBluetoothSocket_SocketError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_SocketError_IDX])))
        return Enum_PythonToCpp_QBluetoothSocket_SocketError;
    return {};
}

static PyObject *QBluetoothSocket_SocketError_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QBluetoothSocket::SocketError>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QBluetoothSocket::SocketError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_SocketError_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBluetoothSocket_PythonToCpp_QBluetoothSocket_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBluetoothSocket_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBluetoothSocket_PythonToCpp_QBluetoothSocket_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBluetoothSocket_TypeF()))
        return QBluetoothSocket_PythonToCpp_QBluetoothSocket_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBluetoothSocket_PTR_CppToPython_QBluetoothSocket(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QBluetoothSocket *>(const_cast<void *>(cppIn)), Sbk_QBluetoothSocket_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBluetoothSocket_SignatureStrings[] = {
    "1:PySide6.QtBluetooth.QBluetoothSocket(self,socketType:PySide6.QtBluetooth.QBluetoothServiceInfo.Protocol,parent:PySide6.QtCore.QObject=nullptr)",
    "0:PySide6.QtBluetooth.QBluetoothSocket(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtBluetooth.QBluetoothSocket.abort(self)",
    "PySide6.QtBluetooth.QBluetoothSocket.bytesAvailable(self)->qint64",
    "PySide6.QtBluetooth.QBluetoothSocket.bytesToWrite(self)->qint64",
    "PySide6.QtBluetooth.QBluetoothSocket.canReadLine(self)->bool",
    "PySide6.QtBluetooth.QBluetoothSocket.close(self)",
    "3:PySide6.QtBluetooth.QBluetoothSocket.connectToService(self,address:PySide6.QtBluetooth.QBluetoothAddress,uuid:PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid,mode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.ReadWrite)",
    "2:PySide6.QtBluetooth.QBluetoothSocket.connectToService(self,address:PySide6.QtBluetooth.QBluetoothAddress,uuid:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid],openMode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.ReadWrite)",
    "1:PySide6.QtBluetooth.QBluetoothSocket.connectToService(self,address:PySide6.QtBluetooth.QBluetoothAddress,port:quint16,openMode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.ReadWrite)",
    "0:PySide6.QtBluetooth.QBluetoothSocket.connectToService(self,service:PySide6.QtBluetooth.QBluetoothServiceInfo,openMode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.ReadWrite)",
    "PySide6.QtBluetooth.QBluetoothSocket.disconnectFromService(self)",
    "PySide6.QtBluetooth.QBluetoothSocket.doDeviceDiscovery(self,service:PySide6.QtBluetooth.QBluetoothServiceInfo,openMode:PySide6.QtCore.QIODeviceBase.OpenModeFlag)",
    "PySide6.QtBluetooth.QBluetoothSocket.error(self)->PySide6.QtBluetooth.QBluetoothSocket.SocketError",
    "PySide6.QtBluetooth.QBluetoothSocket.errorString(self)->QString",
    "PySide6.QtBluetooth.QBluetoothSocket.isSequential(self)->bool",
    "PySide6.QtBluetooth.QBluetoothSocket.localAddress(self)->PySide6.QtBluetooth.QBluetoothAddress",
    "PySide6.QtBluetooth.QBluetoothSocket.localName(self)->QString",
    "PySide6.QtBluetooth.QBluetoothSocket.localPort(self)->quint16",
    "PySide6.QtBluetooth.QBluetoothSocket.peerAddress(self)->PySide6.QtBluetooth.QBluetoothAddress",
    "PySide6.QtBluetooth.QBluetoothSocket.peerName(self)->QString",
    "PySide6.QtBluetooth.QBluetoothSocket.peerPort(self)->quint16",
    "PySide6.QtBluetooth.QBluetoothSocket.preferredSecurityFlags(self)->PySide6.QtBluetooth.QBluetooth.Security",
    "PySide6.QtBluetooth.QBluetoothSocket.readData(self,maxSize:qint64)->PyObject",
    "PySide6.QtBluetooth.QBluetoothSocket.setPreferredSecurityFlags(self,flags:PySide6.QtBluetooth.QBluetooth.Security)",
    "PySide6.QtBluetooth.QBluetoothSocket.setSocketDescriptor(self,socketDescriptor:int,socketType:PySide6.QtBluetooth.QBluetoothServiceInfo.Protocol,socketState:PySide6.QtBluetooth.QBluetoothSocket.SocketState=QBluetoothSocket.SocketState.ConnectedState,openMode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.ReadWrite)->bool",
    "PySide6.QtBluetooth.QBluetoothSocket.setSocketError(self,error:PySide6.QtBluetooth.QBluetoothSocket.SocketError)",
    "PySide6.QtBluetooth.QBluetoothSocket.setSocketState(self,state:PySide6.QtBluetooth.QBluetoothSocket.SocketState)",
    "PySide6.QtBluetooth.QBluetoothSocket.socketDescriptor(self)->int",
    "PySide6.QtBluetooth.QBluetoothSocket.socketType(self)->PySide6.QtBluetooth.QBluetoothServiceInfo.Protocol",
    "PySide6.QtBluetooth.QBluetoothSocket.state(self)->PySide6.QtBluetooth.QBluetoothSocket.SocketState",
    "PySide6.QtBluetooth.QBluetoothSocket.writeData(self,data:char*,maxSize:qint64)->qint64",
    nullptr}; // Sentinel
#else
static constexpr size_t QBluetoothSocket_SignatureByteSize = 622;
static constexpr uint8_t QBluetoothSocket_SignatureBytes[622] = {
    0x78, 0xda, 0xbd, 0x57, 0xdf, 0x6f, 0xda, 0x30, 0x10, 0x7e, 0xe7, 0xaf, 0xe8, 0xe3, 0x98, 0xb2,
    0xa8, 0x6c, 0x13, 0x0f, 0x91, 0x98, 0xd4, 0x42, 0x2b, 0x55, 0xda, 0x06, 0x2c, 0x54, 0x7b, 0x98,
    0xf6, 0x60, 0x9c, 0xa3, 0xf5, 0x66, 0x7c, 0xc1, 0x76, 0xd8, 0xb2, 0xbf, 0xbe, 0x76, 0x1c, 0x02,
    0x5a, 0xdb, 0x71, 0xa1, 0x83, 0x27, 0x9c, 0xc4, 0xdf, 0x9d, 0xbf, 0xfb, 0xf1, 0x9d, 0xe9, 0x25,
    0x93, 0x32, 0x15, 0x19, 0xf4, 0xe3, 0xa9, 0xbd, 0x94, 0x05, 0x58, 0x44, 0x7b, 0x1f, 0x4f, 0x9b,
    0x65, 0x8a, 0xfc, 0x27, 0xd8, 0x57, 0x06, 0xe4, 0x22, 0x32, 0xd5, 0x7a, 0x56, 0xe6, 0xb0, 0x0f,
    0x04, 0x7a, 0x2d, 0x38, 0xdc, 0xa8, 0x05, 0xc6, 0x13, 0x8d, 0x16, 0x39, 0xca, 0x28, 0x67, 0x1a,
    0x94, 0xdd, 0x41, 0x0e, 0x51, 0x43, 0x3c, 0x1d, 0xcf, 0x7f, 0x00, 0xb7, 0x03, 0x55, 0x48, 0x99,
    0x5b, 0xdd, 0xed, 0x9c, 0xb7, 0x38, 0x10, 0xd1, 0x24, 0xc5, 0x60, 0xcc, 0xe6, 0xa8, 0x83, 0x59,
    0x22, 0x60, 0x5e, 0x5a, 0x30, 0x17, 0x6b, 0x26, 0x24, 0x9b, 0x4b, 0x08, 0xc8, 0x37, 0x1f, 0x56,
    0x42, 0xd9, 0xfe, 0xfb, 0x16, 0x16, 0x66, 0xf8, 0x55, 0x0b, 0x7b, 0x10, 0x9e, 0x33, 0xf5, 0x05,
    0x58, 0xf6, 0x51, 0xa8, 0x06, 0x3e, 0x47, 0x94, 0x44, 0xb0, 0x44, 0x53, 0xc3, 0x3a, 0xef, 0x12,
    0x1a, 0x04, 0x95, 0x72, 0x81, 0x9d, 0x61, 0x9d, 0xdf, 0x90, 0x04, 0x96, 0x65, 0x1a, 0x8c, 0xd9,
    0x63, 0xe2, 0x22, 0xec, 0x8a, 0x8a, 0x42, 0x64, 0x7b, 0xb6, 0xde, 0xba, 0x2d, 0x71, 0xed, 0x62,
    0x28, 0x99, 0x31, 0xfe, 0x45, 0xb4, 0xc4, 0x0c, 0x1e, 0x65, 0xfa, 0x66, 0x3c, 0x02, 0xbf, 0xed,
    0x92, 0x19, 0x88, 0xc7, 0x39, 0xa8, 0x4f, 0x6e, 0xd7, 0xb5, 0x64, 0x77, 0x83, 0xe7, 0x3f, 0xc5,
    0x3e, 0x66, 0x55, 0xcc, 0xbb, 0x9d, 0xb7, 0x27, 0x26, 0x6e, 0xcb, 0x5c, 0xa8, 0xbb, 0xf8, 0x56,
    0x09, 0x54, 0xdf, 0xf6, 0x47, 0x21, 0x3a, 0x23, 0x44, 0x6a, 0x78, 0xcf, 0x34, 0xe3, 0x16, 0xb4,
    0x30, 0x56, 0x70, 0xdf, 0x9d, 0x24, 0xd8, 0x08, 0x0c, 0xd7, 0x22, 0xb7, 0xa8, 0xc9, 0x90, 0x4d,
    0x2b, 0x93, 0x8f, 0xf6, 0x28, 0x89, 0x67, 0x7f, 0x27, 0xd0, 0xbf, 0xfd, 0x1e, 0x61, 0x9d, 0x9e,
    0xff, 0x9e, 0xdf, 0xde, 0xe9, 0xf2, 0x9b, 0x3b, 0xf9, 0x48, 0x56, 0x85, 0x6b, 0xdf, 0x5e, 0xff,
    0x78, 0x84, 0xce, 0x5f, 0x42, 0xc8, 0x84, 0x07, 0xba, 0x78, 0x1f, 0x8f, 0x07, 0x89, 0x45, 0x26,
    0x4c, 0x4d, 0xe4, 0x5a, 0xe3, 0x72, 0x97, 0x0a, 0xd5, 0x00, 0x86, 0xa3, 0x8c, 0xbc, 0xa1, 0x35,
    0xe8, 0xf2, 0x74, 0x71, 0x20, 0x9e, 0x10, 0xb4, 0x46, 0xbd, 0x11, 0x6f, 0x12, 0x22, 0xfc, 0x5c,
    0x79, 0x5c, 0x0b, 0x17, 0xa9, 0xd5, 0x4e, 0x78, 0x36, 0x8e, 0xa6, 0xe1, 0x91, 0x86, 0x17, 0x26,
    0x85, 0x55, 0xe1, 0xe6, 0xac, 0x60, 0xb2, 0xfd, 0x98, 0x91, 0xc8, 0x99, 0xac, 0x7b, 0x84, 0xc6,
    0xb3, 0xde, 0xdc, 0xc2, 0xfc, 0x67, 0xb6, 0x84, 0x83, 0xa8, 0x55, 0xe8, 0x49, 0x33, 0xf7, 0xdd,
    0xf4, 0x0d, 0xfd, 0x4b, 0x43, 0xe7, 0x00, 0xfa, 0x78, 0xcc, 0xbc, 0xf5, 0x83, 0x89, 0x79, 0xf0,
    0xe1, 0xbc, 0x34, 0x2c, 0x5c, 0xd1, 0x40, 0x96, 0x02, 0x2f, 0x5c, 0xbb, 0x96, 0xbe, 0x9e, 0x89,
    0x14, 0xe3, 0x0d, 0x86, 0xe6, 0x4a, 0x3b, 0x45, 0x18, 0x31, 0xcb, 0x42, 0x5f, 0x2e, 0xd9, 0xef,
    0x54, 0xfc, 0x81, 0x24, 0xdc, 0x81, 0x2a, 0x5f, 0xe1, 0x2a, 0x47, 0x33, 0x66, 0xc0, 0x4e, 0x9e,
    0x3f, 0x7a, 0xb4, 0xf0, 0xcb, 0x84, 0x78, 0xfc, 0x2e, 0xd9, 0x65, 0x58, 0x6d, 0xa7, 0xe9, 0xee,
    0x55, 0x79, 0xfb, 0x36, 0x71, 0x94, 0x5e, 0x78, 0x7f, 0x0e, 0xe8, 0xd4, 0x32, 0x0b, 0x49, 0x0b,
    0xa5, 0xa8, 0x00, 0x83, 0x7f, 0x7d, 0x8c, 0x87, 0x41, 0x64, 0x5d, 0xd4, 0xfc, 0xe3, 0xd1, 0x44,
    0xbf, 0x8d, 0x6c, 0x34, 0x81, 0xbd, 0x6a, 0x04, 0x32, 0xaa, 0x84, 0x2c, 0x69, 0x2b, 0x92, 0x6d,
    0x33, 0x59, 0xc5, 0xa0, 0x4e, 0xe2, 0x41, 0xb1, 0xa6, 0x3a, 0x7c, 0xaa, 0x6e, 0x5c, 0x8c, 0x5c,
    0xa1, 0xb4, 0x31, 0xe0, 0xab, 0x89, 0x38, 0x3f, 0x9e, 0x28, 0x2a, 0xa2, 0xa7, 0x26, 0x24, 0xed,
    0x86, 0x54, 0x15, 0x0e, 0x9a, 0x8b, 0x5f, 0xbe, 0x42, 0xb6, 0x4a, 0x90, 0xb9, 0x55, 0xc2, 0xdd,
    0xc5, 0xf6, 0xf5, 0x63, 0x51, 0xa8, 0xff, 0x21, 0x3d, 0x00, 0x0c, 0x46, 0x78, 0x68
};
#endif

PyTypeObject *init_QBluetoothSocket(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX].type;

    Shiboken::AutoDecRef Sbk_QBluetoothSocket_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]))));

    _Sbk_QBluetoothSocket_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBluetoothSocket",
        "QBluetoothSocket*",
        &Sbk_QBluetoothSocket_spec,
        &Shiboken::callCppDestructor< QBluetoothSocket >,
        Sbk_QBluetoothSocket_Type_bases.object(),
        0);
    auto *pyType = Sbk_QBluetoothSocket_TypeF(); // references _Sbk_QBluetoothSocket_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBluetoothSocket_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBluetoothSocket_SignatureBytes, QBluetoothSocket_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBluetoothSocket_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBluetoothSocket_PythonToCpp_QBluetoothSocket_PTR,
        is_QBluetoothSocket_PythonToCpp_QBluetoothSocket_PTR_Convertible,
        QBluetoothSocket_PTR_CppToPython_QBluetoothSocket);

    Shiboken::Conversions::registerConverterName(converter, "QBluetoothSocket");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothSocket*");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothSocket&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBluetoothSocket).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QBluetoothSocketWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QBluetoothSocket_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QBluetoothSocket_TypeF(), &Sbk_QBluetoothSocketSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QBluetoothSocket_TypeF(), &Sbk_QBluetoothSocket_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QBluetoothSocket_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SocketState'.
    const char *SocketState_Initializer[] = {
        "UnconnectedState",
        "ServiceLookupState",
        "ConnectingState",
        "ConnectedState",
        "BoundState",
        "ClosingState",
        "ListeningState",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t SocketState_InitializerValues[] = {
        int8_t(QBluetoothSocket::SocketState::UnconnectedState),   //  0x00  0
        int8_t(QBluetoothSocket::SocketState::ServiceLookupState), //  0x01  1
        int8_t(QBluetoothSocket::SocketState::ConnectingState),    //  0x02  2
        int8_t(QBluetoothSocket::SocketState::ConnectedState),     //  0x03  3
        int8_t(QBluetoothSocket::SocketState::BoundState),         //  0x04  4
        int8_t(QBluetoothSocket::SocketState::ClosingState),       //  0x05  5
        int8_t(QBluetoothSocket::SocketState::ListeningState)      //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothSocket_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothSocket.SocketState",
        SocketState_Initializer, SocketState_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_SocketState_IDX].type = EType;
    // Register converter for enum 'QBluetoothSocket::SocketState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothSocket_SocketState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBluetoothSocket_SocketState,
            is_Enum_PythonToCpp_QBluetoothSocket_SocketState_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothSocket::SocketState");
        Shiboken::Conversions::registerConverterAlias(converter, "SocketState");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SocketState' enum.

    // Initialization of enum 'SocketError'.
    const char *SocketError_Initializer[] = {
        "NoSocketError",
        "UnknownSocketError",
        "RemoteHostClosedError",
        "HostNotFoundError",
        "ServiceNotFoundError",
        "NetworkError",
        "UnsupportedProtocolError",
        "OperationError",
        "MissingPermissionsError",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t SocketError_InitializerValues[] = {
        int8_t(QBluetoothSocket::SocketError::NoSocketError),            //  0x00  0
        int8_t(QBluetoothSocket::SocketError::UnknownSocketError),       //  0x01  1
        int8_t(QBluetoothSocket::SocketError::RemoteHostClosedError),    //  0x02  2
        int8_t(QBluetoothSocket::SocketError::HostNotFoundError),        //  0x03  3
        int8_t(QBluetoothSocket::SocketError::ServiceNotFoundError),     //  0x04  4
        int8_t(QBluetoothSocket::SocketError::NetworkError),             //  0x05  5
        int8_t(QBluetoothSocket::SocketError::UnsupportedProtocolError), //  0x06  6
        int8_t(QBluetoothSocket::SocketError::OperationError),           //  0x07  7
        int8_t(QBluetoothSocket::SocketError::MissingPermissionsError)   //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothSocket_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothSocket.SocketError",
        SocketError_Initializer, SocketError_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_SocketError_IDX].type = EType;
    // Register converter for enum 'QBluetoothSocket::SocketError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothSocket_SocketError_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QBluetoothSocket_SocketError,
            is_Enum_PythonToCpp_QBluetoothSocket_SocketError_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothSocket::SocketError");
        Shiboken::Conversions::registerConverterAlias(converter, "SocketError");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SocketError' enum.

    PySide::Signal::registerSignals(pyType, &::QBluetoothSocket::staticMetaObject);
    qRegisterMetaType< ::QBluetoothSocket::SocketState >("QBluetoothSocket::SocketState");
    qRegisterMetaType< ::QBluetoothSocket::SocketError >("QBluetoothSocket::SocketError");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QBluetoothSocket::staticMetaObject, sizeof(QBluetoothSocketWrapper));

    return pyType;
}
