// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcharts_python.h"

// main header
#include "qbarlegendmarker_wrapper.h"

// Wrappers providing overrides
#include "qlegendmarker_wrapper.h"
#include "qxymodelmapper_wrapper.h"

// Argument includes
#include <QtCharts/qabstractbarseries.h>
#include <QtCharts/qbarset.h>
#include <QtCharts/qlegend.h>
#include <QtCharts/qlegendmarker.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QBarLegendMarkerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QBarLegendMarkerWrapper::QBarLegendMarkerWrapper(::QAbstractBarSeries * series, ::QBarSet * barset, ::QLegend * legend, ::QObject * parent) : QBarLegendMarker(series, barset, legend, parent)
{
}

void QBarLegendMarkerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_childEvent("QBarLegendMarker", funcName, gil, pyOverride, event);
}

void QBarLegendMarkerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QBarLegendMarker", funcName, gil, pyOverride, signal);
}

void QBarLegendMarkerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_customEvent("QBarLegendMarker", funcName, gil, pyOverride, event);
}

void QBarLegendMarkerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QBarLegendMarker", funcName, gil, pyOverride, signal);
}

bool QBarLegendMarkerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QXYModelMapperWrapper::sbk_o_event("QBarLegendMarker", funcName, gil, pyOverride, event);
}

bool QBarLegendMarkerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QXYModelMapperWrapper::sbk_o_eventFilter("QBarLegendMarker", funcName, gil, pyOverride, watched, event);
}

::QAbstractBarSeries * QBarLegendMarkerWrapper::series()
{
    static const char *funcName = "series";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBarLegendMarker::series();
    }
    return sbk_o_series("QBarLegendMarker", funcName, gil, pyOverride);
}

::QAbstractBarSeries * QBarLegendMarkerWrapper::sbk_o_series(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractBarSeries_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QAbstractBarSeries >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QAbstractBarSeries *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QBarLegendMarkerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_timerEvent("QBarLegendMarker", funcName, gil, pyOverride, event);
}

::QLegendMarker::LegendMarkerType QBarLegendMarkerWrapper::type()
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBarLegendMarker::type();
    }
    return QLegendMarkerWrapper::sbk_o_type("QBarLegendMarker", funcName, gil, pyOverride);
}

const QMetaObject *QBarLegendMarkerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QBarLegendMarker::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QBarLegendMarkerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QBarLegendMarker::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QBarLegendMarkerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QBarLegendMarkerWrapper *>(this));
    return QBarLegendMarker::qt_metacast(_clname);
}

QBarLegendMarkerWrapper::~QBarLegendMarkerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBarLegendMarker_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBarLegendMarker >()))
        return -1;

    QBarLegendMarkerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOOO:QBarLegendMarker", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBarLegendMarker::QBarLegendMarker(QAbstractBarSeries*,QBarSet*,QLegend*,QObject*=)
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractBarSeries_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QBarSet_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QLegend_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // QBarLegendMarker(QAbstractBarSeries*,QBarSet*,QLegend*,QObject*)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[3])))) {
            overloadId = 0; // QBarLegendMarker(QAbstractBarSeries*,QBarSet*,QLegend*,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QBarLegendMarker_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtChartsTypeStructs[SBK_QBarLegendMarker_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 3}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[3]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QBarLegendMarker_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QAbstractBarSeries *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QBarSet *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return -1;
        ::QLegend *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return -1;
        ::QObject *cppArg3 = nullptr;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QBarLegendMarker(QAbstractBarSeries*,QBarSet*,QLegend*,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QBarLegendMarkerWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QBarLegendMarkerWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[3], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QBarLegendMarker >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QBarLegendMarker_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QBarLegendMarker_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QBarLegendMarkerFunc_barset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarLegendMarker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QBarLegendMarker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // barset()
        QBarSet * cppResult = cppSelf->barset();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QBarSet_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBarLegendMarkerFunc_series(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarLegendMarker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QBarLegendMarker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // series()
        QAbstractBarSeries * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QBarLegendMarker::series()
            : cppSelf->series();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractBarSeries_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBarLegendMarkerFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarLegendMarker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QBarLegendMarker_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()
        QLegendMarker::LegendMarkerType cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QBarLegendMarker::type()
            : cppSelf->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QLegendMarker_LegendMarkerType_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QBarLegendMarker_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBarLegendMarker_methods[] = {
    {"barset", reinterpret_cast<PyCFunction>(Sbk_QBarLegendMarkerFunc_barset), METH_NOARGS, nullptr},
    {"series", reinterpret_cast<PyCFunction>(Sbk_QBarLegendMarkerFunc_series), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QBarLegendMarkerFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QBarLegendMarker_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QBarLegendMarker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QBarLegendMarker_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QBarLegendMarkerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QBarLegendMarker_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBarLegendMarker_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBarLegendMarker_Type = nullptr;
static PyTypeObject *Sbk_QBarLegendMarker_TypeF(void)
{
    return _Sbk_QBarLegendMarker_Type;
}

static PyType_Slot Sbk_QBarLegendMarker_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QBarLegendMarker_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBarLegendMarker_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBarLegendMarker_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBarLegendMarker_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBarLegendMarker_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBarLegendMarker_spec = {
    "2:PySide6.QtCharts.QBarLegendMarker",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBarLegendMarker_slots
};

} //extern "C"

static void *Sbk_QBarLegendMarker_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QBarLegendMarker *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBarLegendMarker_PythonToCpp_QBarLegendMarker_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBarLegendMarker_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBarLegendMarker_PythonToCpp_QBarLegendMarker_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBarLegendMarker_TypeF()))
        return QBarLegendMarker_PythonToCpp_QBarLegendMarker_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBarLegendMarker_PTR_CppToPython_QBarLegendMarker(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QBarLegendMarker *>(const_cast<void *>(cppIn)), Sbk_QBarLegendMarker_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBarLegendMarker_SignatureStrings[] = {
    "PySide6.QtCharts.QBarLegendMarker(self,series:PySide6.QtCharts.QAbstractBarSeries,barset:PySide6.QtCharts.QBarSet,legend:PySide6.QtCharts.QLegend,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtCharts.QBarLegendMarker.barset(self)->PySide6.QtCharts.QBarSet",
    "PySide6.QtCharts.QBarLegendMarker.series(self)->PySide6.QtCharts.QAbstractBarSeries",
    "PySide6.QtCharts.QBarLegendMarker.type(self)->PySide6.QtCharts.QLegendMarker.LegendMarkerType",
    nullptr}; // Sentinel
#else
static constexpr size_t QBarLegendMarker_SignatureByteSize = 157;
static constexpr uint8_t QBarLegendMarker_SignatureBytes[157] = {
    0x78, 0xda, 0x8d, 0x90, 0x31, 0x0e, 0xc2, 0x30, 0x0c, 0x45, 0xf7, 0x9e, 0x84, 0x4a, 0x21, 0x23,
    0x03, 0x12, 0x48, 0xc0, 0x0a, 0x6a, 0xa2, 0x72, 0x81, 0xa4, 0x35, 0x50, 0x88, 0x42, 0x64, 0x9b,
    0xa1, 0xb7, 0xa7, 0x4a, 0x16, 0xaa, 0x36, 0xa2, 0xa3, 0x95, 0xf7, 0x9f, 0xbf, 0xa3, 0xfa, 0xba,
    0x6b, 0x61, 0x23, 0x35, 0x9f, 0x1e, 0x06, 0x99, 0xa4, 0x3e, 0x1a, 0x3c, 0xc3, 0x1d, 0x7c, 0x7b,
    0x31, 0xf8, 0x02, 0x5c, 0x11, 0xb8, 0x9b, 0x20, 0xc0, 0x0e, 0x68, 0xab, 0x26, 0xf4, 0xc1, 0x12,
    0xa3, 0x69, 0x78, 0x48, 0xd5, 0x91, 0x11, 0xd6, 0x20, 0x01, 0xcf, 0xa0, 0x11, 0x61, 0xe1, 0xa2,
    0x7c, 0xe6, 0x3d, 0x6d, 0x15, 0xc1, 0x20, 0xf8, 0x51, 0xfe, 0x8d, 0x20, 0x75, 0x65, 0x9f, 0xd0,
    0xf0, 0xce, 0x7f, 0x9c, 0x0b, 0x8c, 0x65, 0xa1, 0xfe, 0x15, 0x97, 0xa9, 0x48, 0xec, 0x5f, 0xae,
    0xf7, 0xb9, 0x3e, 0x0b, 0x44, 0xe9, 0xf8, 0xbc, 0x68, 0xf2, 0x07, 0x0b, 0x9c, 0xdc, 0x07, 0xc8,
    0x1b, 0x47, 0xe8, 0xef, 0x70, 0x1d, 0x62, 0xc5, 0x17, 0xbb, 0xb1, 0x9d, 0x80
};
#endif

PyTypeObject *init_QBarLegendMarker(PyObject *module)
{
    if (SbkPySide6_QtChartsTypeStructs[SBK_QBarLegendMarker_IDX].type != nullptr)
        return SbkPySide6_QtChartsTypeStructs[SBK_QBarLegendMarker_IDX].type;

    Shiboken::AutoDecRef Sbk_QBarLegendMarker_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QLegendMarker_IDX]))));

    _Sbk_QBarLegendMarker_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBarLegendMarker",
        "QBarLegendMarker*",
        &Sbk_QBarLegendMarker_spec,
        &Shiboken::callCppDestructor< QBarLegendMarker >,
        Sbk_QBarLegendMarker_Type_bases.object(),
        0);
    auto *pyType = Sbk_QBarLegendMarker_TypeF(); // references _Sbk_QBarLegendMarker_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBarLegendMarker_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBarLegendMarker_SignatureBytes, QBarLegendMarker_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBarLegendMarker_PropertyStrings);
    SbkPySide6_QtChartsTypeStructs[SBK_QBarLegendMarker_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBarLegendMarker_PythonToCpp_QBarLegendMarker_PTR,
        is_QBarLegendMarker_PythonToCpp_QBarLegendMarker_PTR_Convertible,
        QBarLegendMarker_PTR_CppToPython_QBarLegendMarker);

    Shiboken::Conversions::registerConverterName(converter, "QBarLegendMarker");
    Shiboken::Conversions::registerConverterName(converter, "QBarLegendMarker*");
    Shiboken::Conversions::registerConverterName(converter, "QBarLegendMarker&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBarLegendMarker).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QBarLegendMarkerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QBarLegendMarker_TypeF(), &Sbk_QBarLegendMarker_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QBarLegendMarker::staticMetaObject, sizeof(QBarLegendMarkerWrapper));

    return pyType;
}
