// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcharts_python.h"

// main header
#include "qpercentbarseries_wrapper.h"

// Wrappers providing overrides
#include "qabstractseries_wrapper.h"
#include "qxymodelmapper_wrapper.h"

// Argument includes
#include <QtCharts/qabstractseries.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPercentBarSeriesWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPercentBarSeriesWrapper::QPercentBarSeriesWrapper(::QObject * parent) : QPercentBarSeries(parent)
{
}

void QPercentBarSeriesWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_childEvent("QPercentBarSeries", funcName, gil, pyOverride, event);
}

void QPercentBarSeriesWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QPercentBarSeries", funcName, gil, pyOverride, signal);
}

void QPercentBarSeriesWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_customEvent("QPercentBarSeries", funcName, gil, pyOverride, event);
}

void QPercentBarSeriesWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QPercentBarSeries", funcName, gil, pyOverride, signal);
}

bool QPercentBarSeriesWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QXYModelMapperWrapper::sbk_o_event("QPercentBarSeries", funcName, gil, pyOverride, event);
}

bool QPercentBarSeriesWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QXYModelMapperWrapper::sbk_o_eventFilter("QPercentBarSeries", funcName, gil, pyOverride, watched, event);
}

void QPercentBarSeriesWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_timerEvent("QPercentBarSeries", funcName, gil, pyOverride, event);
}

::QAbstractSeries::SeriesType QPercentBarSeriesWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPercentBarSeries::type();
    }
    return QAbstractSeriesWrapper::sbk_o_type("QPercentBarSeries", funcName, gil, pyOverride);
}

const QMetaObject *QPercentBarSeriesWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QPercentBarSeries::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QPercentBarSeriesWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QPercentBarSeries::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QPercentBarSeriesWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QPercentBarSeriesWrapper *>(this));
    return QPercentBarSeries::qt_metacast(_clname);
}

QPercentBarSeriesWrapper::~QPercentBarSeriesWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPercentBarSeries_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPercentBarSeries >()))
        return -1;

    QPercentBarSeriesWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QPercentBarSeries", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPercentBarSeries::QPercentBarSeries(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QPercentBarSeries(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QPercentBarSeries(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QPercentBarSeries_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtChartsTypeStructs[SBK_QPercentBarSeries_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QPercentBarSeries_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPercentBarSeries(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QPercentBarSeriesWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QPercentBarSeriesWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPercentBarSeries >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QPercentBarSeries_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QPercentBarSeries_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QPercentBarSeriesFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPercentBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QPercentBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QAbstractSeries::SeriesType cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QPercentBarSeries *>(cppSelf)->::QPercentBarSeries::type()
            : const_cast<const ::QPercentBarSeries *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_SeriesType_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QPercentBarSeries_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPercentBarSeries_methods[] = {
    {"type", reinterpret_cast<PyCFunction>(Sbk_QPercentBarSeriesFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPercentBarSeries_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPercentBarSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QPercentBarSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPercentBarSeriesWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPercentBarSeries_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPercentBarSeries_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPercentBarSeries_Type = nullptr;
static PyTypeObject *Sbk_QPercentBarSeries_TypeF(void)
{
    return _Sbk_QPercentBarSeries_Type;
}

static PyType_Slot Sbk_QPercentBarSeries_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPercentBarSeries_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPercentBarSeries_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPercentBarSeries_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPercentBarSeries_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPercentBarSeries_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPercentBarSeries_spec = {
    "2:PySide6.QtCharts.QPercentBarSeries",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPercentBarSeries_slots
};

} //extern "C"

static void *Sbk_QPercentBarSeries_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QPercentBarSeries *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPercentBarSeries_PythonToCpp_QPercentBarSeries_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPercentBarSeries_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPercentBarSeries_PythonToCpp_QPercentBarSeries_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPercentBarSeries_TypeF()))
        return QPercentBarSeries_PythonToCpp_QPercentBarSeries_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPercentBarSeries_PTR_CppToPython_QPercentBarSeries(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QPercentBarSeries *>(const_cast<void *>(cppIn)), Sbk_QPercentBarSeries_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPercentBarSeries_SignatureStrings[] = {
    "PySide6.QtCharts.QPercentBarSeries(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtCharts.QPercentBarSeries.type(self)->PySide6.QtCharts.QAbstractSeries.SeriesType",
    nullptr}; // Sentinel
#else
static constexpr size_t QPercentBarSeries_SignatureByteSize = 109;
static constexpr uint8_t QPercentBarSeries_SignatureBytes[109] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce, 0x48, 0x2c,
    0x2a, 0x29, 0xd6, 0x0b, 0x0c, 0x48, 0x2d, 0x4a, 0x4e, 0xcd, 0x2b, 0x71, 0x4a, 0x2c, 0x0a, 0x4e,
    0x2d, 0xca, 0x4c, 0x2d, 0xd6, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x29, 0x48, 0x2c, 0x02, 0x0a, 0x5a,
    0x05, 0x20, 0x94, 0xe7, 0x17, 0xa5, 0xea, 0x05, 0xfa, 0x27, 0x65, 0xa5, 0x26, 0x97, 0xd8, 0xe6,
    0x95, 0xe6, 0xe4, 0x14, 0x94, 0x14, 0x69, 0x72, 0x05, 0x10, 0x34, 0x4e, 0xaf, 0xa4, 0xb2, 0x20,
    0x15, 0x6c, 0xa6, 0xa6, 0xae, 0x1d, 0xa6, 0x72, 0xc7, 0xa4, 0xe2, 0x92, 0xa2, 0xc4, 0xe4, 0x12,
    0xa8, 0x62, 0x08, 0x15, 0x02, 0xd4, 0xc2, 0x05, 0x00, 0xb5, 0x42, 0x3e, 0x07
};
#endif

PyTypeObject *init_QPercentBarSeries(PyObject *module)
{
    if (SbkPySide6_QtChartsTypeStructs[SBK_QPercentBarSeries_IDX].type != nullptr)
        return SbkPySide6_QtChartsTypeStructs[SBK_QPercentBarSeries_IDX].type;

    Shiboken::AutoDecRef Sbk_QPercentBarSeries_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractBarSeries_IDX]))));

    _Sbk_QPercentBarSeries_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPercentBarSeries",
        "QPercentBarSeries*",
        &Sbk_QPercentBarSeries_spec,
        &Shiboken::callCppDestructor< QPercentBarSeries >,
        Sbk_QPercentBarSeries_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPercentBarSeries_TypeF(); // references _Sbk_QPercentBarSeries_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPercentBarSeries_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPercentBarSeries_SignatureBytes, QPercentBarSeries_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPercentBarSeries_PropertyStrings);
    SbkPySide6_QtChartsTypeStructs[SBK_QPercentBarSeries_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPercentBarSeries_PythonToCpp_QPercentBarSeries_PTR,
        is_QPercentBarSeries_PythonToCpp_QPercentBarSeries_PTR_Convertible,
        QPercentBarSeries_PTR_CppToPython_QPercentBarSeries);

    Shiboken::Conversions::registerConverterName(converter, "QPercentBarSeries");
    Shiboken::Conversions::registerConverterName(converter, "QPercentBarSeries*");
    Shiboken::Conversions::registerConverterName(converter, "QPercentBarSeries&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPercentBarSeries).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPercentBarSeriesWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPercentBarSeries_TypeF(), &Sbk_QPercentBarSeries_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QPercentBarSeries::staticMetaObject, sizeof(QPercentBarSeriesWrapper));

    return pyType;
}
