// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcharts_python.h"

// main header
#include "qsplineseries_wrapper.h"

// Wrappers providing overrides
#include "qabstractseries_wrapper.h"
#include "qxymodelmapper_wrapper.h"
#include "qxyseries_wrapper.h"

// Argument includes
#include <QtCharts/qabstractseries.h>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qpen.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSplineSeriesWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSplineSeriesWrapper::QSplineSeriesWrapper(::QObject * parent) : QSplineSeries(parent)
{
}

void QSplineSeriesWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_childEvent("QSplineSeries", funcName, gil, pyOverride, event);
}

::QColor QSplineSeriesWrapper::color() const
{
    // This method belongs to a property.
    static const char *funcName = "1:color";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QXYSeries::color();
    }
    return QXYSeriesWrapper::sbk_o_color("QSplineSeries", funcName, gil, pyOverride);
}

void QSplineSeriesWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QSplineSeries", funcName, gil, pyOverride, signal);
}

void QSplineSeriesWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_customEvent("QSplineSeries", funcName, gil, pyOverride, event);
}

void QSplineSeriesWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QSplineSeries", funcName, gil, pyOverride, signal);
}

bool QSplineSeriesWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QXYModelMapperWrapper::sbk_o_event("QSplineSeries", funcName, gil, pyOverride, event);
}

bool QSplineSeriesWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QXYModelMapperWrapper::sbk_o_eventFilter("QSplineSeries", funcName, gil, pyOverride, watched, event);
}

void QSplineSeriesWrapper::setBrush(const ::QBrush & brush)
{
    static const char *funcName = "setBrush";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QXYSeries::setBrush(brush);
    }
    QXYSeriesWrapper::sbk_o_setBrush("QSplineSeries", funcName, gil, pyOverride, brush);
}

void QSplineSeriesWrapper::setColor(const ::QColor & color)
{
    // This method belongs to a property.
    static const char *funcName = "2:setColor";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QXYSeries::setColor(color);
    }
    QXYSeriesWrapper::sbk_o_setColor("QSplineSeries", funcName, gil, pyOverride, color);
}

void QSplineSeriesWrapper::setPen(const ::QPen & pen)
{
    static const char *funcName = "setPen";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QXYSeries::setPen(pen);
    }
    QXYSeriesWrapper::sbk_o_setPen("QSplineSeries", funcName, gil, pyOverride, pen);
}

void QSplineSeriesWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_timerEvent("QSplineSeries", funcName, gil, pyOverride, event);
}

::QAbstractSeries::SeriesType QSplineSeriesWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSplineSeries::type();
    }
    return QAbstractSeriesWrapper::sbk_o_type("QSplineSeries", funcName, gil, pyOverride);
}

const QMetaObject *QSplineSeriesWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSplineSeries::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSplineSeriesWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSplineSeries::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSplineSeriesWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QSplineSeriesWrapper *>(this));
    return QSplineSeries::qt_metacast(_clname);
}

QSplineSeriesWrapper::~QSplineSeriesWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSplineSeries_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSplineSeries >()))
        return -1;

    QSplineSeriesWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QSplineSeries", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSplineSeries::QSplineSeries(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QSplineSeries(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSplineSeries(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QSplineSeries_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtChartsTypeStructs[SBK_QSplineSeries_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QSplineSeries_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSplineSeries(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QSplineSeriesWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QSplineSeriesWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSplineSeries >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QSplineSeries_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QSplineSeries_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QSplineSeriesFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSplineSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QSplineSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QAbstractSeries::SeriesType cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSplineSeries *>(cppSelf)->::QSplineSeries::type()
            : const_cast<const ::QSplineSeries *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_SeriesType_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QSplineSeries_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSplineSeries_methods[] = {
    {"type", reinterpret_cast<PyCFunction>(Sbk_QSplineSeriesFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSplineSeries_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSplineSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QSplineSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSplineSeriesWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSplineSeries_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSplineSeries_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSplineSeries_Type = nullptr;
static PyTypeObject *Sbk_QSplineSeries_TypeF(void)
{
    return _Sbk_QSplineSeries_Type;
}

static PyType_Slot Sbk_QSplineSeries_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSplineSeries_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSplineSeries_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSplineSeries_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSplineSeries_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSplineSeries_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSplineSeries_spec = {
    "2:PySide6.QtCharts.QSplineSeries",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSplineSeries_slots
};

} //extern "C"

static void *Sbk_QSplineSeries_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSplineSeries *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSplineSeries_PythonToCpp_QSplineSeries_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSplineSeries_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSplineSeries_PythonToCpp_QSplineSeries_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSplineSeries_TypeF()))
        return QSplineSeries_PythonToCpp_QSplineSeries_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSplineSeries_PTR_CppToPython_QSplineSeries(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSplineSeries *>(const_cast<void *>(cppIn)), Sbk_QSplineSeries_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSplineSeries_SignatureStrings[] = {
    "PySide6.QtCharts.QSplineSeries(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtCharts.QSplineSeries.type(self)->PySide6.QtCharts.QAbstractSeries.SeriesType",
    nullptr}; // Sentinel
#else
static constexpr size_t QSplineSeries_SignatureByteSize = 106;
static constexpr uint8_t QSplineSeries_SignatureBytes[106] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce, 0x48, 0x2c,
    0x2a, 0x29, 0xd6, 0x0b, 0x0c, 0x2e, 0xc8, 0xc9, 0xcc, 0x4b, 0x0d, 0x4e, 0x2d, 0xca, 0x4c, 0x2d,
    0xd6, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x29, 0x48, 0x2c, 0x4a, 0xcd, 0x2b, 0xb1, 0x0a, 0x40, 0x28,
    0xcd, 0x2f, 0x4a, 0xd5, 0x0b, 0xf4, 0x4f, 0xca, 0x4a, 0x4d, 0x2e, 0xb1, 0xcd, 0x2b, 0xcd, 0xc9,
    0x29, 0x28, 0x29, 0xd2, 0xe4, 0x0a, 0xc0, 0x6b, 0x94, 0x5e, 0x49, 0x65, 0x41, 0x2a, 0xd8, 0x3c,
    0x4d, 0x5d, 0x3b, 0x4c, 0xa5, 0x8e, 0x49, 0xc5, 0x25, 0x45, 0x89, 0xc9, 0x25, 0x50, 0xc5, 0x10,
    0x2a, 0x04, 0xa8, 0x85, 0x0b, 0x00, 0xcb, 0xb9, 0x3b, 0x11
};
#endif

PyTypeObject *init_QSplineSeries(PyObject *module)
{
    if (SbkPySide6_QtChartsTypeStructs[SBK_QSplineSeries_IDX].type != nullptr)
        return SbkPySide6_QtChartsTypeStructs[SBK_QSplineSeries_IDX].type;

    Shiboken::AutoDecRef Sbk_QSplineSeries_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QLineSeries_IDX]))));

    _Sbk_QSplineSeries_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSplineSeries",
        "QSplineSeries*",
        &Sbk_QSplineSeries_spec,
        &Shiboken::callCppDestructor< QSplineSeries >,
        Sbk_QSplineSeries_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSplineSeries_TypeF(); // references _Sbk_QSplineSeries_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSplineSeries_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSplineSeries_SignatureBytes, QSplineSeries_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSplineSeries_PropertyStrings);
    SbkPySide6_QtChartsTypeStructs[SBK_QSplineSeries_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSplineSeries_PythonToCpp_QSplineSeries_PTR,
        is_QSplineSeries_PythonToCpp_QSplineSeries_PTR_Convertible,
        QSplineSeries_PTR_CppToPython_QSplineSeries);

    Shiboken::Conversions::registerConverterName(converter, "QSplineSeries");
    Shiboken::Conversions::registerConverterName(converter, "QSplineSeries*");
    Shiboken::Conversions::registerConverterName(converter, "QSplineSeries&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSplineSeries).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSplineSeriesWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSplineSeries_TypeF(), &Sbk_QSplineSeries_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSplineSeries::staticMetaObject, sizeof(QSplineSeriesWrapper));

    return pyType;
}
