// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtconcurrent_python.h"

// main header
#include "qfuturewatcherqstring_wrapper.h"

// Wrappers providing overrides
#include "qfuturewatchervoid_wrapper.h"

// Argument includes
#include <QString>
#include <QtCore/qfuture.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QFutureWatcherQStringWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QFutureWatcherQStringWrapper::QFutureWatcherQStringWrapper(::QObject * _parent) : QFutureWatcherQString(_parent)
{
}

void QFutureWatcherQStringWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QFutureWatcherVoidWrapper::sbk_o_childEvent("QFutureWatcherQString", funcName, gil, pyOverride, event);
}

void QFutureWatcherQStringWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFutureWatcherBase::connectNotify(signal);
    }
    QFutureWatcherVoidWrapper::sbk_o_connectNotify("QFutureWatcherQString", funcName, gil, pyOverride, signal);
}

void QFutureWatcherQStringWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QFutureWatcherVoidWrapper::sbk_o_customEvent("QFutureWatcherQString", funcName, gil, pyOverride, event);
}

void QFutureWatcherQStringWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFutureWatcherBase::disconnectNotify(signal);
    }
    QFutureWatcherVoidWrapper::sbk_o_connectNotify("QFutureWatcherQString", funcName, gil, pyOverride, signal);
}

bool QFutureWatcherQStringWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFutureWatcherBase::event(event);
    }
    return QFutureWatcherVoidWrapper::sbk_o_event("QFutureWatcherQString", funcName, gil, pyOverride, event);
}

bool QFutureWatcherQStringWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QFutureWatcherVoidWrapper::sbk_o_eventFilter("QFutureWatcherQString", funcName, gil, pyOverride, watched, event);
}

void QFutureWatcherQStringWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QFutureWatcherVoidWrapper::sbk_o_timerEvent("QFutureWatcherQString", funcName, gil, pyOverride, event);
}

const QMetaObject *QFutureWatcherQStringWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QFutureWatcherQString::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QFutureWatcherQStringWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QFutureWatcherQString::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QFutureWatcherQStringWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QFutureWatcherQStringWrapper *>(this));
    return QFutureWatcherQString::qt_metacast(_clname);
}

QFutureWatcherQStringWrapper::~QFutureWatcherQStringWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFutureWatcherQString_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFutureWatcherQString >()))
        return -1;

    QFutureWatcherQStringWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QFutureWatcherQString", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QFutureWatcherQString::QFutureWatcherQString(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QFutureWatcherQString(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QFutureWatcherQString(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureWatcherQString_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureWatcherQString_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"_parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureWatcherQString_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QFutureWatcherQString(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QFutureWatcherQStringWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QFutureWatcherQStringWrapper(cppArg0);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QFutureWatcherQString >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureWatcherQString_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureWatcherQString_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QFutureWatcherQStringFunc_future(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureWatcherQString *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureWatcherQString_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // future()const
        QFuture<QString> cppResult = const_cast<const ::QFutureWatcherQString *>(cppSelf)->future();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFuture_QString_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFutureWatcherQStringFunc_setFuture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFutureWatcherQString *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureWatcherQString_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFutureWatcherQString::setFuture(QFuture<QString>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFuture_QString_IDX]), (pyArg)))) {
        overloadId = 0; // setFuture(QFuture<QString>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFuture", errInfo, SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureWatcherQString_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFuture<QString> cppArg0_local;
        ::QFuture<QString> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setFuture(QFuture<QString>)
            cppSelf->setFuture(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QFutureWatcherQString_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFutureWatcherQString_methods[] = {
    {"future", reinterpret_cast<PyCFunction>(Sbk_QFutureWatcherQStringFunc_future), METH_NOARGS, nullptr},
    {"setFuture", reinterpret_cast<PyCFunction>(Sbk_QFutureWatcherQStringFunc_setFuture), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QFutureWatcherQString_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QFutureWatcherQString *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureWatcherQString_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QFutureWatcherQStringWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QFutureWatcherQString_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFutureWatcherQString_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFutureWatcherQString_Type = nullptr;
static PyTypeObject *Sbk_QFutureWatcherQString_TypeF(void)
{
    return _Sbk_QFutureWatcherQString_Type;
}

static PyType_Slot Sbk_QFutureWatcherQString_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QFutureWatcherQString_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFutureWatcherQString_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFutureWatcherQString_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFutureWatcherQString_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFutureWatcherQString_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFutureWatcherQString_spec = {
    "2:PySide6.QtConcurrent.QFutureWatcherQString",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFutureWatcherQString_slots
};

} //extern "C"

static void *Sbk_QFutureWatcherQString_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< QFutureWatcherQString *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFutureWatcherQString_PythonToCpp_QFutureWatcherQString_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFutureWatcherQString_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFutureWatcherQString_PythonToCpp_QFutureWatcherQString_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFutureWatcherQString_TypeF()))
        return QFutureWatcherQString_PythonToCpp_QFutureWatcherQString_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFutureWatcherQString_PTR_CppToPython_QFutureWatcherQString(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<QFutureWatcherQString *>(const_cast<void *>(cppIn)), Sbk_QFutureWatcherQString_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFutureWatcherQString_SignatureStrings[] = {
    "PySide6.QtConcurrent.QFutureWatcherQString(self,_parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtConcurrent.QFutureWatcherQString.future(self)->PySide6.QtCore.QFuture[QString]",
    "PySide6.QtConcurrent.QFutureWatcherQString.setFuture(self,future:PySide6.QtCore.QFuture[QString])",
    nullptr}; // Sentinel
#else
static constexpr size_t QFutureWatcherQString_SignatureByteSize = 123;
static constexpr uint8_t QFutureWatcherQString_SignatureBytes[123] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce, 0xcf, 0x4b,
    0x2e, 0x2d, 0x2a, 0x4a, 0xcd, 0x2b, 0xd1, 0x0b, 0x74, 0x2b, 0x2d, 0x29, 0x2d, 0x4a, 0x0d, 0x4f,
    0x2c, 0x49, 0xce, 0x48, 0x2d, 0x0a, 0x0c, 0x2e, 0x29, 0xca, 0xcc, 0x4b, 0xd7, 0x28, 0x4e, 0xcd,
    0x49, 0xd3, 0x89, 0x2f, 0x48, 0x04, 0x29, 0xb1, 0x0a, 0x40, 0xd2, 0x57, 0x94, 0xaa, 0x17, 0xe8,
    0x9f, 0x94, 0x95, 0x9a, 0x5c, 0x62, 0x9b, 0x57, 0x9a, 0x93, 0x53, 0x50, 0x52, 0xa4, 0xc9, 0x15,
    0x40, 0xb4, 0xb9, 0x7a, 0x69, 0x60, 0x41, 0xb0, 0xf1, 0x9a, 0xba, 0x76, 0xe8, 0x06, 0x43, 0xb4,
    0x44, 0x43, 0x15, 0xc7, 0x92, 0x62, 0x70, 0x71, 0x6a, 0x89, 0x1b, 0xc2, 0x6c, 0x1d, 0x88, 0x3d,
    0x56, 0x04, 0x2c, 0xd0, 0xe4, 0x02, 0x00, 0x38, 0x1f, 0x66, 0x1f
};
#endif

PyTypeObject *init_QFutureWatcherQString(PyObject *module)
{
    if (SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureWatcherQString_IDX].type != nullptr)
        return SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureWatcherQString_IDX].type;

    Shiboken::AutoDecRef Sbk_QFutureWatcherQString_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QFutureWatcherQString_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFutureWatcherQString",
        "QFutureWatcherQString*",
        &Sbk_QFutureWatcherQString_spec,
        &Shiboken::callCppDestructor< QFutureWatcherQString >,
        Sbk_QFutureWatcherQString_Type_bases.object(),
        0);
    auto *pyType = Sbk_QFutureWatcherQString_TypeF(); // references _Sbk_QFutureWatcherQString_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFutureWatcherQString_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFutureWatcherQString_SignatureBytes, QFutureWatcherQString_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFutureWatcherQString_PropertyStrings);
    SbkPySide6_QtConcurrentTypeStructs[SBK_QFutureWatcherQString_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFutureWatcherQString_PythonToCpp_QFutureWatcherQString_PTR,
        is_QFutureWatcherQString_PythonToCpp_QFutureWatcherQString_PTR_Convertible,
        QFutureWatcherQString_PTR_CppToPython_QFutureWatcherQString);

    Shiboken::Conversions::registerConverterName(converter, "QFutureWatcherQString");
    Shiboken::Conversions::registerConverterName(converter, "QFutureWatcherQString*");
    Shiboken::Conversions::registerConverterName(converter, "QFutureWatcherQString&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFutureWatcherQString).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QFutureWatcherQStringWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QFutureWatcherQString_TypeF(), &Sbk_QFutureWatcherQString_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QFutureWatcherQString::staticMetaObject, sizeof(QFutureWatcherQStringWrapper));

    return pyType;
}
