// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QABSTRACTEVENTDISPATCHERWRAPPER_H
#define SBK_QABSTRACTEVENTDISPATCHERWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <qabstracteventdispatcher.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QAbstractEventDispatcherWrapper : public QAbstractEventDispatcher
{
public:
    QAbstractEventDispatcherWrapper(::QObject * parent = nullptr);
    QAbstractEventDispatcherWrapper(const QAbstractEventDispatcherWrapper &) = delete;
    QAbstractEventDispatcherWrapper& operator=(const QAbstractEventDispatcherWrapper &) = delete;
    QAbstractEventDispatcherWrapper(QAbstractEventDispatcherWrapper &&) = delete;
    QAbstractEventDispatcherWrapper& operator=(QAbstractEventDispatcherWrapper &&) = delete;
    ~QAbstractEventDispatcherWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void closingDown() override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    void interrupt() override;
    bool processEvents(::QFlags<QEventLoop::ProcessEventsFlag> flags) override;
    static bool sbk_o_processEvents(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<QEventLoop::ProcessEventsFlag> flags);
    void registerSocketNotifier(::QSocketNotifier * notifier) override;
    static void sbk_o_registerSocketNotifier(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSocketNotifier * notifier);
    void registerTimer(int timerId, qint64 interval, ::Qt::TimerType timerType, ::QObject * object) override;
    static void sbk_o_registerTimer(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int timerId, qint64 interval, ::Qt::TimerType timerType, ::QObject * object);
    // Inherited overloads, because the using keyword sux
    int registerTimer(qint64 interval, ::Qt::TimerType timerType, ::QObject * object) { return QAbstractEventDispatcher::registerTimer(interval, Qt::TimerType(timerType), object); }

    ::QList<QAbstractEventDispatcher::TimerInfo> registeredTimers(::QObject * object) const override;
    static ::QList<QAbstractEventDispatcher::TimerInfo> sbk_o_registeredTimers(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * object);
    int remainingTime(int timerId) override;
    static int sbk_o_remainingTime(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int timerId);
    void startingUp() override;
    void timerEvent(::QTimerEvent * event) override;
    void unregisterSocketNotifier(::QSocketNotifier * notifier) override;
    bool unregisterTimer(int timerId) override;
    static bool sbk_o_unregisterTimer(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int timerId);
    // Inherited overloads, because the using keyword sux
    bool unregisterTimer(::Qt::TimerId timerId) { return QAbstractEventDispatcher::unregisterTimer(Qt::TimerId(timerId)); }

    bool unregisterTimers(::QObject * object) override;
    static bool sbk_o_unregisterTimers(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * object);
    void wakeUp() override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[19] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QABSTRACTEVENTDISPATCHERWRAPPER_H
