// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qfiledevice_wrapper.h"

// Wrappers providing overrides
#include "qobject_wrapper.h"
#include "qprocess_wrapper.h"
#include "qtranslator_wrapper.h"
#include "qiodevice_wrapper.h"

// Argument includes
#include <QString>
#include <qcoreevent.h>
#include <qdatetime.h>
#include <qfiledevice.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QFileDeviceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QFileDeviceWrapper::QFileDeviceWrapper()
{
}

QFileDeviceWrapper::QFileDeviceWrapper(::QObject * parent) : QFileDevice(parent)
{
}

bool QFileDeviceWrapper::atEnd() const
{
    static const char *funcName = "atEnd";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::atEnd();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QFileDevice", funcName, gil, pyOverride);
}

qint64 QFileDeviceWrapper::bytesAvailable() const
{
    static const char *funcName = "bytesAvailable";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::bytesAvailable();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QFileDevice", funcName, gil, pyOverride);
}

qint64 QFileDeviceWrapper::bytesToWrite() const
{
    static const char *funcName = "bytesToWrite";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::bytesToWrite();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QFileDevice", funcName, gil, pyOverride);
}

bool QFileDeviceWrapper::canReadLine() const
{
    static const char *funcName = "canReadLine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::canReadLine();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QFileDevice", funcName, gil, pyOverride);
}

void QFileDeviceWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QTranslatorWrapper::sbk_o_childEvent("QFileDevice", funcName, gil, pyOverride, event);
}

void QFileDeviceWrapper::close()
{
    static const char *funcName = "close";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::close();
    }
    QProcessWrapper::sbk_o_close("QFileDevice", funcName, gil, pyOverride);
}

void QFileDeviceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QFileDevice", funcName, gil, pyOverride, signal);
}

void QFileDeviceWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QTranslatorWrapper::sbk_o_customEvent("QFileDevice", funcName, gil, pyOverride, event);
}

void QFileDeviceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QFileDevice", funcName, gil, pyOverride, signal);
}

bool QFileDeviceWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QTranslatorWrapper::sbk_o_event("QFileDevice", funcName, gil, pyOverride, event);
}

bool QFileDeviceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QTranslatorWrapper::sbk_o_eventFilter("QFileDevice", funcName, gil, pyOverride, watched, event);
}

::QString QFileDeviceWrapper::fileName() const
{
    static const char *funcName = "fileName";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::fileName();
    }
    return sbk_o_fileName("QFileDevice", funcName, gil, pyOverride);
}

::QString QFileDeviceWrapper::sbk_o_fileName(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QString();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QString", Py_TYPE(pyResult)->tp_name);
        return ::QString();
    }
    ::QString cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QFileDeviceWrapper::isSequential() const
{
    static const char *funcName = "isSequential";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::isSequential();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QFileDevice", funcName, gil, pyOverride);
}

bool QFileDeviceWrapper::open(::QFlags<QIODeviceBase::OpenModeFlag> mode)
{
    static const char *funcName = "open";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::open(mode);
    }
    return QProcessWrapper::sbk_o_open("QFileDevice", funcName, gil, pyOverride, mode);
}

::QFlags<QFileDevice::Permission> QFileDeviceWrapper::permissions() const
{
    static const char *funcName = "permissions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::permissions();
    }
    return sbk_o_permissions("QFileDevice", funcName, gil, pyOverride);
}

::QFlags<QFileDevice::Permission> QFileDeviceWrapper::sbk_o_permissions(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return QFlags<QFileDevice::Permission>(0);
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_Permission_IDX])))->flagsConverter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QFlags<QFileDevice::Permission> >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QFlags<QFileDevice::Permission>(0);
    }
    ::QFlags<QFileDevice::Permission> cppResult = QFlags<QFileDevice::Permission>(0);
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QFileDeviceWrapper::pos() const
{
    static const char *funcName = "pos";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::pos();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QFileDevice", funcName, gil, pyOverride);
}

qint64 QFileDeviceWrapper::readData(char * data, qint64 maxlen)
{
    static const char *funcName = "readData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::readData(data, maxlen);
    }
    return QProcessWrapper::sbk_o_readData("QFileDevice", funcName, gil, pyOverride, data, maxlen);
}

qint64 QFileDeviceWrapper::readLineData(char * data, qint64 maxlen)
{
    static const char *funcName = "readLineData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::readLineData(data, maxlen);
    }
    return QProcessWrapper::sbk_o_readLineData("QFileDevice", funcName, gil, pyOverride, data, maxlen);
}

bool QFileDeviceWrapper::reset()
{
    static const char *funcName = "reset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::reset();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QFileDevice", funcName, gil, pyOverride);
}

bool QFileDeviceWrapper::resize(qint64 sz)
{
    static const char *funcName = "resize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::resize(sz);
    }
    return sbk_o_resize("QFileDevice", funcName, gil, pyOverride, sz);
}

bool QFileDeviceWrapper::sbk_o_resize(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, qint64 sz)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &sz)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        sz
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QFileDeviceWrapper::seek(qint64 offset)
{
    static const char *funcName = "seek";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::seek(offset);
    }
    return QProcessWrapper::sbk_o_seek("QFileDevice", funcName, gil, pyOverride, offset);
}

bool QFileDeviceWrapper::setPermissions(::QFlags<QFileDevice::Permission> permissionSpec)
{
    static const char *funcName = "setPermissions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::setPermissions(permissionSpec);
    }
    return sbk_o_setPermissions("QFileDevice", funcName, gil, pyOverride, permissionSpec);
}

bool QFileDeviceWrapper::sbk_o_setPermissions(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<QFileDevice::Permission> permissionSpec)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_Permission_IDX])))->flagsConverter, &permissionSpec)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_Permission_IDX])))->flagsConverter, &permissionSpec)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QFileDeviceWrapper::size() const
{
    static const char *funcName = "size";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::size();
    }
    return QIODeviceWrapper::sbk_o_bytesAvailable("QFileDevice", funcName, gil, pyOverride);
}

qint64 QFileDeviceWrapper::skipData(qint64 maxSize)
{
    static const char *funcName = "skipData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::skipData(maxSize);
    }
    return QIODeviceWrapper::sbk_o_skipData("QFileDevice", funcName, gil, pyOverride, maxSize);
}

void QFileDeviceWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QTranslatorWrapper::sbk_o_timerEvent("QFileDevice", funcName, gil, pyOverride, event);
}

bool QFileDeviceWrapper::waitForBytesWritten(int msecs)
{
    static const char *funcName = "waitForBytesWritten";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::waitForBytesWritten(msecs);
    }
    return sbk_o_waitForBytesWritten("QFileDevice", funcName, gil, pyOverride, msecs);
}

bool QFileDeviceWrapper::sbk_o_waitForBytesWritten(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int msecs)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &msecs)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        msecs
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QFileDeviceWrapper::waitForReadyRead(int msecs)
{
    static const char *funcName = "waitForReadyRead";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::waitForReadyRead(msecs);
    }
    return QProcessWrapper::sbk_o_waitForReadyRead("QFileDevice", funcName, gil, pyOverride, msecs);
}

qint64 QFileDeviceWrapper::writeData(const char * data, qint64 len)
{
    static const char *funcName = "writeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFileDevice::writeData(data, len);
    }
    return QIODeviceWrapper::sbk_o_writeData("QFileDevice", funcName, gil, pyOverride, data, len);
}

const QMetaObject *QFileDeviceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QFileDevice::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QFileDeviceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QFileDevice::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QFileDeviceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QFileDeviceWrapper *>(this));
    return QFileDevice::qt_metacast(_clname);
}

QFileDeviceWrapper::~QFileDeviceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFileDevice_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFileDevice >()))
        return -1;

    QFileDeviceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QFileDevice", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QFileDevice::QFileDevice()
    // 1: QFileDevice::QFileDevice(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QFileDevice()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QFileDevice(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QFileDevice()
        {

            // QFileDevice()
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QFileDeviceWrapper();
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QFileDeviceWrapper();
            }

            break;
        }
        case 1: // QFileDevice(QObject *parent)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFileDevice(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QFileDeviceWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QFileDeviceWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QFileDevice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QFileDeviceFunc_atEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // atEnd()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QFileDevice *>(cppSelf)->::QFileDevice::atEnd()
            : const_cast<const ::QFileDevice *>(cppSelf)->atEnd();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QFileDevice::close()
            : cppSelf->close();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QFileDeviceFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QFileDevice::FileError cppResult = const_cast<const ::QFileDevice *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_FileError_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileName()const
        QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QFileDevice *>(cppSelf)->::QFileDevice::fileName()
            : const_cast<const ::QFileDevice *>(cppSelf)->fileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_fileTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDevice::fileTime(QFileDevice::FileTime)const->QDateTime
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_FileTime_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // fileTime(QFileDevice::FileTime)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fileTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);

    // Call function/method
    {
        ::QFileDevice::FileTime cppArg0{QFileDevice::FileAccessTime};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fileTime(QFileDevice::FileTime)const
            QDateTime cppResult = const_cast<const ::QFileDevice *>(cppSelf)->fileTime(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_flush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flush()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = cppSelf->flush();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_handle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // handle()const
        int cppResult = const_cast<const ::QFileDevice *>(cppSelf)->handle();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_isSequential(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSequential()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QFileDevice *>(cppSelf)->::QFileDevice::isSequential()
            : const_cast<const ::QFileDevice *>(cppSelf)->isSequential();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_map(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "map", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:map", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileDevice::map(qint64,qint64,QFlags<QFileDevice::MemoryMapFlag>=)->PyObject
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // map(qint64,qint64,QFlags<QFileDevice::MemoryMapFlag>)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_MemoryMapFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
            overloadId = 0; // map(qint64,qint64,QFlags<QFileDevice::MemoryMapFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "map", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"flags", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_MemoryMapFlag_IDX])))->flagsConverter, (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "map", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);
            }
        }
        qint64 cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qint64 cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFlags<QFileDevice::MemoryMapFlag> cppArg2(QFileDevice::MemoryMapFlag::NoOptions);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // map(qint64,qint64,QFlags<QFileDevice::MemoryMapFlag>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qfiledevice-map)]
            pyResult = Shiboken::Buffer::newObject(cppSelf->map(cppArg0, cppArg1, cppArg2), cppArg1, Shiboken::Buffer::ReadWrite);
            // END of custom code block [file: ../glue/qtcore.cpp (qfiledevice-map)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_permissions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // permissions()const
        QFlags<QFileDevice::Permission> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QFileDevice *>(cppSelf)->::QFileDevice::permissions()
            : const_cast<const ::QFileDevice *>(cppSelf)->permissions();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_Permission_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_pos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pos()const
        qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QFileDevice *>(cppSelf)->::QFileDevice::pos()
            : const_cast<const ::QFileDevice *>(cppSelf)->pos();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_readData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QIODevice::readData(char*,qint64)->PyObject
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // readData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "readData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readData(char*,qint64)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            QByteArray ba(1 + qsizetype(cppArg0), char(0));
            Py_BEGIN_ALLOW_THREADS
            (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QFileDevice::readData(ba.data(), qint64(cppArg0)) : cppSelf->readData(ba.data(), qint64(cppArg0)));
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::String::fromCString(ba.constData());
            // END of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_readLineData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QIODevice::readLineData(char*,qint64)->PyObject
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // readLineData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "readLineData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readLineData(char*,qint64)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            QByteArray ba(1 + qsizetype(cppArg0), char(0));
            Py_BEGIN_ALLOW_THREADS
            (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QFileDevice::readLineData(ba.data(), qint64(cppArg0)) : cppSelf->readLineData(ba.data(), qint64(cppArg0)));
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::String::fromCString(ba.constData());
            // END of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_resize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDevice::resize(qint64)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // resize(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resize", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resize(qint64)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QFileDevice::resize(cppArg0)
                : cppSelf->resize(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_seek(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QIODevice::seek(qint64)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // seek(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "seek", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // seek(qint64)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QFileDevice::seek(cppArg0)
                : cppSelf->seek(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_setFileTime(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setFileTime", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileDevice::setFileTime(QDateTime,QFileDevice::FileTime)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_FileTime_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // setFileTime(QDateTime,QFileDevice::FileTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFileTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QFileDevice::FileTime cppArg1{QFileDevice::FileAccessTime};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileTime(QDateTime,QFileDevice::FileTime)
            bool cppResult = cppSelf->setFileTime(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_setPermissions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDevice::setPermissions(QFlags<QFileDevice::Permission>)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_Permission_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setPermissions(QFlags<QFileDevice::Permission>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPermissions", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);

    // Call function/method
    {
        ::QFlags<QFileDevice::Permission> cppArg0 = QFlags<QFileDevice::Permission>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPermissions(QFlags<QFileDevice::Permission>)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QFileDevice::setPermissions(cppArg0)
                : cppSelf->setPermissions(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QFileDevice *>(cppSelf)->::QFileDevice::size()
            : const_cast<const ::QFileDevice *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_unmap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDevice::unmap(PyBuffer)->bool
    if (Shiboken::Buffer::checkType(pyArg)) {
        overloadId = 0; // unmap(uchar*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "unmap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // unmap(uchar*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qfiledevice-unmap)]
            uchar *ptr = reinterpret_cast<uchar *>(Shiboken::Buffer::getPointer(pyArg));
            bool cppResult = cppSelf->unmap(ptr);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            // END of custom code block [file: ../glue/qtcore.cpp (qfiledevice-unmap)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileDeviceFunc_unsetError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unsetError()
        cppSelf->unsetError();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QFileDeviceFunc_writeData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QIODevice::writeData(const char*,qint64)->qint64
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
        overloadId = 0; // writeData(const char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qint64 cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeData(const char*,qint64)
            qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QFileDevice::writeData(cppArg0, cppArg1)
                : cppSelf->writeData(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QFileDevice_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QFileDevice_EnumFlagInfo[] = {
    "FileError:Enum",
    "FileHandleFlag:Flag:FileHandleFlags",
    "FileTime:Enum",
    "MemoryMapFlag:Flag:MemoryMapFlags",
    "Permission:Flag:Permissions",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFileDevice_methods[] = {
    {"atEnd", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_atEnd), METH_NOARGS, nullptr},
    {"close", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_close), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_error), METH_NOARGS, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_fileName), METH_NOARGS, nullptr},
    {"fileTime", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_fileTime), METH_O, nullptr},
    {"flush", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_flush), METH_NOARGS, nullptr},
    {"handle", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_handle), METH_NOARGS, nullptr},
    {"isSequential", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_isSequential), METH_NOARGS, nullptr},
    {"map", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_map), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"permissions", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_permissions), METH_NOARGS, nullptr},
    {"pos", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_pos), METH_NOARGS, nullptr},
    {"readData", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_readData), METH_O, nullptr},
    {"readLineData", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_readLineData), METH_O, nullptr},
    {"resize", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_resize), METH_O, nullptr},
    {"seek", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_seek), METH_O, nullptr},
    {"setFileTime", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_setFileTime), METH_VARARGS, nullptr},
    {"setPermissions", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_setPermissions), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_size), METH_NOARGS, nullptr},
    {"unmap", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_unmap), METH_O, nullptr},
    {"unsetError", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_unsetError), METH_NOARGS, nullptr},
    {"writeData", reinterpret_cast<PyCFunction>(Sbk_QFileDeviceFunc_writeData), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QFileDevice_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QFileDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QFileDeviceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QFileDevice_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFileDevice_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QFileDeviceSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QFileDevice *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]))
        return static_cast< ::QIODevice *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_IDX]))
        return static_cast< ::QIODeviceBase *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFileDevice_Type = nullptr;
static PyTypeObject *Sbk_QFileDevice_TypeF(void)
{
    return _Sbk_QFileDevice_Type;
}

static PyType_Slot Sbk_QFileDevice_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QFileDevice_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFileDevice_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFileDevice_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFileDevice_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFileDevice_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFileDevice_spec = {
    "2:PySide6.QtCore.QFileDevice",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFileDevice_slots
};

} //extern "C"

static void *Sbk_QFileDevice_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QFileDevice *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QFileDevice_FileError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFileDevice::FileError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFileDevice::FileError *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFileDevice_FileError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_FileError_IDX])))
        return Enum_PythonToCpp_QFileDevice_FileError;
    return {};
}

static PyObject *QFileDevice_FileError_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFileDevice::FileError>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFileDevice::FileError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_FileError_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QFileDevice_FileTime(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFileDevice::FileTime>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFileDevice::FileTime *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFileDevice_FileTime_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_FileTime_IDX])))
        return Enum_PythonToCpp_QFileDevice_FileTime;
    return {};
}

static PyObject *QFileDevice_FileTime_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFileDevice::FileTime>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFileDevice::FileTime *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_FileTime_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QFileDevice_Permission(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFileDevice::Permission>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFileDevice::Permission *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFileDevice_Permission_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_Permission_IDX])))
        return Enum_PythonToCpp_QFileDevice_Permission;
    return {};
}

static PyObject *QFileDevice_Permission_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFileDevice::Permission>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFileDevice::Permission *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_Permission_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QFileDevice_Permission(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QFileDevice::Permission>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QFileDevice::Permission> *>(cppOut) = value;

}

static PyObject *QFileDevice_Permission_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QFileDevice::Permission> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_Permission_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QFileDevice_FileHandleFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFileDevice::FileHandleFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFileDevice::FileHandleFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFileDevice_FileHandleFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_FileHandleFlag_IDX])))
        return Enum_PythonToCpp_QFileDevice_FileHandleFlag;
    return {};
}

static PyObject *QFileDevice_FileHandleFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFileDevice::FileHandleFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFileDevice::FileHandleFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_FileHandleFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QFileDevice_FileHandleFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QFileDevice::FileHandleFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QFileDevice::FileHandleFlag> *>(cppOut) = value;

}

static PyObject *QFileDevice_FileHandleFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QFileDevice::FileHandleFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_FileHandleFlag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QFileDevice_MemoryMapFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFileDevice::MemoryMapFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFileDevice::MemoryMapFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFileDevice_MemoryMapFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_MemoryMapFlag_IDX])))
        return Enum_PythonToCpp_QFileDevice_MemoryMapFlag;
    return {};
}

static PyObject *QFileDevice_MemoryMapFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFileDevice::MemoryMapFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFileDevice::MemoryMapFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_MemoryMapFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QFileDevice_MemoryMapFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QFileDevice::MemoryMapFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QFileDevice::MemoryMapFlag> *>(cppOut) = value;

}

static PyObject *QFileDevice_MemoryMapFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QFileDevice::MemoryMapFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_MemoryMapFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFileDevice_PythonToCpp_QFileDevice_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFileDevice_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFileDevice_PythonToCpp_QFileDevice_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFileDevice_TypeF()))
        return QFileDevice_PythonToCpp_QFileDevice_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFileDevice_PTR_CppToPython_QFileDevice(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QFileDevice *>(const_cast<void *>(cppIn)), Sbk_QFileDevice_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFileDevice_SignatureStrings[] = {
    "1:PySide6.QtCore.QFileDevice(self)",
    "0:PySide6.QtCore.QFileDevice(self,parent:PySide6.QtCore.QObject)",
    "PySide6.QtCore.QFileDevice.atEnd(self)->bool",
    "PySide6.QtCore.QFileDevice.close(self)",
    "PySide6.QtCore.QFileDevice.error(self)->PySide6.QtCore.QFileDevice.FileError",
    "PySide6.QtCore.QFileDevice.fileName(self)->QString",
    "PySide6.QtCore.QFileDevice.fileTime(self,time:PySide6.QtCore.QFileDevice.FileTime)->PySide6.QtCore.QDateTime",
    "PySide6.QtCore.QFileDevice.flush(self)->bool",
    "PySide6.QtCore.QFileDevice.handle(self)->int",
    "PySide6.QtCore.QFileDevice.isSequential(self)->bool",
    "PySide6.QtCore.QFileDevice.map(self,offset:qint64,size:qint64,flags:PySide6.QtCore.QFileDevice.MemoryMapFlag=QFileDevice.MemoryMapFlag.NoOptions)->PyObject",
    "PySide6.QtCore.QFileDevice.permissions(self)->PySide6.QtCore.QFileDevice.Permission",
    "PySide6.QtCore.QFileDevice.pos(self)->qint64",
    "PySide6.QtCore.QFileDevice.readData(self,maxlen:qint64)->PyObject",
    "PySide6.QtCore.QFileDevice.readLineData(self,maxlen:qint64)->PyObject",
    "PySide6.QtCore.QFileDevice.resize(self,sz:qint64)->bool",
    "PySide6.QtCore.QFileDevice.seek(self,offset:qint64)->bool",
    "PySide6.QtCore.QFileDevice.setFileTime(self,newDate:PySide6.QtCore.QDateTime,fileTime:PySide6.QtCore.QFileDevice.FileTime)->bool",
    "PySide6.QtCore.QFileDevice.setPermissions(self,permissionSpec:PySide6.QtCore.QFileDevice.Permission)->bool",
    "PySide6.QtCore.QFileDevice.size(self)->qint64",
    "PySide6.QtCore.QFileDevice.unmap(self,address:PyBuffer)->bool",
    "PySide6.QtCore.QFileDevice.unsetError(self)",
    "PySide6.QtCore.QFileDevice.writeData(self,data:char*,len:qint64)->qint64",
    nullptr}; // Sentinel
#else
static constexpr size_t QFileDevice_SignatureByteSize = 372;
static constexpr uint8_t QFileDevice_SignatureBytes[372] = {
    0x78, 0xda, 0xa5, 0x54, 0x5d, 0x4f, 0xc2, 0x30, 0x14, 0x7d, 0xe7, 0x97, 0x88, 0x99, 0x8b, 0x26,
    0x86, 0x87, 0x25, 0xfa, 0xa0, 0xc0, 0x93, 0x7c, 0x65, 0xfe, 0x81, 0xcb, 0x7a, 0xcb, 0xaa, 0x5d,
    0x3b, 0xda, 0x4e, 0x84, 0x5f, 0x6f, 0xcb, 0xd8, 0x10, 0x84, 0xae, 0x89, 0x6f, 0x37, 0xe9, 0x39,
    0xf7, 0xeb, 0x9c, 0xdb, 0x87, 0x64, 0xbe, 0x4d, 0x19, 0xc1, 0x41, 0xbc, 0x30, 0xaf, 0x52, 0x61,
    0xbc, 0x18, 0x33, 0x8e, 0x43, 0xfc, 0x62, 0x19, 0xde, 0x68, 0xe4, 0xb4, 0xdf, 0xbb, 0xef, 0x82,
    0x44, 0x25, 0x28, 0x14, 0xe6, 0x0f, 0x6c, 0xb6, 0xfc, 0xc0, 0xcc, 0xf4, 0x7b, 0xd7, 0xe9, 0x31,
    0x98, 0x91, 0x20, 0x75, 0x9d, 0xbb, 0xe7, 0xa5, 0x94, 0xdc, 0x07, 0xce, 0xb8, 0xd4, 0x4d, 0x53,
    0x1e, 0x18, 0x2a, 0x25, 0x55, 0x93, 0xd3, 0x83, 0x73, 0xe1, 0xc8, 0x61, 0x7d, 0xc9, 0xa8, 0x0d,
    0xa7, 0x50, 0x60, 0x93, 0x6f, 0x91, 0x1a, 0xc5, 0xc4, 0xaa, 0x8b, 0xf2, 0xce, 0x0e, 0x94, 0xc8,
    0xd8, 0x28, 0xe9, 0xe8, 0xc2, 0xa1, 0x2f, 0xf4, 0x3a, 0x04, 0xb3, 0x7f, 0xf2, 0x16, 0xe3, 0x95,
    0xce, 0x43, 0x17, 0x98, 0x83, 0x20, 0xbc, 0x1d, 0x85, 0x09, 0xe3, 0x03, 0x33, 0x9d, 0xe2, 0xba,
    0xb2, 0xba, 0x32, 0xe0, 0xa1, 0x05, 0x0a, 0x28, 0xeb, 0xa9, 0x25, 0xa5, 0x1a, 0x4d, 0xb2, 0xb6,
    0x35, 0x06, 0x8f, 0x91, 0x66, 0x3b, 0x6c, 0x62, 0xca, 0x61, 0xa5, 0x7d, 0x0b, 0x99, 0x60, 0x21,
    0xd5, 0x76, 0x02, 0xe5, 0xd8, 0x22, 0x9f, 0xae, 0xbe, 0xc4, 0x53, 0x39, 0x2b, 0x0d, 0x93, 0x42,
    0xef, 0x37, 0x57, 0x7b, 0xcd, 0xd7, 0x5b, 0x89, 0xaa, 0x60, 0x5a, 0x3b, 0x46, 0x80, 0x39, 0xe6,
    0x2d, 0xda, 0x9b, 0x53, 0xb6, 0xb9, 0xea, 0xf1, 0x7c, 0x60, 0x85, 0x40, 0xac, 0xa4, 0x50, 0x6f,
    0xa8, 0x80, 0x6f, 0x8e, 0xe2, 0xb0, 0x95, 0xc0, 0x11, 0x5c, 0x86, 0x37, 0x26, 0xf0, 0xbf, 0x59,
    0x9c, 0x1e, 0x35, 0x5f, 0xef, 0x8e, 0xdc, 0x2e, 0x71, 0x35, 0xe2, 0xe7, 0x05, 0x75, 0x83, 0x98,
    0x66, 0x7c, 0x72, 0x14, 0x02, 0x37, 0xce, 0xdc, 0xc9, 0x35, 0xc7, 0x47, 0xcd, 0x0d, 0x05, 0x5e,
    0x4e, 0x40, 0x03, 0xf3, 0x33, 0xf9, 0xa3, 0xa3, 0x1f, 0xd2, 0x12, 0xb3, 0x24, 0xc8, 0x0b, 0x21,
    0xa5, 0x9a, 0xdd, 0x06, 0x79, 0xa2, 0x12, 0xed, 0xc9, 0x00, 0x21, 0x56, 0x19, 0x77, 0x1a, 0x2f,
    0x15, 0xa5, 0xa8, 0x02, 0x6a, 0x55, 0xc2, 0x0e, 0x36, 0x3a, 0x7e, 0x77, 0x3e, 0xec, 0x46, 0x31,
    0xf3, 0xcb, 0x38, 0xc4, 0x46, 0x49, 0x96, 0x83, 0xba, 0x8d, 0x4e, 0x0c, 0x74, 0x68, 0xf9, 0x07,
    0x79, 0xb2, 0x26, 0x8e
};
#endif

PyTypeObject *init_QFileDevice(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX].type;

    Shiboken::AutoDecRef Sbk_QFileDevice_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]))));

    _Sbk_QFileDevice_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFileDevice",
        "QFileDevice*",
        &Sbk_QFileDevice_spec,
        &Shiboken::callCppDestructor< QFileDevice >,
        Sbk_QFileDevice_Type_bases.object(),
        0);
    auto *pyType = Sbk_QFileDevice_TypeF(); // references _Sbk_QFileDevice_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFileDevice_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFileDevice_SignatureBytes, QFileDevice_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFileDevice_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFileDevice_PythonToCpp_QFileDevice_PTR,
        is_QFileDevice_PythonToCpp_QFileDevice_PTR_Convertible,
        QFileDevice_PTR_CppToPython_QFileDevice);

    Shiboken::Conversions::registerConverterName(converter, "QFileDevice");
    Shiboken::Conversions::registerConverterName(converter, "QFileDevice*");
    Shiboken::Conversions::registerConverterName(converter, "QFileDevice&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFileDevice).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QFileDeviceWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QFileDevice_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QFileDevice_TypeF(), &Sbk_QFileDeviceSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QFileDevice_TypeF(), &Sbk_QFileDevice_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QFileDevice_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'FileError'.
    const char *FileError_Initializer[] = {
        "NoError",
        "ReadError",
        "WriteError",
        "FatalError",
        "ResourceError",
        "OpenError",
        "AbortError",
        "TimeOutError",
        "UnspecifiedError",
        "RemoveError",
        "RenameError",
        "PositionError",
        "ResizeError",
        "PermissionsError",
        "CopyError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FileError_InitializerValues[] = {
        uint8_t(QFileDevice::FileError::NoError),          //  0x00  0
        uint8_t(QFileDevice::FileError::ReadError),        //  0x01  1
        uint8_t(QFileDevice::FileError::WriteError),       //  0x02  2
        uint8_t(QFileDevice::FileError::FatalError),       //  0x03  3
        uint8_t(QFileDevice::FileError::ResourceError),    //  0x04  4
        uint8_t(QFileDevice::FileError::OpenError),        //  0x05  5
        uint8_t(QFileDevice::FileError::AbortError),       //  0x06  6
        uint8_t(QFileDevice::FileError::TimeOutError),     //  0x07  7
        uint8_t(QFileDevice::FileError::UnspecifiedError), //  0x08  8
        uint8_t(QFileDevice::FileError::RemoveError),      //  0x09  9
        uint8_t(QFileDevice::FileError::RenameError),      //  0x0a  10
        uint8_t(QFileDevice::FileError::PositionError),    //  0x0b  11
        uint8_t(QFileDevice::FileError::ResizeError),      //  0x0c  12
        uint8_t(QFileDevice::FileError::PermissionsError), //  0x0d  13
        uint8_t(QFileDevice::FileError::CopyError)         //  0x0e  14
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFileDevice_TypeF(),
        "2:PySide6.QtCore.QFileDevice.FileError",
        FileError_Initializer, FileError_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_FileError_IDX].type = EType;
    // Register converter for enum 'QFileDevice::FileError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFileDevice_FileError_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFileDevice_FileError,
            is_Enum_PythonToCpp_QFileDevice_FileError_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFileDevice::FileError");
        Shiboken::Conversions::registerConverterAlias(converter, "FileError");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FileError' enum.

    // Initialization of enum 'FileTime'.
    const char *FileTime_Initializer[] = {
        "FileAccessTime",
        "FileBirthTime",
        "FileMetadataChangeTime",
        "FileModificationTime",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FileTime_InitializerValues[] = {
        uint8_t(QFileDevice::FileTime::FileAccessTime),         //  0x00  0
        uint8_t(QFileDevice::FileTime::FileBirthTime),          //  0x01  1
        uint8_t(QFileDevice::FileTime::FileMetadataChangeTime), //  0x02  2
        uint8_t(QFileDevice::FileTime::FileModificationTime)    //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFileDevice_TypeF(),
        "2:PySide6.QtCore.QFileDevice.FileTime",
        FileTime_Initializer, FileTime_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_FileTime_IDX].type = EType;
    // Register converter for enum 'QFileDevice::FileTime'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFileDevice_FileTime_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFileDevice_FileTime,
            is_Enum_PythonToCpp_QFileDevice_FileTime_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFileDevice::FileTime");
        Shiboken::Conversions::registerConverterAlias(converter, "FileTime");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FileTime' enum.

    // Initialization of enum 'Permission'.
    const char *Permission_Initializer[] = {
        "ReadOwner",
        "WriteOwner",
        "ExeOwner",
        "ReadUser",
        "WriteUser",
        "ExeUser",
        "ReadGroup",
        "WriteGroup",
        "ExeGroup",
        "ReadOther",
        "WriteOther",
        "ExeOther",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Permission_InitializerValues[] = {
        uint16_t(QFileDevice::Permission::ReadOwner),  //  0x4000  16384
        uint16_t(QFileDevice::Permission::WriteOwner), //  0x2000  8192
        uint16_t(QFileDevice::Permission::ExeOwner),   //  0x1000  4096
        uint16_t(QFileDevice::Permission::ReadUser),   //  0x0400  1024
        uint16_t(QFileDevice::Permission::WriteUser),  //  0x0200  512
        uint16_t(QFileDevice::Permission::ExeUser),    //  0x0100  256
        uint16_t(QFileDevice::Permission::ReadGroup),  //  0x0040  64
        uint16_t(QFileDevice::Permission::WriteGroup), //  0x0020  32
        uint16_t(QFileDevice::Permission::ExeGroup),   //  0x0010  16
        uint16_t(QFileDevice::Permission::ReadOther),  //  0x0004  4
        uint16_t(QFileDevice::Permission::WriteOther), //  0x0002  2
        uint16_t(QFileDevice::Permission::ExeOther)    //  0x0001  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFileDevice_TypeF(),
        "2:PySide6.QtCore.QFileDevice.Permission",
        Permission_Initializer, Permission_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_Permission_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_Permission_IDX].type =
        EType;
    // Register converter for enum 'QFileDevice::Permission'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFileDevice_Permission_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFileDevice_Permission,
            is_Enum_PythonToCpp_QFileDevice_Permission_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFileDevice::Permission");
        Shiboken::Conversions::registerConverterAlias(converter, "Permission");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QFileDevice_Permission_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QFileDevice_Permission,
            is_Enum_PythonToCpp_QFileDevice_Permission_Convertible);
        // Register converter for flag 'QFlags<QFileDevice::Permission>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QFileDevice::Permission>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFileDevice::Permissions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Permission' enum/flags.

    // Initialization of enum 'FileHandleFlag'.
    const char *FileHandleFlag_Initializer[] = {
        "AutoCloseHandle",
        "DontCloseHandle",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FileHandleFlag_InitializerValues[] = {
        uint8_t(QFileDevice::FileHandleFlag::AutoCloseHandle), //  0x01  1
        uint8_t(QFileDevice::FileHandleFlag::DontCloseHandle)  //  0x00  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFileDevice_TypeF(),
        "2:PySide6.QtCore.QFileDevice.FileHandleFlag",
        FileHandleFlag_Initializer, FileHandleFlag_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_FileHandleFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_FileHandleFlag_IDX].type =
        EType;
    // Register converter for enum 'QFileDevice::FileHandleFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFileDevice_FileHandleFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFileDevice_FileHandleFlag,
            is_Enum_PythonToCpp_QFileDevice_FileHandleFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFileDevice::FileHandleFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "FileHandleFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QFileDevice_FileHandleFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QFileDevice_FileHandleFlag,
            is_Enum_PythonToCpp_QFileDevice_FileHandleFlag_Convertible);
        // Register converter for flag 'QFlags<QFileDevice::FileHandleFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QFileDevice::FileHandleFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFileDevice::FileHandleFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'FileHandleFlag' enum/flags.

    // Initialization of enum 'MemoryMapFlag'.
    const char *MemoryMapFlag_Initializer[] = {
        "NoOptions",
        "MapPrivateOption",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MemoryMapFlag_InitializerValues[] = {
        uint8_t(QFileDevice::MemoryMapFlag::NoOptions),       //  0x00  0
        uint8_t(QFileDevice::MemoryMapFlag::MapPrivateOption) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFileDevice_TypeF(),
        "2:PySide6.QtCore.QFileDevice.MemoryMapFlag",
        MemoryMapFlag_Initializer, MemoryMapFlag_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QFileDevice_MemoryMapFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QFileDevice_MemoryMapFlag_IDX].type =
        EType;
    // Register converter for enum 'QFileDevice::MemoryMapFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFileDevice_MemoryMapFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFileDevice_MemoryMapFlag,
            is_Enum_PythonToCpp_QFileDevice_MemoryMapFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFileDevice::MemoryMapFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "MemoryMapFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QFileDevice_MemoryMapFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QFileDevice_MemoryMapFlag,
            is_Enum_PythonToCpp_QFileDevice_MemoryMapFlag_Convertible);
        // Register converter for flag 'QFlags<QFileDevice::MemoryMapFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QFileDevice::MemoryMapFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFileDevice::MemoryMapFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'MemoryMapFlag' enum/flags.

    qRegisterMetaType< ::QFileDevice::FileError >("QFileDevice::FileError");
    qRegisterMetaType< ::QFileDevice::FileTime >("QFileDevice::FileTime");
    qRegisterMetaType< ::QFileDevice::Permission >("QFileDevice::Permission");
    qRegisterMetaType< ::QFileDevice::FileHandleFlag >("QFileDevice::FileHandleFlag");
    qRegisterMetaType< ::QFileDevice::MemoryMapFlag >("QFileDevice::MemoryMapFlag");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QFileDevice::staticMetaObject, sizeof(QFileDeviceWrapper));

    return pyType;
}
