// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qfileselector_wrapper.h"

// Wrappers providing overrides
#include "qobject_wrapper.h"
#include "qtranslator_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QFileSelectorWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QFileSelectorWrapper::QFileSelectorWrapper(::QObject * parent) : QFileSelector(parent)
{
}

void QFileSelectorWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QTranslatorWrapper::sbk_o_childEvent("QFileSelector", funcName, gil, pyOverride, event);
}

void QFileSelectorWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QFileSelector", funcName, gil, pyOverride, signal);
}

void QFileSelectorWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QTranslatorWrapper::sbk_o_customEvent("QFileSelector", funcName, gil, pyOverride, event);
}

void QFileSelectorWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QFileSelector", funcName, gil, pyOverride, signal);
}

bool QFileSelectorWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QTranslatorWrapper::sbk_o_event("QFileSelector", funcName, gil, pyOverride, event);
}

bool QFileSelectorWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QTranslatorWrapper::sbk_o_eventFilter("QFileSelector", funcName, gil, pyOverride, watched, event);
}

void QFileSelectorWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QTranslatorWrapper::sbk_o_timerEvent("QFileSelector", funcName, gil, pyOverride, event);
}

const QMetaObject *QFileSelectorWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QFileSelector::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QFileSelectorWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QFileSelector::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QFileSelectorWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QFileSelectorWrapper *>(this));
    return QFileSelector::qt_metacast(_clname);
}

QFileSelectorWrapper::~QFileSelectorWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFileSelector_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFileSelector >()))
        return -1;

    QFileSelectorWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QFileSelector", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QFileSelector::QFileSelector(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QFileSelector(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QFileSelector(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QFileSelector(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QFileSelectorWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QFileSelectorWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QFileSelector >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QFileSelectorFunc_allSelectors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // allSelectors()const
        QStringList cppResult = const_cast<const ::QFileSelector *>(cppSelf)->allSelectors();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileSelectorFunc_extraSelectors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // extraSelectors()const
        QStringList cppResult = const_cast<const ::QFileSelector *>(cppSelf)->extraSelectors();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileSelectorFunc_select(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileSelector::select(QString)const->QString
    // 1: QFileSelector::select(QUrl)const->QUrl
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // select(QString)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 1; // select(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "select", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // select(const QString &filePath) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // select(QString)const
                QString cppResult = const_cast<const ::QFileSelector *>(cppSelf)->select(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // select(const QUrl &filePath) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // select(QUrl)const
                QUrl cppResult = const_cast<const ::QFileSelector *>(cppSelf)->select(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFileSelectorFunc_setExtraSelectors(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileSelector::setExtraSelectors(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setExtraSelectors(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExtraSelectors", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExtraSelectors(QStringList)
            cppSelf->setExtraSelectors(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QFileSelector_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFileSelector_methods[] = {
    {"allSelectors", reinterpret_cast<PyCFunction>(Sbk_QFileSelectorFunc_allSelectors), METH_NOARGS, nullptr},
    {"extraSelectors", reinterpret_cast<PyCFunction>(Sbk_QFileSelectorFunc_extraSelectors), METH_NOARGS, nullptr},
    {"select", reinterpret_cast<PyCFunction>(Sbk_QFileSelectorFunc_select), METH_O, nullptr},
    {"setExtraSelectors", reinterpret_cast<PyCFunction>(Sbk_QFileSelectorFunc_setExtraSelectors), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QFileSelector_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QFileSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QFileSelectorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QFileSelector_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFileSelector_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFileSelector_Type = nullptr;
static PyTypeObject *Sbk_QFileSelector_TypeF(void)
{
    return _Sbk_QFileSelector_Type;
}

static PyType_Slot Sbk_QFileSelector_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QFileSelector_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFileSelector_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFileSelector_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFileSelector_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFileSelector_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFileSelector_spec = {
    "2:PySide6.QtCore.QFileSelector",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFileSelector_slots
};

} //extern "C"

static void *Sbk_QFileSelector_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QFileSelector *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFileSelector_PythonToCpp_QFileSelector_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFileSelector_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFileSelector_PythonToCpp_QFileSelector_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFileSelector_TypeF()))
        return QFileSelector_PythonToCpp_QFileSelector_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFileSelector_PTR_CppToPython_QFileSelector(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QFileSelector *>(const_cast<void *>(cppIn)), Sbk_QFileSelector_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFileSelector_SignatureStrings[] = {
    "PySide6.QtCore.QFileSelector(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtCore.QFileSelector.allSelectors(self)->QStringList",
    "PySide6.QtCore.QFileSelector.extraSelectors(self)->QStringList",
    "1:PySide6.QtCore.QFileSelector.select(self,filePath:QString)->QString",
    "0:PySide6.QtCore.QFileSelector.select(self,filePath:typing.Union[PySide6.QtCore.QUrl, QString])->PySide6.QtCore.QUrl",
    "PySide6.QtCore.QFileSelector.setExtraSelectors(self,list:QStringList)",
    nullptr}; // Sentinel
#else
static constexpr size_t QFileSelector_SignatureByteSize = 171;
static constexpr uint8_t QFileSelector_SignatureBytes[171] = {
    0x78, 0xda, 0x9d, 0x8f, 0x31, 0x0b, 0xc2, 0x30, 0x10, 0x85, 0xf7, 0xfc, 0x0a, 0x47, 0x0b, 0x35,
    0xe8, 0xe2, 0x10, 0xd0, 0x45, 0x74, 0x12, 0x4c, 0x29, 0x9d, 0xc4, 0x21, 0xea, 0x55, 0x23, 0x47,
    0x5a, 0x2e, 0x27, 0xd8, 0x7f, 0x6f, 0xa8, 0x15, 0xa5, 0x4a, 0x04, 0xb7, 0x07, 0xf7, 0xbe, 0xef,
    0x78, 0xba, 0xc9, 0xed, 0x11, 0xa6, 0x32, 0xe3, 0x45, 0x45, 0x20, 0xb3, 0x95, 0x45, 0xc8, 0x01,
    0xe1, 0xc0, 0x15, 0x0d, 0x3d, 0x60, 0x99, 0xd6, 0x86, 0xc0, 0xb1, 0xd2, 0xbd, 0xe2, 0x66, 0x7f,
    0x09, 0xa5, 0x99, 0xbb, 0x22, 0xd6, 0x4c, 0x89, 0xd0, 0x11, 0x91, 0x34, 0x88, 0xcf, 0xec, 0x5b,
    0x6b, 0x32, 0x9a, 0x67, 0x39, 0x93, 0x75, 0xa7, 0xb5, 0xf5, 0x1c, 0x87, 0xe1, 0xc6, 0x64, 0xa2,
    0xf8, 0x44, 0x45, 0x05, 0xbe, 0x0d, 0x8f, 0x35, 0x65, 0x38, 0x68, 0xc3, 0x67, 0xd5, 0xf1, 0x2f,
    0x93, 0x18, 0xff, 0x61, 0xe1, 0xa6, 0x0e, 0xa8, 0x2c, 0x9c, 0xad, 0xdc, 0xb6, 0x8f, 0x17, 0x84,
    0xe9, 0xa0, 0xb3, 0xef, 0xc2, 0xa3, 0x2f, 0x77, 0xf1, 0xe3, 0x25, 0x2f, 0x3f, 0xc7, 0xa7, 0x18,
    0x36, 0xab, 0xb7, 0xfd, 0x89, 0xb8, 0x03, 0xcb, 0xf3, 0xa3, 0xe9
};
#endif

PyTypeObject *init_QFileSelector(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX].type;

    Shiboken::AutoDecRef Sbk_QFileSelector_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QFileSelector_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFileSelector",
        "QFileSelector*",
        &Sbk_QFileSelector_spec,
        &Shiboken::callCppDestructor< QFileSelector >,
        Sbk_QFileSelector_Type_bases.object(),
        0);
    auto *pyType = Sbk_QFileSelector_TypeF(); // references _Sbk_QFileSelector_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFileSelector_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFileSelector_SignatureBytes, QFileSelector_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFileSelector_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QFileSelector_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFileSelector_PythonToCpp_QFileSelector_PTR,
        is_QFileSelector_PythonToCpp_QFileSelector_PTR_Convertible,
        QFileSelector_PTR_CppToPython_QFileSelector);

    Shiboken::Conversions::registerConverterName(converter, "QFileSelector");
    Shiboken::Conversions::registerConverterName(converter, "QFileSelector*");
    Shiboken::Conversions::registerConverterName(converter, "QFileSelector&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFileSelector).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QFileSelectorWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QFileSelector_TypeF(), &Sbk_QFileSelector_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QFileSelector::staticMetaObject, sizeof(QFileSelectorWrapper));

    return pyType;
}
