// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qjsonvalue_wrapper.h"

// Extra includes
#include <QJsonArray>
#include <QJsonObject>
#include <QVariant>

// Argument includes
#include <QString>
#include <QStringView>
#include <QtCore/qlatin1stringview.h>
#include <qbytearray.h>
#include <qbytearrayview.h>
#include <qjsonarray.h>
#include <qjsondocument.h>
#include <qjsonobject.h>
#include <qjsonparseerror.h>
#include <qjsonvalue.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QJsonValue_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QJsonValue >()))
        return -1;

    ::QJsonValue *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    if (PyArg_ParseTuple(args, "|O:QJsonValue", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QJsonValue::QJsonValue(QJsonValue::Type=)
    // 1: QJsonValue::QJsonValue(QLatin1String)
    // 2: QJsonValue::QJsonValue(bool)
    // 3: QJsonValue::QJsonValue(QJsonArray)
    // 4: QJsonValue::QJsonValue(QJsonObject)
    // 5: QJsonValue::QJsonValue(QJsonValue)
    // 6: QJsonValue::QJsonValue(QString)
    // 7: QJsonValue::QJsonValue(const char*)
    // 8: QJsonValue::QJsonValue(double)
    // 9: QJsonValue::QJsonValue(int)
    // 10: QJsonValue::QJsonValue(qint64)
    if (numArgs == 0) {
        overloadId = 0; // QJsonValue(QJsonValue::Type)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], (pyArgs[0])))) {
        overloadId = 4; // QJsonValue(QJsonObject)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QJsonValue(QJsonArray)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], (pyArgs[0])))) {
        overloadId = 1; // QJsonValue(QLatin1String)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QJsonValue(QJsonValue::Type)
    } else if (numArgs == 1
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))) {
        overloadId = 8; // QJsonValue(double)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 7; // QJsonValue(const char*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 6; // QJsonValue(QString)
    } else if (numArgs == 1
        && PyBool_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 2; // QJsonValue(bool)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        overloadId = 10; // QJsonValue(qint64)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 9; // QJsonValue(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), (pyArgs[0])))) {
        overloadId = 5; // QJsonValue(QJsonValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QJsonValue(QJsonValue::Type arg__1)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"arg__1", 0}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX])))->converter, (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
                }
            }
            ::QJsonValue::Type cppArg0(QJsonValue::Type::Null);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(QJsonValue::Type)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 1: // QJsonValue(QLatin1String s)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
            ::QLatin1String cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(QLatin1String)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 2: // QJsonValue(bool b)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
            bool cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(bool)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 3: // QJsonValue(const QJsonArray &a)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QJsonArray cppArg0_local;
            ::QJsonArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(QJsonArray)
                cptr = new ::QJsonValue(*cppArg0);
            }
            break;
        }
        case 4: // QJsonValue(const QJsonObject &o)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
            ::QJsonObject cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(QJsonObject)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 5: // QJsonValue(const QJsonValue &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QJsonValue cppArg0_local;
            ::QJsonValue *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(QJsonValue)
                cptr = new ::QJsonValue(*cppArg0);
            }
            break;
        }
        case 6: // QJsonValue(const QString &s)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(QString)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 7: // QJsonValue(const char *s)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(const char*)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 8: // QJsonValue(double n)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
            double cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(double)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 9: // QJsonValue(int n)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(int)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 10: // QJsonValue(qint64 v)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
            qint64 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(qint64)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QJsonValue >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QJsonValueFunc_fromJson(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fromJson", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QJsonValue::fromJson(QByteArrayView,QJsonParseError*=)->QJsonValue
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromJson(QByteArrayView,QJsonParseError*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]), (pyArgs[1])))) {
            overloadId = 0; // fromJson(QByteArrayView,QJsonParseError*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"error", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonParseError_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QJsonParseError *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromJson(QByteArrayView,QJsonParseError*)
            QJsonValue cppResult = ::QJsonValue::fromJson(QByteArrayView(cppArg0), cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_fromVariant(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QJsonValue::fromVariant(QVariant)->QJsonValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // fromVariant(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromVariant", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromVariant(QVariant)
            QJsonValue cppResult = ::QJsonValue::fromVariant(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_isArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isArray()const
        bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->isArray();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_isBool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBool()const
        bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->isBool();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_isDouble(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDouble()const
        bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->isDouble();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_isObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isObject()const
        bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->isObject();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_isString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isString()const
        bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->isString();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_isUndefined(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isUndefined()const
        bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->isUndefined();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJsonValue::swap(QJsonValue&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QJsonValue&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJsonValue cppArg0_local;
        ::QJsonValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QJsonValue&)
            cppSelf->swap(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QJsonValueFunc_toArray(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "toArray", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toArray()const->QJsonArray
    // 1: QJsonValue::toArray(QJsonArray)const->QJsonArray
    if (numArgs == 0) {
        overloadId = 0; // toArray()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), (pyArgs[0])))) {
        overloadId = 1; // toArray(QJsonArray)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toArray", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // toArray() const
        {

            // toArray()const
            QJsonArray cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toArray();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), &cppResult);
            break;
        }
        case 1: // toArray(const QJsonArray &defaultValue) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QJsonArray cppArg0_local;
            ::QJsonArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // toArray(QJsonArray)const
                QJsonArray cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toArray(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_toBool(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toBool", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    if (PyArg_ParseTuple(args, "|O:toBool", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toBool(bool=)const->bool
    if (numArgs == 0) {
        overloadId = 0; // toBool(bool)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // toBool(bool)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toBool", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"defaultValue", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "toBool", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
        }
        bool cppArg0 = false;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toBool(bool)const
            bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toBool(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_toDouble(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toDouble", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    if (PyArg_ParseTuple(args, "|O:toDouble", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toDouble(double=)const->double
    if (numArgs == 0) {
        overloadId = 0; // toDouble(double)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))) {
        overloadId = 0; // toDouble(double)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toDouble", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"defaultValue", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "toDouble", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
        }
        double cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toDouble(double)const
            double cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toDouble(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_toInt(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toInt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    if (PyArg_ParseTuple(args, "|O:toInt", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toInt(int=)const->int
    if (numArgs == 0) {
        overloadId = 0; // toInt(int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // toInt(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toInt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"defaultValue", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "toInt", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
        }
        int cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toInt(int)const
            int cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toInt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_toInteger(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toInteger", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    if (PyArg_ParseTuple(args, "|O:toInteger", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toInteger(qint64=)const->qint64
    if (numArgs == 0) {
        overloadId = 0; // toInteger(qint64)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        overloadId = 0; // toInteger(qint64)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toInteger", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"defaultValue", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "toInteger", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
        }
        qint64 cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toInteger(qint64)const
            qint64 cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toInteger(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_toJson(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    if (PyArg_ParseTuple(args, "|O:toJson", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toJson(QJsonDocument::JsonFormat=)const->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // toJson(QJsonDocument::JsonFormat)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_JsonFormat_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // toJson(QJsonDocument::JsonFormat)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"format", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_JsonFormat_IDX])))->converter, (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "toJson", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);
            }
        }
        ::QJsonDocument::JsonFormat cppArg0(QJsonDocument::JsonFormat::Indented);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toJson(QJsonDocument::JsonFormat)const
            QByteArray cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toJson(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_toObject(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "toObject", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toObject()const->QJsonObject
    // 1: QJsonValue::toObject(QJsonObject)const->QJsonObject
    if (numArgs == 0) {
        overloadId = 0; // toObject()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], (pyArgs[0])))) {
        overloadId = 1; // toObject(QJsonObject)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toObject", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // toObject() const
        {

            // toObject()const
            QJsonObject cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toObject();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], &cppResult);
            break;
        }
        case 1: // toObject(const QJsonObject &defaultValue) const
        {
            ::QJsonObject cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toObject(QJsonObject)const
                QJsonObject cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toObject(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_toString(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "toString", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toString()const->QString
    // 1: QJsonValue::toString(QString)const->QString
    if (numArgs == 0) {
        overloadId = 0; // toString()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // toString(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // toString() const
        {

            // toString()const
            QString cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            break;
        }
        case 1: // toString(const QString &defaultValue) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QString)const
                QString cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toString(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_toVariant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toVariant()const
        QVariant cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toVariant();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValueFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QJsonValue::Type cppResult = const_cast<const ::QJsonValue *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJsonValue__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QJsonValue_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QJsonValue_EnumFlagInfo[] = {
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QJsonValue_methods[] = {
    {"fromJson", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_fromJson), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromVariant", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_fromVariant), METH_O|METH_STATIC, nullptr},
    {"isArray", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_isArray), METH_NOARGS, nullptr},
    {"isBool", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_isBool), METH_NOARGS, nullptr},
    {"isDouble", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_isDouble), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_isNull), METH_NOARGS, nullptr},
    {"isObject", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_isObject), METH_NOARGS, nullptr},
    {"isString", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_isString), METH_NOARGS, nullptr},
    {"isUndefined", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_isUndefined), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_swap), METH_O, nullptr},
    {"toArray", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toArray), METH_VARARGS, nullptr},
    {"toBool", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toBool), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toDouble", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toDouble), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toInt", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toInt), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toInteger", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toInteger), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toJson", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toJson), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toObject", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toObject), METH_VARARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toString), METH_VARARGS, nullptr},
    {"toVariant", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toVariant), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QJsonValue__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QJsonValue___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QJsonValue_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], (pyArg)))) {
                // operator!=(const QJsonObject &rhs)
                ::QJsonObject cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], (pyArg)))) {
                // operator!=(const QJsonObject &lhs)
                ::QJsonObject cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), (pyArg)))) {
                // operator!=(const QJsonArray &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJsonArray cppArg0_local;
                ::QJsonArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), (pyArg)))) {
                // operator!=(const QJsonValue &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJsonValue cppArg0_local;
                ::QJsonValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], (pyArg)))) {
                // operator==(const QJsonObject &rhs)
                ::QJsonObject cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], (pyArg)))) {
                // operator==(const QJsonObject &lhs)
                ::QJsonObject cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), (pyArg)))) {
                // operator==(const QJsonArray &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJsonArray cppArg0_local;
                ::QJsonArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), (pyArg)))) {
                // operator==(const QJsonValue &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJsonValue cppArg0_local;
                ::QJsonValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QJsonValue_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QJsonValue_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QJsonValue_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QJsonValue__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QJsonValue_Type = nullptr;
static PyTypeObject *Sbk_QJsonValue_TypeF(void)
{
    return _Sbk_QJsonValue_Type;
}

static PyType_Slot Sbk_QJsonValue_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QJsonValue__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QJsonValue_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QJsonValue_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QJsonValue_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QJsonValue_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QJsonValue_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QJsonValue_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QJsonValue___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QJsonValue_spec = {
    "2:PySide6.QtCore.QJsonValue",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QJsonValue_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QJsonValue_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QJsonValue::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QJsonValue::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QJsonValue_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX])))
        return Enum_PythonToCpp_QJsonValue_Type;
    return {};
}

static PyObject *QJsonValue_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QJsonValue::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QJsonValue::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QJsonValue_PythonToCpp_QJsonValue_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QJsonValue_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QJsonValue_PythonToCpp_QJsonValue_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QJsonValue_TypeF()))
        return QJsonValue_PythonToCpp_QJsonValue_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QJsonValue_PTR_CppToPython_QJsonValue(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QJsonValue_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QJsonValue_COPY_CppToPython_QJsonValue(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QJsonValue *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QJsonValue_TypeF(), new ::QJsonValue(*source), true, true);
}

// Python to C++ copy conversion.
static void QJsonValue_PythonToCpp_QJsonValue_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QJsonValue *>(cppOut) = *reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QJsonValue_PythonToCpp_QJsonValue_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QJsonValue_TypeF()))
        return QJsonValue_PythonToCpp_QJsonValue_COPY;
    return {};
}

// Implicit conversions.
static void QJsonValue_Type_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    ::QJsonValue::Type cppIn{QJsonValue::Null};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_QJsonValue_Type_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX]), pyIn))
        return QJsonValue_Type_PythonToCpp_QJsonValue;
    return {};
}

static void QLatin1String_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    ::QLatin1String cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_QLatin1String_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return QLatin1String_PythonToCpp_QJsonValue;
    return {};
}

static void bool_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    bool cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_bool_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (PyBool_Check(pyIn))
        return bool_PythonToCpp_QJsonValue;
    return {};
}

static void constQJsonArrayREF_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue( *reinterpret_cast< ::QJsonArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQJsonArrayREF_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), pyIn))
        return constQJsonArrayREF_PythonToCpp_QJsonValue;
    return {};
}

static void constQJsonObjectREF_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    ::QJsonObject cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_constQJsonObjectREF_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::isPythonToCppConvertible(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], pyIn))
        return constQJsonObjectREF_PythonToCpp_QJsonValue;
    return {};
}

static void constQStringREF_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    ::QString cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_constQStringREF_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return constQStringREF_PythonToCpp_QJsonValue;
    return {};
}

static void constcharPTR_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    const char* cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_constcharPTR_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (Shiboken::String::check(pyIn))
        return constcharPTR_PythonToCpp_QJsonValue;
    return {};
}

static void double_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    double cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<double>(), pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_double_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (PyFloat_Check(pyIn))
        return double_PythonToCpp_QJsonValue;
    return {};
}

static void int_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    int cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_int_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return int_PythonToCpp_QJsonValue;
    return {};
}

static void qint64_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    qint64 cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_qint64_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return qint64_PythonToCpp_QJsonValue;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QJsonValue_SignatureStrings[] = {
    "10:PySide6.QtCore.QJsonValue(self,arg__1:PySide6.QtCore.QJsonValue.Type=QJsonValue.Type.Null)",
    "9:PySide6.QtCore.QJsonValue(self,s:QLatin1String)",
    "8:PySide6.QtCore.QJsonValue(self,b:bool)",
    "7:PySide6.QtCore.QJsonValue(self,a:PySide6.QtCore.QJsonArray)",
    "6:PySide6.QtCore.QJsonValue(self,o:QJsonObject)",
    "5:PySide6.QtCore.QJsonValue(self,other:PySide6.QtCore.QJsonValue)",
    "4:PySide6.QtCore.QJsonValue(self,s:QString)",
    "3:PySide6.QtCore.QJsonValue(self,s:char*)",
    "2:PySide6.QtCore.QJsonValue(self,n:double)",
    "1:PySide6.QtCore.QJsonValue(self,n:int)",
    "0:PySide6.QtCore.QJsonValue(self,v:qint64)",
    "PySide6.QtCore.QJsonValue.fromJson(json:typing.Union[PySide6.QtCore.QByteArray, char*],error:PySide6.QtCore.QJsonParseError=nullptr)->PySide6.QtCore.QJsonValue",
    "PySide6.QtCore.QJsonValue.fromVariant(variant:QVariant)->PySide6.QtCore.QJsonValue",
    "PySide6.QtCore.QJsonValue.isArray(self)->bool",
    "PySide6.QtCore.QJsonValue.isBool(self)->bool",
    "PySide6.QtCore.QJsonValue.isDouble(self)->bool",
    "PySide6.QtCore.QJsonValue.isNull(self)->bool",
    "PySide6.QtCore.QJsonValue.isObject(self)->bool",
    "PySide6.QtCore.QJsonValue.isString(self)->bool",
    "PySide6.QtCore.QJsonValue.isUndefined(self)->bool",
    "PySide6.QtCore.QJsonValue.swap(self,other:typing.Union[PySide6.QtCore.QJsonValue, PySide6.QtCore.QJsonValue.Type, QLatin1String, bool, PySide6.QtCore.QJsonArray, QJsonObject, QString, char*, double, int, qint64])",
    "1:PySide6.QtCore.QJsonValue.toArray(self)->PySide6.QtCore.QJsonArray",
    "0:PySide6.QtCore.QJsonValue.toArray(self,defaultValue:PySide6.QtCore.QJsonArray)->PySide6.QtCore.QJsonArray",
    "PySide6.QtCore.QJsonValue.toBool(self,defaultValue:bool=false)->bool",
    "PySide6.QtCore.QJsonValue.toDouble(self,defaultValue:double=0)->double",
    "PySide6.QtCore.QJsonValue.toInt(self,defaultValue:int=0)->int",
    "PySide6.QtCore.QJsonValue.toInteger(self,defaultValue:qint64=0)->qint64",
    "PySide6.QtCore.QJsonValue.toJson(self,format:PySide6.QtCore.QJsonDocument.JsonFormat=QJsonDocument.JsonFormat.Indented)->PySide6.QtCore.QByteArray",
    "1:PySide6.QtCore.QJsonValue.toObject(self)->QJsonObject",
    "0:PySide6.QtCore.QJsonValue.toObject(self,defaultValue:QJsonObject)->QJsonObject",
    "1:PySide6.QtCore.QJsonValue.toString(self)->QString",
    "0:PySide6.QtCore.QJsonValue.toString(self,defaultValue:QString)->QString",
    "PySide6.QtCore.QJsonValue.toVariant(self)->QVariant",
    "PySide6.QtCore.QJsonValue.type(self)->PySide6.QtCore.QJsonValue.Type",
    "PySide6.QtCore.QJsonValue.__copy__(self)->typing.Self",
    "3:PySide6.QtCore.QJsonValue.__ne__(self,rhs:PySide6.QtCore.QJsonArray)->bool",
    "2:PySide6.QtCore.QJsonValue.__ne__(self,lhs:QJsonObject)->bool",
    "1:PySide6.QtCore.QJsonValue.__ne__(self,rhs:QJsonObject)->bool",
    "0:PySide6.QtCore.QJsonValue.__ne__(self,rhs:typing.Union[PySide6.QtCore.QJsonValue, PySide6.QtCore.QJsonValue.Type, QLatin1String, bool, PySide6.QtCore.QJsonArray, QJsonObject, QString, char*, double, int, qint64])->bool",
    "3:PySide6.QtCore.QJsonValue.__eq__(self,rhs:PySide6.QtCore.QJsonArray)->bool",
    "2:PySide6.QtCore.QJsonValue.__eq__(self,lhs:QJsonObject)->bool",
    "1:PySide6.QtCore.QJsonValue.__eq__(self,rhs:QJsonObject)->bool",
    "0:PySide6.QtCore.QJsonValue.__eq__(self,rhs:typing.Union[PySide6.QtCore.QJsonValue, PySide6.QtCore.QJsonValue.Type, QLatin1String, bool, PySide6.QtCore.QJsonArray, QJsonObject, QString, char*, double, int, qint64])->bool",
    "PySide6.QtCore.QJsonValue.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QJsonValue_SignatureByteSize = 607;
static constexpr uint8_t QJsonValue_SignatureBytes[607] = {
    0x78, 0xda, 0xd5, 0x55, 0xd1, 0x6e, 0x9b, 0x30, 0x14, 0x7d, 0xe7, 0x2b, 0x78, 0x0c, 0x93, 0x87,
    0x42, 0xd7, 0x65, 0x2b, 0x12, 0x93, 0xd6, 0x75, 0x93, 0x3a, 0x4d, 0x5b, 0xa3, 0xac, 0x7d, 0xa9,
    0x2a, 0xe4, 0x04, 0x13, 0xa8, 0x88, 0x4d, 0x8d, 0xe9, 0xc4, 0xdf, 0xf7, 0x62, 0x20, 0xc1, 0x11,
    0xd8, 0xa4, 0xda, 0x4b, 0x5f, 0x42, 0x0c, 0xe7, 0x1c, 0x5f, 0xdf, 0x7b, 0xcf, 0xb5, 0x37, 0xf7,
    0x6f, 0xaa, 0x55, 0x1a, 0x91, 0x85, 0xbb, 0x14, 0xdf, 0x18, 0x27, 0xee, 0xf2, 0x67, 0xc1, 0xe8,
    0x1d, 0xce, 0x4a, 0x32, 0x2b, 0x48, 0x16, 0x23, 0xcc, 0xb7, 0x61, 0xe8, 0x8d, 0xa3, 0xdc, 0xbf,
    0x55, 0x4e, 0x82, 0xa3, 0xb5, 0xfb, 0xbb, 0xcc, 0x32, 0xc7, 0xba, 0x30, 0x89, 0x17, 0xfe, 0xf2,
    0x17, 0x16, 0x29, 0xf5, 0x56, 0x82, 0xa7, 0x74, 0xeb, 0x58, 0x9f, 0x4d, 0x8c, 0xb5, 0xbf, 0x66,
    0x0c, 0xa4, 0x3f, 0x19, 0xe3, 0x1e, 0x04, 0x7c, 0xe5, 0x1c, 0x57, 0x8e, 0xb5, 0x30, 0xb1, 0x99,
    0x2f, 0xdf, 0xfc, 0x59, 0x3f, 0x92, 0x8d, 0x70, 0xac, 0x8f, 0x46, 0xbc, 0x48, 0x08, 0x1f, 0x07,
    0x39, 0xd6, 0xf9, 0x84, 0x54, 0x74, 0x49, 0xf8, 0x60, 0xc6, 0x6e, 0x12, 0xcc, 0xdf, 0x39, 0xd6,
    0x99, 0x09, 0x49, 0xfd, 0x88, 0x95, 0xeb, 0x0c, 0x02, 0xf0, 0xcc, 0xd0, 0x94, 0xc2, 0x51, 0x8d,
    0x0d, 0xf1, 0xec, 0x3f, 0x01, 0x70, 0x71, 0xee, 0x58, 0xe3, 0x3d, 0x11, 0x73, 0xb6, 0xab, 0x57,
    0xb3, 0x47, 0xf8, 0xf1, 0x45, 0x95, 0xc3, 0xb9, 0xdc, 0x5b, 0x9a, 0x32, 0x7a, 0x7f, 0x4c, 0xba,
    0xac, 0x04, 0x91, 0x55, 0x41, 0xb6, 0x3c, 0xd4, 0x03, 0x22, 0x9c, 0xb3, 0xe1, 0x5c, 0xde, 0x60,
    0x5e, 0x90, 0xef, 0xf5, 0xe7, 0x80, 0x42, 0x83, 0xe5, 0x82, 0x3b, 0xef, 0xbf, 0x8c, 0x46, 0x61,
    0x88, 0xef, 0x0e, 0xf3, 0x14, 0x53, 0x31, 0x7b, 0x6e, 0x9e, 0xfe, 0xb2, 0x7d, 0xf1, 0x4a, 0xc9,
    0xb4, 0x90, 0xa7, 0x90, 0x39, 0x02, 0x89, 0xba, 0x4b, 0xb5, 0xe8, 0x4b, 0x00, 0x4c, 0x06, 0x5f,
    0xc9, 0x22, 0x4e, 0x86, 0xd7, 0xee, 0x9b, 0x0c, 0x6e, 0x7a, 0x7c, 0x32, 0xbc, 0x69, 0xd2, 0xc9,
    0xf0, 0x5b, 0x1a, 0x91, 0x38, 0xa5, 0x24, 0x9a, 0xc8, 0x28, 0xfe, 0xe1, 0xbc, 0x6f, 0x29, 0x6d,
    0xef, 0xec, 0x69, 0xc8, 0xd6, 0xcf, 0x27, 0x64, 0x2b, 0x73, 0x06, 0xd9, 0x75, 0x14, 0xc3, 0xa4,
    0xb6, 0x17, 0x7b, 0xf6, 0x87, 0x45, 0x47, 0x93, 0x1d, 0x8a, 0xec, 0xc6, 0x53, 0xc8, 0x06, 0x1f,
    0x20, 0xbb, 0x71, 0xc3, 0x83, 0xd6, 0x61, 0xae, 0x60, 0x4a, 0x77, 0x8c, 0x6e, 0xac, 0xb3, 0x9f,
    0x22, 0x82, 0x20, 0xad, 0xb8, 0xcc, 0x84, 0xfc, 0xa2, 0x19, 0x75, 0xba, 0xbd, 0x74, 0x3b, 0xed,
    0xdb, 0x53, 0xdd, 0xa8, 0xce, 0x5b, 0x10, 0xe3, 0xac, 0x20, 0xe6, 0x52, 0x0a, 0xd6, 0x6b, 0x5b,
    0x55, 0xa6, 0x49, 0x60, 0x30, 0x07, 0x91, 0xe6, 0xaf, 0x56, 0xe6, 0x9a, 0x8a, 0x01, 0x0d, 0x48,
    0xbb, 0x14, 0x80, 0xa7, 0x89, 0x4d, 0xb6, 0x84, 0x0f, 0x28, 0x34, 0x95, 0x93, 0x22, 0xcd, 0x5f,
    0xad, 0x8e, 0x9c, 0x67, 0x52, 0x24, 0x66, 0x7c, 0x87, 0xc5, 0x60, 0xd2, 0xaf, 0xd8, 0xa6, 0xdc,
    0x11, 0x2a, 0xdc, 0x7a, 0xf1, 0x43, 0xe2, 0x82, 0xb1, 0x0f, 0xee, 0x35, 0x78, 0x03, 0x82, 0x8b,
    0x06, 0x8a, 0xb4, 0x9f, 0x8a, 0x86, 0xae, 0x52, 0xcd, 0xdb, 0x6b, 0x5a, 0x43, 0x23, 0xf5, 0x78,
    0x6a, 0x4e, 0xfa, 0xd7, 0x9e, 0x2a, 0xa8, 0x0f, 0x44, 0x1d, 0x0b, 0xad, 0x61, 0x0c, 0x41, 0xf4,
    0x38, 0x47, 0x41, 0xb4, 0x37, 0xe1, 0x41, 0x48, 0x27, 0xd3, 0x0d, 0xf2, 0x6e, 0xef, 0x76, 0xad,
    0xe3, 0xc0, 0x48, 0xd0, 0x59, 0xf1, 0x30, 0x38, 0x34, 0x22, 0x61, 0xb8, 0x61, 0x79, 0x15, 0x86,
    0x9d, 0x50, 0x3b, 0xa9, 0x56, 0xb0, 0xd2, 0xdd, 0xe0, 0xc0, 0xa3, 0xa4, 0x65, 0x21, 0x9e, 0x14,
    0x5a, 0xef, 0x4a, 0x87, 0x9d, 0x4d, 0x14, 0xcb, 0x40, 0x4c, 0x2d, 0x9f, 0xa4, 0x7b, 0x27, 0xc4,
    0x32, 0x40, 0x9f, 0x9f, 0x40, 0x7f, 0x3b, 0xc3, 0xba, 0x3d, 0x9c, 0xbe, 0x4e, 0xe4, 0xe9, 0x3f,
    0xd6, 0xe9, 0x20, 0xf6, 0xaa, 0x3a, 0xa9, 0xb1, 0x9c, 0x5c, 0x27, 0x95, 0xfe, 0xe6, 0xea, 0xa4,
    0x3b, 0x5a, 0x82, 0x8b, 0xe4, 0xe0, 0xc2, 0xfa, 0x36, 0x78, 0x01, 0x61, 0xe4, 0x85, 0x90
};
#endif

PyTypeObject *init_QJsonValue(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX].type;

    Shiboken::AutoDecRef Sbk_QJsonValue_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QJsonValue_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QJsonValue",
        "QJsonValue",
        &Sbk_QJsonValue_spec,
        &Shiboken::callCppDestructor< ::QJsonValue >,
        Sbk_QJsonValue_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QJsonValue_TypeF(); // references _Sbk_QJsonValue_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QJsonValue_SignatureStrings);
#else
    InitSignatureBytes(pyType, QJsonValue_SignatureBytes, QJsonValue_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QJsonValue_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QJsonValue_PythonToCpp_QJsonValue_PTR,
        is_QJsonValue_PythonToCpp_QJsonValue_PTR_Convertible,
        QJsonValue_PTR_CppToPython_QJsonValue,
        QJsonValue_COPY_CppToPython_QJsonValue);

    Shiboken::Conversions::registerConverterName(converter, "QJsonValue");
    Shiboken::Conversions::registerConverterName(converter, "QJsonValue*");
    Shiboken::Conversions::registerConverterName(converter, "QJsonValue&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QJsonValue).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QJsonValue_PythonToCpp_QJsonValue_COPY,
        is_QJsonValue_PythonToCpp_QJsonValue_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QJsonValue_Type_PythonToCpp_QJsonValue,
        is_QJsonValue_Type_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLatin1String_PythonToCpp_QJsonValue,
        is_QLatin1String_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        bool_PythonToCpp_QJsonValue,
        is_bool_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQJsonArrayREF_PythonToCpp_QJsonValue,
        is_constQJsonArrayREF_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQJsonObjectREF_PythonToCpp_QJsonValue,
        is_constQJsonObjectREF_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQStringREF_PythonToCpp_QJsonValue,
        is_constQStringREF_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constcharPTR_PythonToCpp_QJsonValue,
        is_constcharPTR_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        double_PythonToCpp_QJsonValue,
        is_double_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        int_PythonToCpp_QJsonValue,
        is_int_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        qint64_PythonToCpp_QJsonValue,
        is_qint64_PythonToCpp_QJsonValue_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QJsonValue_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "Null",
        "Bool",
        "Double",
        "String",
        "Array",
        "Object",
        "Undefined",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QJsonValue::Type::Null),     //  0x00  0
        uint8_t(QJsonValue::Type::Bool),     //  0x01  1
        uint8_t(QJsonValue::Type::Double),   //  0x02  2
        uint8_t(QJsonValue::Type::String),   //  0x03  3
        uint8_t(QJsonValue::Type::Array),    //  0x04  4
        uint8_t(QJsonValue::Type::Object),   //  0x05  5
        uint8_t(QJsonValue::Type::Undefined) //  0x80  128
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QJsonValue_TypeF(),
        "2:PySide6.QtCore.QJsonValue.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX].type = EType;
    // Register converter for enum 'QJsonValue::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QJsonValue_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QJsonValue_Type,
            is_Enum_PythonToCpp_QJsonValue_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QJsonValue::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    qRegisterMetaType< ::QJsonValue >("QJsonValue");
    qRegisterMetaType< ::QJsonValue::Type >("QJsonValue::Type");

    return pyType;
}
