// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qlockfile_wrapper.h"

// Argument includes
#include <QString>
#include <qlockfile.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLockFile_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLockFile >()))
        return -1;

    ::QLockFile *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QLockFile", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLockFile::QLockFile(QString)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // QLockFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QLockFile(QString)
            cptr = new ::QLockFile(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLockFile >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLockFileFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLockFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QLockFile::LockError cppResult = const_cast<const ::QLockFile *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_LockError_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLockFileFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLockFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileName()const
        QString cppResult = const_cast<const ::QLockFile *>(cppSelf)->fileName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLockFileFunc_getLockInfo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLockFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getLockInfo(qint64*,QString*,QString*)const
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qlockfile-getlockinfo)]
            qint64 pid{};
            QString hostname, appname;
            cppSelf->getLockInfo(&pid, &hostname, &appname);
            pyResult = PyTuple_New(3);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &pid));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &hostname));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &appname));
            // END of custom code block [file: ../glue/qtcore.cpp (qlockfile-getlockinfo)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLockFileFunc_isLocked(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLockFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLocked()const
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = const_cast<const ::QLockFile *>(cppSelf)->isLocked();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLockFileFunc_lock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLockFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lock()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = cppSelf->lock();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLockFileFunc_removeStaleLockFile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLockFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeStaleLockFile()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = cppSelf->removeStaleLockFile();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLockFileFunc_setStaleLockTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLockFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLockFile::setStaleLockTime(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setStaleLockTime(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStaleLockTime", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStaleLockTime(int)
            cppSelf->setStaleLockTime(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLockFileFunc_staleLockTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLockFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // staleLockTime()const
        int cppResult = const_cast<const ::QLockFile *>(cppSelf)->staleLockTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLockFileFunc_staleLockTimeAsDuration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLockFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // staleLockTimeAsDuration()const
        std::chrono::milliseconds cppResult = const_cast<const ::QLockFile *>(cppSelf)->staleLockTimeAsDuration();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_std_chrono_milliseconds_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLockFileFunc_tryLock(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLockFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLockFile::tryLock(int)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // tryLock(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "tryLock", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // tryLock(int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->tryLock(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLockFileFunc_unlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLockFile *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unlock()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        cppSelf->unlock();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QLockFile_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QLockFile_EnumFlagInfo[] = {
    "LockError:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLockFile_methods[] = {
    {"error", reinterpret_cast<PyCFunction>(Sbk_QLockFileFunc_error), METH_NOARGS, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QLockFileFunc_fileName), METH_NOARGS, nullptr},
    {"getLockInfo", reinterpret_cast<PyCFunction>(Sbk_QLockFileFunc_getLockInfo), METH_NOARGS, nullptr},
    {"isLocked", reinterpret_cast<PyCFunction>(Sbk_QLockFileFunc_isLocked), METH_NOARGS, nullptr},
    {"lock", reinterpret_cast<PyCFunction>(Sbk_QLockFileFunc_lock), METH_NOARGS, nullptr},
    {"removeStaleLockFile", reinterpret_cast<PyCFunction>(Sbk_QLockFileFunc_removeStaleLockFile), METH_NOARGS, nullptr},
    {"setStaleLockTime", reinterpret_cast<PyCFunction>(Sbk_QLockFileFunc_setStaleLockTime), METH_O, nullptr},
    {"staleLockTime", reinterpret_cast<PyCFunction>(Sbk_QLockFileFunc_staleLockTime), METH_NOARGS, nullptr},
    {"staleLockTimeAsDuration", reinterpret_cast<PyCFunction>(Sbk_QLockFileFunc_staleLockTimeAsDuration), METH_NOARGS, nullptr},
    {"tryLock", reinterpret_cast<PyCFunction>(Sbk_QLockFileFunc_tryLock), METH_O, nullptr},
    {"unlock", reinterpret_cast<PyCFunction>(Sbk_QLockFileFunc_unlock), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QLockFile_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLockFile_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLockFile_Type = nullptr;
static PyTypeObject *Sbk_QLockFile_TypeF(void)
{
    return _Sbk_QLockFile_Type;
}

static PyType_Slot Sbk_QLockFile_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLockFile_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLockFile_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLockFile_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLockFile_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLockFile_spec = {
    "2:PySide6.QtCore.QLockFile",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLockFile_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QLockFile_LockError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLockFile::LockError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLockFile::LockError *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLockFile_LockError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_LockError_IDX])))
        return Enum_PythonToCpp_QLockFile_LockError;
    return {};
}

static PyObject *QLockFile_LockError_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QLockFile::LockError>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QLockFile::LockError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_LockError_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLockFile_PythonToCpp_QLockFile_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLockFile_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLockFile_PythonToCpp_QLockFile_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLockFile_TypeF()))
        return QLockFile_PythonToCpp_QLockFile_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLockFile_PTR_CppToPython_QLockFile(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QLockFile_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLockFile_SignatureStrings[] = {
    "PySide6.QtCore.QLockFile(self,fileName:QString)",
    "PySide6.QtCore.QLockFile.error(self)->PySide6.QtCore.QLockFile.LockError",
    "PySide6.QtCore.QLockFile.fileName(self)->QString",
    "PySide6.QtCore.QLockFile.getLockInfo(self)->Tuple[int, str, str]",
    "PySide6.QtCore.QLockFile.isLocked(self)->bool",
    "PySide6.QtCore.QLockFile.lock(self)->bool",
    "PySide6.QtCore.QLockFile.removeStaleLockFile(self)->bool",
    "PySide6.QtCore.QLockFile.setStaleLockTime(self,arg__1:int)",
    "PySide6.QtCore.QLockFile.staleLockTime(self)->int",
    "PySide6.QtCore.QLockFile.staleLockTimeAsDuration(self)->std.chrono.milliseconds",
    "PySide6.QtCore.QLockFile.tryLock(self,timeout:int)->bool",
    "PySide6.QtCore.QLockFile.unlock(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QLockFile_SignatureByteSize = 228;
static constexpr uint8_t QLockFile_SignatureBytes[228] = {
    0x78, 0xda, 0x8d, 0x91, 0x4f, 0x6b, 0xc2, 0x40, 0x10, 0xc5, 0xef, 0x7e, 0x0a, 0x8f, 0x0a, 0xe9,
    0x82, 0x97, 0x1e, 0x3c, 0x08, 0xc5, 0x3f, 0x20, 0x48, 0x31, 0xc4, 0x5b, 0x29, 0x12, 0x93, 0x49,
    0x1c, 0xba, 0xd9, 0x29, 0x33, 0x13, 0xc1, 0x6f, 0xef, 0x26, 0xb8, 0x95, 0x22, 0xab, 0x5e, 0x96,
    0x77, 0x78, 0xbf, 0x37, 0x3b, 0x6f, 0xb6, 0xe7, 0x0c, 0x4b, 0x78, 0x37, 0xa9, 0xce, 0x89, 0xc1,
    0xa4, 0x1b, 0x2a, 0x7e, 0x56, 0x68, 0x61, 0x24, 0x60, 0xab, 0xa4, 0xf2, 0xea, 0x33, 0x6f, 0x60,
    0x9a, 0x66, 0xca, 0xe8, 0xea, 0xf1, 0x60, 0x1b, 0xf1, 0x1b, 0x60, 0x26, 0xee, 0xa9, 0xf1, 0xdb,
    0x2c, 0xea, 0xea, 0xc4, 0xb2, 0x73, 0xc6, 0x83, 0xc2, 0xcc, 0x90, 0x75, 0x1d, 0x1d, 0x07, 0x6a,
    0xd0, 0x4e, 0xaf, 0x5d, 0x45, 0x81, 0xd9, 0xb5, 0xbf, 0x16, 0xbe, 0xd0, 0x69, 0x32, 0x14, 0xe5,
    0xfe, 0xf9, 0x8e, 0x07, 0xa0, 0x74, 0x12, 0xca, 0x40, 0x1f, 0x88, 0x6c, 0xdc, 0x6d, 0xbd, 0x78,
    0xcd, 0xc9, 0xd0, 0xd0, 0x09, 0x32, 0xcd, 0x2d, 0xfc, 0xab, 0xf5, 0x29, 0x28, 0xa0, 0x7f, 0xd4,
    0x0e, 0xaf, 0x55, 0x24, 0x39, 0xd7, 0xfb, 0xfd, 0x64, 0xea, 0xb7, 0x7a, 0x70, 0x06, 0xb9, 0xe3,
    0xfc, 0x34, 0x8f, 0xbc, 0x48, 0x7c, 0xc8, 0xa2, 0xe5, 0x5c, 0x91, 0x5c, 0x60, 0x45, 0x4b, 0x53,
    0x1c, 0x99, 0x1c, 0x99, 0x06, 0xad, 0x45, 0x81, 0x82, 0x5c, 0x29, 0xf1, 0x3c, 0xe5, 0xf3, 0x26,
    0x54, 0x94, 0xa8, 0xcf, 0xa4, 0x56, 0xfb, 0x4f, 0x3f, 0xdb, 0xba, 0x75, 0xb7, 0x6a, 0x07, 0x17,
    0xb4, 0x00, 0xeb, 0x08
};
#endif

PyTypeObject *init_QLockFile(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX].type;

    Shiboken::AutoDecRef Sbk_QLockFile_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLockFile_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLockFile",
        "QLockFile*",
        &Sbk_QLockFile_spec,
        &Shiboken::callCppDestructor< ::QLockFile >,
        Sbk_QLockFile_Type_bases.object(),
        0);
    auto *pyType = Sbk_QLockFile_TypeF(); // references _Sbk_QLockFile_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLockFile_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLockFile_SignatureBytes, QLockFile_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLockFile_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLockFile_PythonToCpp_QLockFile_PTR,
        is_QLockFile_PythonToCpp_QLockFile_PTR_Convertible,
        QLockFile_PTR_CppToPython_QLockFile);

    Shiboken::Conversions::registerConverterName(converter, "QLockFile");
    Shiboken::Conversions::registerConverterName(converter, "QLockFile*");
    Shiboken::Conversions::registerConverterName(converter, "QLockFile&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLockFile).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QLockFile_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'LockError'.
    const char *LockError_Initializer[] = {
        "NoError",
        "LockFailedError",
        "PermissionError",
        "UnknownError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t LockError_InitializerValues[] = {
        uint8_t(QLockFile::LockError::NoError),         //  0x00  0
        uint8_t(QLockFile::LockError::LockFailedError), //  0x01  1
        uint8_t(QLockFile::LockError::PermissionError), //  0x02  2
        uint8_t(QLockFile::LockError::UnknownError)     //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLockFile_TypeF(),
        "2:PySide6.QtCore.QLockFile.LockError",
        LockError_Initializer, LockError_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLockFile_LockError_IDX].type = EType;
    // Register converter for enum 'QLockFile::LockError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLockFile_LockError_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLockFile_LockError,
            is_Enum_PythonToCpp_QLockFile_LockError_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QLockFile::LockError");
        Shiboken::Conversions::registerConverterAlias(converter, "LockError");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'LockError' enum.

    qRegisterMetaType< ::QLockFile *>();
    qRegisterMetaType< ::QLockFile::LockError >("QLockFile::LockError");

    return pyType;
}
