// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qmetaenum_wrapper.h"

// Argument includes
#include <qbytearray.h>
#include <qmetatype.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMetaEnum_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMetaEnum >()))
        return -1;

    ::QMetaEnum *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QMetaEnum", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMetaEnum::QMetaEnum()
    // 1: QMetaEnum::QMetaEnum(QMetaEnum)
    if (numArgs == 0) {
        overloadId = 0; // QMetaEnum()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QMetaEnum(QMetaEnum)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QMetaEnum()
        {

            // QMetaEnum()
            cptr = new ::QMetaEnum();
            break;
        }
        case 1: // QMetaEnum(const QMetaEnum &QMetaEnum)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QMetaEnum cppArg0_local;
            ::QMetaEnum *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QMetaEnum(QMetaEnum)
                cptr = new ::QMetaEnum(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMetaEnum >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMetaEnumFunc_enumName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // enumName()const
        const char * cppResult = const_cast<const ::QMetaEnum *>(cppSelf)->enumName();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnumFunc_is64Bit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // is64Bit()const
        bool cppResult = const_cast<const ::QMetaEnum *>(cppSelf)->is64Bit();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnumFunc_isFlag(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFlag()const
        bool cppResult = const_cast<const ::QMetaEnum *>(cppSelf)->isFlag();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnumFunc_isScoped(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isScoped()const
        bool cppResult = const_cast<const ::QMetaEnum *>(cppSelf)->isScoped();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnumFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QMetaEnum *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnumFunc_key(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaEnum::key(int)const->const char*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // key(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "key", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // key(int)const
            const char * cppResult = const_cast<const ::QMetaEnum *>(cppSelf)->key(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnumFunc_keyCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // keyCount()const
        int cppResult = const_cast<const ::QMetaEnum *>(cppSelf)->keyCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnumFunc_keyToValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaEnum::keyToValue(const char*,bool*=)const->PyTuple
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // keyToValue(const char*,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyToValue", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        bool* removed_cppArg1 = nullptr;
        SBK_UNUSED(removed_cppArg1)

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyToValue(const char*,bool*)const
            // Begin code injection
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            int retval_ = cppSelf->keyToValue(cppArg0, &ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_args,bool* - END
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnumFunc_keysToValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaEnum::keysToValue(const char*,bool*=)const->PyTuple
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // keysToValue(const char*,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keysToValue", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        bool* removed_cppArg1 = nullptr;
        SBK_UNUSED(removed_cppArg1)

        if (Shiboken::Errors::occurred() == nullptr) {
            // keysToValue(const char*,bool*)const
            // Begin code injection
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            int retval_ = cppSelf->keysToValue(cppArg0, &ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_args,bool* - END
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnumFunc_metaType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // metaType()const
        QMetaType cppResult = const_cast<const ::QMetaEnum *>(cppSelf)->metaType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnumFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        const char * cppResult = const_cast<const ::QMetaEnum *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnumFunc_scope(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scope()const
        const char * cppResult = const_cast<const ::QMetaEnum *>(cppSelf)->scope();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnumFunc_value(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaEnum::value(int)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // value(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "value", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // value(int)const
            int cppResult = const_cast<const ::QMetaEnum *>(cppSelf)->value(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnumFunc_valueToKey(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaEnum::valueToKey(quint64)const->const char*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArg)))) {
        overloadId = 0; // valueToKey(quint64)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "valueToKey", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]);

    // Call function/method
    {
        quint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // valueToKey(quint64)const
            const char * cppResult = const_cast<const ::QMetaEnum *>(cppSelf)->valueToKey(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnumFunc_valueToKeys(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaEnum::valueToKeys(quint64)const->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArg)))) {
        overloadId = 0; // valueToKeys(quint64)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "valueToKeys", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]);

    // Call function/method
    {
        quint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // valueToKeys(quint64)const
            QByteArray cppResult = const_cast<const ::QMetaEnum *>(cppSelf)->valueToKeys(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaEnum__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMetaEnum_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMetaEnum_methods[] = {
    {"enumName", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_enumName), METH_NOARGS, nullptr},
    {"is64Bit", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_is64Bit), METH_NOARGS, nullptr},
    {"isFlag", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_isFlag), METH_NOARGS, nullptr},
    {"isScoped", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_isScoped), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_isValid), METH_NOARGS, nullptr},
    {"key", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_key), METH_O, nullptr},
    {"keyCount", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_keyCount), METH_NOARGS, nullptr},
    {"keyToValue", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_keyToValue), METH_O, nullptr},
    {"keysToValue", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_keysToValue), METH_O, nullptr},
    {"metaType", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_metaType), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_name), METH_NOARGS, nullptr},
    {"scope", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_scope), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_value), METH_O, nullptr},
    {"valueToKey", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_valueToKey), METH_O, nullptr},
    {"valueToKeys", reinterpret_cast<PyCFunction>(Sbk_QMetaEnumFunc_valueToKeys), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QMetaEnum__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QMetaEnum_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMetaEnum_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMetaEnum_Type = nullptr;
static PyTypeObject *Sbk_QMetaEnum_TypeF(void)
{
    return _Sbk_QMetaEnum_Type;
}

static PyType_Slot Sbk_QMetaEnum_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMetaEnum_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMetaEnum_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMetaEnum_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMetaEnum_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMetaEnum_spec = {
    "2:PySide6.QtCore.QMetaEnum",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMetaEnum_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMetaEnum_PythonToCpp_QMetaEnum_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMetaEnum_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMetaEnum_PythonToCpp_QMetaEnum_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMetaEnum_TypeF()))
        return QMetaEnum_PythonToCpp_QMetaEnum_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMetaEnum_PTR_CppToPython_QMetaEnum(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QMetaEnum_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QMetaEnum_COPY_CppToPython_QMetaEnum(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QMetaEnum *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QMetaEnum_TypeF(), new ::QMetaEnum(*source), true, true);
}

// Python to C++ copy conversion.
static void QMetaEnum_PythonToCpp_QMetaEnum_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QMetaEnum *>(cppOut) = *reinterpret_cast< ::QMetaEnum *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QMetaEnum_PythonToCpp_QMetaEnum_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QMetaEnum_TypeF()))
        return QMetaEnum_PythonToCpp_QMetaEnum_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMetaEnum_SignatureStrings[] = {
    "1:PySide6.QtCore.QMetaEnum(self)",
    "0:PySide6.QtCore.QMetaEnum(self,QMetaEnum:PySide6.QtCore.QMetaEnum)",
    "PySide6.QtCore.QMetaEnum.enumName(self)->char*",
    "PySide6.QtCore.QMetaEnum.is64Bit(self)->bool",
    "PySide6.QtCore.QMetaEnum.isFlag(self)->bool",
    "PySide6.QtCore.QMetaEnum.isScoped(self)->bool",
    "PySide6.QtCore.QMetaEnum.isValid(self)->bool",
    "PySide6.QtCore.QMetaEnum.key(self,index:int)->char*",
    "PySide6.QtCore.QMetaEnum.keyCount(self)->int",
    "PySide6.QtCore.QMetaEnum.keyToValue(self,key:char*)->PyTuple",
    "PySide6.QtCore.QMetaEnum.keysToValue(self,keys:char*)->PyTuple",
    "PySide6.QtCore.QMetaEnum.metaType(self)->PySide6.QtCore.QMetaType",
    "PySide6.QtCore.QMetaEnum.name(self)->char*",
    "PySide6.QtCore.QMetaEnum.scope(self)->char*",
    "PySide6.QtCore.QMetaEnum.value(self,index:int)->int",
    "PySide6.QtCore.QMetaEnum.valueToKey(self,value:quint64)->char*",
    "PySide6.QtCore.QMetaEnum.valueToKeys(self,value:quint64)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QMetaEnum.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QMetaEnum_SignatureByteSize = 246;
static constexpr uint8_t QMetaEnum_SignatureBytes[246] = {
    0x78, 0xda, 0x8d, 0x91, 0xc1, 0x8a, 0xc2, 0x30, 0x10, 0x86, 0xef, 0x7d, 0x12, 0x15, 0x2d, 0x2b,
    0x48, 0x0f, 0x3d, 0x08, 0x2a, 0xeb, 0x45, 0x14, 0xa5, 0xc5, 0x6b, 0x89, 0x76, 0x74, 0xc3, 0xa6,
    0x49, 0x6d, 0x12, 0x31, 0x6f, 0xef, 0xd8, 0xd2, 0x2a, 0x62, 0x62, 0x2e, 0xa5, 0x43, 0xbe, 0x6f,
    0x92, 0x7f, 0x66, 0x1c, 0x6f, 0x4d, 0x42, 0x73, 0x88, 0xc2, 0x9d, 0x5a, 0x88, 0x0a, 0xc2, 0xdd,
    0x1a, 0x14, 0xf9, 0xe5, 0xba, 0xe8, 0x49, 0x60, 0xa7, 0x7e, 0xf0, 0xe3, 0x06, 0x86, 0x5d, 0x69,
    0xe5, 0xfa, 0x81, 0xed, 0x24, 0x04, 0xfc, 0x6c, 0x48, 0x01, 0xcd, 0x5d, 0xa3, 0xe9, 0xf1, 0x8f,
    0x54, 0x03, 0x3b, 0x4e, 0x65, 0x34, 0x99, 0x53, 0xd5, 0xd2, 0x07, 0x21, 0x98, 0x0b, 0x5e, 0x32,
    0x72, 0xf6, 0x65, 0x93, 0xa3, 0x28, 0x21, 0xf7, 0xa5, 0xf7, 0x84, 0x51, 0x4f, 0xf8, 0x1f, 0x4c,
    0x33, 0x28, 0xca, 0x73, 0xb8, 0xc5, 0x94, 0xab, 0xef, 0x39, 0xd1, 0x59, 0x08, 0xcd, 0xbb, 0xa0,
    0x28, 0x39, 0xe1, 0x54, 0xe0, 0x83, 0x74, 0x33, 0xc5, 0x21, 0xd6, 0x71, 0xdd, 0x1f, 0xc5, 0xad,
    0x49, 0x75, 0xc9, 0xc0, 0x29, 0xcb, 0x77, 0x5b, 0xfa, 0xeb, 0x05, 0xfe, 0xa4, 0xa6, 0xec, 0xf6,
    0xf7, 0x09, 0x7c, 0x9c, 0xdb, 0x3b, 0x70, 0xff, 0xed, 0xcb, 0xc7, 0x8a, 0x3c, 0xd9, 0xeb, 0x33,
    0xd1, 0xeb, 0xdc, 0x9d, 0x83, 0xac, 0x9d, 0x54, 0xac, 0xda, 0x85, 0xd5, 0x75, 0x7c, 0xd1, 0x28,
    0x45, 0x13, 0xcf, 0x2b, 0x6b, 0x5d, 0x7e, 0xf6, 0xdf, 0xcd, 0xb9, 0x51, 0x30, 0xab, 0x2a, 0x62,
    0xec, 0x3d, 0xb3, 0x0c, 0x33, 0x9b, 0x2c, 0x6b, 0x53, 0x2b, 0x53, 0x52, 0x7e, 0x0e, 0x13, 0xac,
    0x82, 0x3b, 0x6e, 0xea, 0x4d, 0x27
};
#endif

PyTypeObject *init_QMetaEnum(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX].type;

    Shiboken::AutoDecRef Sbk_QMetaEnum_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QMetaEnum_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMetaEnum",
        "QMetaEnum",
        &Sbk_QMetaEnum_spec,
        &Shiboken::callCppDestructor< ::QMetaEnum >,
        Sbk_QMetaEnum_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QMetaEnum_TypeF(); // references _Sbk_QMetaEnum_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMetaEnum_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMetaEnum_SignatureBytes, QMetaEnum_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMetaEnum_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMetaEnum_PythonToCpp_QMetaEnum_PTR,
        is_QMetaEnum_PythonToCpp_QMetaEnum_PTR_Convertible,
        QMetaEnum_PTR_CppToPython_QMetaEnum,
        QMetaEnum_COPY_CppToPython_QMetaEnum);

    Shiboken::Conversions::registerConverterName(converter, "QMetaEnum");
    Shiboken::Conversions::registerConverterName(converter, "QMetaEnum*");
    Shiboken::Conversions::registerConverterName(converter, "QMetaEnum&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMetaEnum).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QMetaEnum_PythonToCpp_QMetaEnum_COPY,
        is_QMetaEnum_PythonToCpp_QMetaEnum_COPY_Convertible);

    qRegisterMetaType< ::QMetaEnum >("QMetaEnum");

    return pyType;
}
