// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qobject_wrapper.h"

// Wrappers providing overrides
#include "qobject_wrapper.h"

// Extra includes
#include <QCoreApplication>
#include <QThread>
#include "signalmanager.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qregularexpression.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (core-snippets-p-h)]
#include "glue/core_snippets_p.h"
// END of custom code block [file: ../glue/qtcore.cpp (core-snippets-p-h)]
// ========================================================================
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (qobject-connect)]
#include <qobjectconnect.h>
// END of custom code block [file: ../glue/qtcore.cpp (qobject-connect)]
// ========================================================================
// End of code injection


// Native ---------------------------------------------------------

void QObjectWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QObjectWrapper::QObjectWrapper(::QObject * parent) : QObject(parent)
{
}

void QObjectWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    sbk_o_childEvent("QObject", funcName, gil, pyOverride, event);
}

void QObjectWrapper::sbk_o_childEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QChildEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QObjectWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    sbk_o_connectNotify("QObject", funcName, gil, pyOverride, signal);
}

void QObjectWrapper::sbk_o_connectNotify(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QMetaMethod & signal)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QObjectWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    sbk_o_customEvent("QObject", funcName, gil, pyOverride, event);
}

void QObjectWrapper::sbk_o_customEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QObjectWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QObject", funcName, gil, pyOverride, signal);
}

bool QObjectWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return sbk_o_event("QObject", funcName, gil, pyOverride, event);
}

bool QObjectWrapper::sbk_o_event(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QObjectWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return sbk_o_eventFilter("QObject", funcName, gil, pyOverride, watched, event);
}

bool QObjectWrapper::sbk_o_eventFilter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * watched, ::QEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QObjectWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    sbk_o_timerEvent("QObject", funcName, gil, pyOverride, event);
}

void QObjectWrapper::sbk_o_timerEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QTimerEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

const QMetaObject *QObjectWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QObject::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QObjectWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QObject::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QObjectWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QObjectWrapper *>(this));
    return QObject::qt_metacast(_clname);
}

QObjectWrapper::~QObjectWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QObject_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QObject >()))
        return -1;

    QObjectWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QObject", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QObject::QObject(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QObject(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QObject(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QObject(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QObjectWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QObjectWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QObject >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QObjectFunc_blockSignals(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::blockSignals(bool)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // blockSignals(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "blockSignals", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // blockSignals(bool)
            bool cppResult = cppSelf->blockSignals(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_childEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::childEvent(QChildEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), (pyArg)))) {
        overloadId = 0; // childEvent(QChildEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "childEvent", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QChildEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // childEvent(QChildEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QObject::childEvent(cppArg0)
                : cppSelf->childEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QObjectFunc_children(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // children()const
        const QList<QObject*> & cppResult = const_cast<const ::QObject *>(cppSelf)->children();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QObjectPTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_connect(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QObject *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "connect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:connect", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QObject::connect(const QObject*,QMetaMethod,const QObject*,QMetaMethod,Qt::ConnectionType=)->QMetaObject::Connection
    // 1: static QObject::connect(const QObject*,const char*,PyCallable*,Qt::ConnectionType=)->QMetaObject::Connection
    // 2: static QObject::connect(const QObject*,const char*,const QObject*,PyCallable*,Qt::ConnectionType=)->QMetaObject::Connection
    // 3: static QObject::connect(const QObject*,const char*,const QObject*,const char*,Qt::ConnectionType=)->QMetaObject::Connection
    // 4: QObject::connect(const QObject*,const char*,const char*,Qt::ConnectionType=)const->QMetaObject::Connection
    // 5: QObject::connect(const char*,PyCallable*,Qt::ConnectionType=)->QMetaObject::Connection
    // 6: QObject::connect(const char*,const QObject*,const char*,Qt::ConnectionType=)->QMetaObject::Connection
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        if (numArgs >= 4
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // connect(const QObject*,QMetaMethod,const QObject*,QMetaMethod,Qt::ConnectionType)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[4])))) {
                overloadId = 0; // connect(const QObject*,QMetaMethod,const QObject*,QMetaMethod,Qt::ConnectionType)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 4; // connect(const QObject*,const char*,const char*,Qt::ConnectionType)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[3])))) {
                    overloadId = 4; // connect(const QObject*,const char*,const char*,Qt::ConnectionType)const
                }
            } else if (numArgs >= 3
                && PyCallable_Check(pyArgs[2])) {
                if (numArgs == 3) {
                    overloadId = 1; // connect(const QObject*,const char*,PyCallable*,Qt::ConnectionType)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[3])))) {
                    overloadId = 1; // connect(const QObject*,const char*,PyCallable*,Qt::ConnectionType)
                }
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))) {
                if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 3; // connect(const QObject*,const char*,const QObject*,const char*,Qt::ConnectionType)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[4])))) {
                        overloadId = 3; // connect(const QObject*,const char*,const QObject*,const char*,Qt::ConnectionType)
                    }
                } else if (numArgs >= 4
                    && PyCallable_Check(pyArgs[3])) {
                    if (numArgs == 4) {
                        overloadId = 2; // connect(const QObject*,const char*,const QObject*,PyCallable*,Qt::ConnectionType)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[4])))) {
                        overloadId = 2; // connect(const QObject*,const char*,const QObject*,PyCallable*,Qt::ConnectionType)
                    }
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs >= 2
            && PyCallable_Check(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 5; // connect(const char*,PyCallable*,Qt::ConnectionType)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 5; // connect(const char*,PyCallable*,Qt::ConnectionType)
            }
        } else if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 6; // connect(const char*,const QObject*,const char*,Qt::ConnectionType)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[3])))) {
                overloadId = 6; // connect(const char*,const QObject*,const char*,Qt::ConnectionType)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "connect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // connect(const QObject *sender, const QMetaMethod &signal, const QObject *receiver, const QMetaMethod &method, Qt::ConnectionType type)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"type", 4}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[4]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "connect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMetaMethod cppArg1_local;
            ::QMetaMethod *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QMetaMethod cppArg3_local;
            ::QMetaMethod *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);

            ::Qt::ConnectionType cppArg4(Qt::AutoConnection);
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connect(const QObject*,QMetaMethod,const QObject*,QMetaMethod,Qt::ConnectionType)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qobject-connect-2)]
                // connect() - disable generation of function call.
                ::QMetaObject::Connection cppResult = PySide::qobjectConnect(cppArg0, (*cppArg1), cppArg2, (*cppArg3), cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_Connection_IDX]), &cppResult);
                // END of custom code block [file: ../glue/qtcore.cpp (qobject-connect-2)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // connect(const QObject *sender, const char *signal, PyCallable *functor, Qt::ConnectionType type)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"type", 3}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[3]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "connect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            ::Qt::ConnectionType cppArg3(Qt::AutoConnection);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            SBK_UNUSED(cppArg3)

            if (Shiboken::Errors::occurred() == nullptr) {
                // connect(const QObject*,const char*,PyCallable*,Qt::ConnectionType)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qobject-connect-4)]
                // connect() - disable generation of function call.
                ::QMetaObject::Connection cppResult = PySide::qobjectConnectCallback(cppArg0, cppArg1, pyArgs[3-1], cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_Connection_IDX]), &cppResult);
                // END of custom code block [file: ../glue/qtcore.cpp (qobject-connect-4)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 2: // connect(const QObject *sender, const char *signal, const QObject *context, PyCallable *functor, Qt::ConnectionType type)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"type", 4}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[4]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "connect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)
            ::Qt::ConnectionType cppArg4(Qt::AutoConnection);
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            SBK_UNUSED(cppArg4)

            if (Shiboken::Errors::occurred() == nullptr) {
                // connect(const QObject*,const char*,const QObject*,PyCallable*,Qt::ConnectionType)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qobject-connect-4-context)]
                // connect() - disable generation of function call.
                ::QMetaObject::Connection cppResult = PySide::qobjectConnectCallback(cppArg0, cppArg1, cppArg2, pyArgs[4-1], cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_Connection_IDX]), &cppResult);
                // END of custom code block [file: ../glue/qtcore.cpp (qobject-connect-4-context)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 3: // connect(const QObject *sender, const char *signal, const QObject *receiver, const char *member, Qt::ConnectionType type)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"type", 4}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[4]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "connect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            const char* cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::Qt::ConnectionType cppArg4(Qt::AutoConnection);
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connect(const QObject*,const char*,const QObject*,const char*,Qt::ConnectionType)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qobject-connect-3)]
                // connect() - disable generation of function call.
                ::QMetaObject::Connection cppResult = PySide::qobjectConnect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_Connection_IDX]), &cppResult);
                // END of custom code block [file: ../glue/qtcore.cpp (qobject-connect-3)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 4: // connect(const QObject *sender, const char *signal, const char *member, Qt::ConnectionType type) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"type", 3}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[3]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "connect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            const char* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::Qt::ConnectionType cppArg3(Qt::AutoConnection);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connect(const QObject*,const char*,const char*,Qt::ConnectionType)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qobject-connect-1)]
                // connect() - disable generation of function call.
                ::QMetaObject::Connection cppResult = PySide::qobjectConnect(cppArg0, cppArg1, cppSelf, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_Connection_IDX]), &cppResult);
                // END of custom code block [file: ../glue/qtcore.cpp (qobject-connect-1)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 5: // connect(const char *signal, PyCallable *functor, Qt::ConnectionType type)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"type", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "connect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
                }
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            ::Qt::ConnectionType cppArg2(Qt::AutoConnection);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // connect(const char*,PyCallable*,Qt::ConnectionType)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qobject-connect-5)]
                // connect() - disable generation of function call.
                ::QMetaObject::Connection cppResult = PySide::qobjectConnectCallback(cppSelf, cppArg0, pyArgs[2-1], cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_Connection_IDX]), &cppResult);
                // END of custom code block [file: ../glue/qtcore.cpp (qobject-connect-5)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 6: // connect(const char *signal, const QObject *receiver, const char *method, Qt::ConnectionType type)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"type", 3}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[3]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "connect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
                }
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            const char* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)
            ::Qt::ConnectionType cppArg3(Qt::AutoConnection);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            SBK_UNUSED(cppArg3)

            if (Shiboken::Errors::occurred() == nullptr) {
                // connect(const char*,const QObject*,const char*,Qt::ConnectionType)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qobject-connect-6)]
                // connect() - disable generation of function call.
                ::QMetaObject::Connection cppResult = PySide::qobjectConnect(cppSelf, cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_Connection_IDX]), &cppResult);
                // END of custom code block [file: ../glue/qtcore.cpp (qobject-connect-6)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_connectNotify(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::connectNotify(QMetaMethod)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArg)))) {
        overloadId = 0; // connectNotify(QMetaMethod)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "connectNotify", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaMethod cppArg0_local;
        ::QMetaMethod *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // connectNotify(QMetaMethod)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QObject::connectNotify(*cppArg0)
                : cppSelf->connectNotify(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QObjectFunc_customEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::customEvent(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // customEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "customEvent", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // customEvent(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QObject::customEvent(cppArg0)
                : cppSelf->customEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QObjectFunc_deleteLater(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // deleteLater()
        cppSelf->deleteLater();

        // Ownership transferences.
        Shiboken::Object::releaseOwnership(self);
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QObjectFunc_disconnect(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QObject *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "disconnect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:disconnect", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QObject::disconnect(QMetaObject::Connection)->bool
    // 1: QObject::disconnect(const QObject*,const char*=)const->bool
    // 2: static QObject::disconnect(const QObject*,QMetaMethod,const QObject*,QMetaMethod)->bool
    // 3: static QObject::disconnect(const QObject*,const char*,PyCallable*)->bool
    // 4: static QObject::disconnect(const QObject*,const char*,const QObject*,const char*)->bool
    // 5: QObject::disconnect(const char*,PyCallable*)->bool
    // 6: QObject::disconnect(const char*,const QObject*,const char*)const->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))) {
            overloadId = 6; // disconnect(const char*,const QObject*,const char*)const
        } else if (numArgs == 2
            && PyCallable_Check(pyArgs[1])) {
            overloadId = 5; // disconnect(const char*,PyCallable*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // disconnect(const QObject*,const char*)const
        } else if (numArgs == 4
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArgs[3])))) {
            overloadId = 2; // disconnect(const QObject*,QMetaMethod,const QObject*,QMetaMethod)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // disconnect(const QObject*,const char*)const
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[3])))) {
                overloadId = 4; // disconnect(const QObject*,const char*,const QObject*,const char*)
            } else if (numArgs == 3
                && PyCallable_Check(pyArgs[2])) {
                overloadId = 3; // disconnect(const QObject*,const char*,PyCallable*)
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_Connection_IDX]), (pyArgs[0])))) {
        overloadId = 0; // disconnect(QMetaObject::Connection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "disconnect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // disconnect(const QMetaObject::Connection &connection)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "disconnect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMetaObject::Connection cppArg0_local;
            ::QMetaObject::Connection *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // disconnect(QMetaObject::Connection)
                bool cppResult = ::QObject::disconnect(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // disconnect(const QObject *receiver, const char *member) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"member", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "disconnect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // disconnect(const QObject*,const char*)const
                bool cppResult = const_cast<const ::QObject *>(cppSelf)->disconnect(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // disconnect(const QObject *sender, const QMetaMethod &signal, const QObject *receiver, const QMetaMethod &member)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "disconnect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMetaMethod cppArg1_local;
            ::QMetaMethod *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QMetaMethod cppArg3_local;
            ::QMetaMethod *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);


            if (Shiboken::Errors::occurred() == nullptr) {
                // disconnect(const QObject*,QMetaMethod,const QObject*,QMetaMethod)
                bool cppResult = ::QObject::disconnect(cppArg0, *cppArg1, cppArg2, *cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 3: // disconnect(const QObject *sender, const char *signal, PyCallable *functor)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "disconnect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // disconnect(const QObject*,const char*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qobject-disconnect-2)]
                // disconnect() - disable generation of function call.
                bool cppResult = PySide::qobjectDisconnectCallback(cppArg0, cppArg1, pyArgs[2]);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
                // END of custom code block [file: ../glue/qtcore.cpp (qobject-disconnect-2)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 4: // disconnect(const QObject *sender, const char *signal, const QObject *receiver, const char *member)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "disconnect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            const char* cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // disconnect(const QObject*,const char*,const QObject*,const char*)
                bool cppResult = ::QObject::disconnect(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 5: // disconnect(const char *signal, PyCallable *functor)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "disconnect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // disconnect(const char*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qobject-disconnect-1)]
                // disconnect() - disable generation of function call.
                bool cppResult = PySide::qobjectDisconnectCallback(cppSelf, cppArg0, pyArgs[1]);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
                // END of custom code block [file: ../glue/qtcore.cpp (qobject-disconnect-1)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 6: // disconnect(const char *signal, const QObject *receiver, const char *member) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "disconnect", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            const char* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // disconnect(const char*,const QObject*,const char*)const
                bool cppResult = const_cast<const ::QObject *>(cppSelf)->disconnect(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_disconnectNotify(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::disconnectNotify(QMetaMethod)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArg)))) {
        overloadId = 0; // disconnectNotify(QMetaMethod)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "disconnectNotify", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaMethod cppArg0_local;
        ::QMetaMethod *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // disconnectNotify(QMetaMethod)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QObject::disconnectNotify(*cppArg0)
                : cppSelf->disconnectNotify(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QObjectFunc_dumpObjectInfo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dumpObjectInfo()const
        const_cast<const ::QObject *>(cppSelf)->dumpObjectInfo();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QObjectFunc_dumpObjectTree(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dumpObjectTree()const
        const_cast<const ::QObject *>(cppSelf)->dumpObjectTree();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QObjectFunc_dynamicPropertyNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dynamicPropertyNames()const
        QList<QByteArray> cppResult = const_cast<const ::QObject *>(cppSelf)->dynamicPropertyNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_emit(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    PyObject *nonvarargs = PyTuple_GetSlice(args, 0, 1);
    Shiboken::AutoDecRef auto_nonvarargs(nonvarargs);
    pyArgs[1] = PyTuple_GetSlice(args, 1, numArgs);
    Shiboken::AutoDecRef auto_varargs(pyArgs[1]);

    // invalid argument lengths

    if (PyArg_UnpackTuple(nonvarargs, "emit", 1, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QObject::emit(const char*,...)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 0; // emit(const char*,...)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "emit", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // emit(const char*,...)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qobject-emit)]
            bool cppResult = PySide::SignalManager::emitSignal(cppSelf, cppArg0, pyArgs[2-1]);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            // END of custom code block [file: ../glue/qtcore.cpp (qobject-emit)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QObject::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_eventFilter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "eventFilter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QObject::eventFilter(QObject*,QEvent*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // eventFilter(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "eventFilter", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // eventFilter(QObject*,QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QObject::eventFilter(cppArg0, cppArg1)
                : cppSelf->eventFilter(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_findChild(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "findChild", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:findChild", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QObject::findChild(PyTypeObject*,const QString&=,QFlags<Qt::FindChildOption>=)->PyObject*
    if (numArgs >= 1
        && PyType_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // findChild(PyTypeObject*,QString,QFlags<Qt::FindChildOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // findChild(PyTypeObject*,QString,QFlags<Qt::FindChildOption>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_FindChildOption_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 0; // findChild(PyTypeObject*,QString,QFlags<Qt::FindChildOption>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "findChild", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"name", 1}, {"options", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_FindChildOption_IDX])))->flagsConverter, (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "findChild", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
            }
        }
        ::QString cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        SBK_UNUSED(cppArg1)
        ::QFlags<Qt::FindChildOption> cppArg2(Qt::FindChildrenRecursively);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        SBK_UNUSED(cppArg2)

        if (Shiboken::Errors::occurred() == nullptr) {
            // findChild(PyTypeObject*,QString,QFlags<Qt::FindChildOption>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qobject-findchild-2)]
            QObject *child = qObjectFindChild(cppSelf, cppArg1, reinterpret_cast<PyTypeObject *>(pyArgs[1-1]), cppArg2);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), child);
            // END of custom code block [file: ../glue/qtcore.cpp (qobject-findchild-2)]
            // ========================================================================
            // End of code injection

            // Ownership transferences.
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_findChildren(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "findChildren", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:findChildren", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QObject::findChildren(PyTypeObject*,QRegularExpression,QFlags<Qt::FindChildOption>=)->PySequence*
    // 1: QObject::findChildren(PyTypeObject*,const QString&=,QFlags<Qt::FindChildOption>=)->PySequence*
    if (numArgs >= 1
        && PyType_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // findChildren(PyTypeObject*,QString,QFlags<Qt::FindChildOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // findChildren(PyTypeObject*,QString,QFlags<Qt::FindChildOption>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_FindChildOption_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 1; // findChildren(PyTypeObject*,QString,QFlags<Qt::FindChildOption>)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // findChildren(PyTypeObject*,QRegularExpression,QFlags<Qt::FindChildOption>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_FindChildOption_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 0; // findChildren(PyTypeObject*,QRegularExpression,QFlags<Qt::FindChildOption>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "findChildren", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // findChildren(PyTypeObject *type, const QRegularExpression &pattern, QFlags<Qt::FindChildOption> options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"options", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_FindChildOption_IDX])))->flagsConverter, (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "findChildren", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRegularExpression cppArg1_local;
            ::QRegularExpression *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            SBK_UNUSED(cppArg1)
            ::QFlags<Qt::FindChildOption> cppArg2(Qt::FindChildrenRecursively);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // findChildren(PyTypeObject*,QRegularExpression,QFlags<Qt::FindChildOption>)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qobject-findchildren)]
                pyResult = PyList_New(0);
                qObjectFindChildren(cppSelf, (*cppArg1), reinterpret_cast<PyTypeObject *>(pyArgs[1-1]), cppArg2,
                                    [pyResult](QObject *child) {
                                        Shiboken::AutoDecRef pyChild(Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), child));
                                        PyList_Append(pyResult, pyChild.object());
                                    });
                // END of custom code block [file: ../glue/qtcore.cpp (qobject-findchildren)]
                // ========================================================================
                // End of code injection

                // Ownership transferences.
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // findChildren(PyTypeObject *type, const QString &name, QFlags<Qt::FindChildOption> options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"name", 1}, {"options", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_FindChildOption_IDX])))->flagsConverter, (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "findChildren", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
                }
            }
            ::QString cppArg1{};
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            ::QFlags<Qt::FindChildOption> cppArg2(Qt::FindChildrenRecursively);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)

            if (Shiboken::Errors::occurred() == nullptr) {
                // findChildren(PyTypeObject*,QString,QFlags<Qt::FindChildOption>)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qobject-findchildren)]
                pyResult = PyList_New(0);
                qObjectFindChildren(cppSelf, cppArg1, reinterpret_cast<PyTypeObject *>(pyArgs[1-1]), cppArg2,
                                    [pyResult](QObject *child) {
                                        Shiboken::AutoDecRef pyChild(Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), child));
                                        PyList_Append(pyResult, pyChild.object());
                                    });
                // END of custom code block [file: ../glue/qtcore.cpp (qobject-findchildren)]
                // ========================================================================
                // End of code injection

                // Ownership transferences.
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_inherits(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::inherits(const char*)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // inherits(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "inherits", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // inherits(const char*)const
            bool cppResult = const_cast<const ::QObject *>(cppSelf)->inherits(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_installEventFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::installEventFilter(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // installEventFilter(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "installEventFilter", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // installEventFilter(QObject*)
            cppSelf->installEventFilter(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QObjectFunc_isQuickItemType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isQuickItemType()const
        bool cppResult = const_cast<const ::QObject *>(cppSelf)->isQuickItemType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_isSignalConnected(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::isSignalConnected(QMetaMethod)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArg)))) {
        overloadId = 0; // isSignalConnected(QMetaMethod)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isSignalConnected", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaMethod cppArg0_local;
        ::QMetaMethod *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isSignalConnected(QMetaMethod)const
            bool cppResult = const_cast<const ::QObject *>(cppSelf)->isSignalConnected(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_isWidgetType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isWidgetType()const
        bool cppResult = const_cast<const ::QObject *>(cppSelf)->isWidgetType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_isWindowType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isWindowType()const
        bool cppResult = const_cast<const ::QObject *>(cppSelf)->isWindowType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_killTimer(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::killTimer(Qt::TimerId)
    // 1: QObject::killTimer(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerId_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // killTimer(Qt::TimerId)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 1; // killTimer(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "killTimer", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // killTimer(Qt::TimerId id)
        {
            ::Qt::TimerId cppArg0{Qt::TimerId::Invalid};
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // killTimer(Qt::TimerId)
                cppSelf->killTimer(cppArg0);
            }
            break;
        }
        case 1: // killTimer(int id)
        {
            int cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // killTimer(int)
                cppSelf->killTimer(cppArg0);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QObjectFunc_metaObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // metaObject()const
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (qobject-metaobject)]
        const ::QMetaObject * cppResult = cppSelf->metaObject();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), cppResult);
        // END of custom code block [file: ../glue/qtcore.cpp (qobject-metaobject)]
        // ========================================================================
        // End of code injection

        Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "metaObject()const0", pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_moveToThread(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::moveToThread(QThread*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), (pyArg)))) {
        overloadId = 0; // moveToThread(QThread*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "moveToThread", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QThread *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // moveToThread(QThread*)
            bool cppResult = cppSelf->moveToThread(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_objectName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // objectName()const
        QString cppResult = const_cast<const ::QObject *>(cppSelf)->objectName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_parent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parent()const
        QObject * cppResult = const_cast<const ::QObject *>(cppSelf)->parent();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);

        // Ownership transferences.
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_property(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::property(const char*)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // property(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "property", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // property(const char*)const
            QVariant cppResult = const_cast<const ::QObject *>(cppSelf)->property(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_receivers(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::receivers(const char*)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // receivers(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "receivers", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // receivers(const char*)const
            int cppResult = const_cast<const ::QObject *>(cppSelf)->receivers(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_removeEventFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::removeEventFilter(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // removeEventFilter(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeEventFilter", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeEventFilter(QObject*)
            cppSelf->removeEventFilter(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QObjectFunc_sender(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sender()const
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (qobject-sender)]
        // Retrieve the sender from a dynamic property set by GlobalReceiverV2 in case of a
        // non-C++ slot (Python callback).
        auto *ret = cppSelf->sender();
        if (ret == nullptr) {
            auto senderV = cppSelf->property("_q_pyside_sender");
            if (senderV.typeId() == QMetaType::QObjectStar)
                ret = senderV.value<QObject *>();
        }
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), ret);
        // END of custom code block [file: ../glue/qtcore.cpp (qobject-sender)]
        // ========================================================================
        // End of code injection


        // Ownership transferences.
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_senderSignalIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // senderSignalIndex()const
        int cppResult = const_cast<const ::QObject *>(cppSelf)->senderSignalIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_setObjectName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::setObjectName(QAnyStringView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setObjectName(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setObjectName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setObjectName(QAnyStringView)
            cppSelf->setObjectName(QAnyStringView(cppArg0));
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QObjectFunc_setParent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::setParent(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // setParent(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setParent", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setParent(QObject*)
            cppSelf->setParent(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(pyArg, self);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QObjectFunc_setProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setProperty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QObject::setProperty(const char*,QVariant)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // setProperty(const char*,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setProperty", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProperty(const char*,QVariant)
            bool cppResult = cppSelf->setProperty(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_signalsBlocked(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // signalsBlocked()const
        bool cppResult = const_cast<const ::QObject *>(cppSelf)->signalsBlocked();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_startTimer(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "startTimer", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    if (PyArg_ParseTuple(args, "|OO:startTimer", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QObject::startTimer(int,Qt::TimerType=)->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // startTimer(int,Qt::TimerType)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // startTimer(int,Qt::TimerType)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "startTimer", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"timerType", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimerType_IDX])))->converter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "startTimer", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::TimerType cppArg1(Qt::CoarseTimer);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // startTimer(int,Qt::TimerType)
            int cppResult = cppSelf->startTimer(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_thread(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // thread()const
        QThread * cppResult = const_cast<const ::QObject *>(cppSelf)->thread();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QObjectFunc_timerEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::timerEvent(QTimerEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), (pyArg)))) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "timerEvent", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTimerEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // timerEvent(QTimerEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QObject::timerEvent(cppArg0)
                : cppSelf->timerEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QObjectFunc_tr(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "tr", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:tr", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QObject::tr(const char*,const char*=,int=)->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // tr(const char*,const char*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // tr(const char*,const char*,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 0; // tr(const char*,const char*,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "tr", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"disambiguation", 1}, {"n", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1]))))
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "tr", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]);
            }
        }
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        SBK_UNUSED(cppArg0)
        const char* cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        SBK_UNUSED(cppArg1)
        int cppArg2 = -1;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        SBK_UNUSED(cppArg2)

        if (Shiboken::Errors::occurred() == nullptr) {
            // tr(const char*,const char*,int)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qobject-tr)]
            const QString result = qObjectTr(reinterpret_cast<PyTypeObject *>(self), cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &result);
            // END of custom code block [file: ../glue/qtcore.cpp (qobject-tr)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyMethodDef Sbk_QObjectMethod_connect = {"connect", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_connect), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QObjectMethod_disconnect = {"disconnect", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_disconnect), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr};


static const char *Sbk_QObject_PropertyStrings[] = {
    "objectName::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QObject_methods[] = {
    {"blockSignals", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_blockSignals), METH_O, nullptr},
    {"childEvent", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_childEvent), METH_O, nullptr},
    {"children", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_children), METH_NOARGS, nullptr},
    {"connect", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_connect), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"connectNotify", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_connectNotify), METH_O, nullptr},
    {"customEvent", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_customEvent), METH_O, nullptr},
    {"deleteLater", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_deleteLater), METH_NOARGS, nullptr},
    {"disconnect", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_disconnect), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"disconnectNotify", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_disconnectNotify), METH_O, nullptr},
    {"dumpObjectInfo", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_dumpObjectInfo), METH_NOARGS, nullptr},
    {"dumpObjectTree", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_dumpObjectTree), METH_NOARGS, nullptr},
    {"dynamicPropertyNames", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_dynamicPropertyNames), METH_NOARGS, nullptr},
    {"emit", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_emit), METH_VARARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_event), METH_O, nullptr},
    {"eventFilter", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_eventFilter), METH_VARARGS, nullptr},
    {"findChild", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_findChild), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"findChildren", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_findChildren), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"inherits", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_inherits), METH_O, nullptr},
    {"installEventFilter", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_installEventFilter), METH_O, nullptr},
    {"isQuickItemType", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_isQuickItemType), METH_NOARGS, nullptr},
    {"isSignalConnected", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_isSignalConnected), METH_O, nullptr},
    {"isWidgetType", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_isWidgetType), METH_NOARGS, nullptr},
    {"isWindowType", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_isWindowType), METH_NOARGS, nullptr},
    {"killTimer", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_killTimer), METH_O, nullptr},
    {"metaObject", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_metaObject), METH_NOARGS, nullptr},
    {"moveToThread", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_moveToThread), METH_O, nullptr},
    {"objectName", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_objectName), METH_NOARGS, nullptr},
    {"parent", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_parent), METH_NOARGS, nullptr},
    {"property", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_property), METH_O, nullptr},
    {"receivers", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_receivers), METH_O, nullptr},
    {"removeEventFilter", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_removeEventFilter), METH_O, nullptr},
    {"sender", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_sender), METH_NOARGS, nullptr},
    {"senderSignalIndex", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_senderSignalIndex), METH_NOARGS, nullptr},
    {"setObjectName", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_setObjectName), METH_O, nullptr},
    {"setParent", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_setParent), METH_O, nullptr},
    {"setProperty", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_setProperty), METH_VARARGS, nullptr},
    {"signalsBlocked", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_signalsBlocked), METH_NOARGS, nullptr},
    {"startTimer", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_startTimer), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"thread", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_thread), METH_NOARGS, nullptr},
    {"timerEvent", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_timerEvent), METH_O, nullptr},
    {"tr", reinterpret_cast<PyCFunction>(Sbk_QObjectFunc_tr), METH_VARARGS|METH_KEYWORDS|METH_CLASS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QObject_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PySide::getHiddenDataFromQObject(reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self))), self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QObjectMethod_connect = {
        Sbk_QObjectMethod_connect.ml_name,
        Sbk_QObjectMethod_connect.ml_meth,
        Sbk_QObjectMethod_connect.ml_flags & (~METH_STATIC),
        Sbk_QObjectMethod_connect.ml_doc,
    };
    if (Shiboken::String::compare(name, "connect") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QObjectMethod_connect, self, 0);
    static PyMethodDef non_static_Sbk_QObjectMethod_disconnect = {
        Sbk_QObjectMethod_disconnect.ml_name,
        Sbk_QObjectMethod_disconnect.ml_meth,
        Sbk_QObjectMethod_disconnect.ml_flags & (~METH_STATIC),
        Sbk_QObjectMethod_disconnect.ml_doc,
    };
    if (Shiboken::String::compare(name, "disconnect") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QObjectMethod_disconnect, self, 0);
    return PySide::getHiddenDataFromQObject(reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self))), self, name);
}

static int Sbk_QObject_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QObjectWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QObject_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QObject_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QObject__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QObject_Type = nullptr;
static PyTypeObject *Sbk_QObject_TypeF(void)
{
    return _Sbk_QObject_Type;
}

static PyType_Slot Sbk_QObject_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QObject__repr__)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QObject_getattro)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QObject_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QObject_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QObject_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QObject_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QObject_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QObject_spec = {
    "2:PySide6.QtCore.QObject",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QObject_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QObject_PythonToCpp_QObject_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QObject_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QObject_PythonToCpp_QObject_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QObject_TypeF()))
        return QObject_PythonToCpp_QObject_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QObject_PTR_CppToPython_QObject(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QObject *>(const_cast<void *>(cppIn)), Sbk_QObject_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QObject_SignatureStrings[] = {
    "PySide6.QtCore.QObject(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,objectName:QString=None)",
    "PySide6.QtCore.QObject.blockSignals(self,b:bool)->bool",
    "PySide6.QtCore.QObject.childEvent(self,event:PySide6.QtCore.QChildEvent)",
    "PySide6.QtCore.QObject.children(self)->QList[PySide6.QtCore.QObject]",
    "6:PySide6.QtCore.QObject.connect(sender:PySide6.QtCore.QObject,signal:PySide6.QtCore.QMetaMethod,receiver:PySide6.QtCore.QObject,method:PySide6.QtCore.QMetaMethod,type:PySide6.QtCore.Qt.ConnectionType=Qt.AutoConnection)->PySide6.QtCore.QMetaObject.Connection",
    "5:PySide6.QtCore.QObject.connect(sender:PySide6.QtCore.QObject,signal:char*,functor:PyCallable,type:PySide6.QtCore.Qt.ConnectionType=Qt.AutoConnection)->PySide6.QtCore.QMetaObject.Connection",
    "4:PySide6.QtCore.QObject.connect(sender:PySide6.QtCore.QObject,signal:char*,context:PySide6.QtCore.QObject,functor:PyCallable,type:PySide6.QtCore.Qt.ConnectionType=Qt.AutoConnection)->PySide6.QtCore.QMetaObject.Connection",
    "3:PySide6.QtCore.QObject.connect(sender:PySide6.QtCore.QObject,signal:char*,receiver:PySide6.QtCore.QObject,member:char*,type:PySide6.QtCore.Qt.ConnectionType=Qt.AutoConnection)->PySide6.QtCore.QMetaObject.Connection",
    "2:PySide6.QtCore.QObject.connect(self,sender:PySide6.QtCore.QObject,signal:char*,member:char*,type:PySide6.QtCore.Qt.ConnectionType=Qt.AutoConnection)->PySide6.QtCore.QMetaObject.Connection",
    "1:PySide6.QtCore.QObject.connect(self,signal:char*,functor:PyCallable,type:PySide6.QtCore.Qt.ConnectionType=Qt.AutoConnection)->PySide6.QtCore.QMetaObject.Connection",
    "0:PySide6.QtCore.QObject.connect(self,signal:char*,receiver:PySide6.QtCore.QObject,method:char*,type:PySide6.QtCore.Qt.ConnectionType=Qt.AutoConnection)->PySide6.QtCore.QMetaObject.Connection",
    "PySide6.QtCore.QObject.connectNotify(self,signal:PySide6.QtCore.QMetaMethod)",
    "PySide6.QtCore.QObject.customEvent(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtCore.QObject.deleteLater(self)",
    "6:PySide6.QtCore.QObject.disconnect(connection:PySide6.QtCore.QMetaObject.Connection)->bool",
    "5:PySide6.QtCore.QObject.disconnect(self,receiver:PySide6.QtCore.QObject,member:char*=nullptr)->bool",
    "4:PySide6.QtCore.QObject.disconnect(sender:PySide6.QtCore.QObject,signal:PySide6.QtCore.QMetaMethod,receiver:PySide6.QtCore.QObject,member:PySide6.QtCore.QMetaMethod)->bool",
    "3:PySide6.QtCore.QObject.disconnect(sender:PySide6.QtCore.QObject,signal:char*,functor:PyCallable)->bool",
    "2:PySide6.QtCore.QObject.disconnect(sender:PySide6.QtCore.QObject,signal:char*,receiver:PySide6.QtCore.QObject,member:char*)->bool",
    "1:PySide6.QtCore.QObject.disconnect(self,signal:char*,functor:PyCallable)->bool",
    "0:PySide6.QtCore.QObject.disconnect(self,signal:char*,receiver:PySide6.QtCore.QObject,member:char*)->bool",
    "PySide6.QtCore.QObject.disconnectNotify(self,signal:PySide6.QtCore.QMetaMethod)",
    "PySide6.QtCore.QObject.dumpObjectInfo(self)",
    "PySide6.QtCore.QObject.dumpObjectTree(self)",
    "PySide6.QtCore.QObject.dynamicPropertyNames(self)->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtCore.QObject.emit(self,signal:char*,arg__2:...)->bool",
    "PySide6.QtCore.QObject.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtCore.QObject.eventFilter(self,watched:PySide6.QtCore.QObject,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtCore.QObject.findChild(self,type:typing.Type[PlaceholderType],name:QString={},options:PySide6.QtCore.Qt.FindChildOption=Qt.FindChildrenRecursively)->Optional[PlaceholderType]",
    "1:PySide6.QtCore.QObject.findChildren(self,type:typing.Type[PlaceholderType],pattern:typing.Union[PySide6.QtCore.QRegularExpression, QString],options:PySide6.QtCore.Qt.FindChildOption=Qt.FindChildrenRecursively)->List[PlaceholderType]",
    "0:PySide6.QtCore.QObject.findChildren(self,type:typing.Type[PlaceholderType],name:QString={},options:PySide6.QtCore.Qt.FindChildOption=Qt.FindChildrenRecursively)->List[PlaceholderType]",
    "PySide6.QtCore.QObject.inherits(self,classname:char*)->bool",
    "PySide6.QtCore.QObject.installEventFilter(self,filterObj:PySide6.QtCore.QObject)",
    "PySide6.QtCore.QObject.isQuickItemType(self)->bool",
    "PySide6.QtCore.QObject.isSignalConnected(self,signal:PySide6.QtCore.QMetaMethod)->bool",
    "PySide6.QtCore.QObject.isWidgetType(self)->bool",
    "PySide6.QtCore.QObject.isWindowType(self)->bool",
    "1:PySide6.QtCore.QObject.killTimer(self,id:PySide6.QtCore.Qt.TimerId)",
    "0:PySide6.QtCore.QObject.killTimer(self,id:int)",
    "PySide6.QtCore.QObject.metaObject(self)->PySide6.QtCore.QMetaObject",
    "PySide6.QtCore.QObject.moveToThread(self,thread:PySide6.QtCore.QThread)->bool",
    "PySide6.QtCore.QObject.objectName(self)->QString",
    "PySide6.QtCore.QObject.parent(self)->PySide6.QtCore.QObject",
    "PySide6.QtCore.QObject.property(self,name:char*)->QVariant",
    "PySide6.QtCore.QObject.receivers(self,signal:char*)->int",
    "PySide6.QtCore.QObject.removeEventFilter(self,obj:PySide6.QtCore.QObject)",
    "PySide6.QtCore.QObject.sender(self)->PySide6.QtCore.QObject",
    "PySide6.QtCore.QObject.senderSignalIndex(self)->int",
    "PySide6.QtCore.QObject.setObjectName(self,name:QString)",
    "PySide6.QtCore.QObject.setParent(self,parent:Optional[PySide6.QtCore.QObject])",
    "PySide6.QtCore.QObject.setProperty(self,name:char*,value:QVariant)->bool",
    "PySide6.QtCore.QObject.signalsBlocked(self)->bool",
    "PySide6.QtCore.QObject.startTimer(self,interval:int,timerType:PySide6.QtCore.Qt.TimerType=Qt.CoarseTimer)->int",
    "PySide6.QtCore.QObject.thread(self)->PySide6.QtCore.QThread",
    "PySide6.QtCore.QObject.timerEvent(self,event:PySide6.QtCore.QTimerEvent)",
    "PySide6.QtCore.QObject.tr(self,sourceText:str,disambiguation:Optional[str]=nullptr,n:int=-1)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QObject_SignatureByteSize = 953;
static constexpr uint8_t QObject_SignatureBytes[953] = {
    0x78, 0xda, 0xc5, 0x58, 0xdd, 0x4f, 0xdb, 0x30, 0x10, 0x7f, 0xe7, 0xaf, 0xd8, 0xe3, 0x40, 0x59,
    0x55, 0x3e, 0x1f, 0x2a, 0x75, 0x12, 0x54, 0x20, 0x55, 0x63, 0xb4, 0x85, 0x6c, 0x3c, 0xa0, 0x0a,
    0xb9, 0xc9, 0xb5, 0xf5, 0x70, 0xec, 0xc8, 0x76, 0x0a, 0xd1, 0xb4, 0xff, 0x7d, 0x8e, 0x1d, 0xf7,
    0x83, 0xc6, 0x49, 0x5a, 0xb5, 0xf0, 0x00, 0x04, 0xfb, 0xe7, 0xbb, 0xdf, 0xdd, 0xf9, 0xee, 0x6c,
    0xf7, 0xd3, 0x07, 0x1c, 0xc2, 0x45, 0x63, 0x20, 0x3b, 0x8c, 0x43, 0x63, 0xd0, 0x1b, 0xfd, 0x81,
    0x40, 0x7e, 0x15, 0x40, 0xc6, 0x5e, 0x8c, 0x38, 0x50, 0xd9, 0xea, 0x17, 0x42, 0xda, 0x34, 0x21,
    0x24, 0x96, 0xdc, 0x3b, 0x6a, 0xfd, 0x80, 0xf4, 0x95, 0xf1, 0xb0, 0x47, 0x49, 0xda, 0xbe, 0x63,
    0x14, 0x3c, 0xa6, 0x11, 0x77, 0x28, 0x82, 0xd6, 0xe0, 0x41, 0x72, 0x4c, 0x27, 0x7a, 0xfc, 0xf0,
    0xa0, 0x58, 0x54, 0x63, 0x44, 0x58, 0xf0, 0xf2, 0x80, 0x27, 0x14, 0x11, 0x61, 0x54, 0x8f, 0x5a,
    0x23, 0xc6, 0xc8, 0xe1, 0xb7, 0xef, 0xd9, 0x1f, 0xd7, 0xb2, 0x60, 0x8a, 0x49, 0x78, 0x3d, 0x53,
    0x1c, 0xcd, 0x22, 0x98, 0x15, 0xd1, 0xed, 0xcc, 0x51, 0x87, 0xa5, 0x82, 0x94, 0xad, 0x5a, 0x8c,
    0x52, 0x3a, 0xb8, 0xc5, 0x42, 0x3e, 0x15, 0x83, 0x87, 0x07, 0x17, 0x2d, 0x97, 0x18, 0x46, 0xa9,
    0x71, 0x1e, 0x0d, 0x81, 0x3b, 0x50, 0x9e, 0xd0, 0x76, 0xae, 0xcd, 0xfe, 0x04, 0x89, 0xd4, 0xcf,
    0x94, 0x85, 0x1e, 0x87, 0x00, 0xf0, 0xcc, 0x2d, 0x21, 0xd2, 0xb0, 0x32, 0x09, 0x32, 0x8d, 0x61,
    0x6d, 0x5e, 0x36, 0x3a, 0x86, 0x20, 0x66, 0xd4, 0x57, 0x80, 0xb6, 0x1a, 0xb9, 0x4c, 0x24, 0x5b,
    0x8c, 0x2a, 0xd3, 0x8b, 0x84, 0xe6, 0xe6, 0x2d, 0x70, 0x07, 0xe7, 0x3b, 0x71, 0x41, 0x30, 0x45,
    0xfc, 0xc8, 0x1b, 0x27, 0x34, 0x90, 0x2c, 0xc3, 0x76, 0x10, 0x21, 0x68, 0x44, 0x60, 0xef, 0xf4,
    0xcf, 0x76, 0x48, 0x5f, 0x2d, 0x91, 0xf0, 0xe6, 0xca, 0x92, 0xcf, 0xb0, 0xee, 0x74, 0x87, 0xd6,
    0x55, 0x6f, 0xc5, 0x68, 0xa4, 0x66, 0x0d, 0x78, 0xdf, 0x86, 0x9d, 0x54, 0x1b, 0xa6, 0xaa, 0xc0,
    0x06, 0xd6, 0x7d, 0x28, 0xfb, 0xe3, 0x7a, 0xec, 0x3f, 0x39, 0x35, 0x9a, 0x9b, 0xb3, 0xac, 0x59,
    0xae, 0x3e, 0xc6, 0xcb, 0xe5, 0xec, 0xef, 0x98, 0xc4, 0xe3, 0x74, 0xc5, 0x06, 0x77, 0x15, 0x75,
    0xb7, 0x8b, 0x44, 0x48, 0x16, 0x55, 0x36, 0x9e, 0xf2, 0x9e, 0x13, 0x02, 0x01, 0x09, 0xb7, 0x48,
    0x02, 0x37, 0x6d, 0xc7, 0xdd, 0x57, 0x42, 0x2c, 0xac, 0xf7, 0x83, 0xb9, 0xa5, 0xad, 0x5a, 0xfe,
    0xb0, 0x1d, 0xf4, 0xbc, 0x86, 0x6c, 0x6d, 0xca, 0x26, 0x09, 0x6f, 0x8f, 0x00, 0x56, 0xc9, 0x59,
    0x2d, 0x25, 0xfb, 0xee, 0x8d, 0x9a, 0x5f, 0x49, 0x54, 0x73, 0xb2, 0xa7, 0xbb, 0x22, 0xeb, 0x4a,
    0x55, 0xab, 0xe8, 0x64, 0xb7, 0x8a, 0x36, 0x09, 0x90, 0xa5, 0x70, 0x5c, 0x37, 0xfa, 0x35, 0x4d,
    0x6a, 0x6e, 0x25, 0x6f, 0x1b, 0xe6, 0x95, 0x7a, 0x76, 0x93, 0xd1, 0x61, 0x12, 0xc5, 0xe6, 0xb3,
    0x4b, 0xc7, 0x2c, 0xcf, 0xc7, 0x4a, 0xac, 0xcf, 0x01, 0x2a, 0xb0, 0x29, 0x45, 0x11, 0x0e, 0xfa,
    0x9c, 0xc5, 0xc0, 0x65, 0x9a, 0x9d, 0x88, 0x45, 0xf9, 0x21, 0xf3, 0x2a, 0x95, 0x70, 0xc9, 0x39,
    0x4a, 0x87, 0x2e, 0x99, 0x10, 0xe1, 0x22, 0xef, 0x22, 0x3e, 0x79, 0x7e, 0x3e, 0x69, 0x35, 0x1a,
    0x8d, 0x0a, 0xdf, 0x41, 0xbd, 0xba, 0x55, 0x43, 0xc8, 0x0d, 0x26, 0xb6, 0x7a, 0x79, 0xaf, 0x48,
    0x06, 0x53, 0x08, 0x5d, 0xb1, 0xdd, 0x5e, 0xd3, 0x18, 0xd3, 0x50, 0x1f, 0xe1, 0x8d, 0x1e, 0xdd,
    0x3f, 0xd4, 0x2f, 0x75, 0xa7, 0x68, 0x64, 0xad, 0xe2, 0xa9, 0x4f, 0x50, 0x00, 0x53, 0x46, 0x54,
    0xfe, 0x64, 0xff, 0x0f, 0x3d, 0xba, 0x7c, 0xed, 0xf8, 0xfb, 0xcf, 0x63, 0x71, 0x56, 0x08, 0x45,
    0x41, 0xd3, 0xb9, 0xb1, 0xa2, 0x7b, 0x1a, 0xd2, 0x5e, 0x1e, 0x52, 0xb7, 0x81, 0x7b, 0x08, 0x12,
    0x2e, 0xd4, 0x8e, 0x25, 0xa9, 0xe2, 0x68, 0x30, 0x88, 0xac, 0x29, 0x74, 0x67, 0xd7, 0x78, 0x49,
    0x58, 0x5d, 0xf6, 0x31, 0x92, 0xca, 0xa7, 0xd4, 0x82, 0x7e, 0x51, 0xa5, 0x74, 0x6d, 0x93, 0xdc,
    0xc3, 0x24, 0x21, 0x88, 0x5f, 0xbf, 0xc5, 0x1c, 0x84, 0x50, 0x08, 0xef, 0x4b, 0x6e, 0xf0, 0x70,
    0x57, 0xe6, 0x9a, 0xcd, 0xf9, 0xde, 0xd4, 0xe6, 0x2e, 0x4d, 0xdd, 0x53, 0xa0, 0x8a, 0x99, 0x3b,
    0x78, 0x63, 0x3a, 0x05, 0x8e, 0x65, 0x7e, 0xeb, 0x0c, 0x08, 0x12, 0x42, 0xd3, 0xaa, 0x53, 0x84,
    0x30, 0x15, 0x52, 0x15, 0xc6, 0xeb, 0xf7, 0xa9, 0x30, 0xd6, 0xdf, 0x0a, 0xe4, 0x70, 0x96, 0xb3,
    0x5a, 0x60, 0x31, 0x48, 0x70, 0xf0, 0xd2, 0x95, 0x10, 0x65, 0xa4, 0x6d, 0xa1, 0x28, 0xe5, 0x20,
    0xcc, 0xb5, 0x39, 0xef, 0xf8, 0x10, 0xd6, 0xad, 0x84, 0x55, 0x62, 0x1f, 0x71, 0x38, 0x01, 0x59,
    0x9f, 0xc6, 0xa3, 0x8a, 0x07, 0x7b, 0x5d, 0xc3, 0x3b, 0x73, 0xe3, 0x05, 0x13, 0xe2, 0xe3, 0xc8,
    0xfa, 0x0c, 0x87, 0x05, 0x61, 0xd7, 0xf3, 0x5d, 0x55, 0xb5, 0x9b, 0xf5, 0xa5, 0xe0, 0x92, 0x23,
    0x57, 0x34, 0x3f, 0x21, 0x59, 0x8e, 0xee, 0x33, 0x94, 0x53, 0x06, 0x9b, 0x81, 0xcf, 0xfc, 0x29,
    0x07, 0x64, 0x2b, 0x92, 0xfe, 0x5e, 0x63, 0x68, 0x20, 0x15, 0x7e, 0x5b, 0x3c, 0x94, 0xcc, 0xbb,
    0x82, 0xc9, 0x07, 0xd7, 0x02, 0xf3, 0x24, 0xe3, 0xa2, 0x5f, 0x4e, 0x3d, 0xce, 0xbb, 0x90, 0xa1,
    0xbd, 0xb2, 0xcd, 0x07, 0xbf, 0x11, 0xc7, 0x88, 0x3a, 0x97, 0xda, 0xd6, 0x2d, 0xd6, 0x1b, 0x8f,
    0x5a, 0x8d, 0xcb, 0x16, 0x66, 0x0e, 0x5b, 0x4b, 0x11, 0xb6, 0x79, 0x72, 0x98, 0x23, 0xd2, 0x76,
    0x96, 0x9b, 0xb5, 0x26, 0x53, 0xba, 0xea, 0xf3, 0xcd, 0x8a, 0x29, 0x61, 0x2e, 0x40, 0xf6, 0x56,
    0xa3, 0xb3, 0x52, 0xb0, 0x4a, 0x78, 0xca, 0xfe, 0x22, 0x48, 0xf6, 0x0d, 0x6d, 0xd1, 0x3d, 0x8a,
    0x1f, 0x95, 0x4a, 0xc5, 0x39, 0xe2, 0xe6, 0xcd, 0x10, 0x49, 0x14, 0xa1, 0x3c, 0x76, 0x15, 0x5b,
    0xcd, 0xc4, 0x4c, 0x5c, 0x65, 0x4f, 0x6d, 0x79, 0x99, 0xa8, 0x5a, 0x21, 0x11, 0x97, 0xcb, 0xd9,
    0x45, 0x55, 0xfc, 0x94, 0xce, 0x2c, 0xc7, 0x3c, 0x99, 0x8d, 0xfb, 0xc5, 0x97, 0x39, 0xdf, 0xce,
    0xb5, 0xf5, 0xcd, 0x0e, 0x71, 0x01, 0x7a, 0xa8, 0xdc, 0xe1, 0x72, 0x91, 0x53, 0x05, 0x01, 0x36,
    0xe9, 0xe4, 0x5c, 0x9b, 0x89, 0xaf, 0xbc, 0x90, 0xf9, 0x73, 0x94, 0xd3, 0xdd, 0x32, 0xb7, 0x55,
    0xb0, 0x84, 0x07, 0xe0, 0x67, 0x0f, 0x3b, 0x42, 0x72, 0x4f, 0x9d, 0x37, 0x51, 0x34, 0xc2, 0x93,
    0x04, 0xe9, 0xab, 0xd7, 0x3c, 0x9a, 0x6a, 0x6e, 0x38, 0x7f, 0x08, 0xa5, 0x99, 0x63, 0xda, 0xdf,
    0x8e, 0x97, 0xb2, 0xf8, 0x3f, 0x9a, 0xc5, 0xad, 0xdb
};
#endif

PyTypeObject *init_QObject(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX].type;

    Shiboken::AutoDecRef Sbk_QObject_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QObject_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QObject",
        "QObject*",
        &Sbk_QObject_spec,
        &Shiboken::callCppDestructor< QObject >,
        Sbk_QObject_Type_bases.object(),
        0);
    auto *pyType = Sbk_QObject_TypeF(); // references _Sbk_QObject_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QObject_SignatureStrings);
#else
    InitSignatureBytes(pyType, QObject_SignatureBytes, QObject_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QObject_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QObject_PythonToCpp_QObject_PTR,
        is_QObject_PythonToCpp_QObject_PTR_Convertible,
        QObject_PTR_CppToPython_QObject);

    Shiboken::Conversions::registerConverterName(converter, "QObject");
    Shiboken::Conversions::registerConverterName(converter, "QObject*");
    Shiboken::Conversions::registerConverterName(converter, "QObject&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QObject).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QObjectWrapper).name());


    PySide::Signal::registerSignals(pyType, &::QObject::staticMetaObject);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QObject::staticMetaObject, sizeof(QObjectWrapper));

    return pyType;
}

