// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qoperatingsystemversionbase_wrapper.h"

// Argument includes
#include <QString>
#include <qoperatingsystemversion.h>
#include <qversionnumber.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOperatingSystemVersionBase_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOperatingSystemVersionBase >()))
        return -1;

    ::QOperatingSystemVersionBase *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QOperatingSystemVersionBase", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOperatingSystemVersionBase::QOperatingSystemVersionBase()
    // 1: QOperatingSystemVersionBase::QOperatingSystemVersionBase(QOperatingSystemVersionBase)
    if (numArgs == 0) {
        overloadId = 0; // QOperatingSystemVersionBase()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QOperatingSystemVersionBase(QOperatingSystemVersionBase)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOperatingSystemVersionBase()
        {

            // QOperatingSystemVersionBase()
            cptr = new ::QOperatingSystemVersionBase();
            break;
        }
        case 1: // QOperatingSystemVersionBase(const QOperatingSystemVersionBase &QOperatingSystemVersionBase)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QOperatingSystemVersionBase cppArg0_local = QOperatingSystemVersionBase(QOperatingSystemVersionBase::Unknown, 1);
            ::QOperatingSystemVersionBase *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QOperatingSystemVersionBase(QOperatingSystemVersionBase)
                cptr = new ::QOperatingSystemVersionBase(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOperatingSystemVersionBase >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_compare(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "compare", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QOperatingSystemVersionBase::compare(QOperatingSystemVersionBase,QOperatingSystemVersionBase)->int
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArgs[1])))) {
        overloadId = 0; // compare(QOperatingSystemVersionBase,QOperatingSystemVersionBase)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "compare", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QOperatingSystemVersionBase cppArg0 = QOperatingSystemVersionBase(QOperatingSystemVersionBase::Unknown, 1);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QOperatingSystemVersionBase cppArg1 = QOperatingSystemVersionBase(QOperatingSystemVersionBase::Unknown, 1);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // compare(QOperatingSystemVersionBase,QOperatingSystemVersionBase)
            int cppResult = ::QOperatingSystemVersionBase::compare(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_current(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // current()
        QOperatingSystemVersionBase cppResult = ::QOperatingSystemVersionBase::current();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_majorVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // majorVersion()const
        int cppResult = const_cast<const ::QOperatingSystemVersionBase *>(cppSelf)->majorVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_microVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // microVersion()const
        int cppResult = const_cast<const ::QOperatingSystemVersionBase *>(cppSelf)->microVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_minorVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minorVersion()const
        int cppResult = const_cast<const ::QOperatingSystemVersionBase *>(cppSelf)->minorVersion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_name(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QOperatingSystemVersionBase *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "name", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOperatingSystemVersionBase::name()const->QString
    // 1: static QOperatingSystemVersionBase::name(QOperatingSystemVersionBase)->QString
    if (numArgs == 0) {
        overloadId = 0; // name()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArgs[0])))) {
        overloadId = 1; // name(QOperatingSystemVersionBase)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "name", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // name() const
        {

            // name()const
            QString cppResult = const_cast<const ::QOperatingSystemVersionBase *>(cppSelf)->name();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            break;
        }
        case 1: // name(QOperatingSystemVersionBase osversion)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QOperatingSystemVersionBase cppArg0 = QOperatingSystemVersionBase(QOperatingSystemVersionBase::Unknown, 1);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // name(QOperatingSystemVersionBase)
                QString cppResult = ::QOperatingSystemVersionBase::name(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_segmentCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // segmentCount()const
        int cppResult = const_cast<const ::QOperatingSystemVersionBase *>(cppSelf)->segmentCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOperatingSystemVersionBaseFunc_version(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // version()const
        QVersionNumber cppResult = const_cast<const ::QOperatingSystemVersionBase *>(cppSelf)->version();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOperatingSystemVersionBase__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QOperatingSystemVersionBaseMethod_name = {"name", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_name), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_QOperatingSystemVersionBase_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOperatingSystemVersionBase_methods[] = {
    {"compare", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_compare), METH_VARARGS|METH_STATIC, nullptr},
    {"current", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_current), METH_NOARGS|METH_STATIC, nullptr},
    {"majorVersion", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_majorVersion), METH_NOARGS, nullptr},
    {"microVersion", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_microVersion), METH_NOARGS, nullptr},
    {"minorVersion", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_minorVersion), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_name), METH_VARARGS|METH_STATIC, nullptr},
    {"segmentCount", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_segmentCount), METH_NOARGS, nullptr},
    {"version", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBaseFunc_version), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QOperatingSystemVersionBase__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QOperatingSystemVersionBase_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QOperatingSystemVersionBaseMethod_name = {
        Sbk_QOperatingSystemVersionBaseMethod_name.ml_name,
        Sbk_QOperatingSystemVersionBaseMethod_name.ml_meth,
        Sbk_QOperatingSystemVersionBaseMethod_name.ml_flags & (~METH_STATIC),
        Sbk_QOperatingSystemVersionBaseMethod_name.ml_doc,
    };
    if (Shiboken::String::compare(name, "name") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QOperatingSystemVersionBaseMethod_name, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

// Rich comparison
static PyObject * Sbk_QOperatingSystemVersionBase_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArg)))) {
                // operator<(QOperatingSystemVersionBase rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QOperatingSystemVersionBase cppArg0 = QOperatingSystemVersionBase(QOperatingSystemVersionBase::Unknown, 1);
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf < (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArg)))) {
                // operator<=(QOperatingSystemVersionBase rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QOperatingSystemVersionBase cppArg0 = QOperatingSystemVersionBase(QOperatingSystemVersionBase::Unknown, 1);
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf <= (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArg)))) {
                // operator>(QOperatingSystemVersionBase rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QOperatingSystemVersionBase cppArg0 = QOperatingSystemVersionBase(QOperatingSystemVersionBase::Unknown, 1);
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf > (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), (pyArg)))) {
                // operator>=(QOperatingSystemVersionBase rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QOperatingSystemVersionBase cppArg0 = QOperatingSystemVersionBase(QOperatingSystemVersionBase::Unknown, 1);
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf >= (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QOperatingSystemVersionBase_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOperatingSystemVersionBase_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOperatingSystemVersionBase_Type = nullptr;
static PyTypeObject *Sbk_QOperatingSystemVersionBase_TypeF(void)
{
    return _Sbk_QOperatingSystemVersionBase_Type;
}

static PyType_Slot Sbk_QOperatingSystemVersionBase_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QOperatingSystemVersionBase_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOperatingSystemVersionBase_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOperatingSystemVersionBase_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QOperatingSystemVersionBase_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOperatingSystemVersionBase_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOperatingSystemVersionBase_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOperatingSystemVersionBase_spec = {
    "2:PySide6.QtCore.QOperatingSystemVersionBase",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOperatingSystemVersionBase_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOperatingSystemVersionBase_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOperatingSystemVersionBase_TypeF()))
        return QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOperatingSystemVersionBase_PTR_CppToPython_QOperatingSystemVersionBase(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QOperatingSystemVersionBase_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QOperatingSystemVersionBase_COPY_CppToPython_QOperatingSystemVersionBase(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QOperatingSystemVersionBase *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QOperatingSystemVersionBase_TypeF(), new ::QOperatingSystemVersionBase(*source), true, true);
}

// Python to C++ copy conversion.
static void QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QOperatingSystemVersionBase *>(cppOut) = *reinterpret_cast< ::QOperatingSystemVersionBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QOperatingSystemVersionBase_TypeF()))
        return QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOperatingSystemVersionBase_SignatureStrings[] = {
    "1:PySide6.QtCore.QOperatingSystemVersionBase(self)",
    "0:PySide6.QtCore.QOperatingSystemVersionBase(self,QOperatingSystemVersionBase:PySide6.QtCore.QOperatingSystemVersionBase)",
    "PySide6.QtCore.QOperatingSystemVersionBase.compare(v1:PySide6.QtCore.QOperatingSystemVersionBase,v2:PySide6.QtCore.QOperatingSystemVersionBase)->int",
    "PySide6.QtCore.QOperatingSystemVersionBase.current()->PySide6.QtCore.QOperatingSystemVersionBase",
    "PySide6.QtCore.QOperatingSystemVersionBase.majorVersion(self)->int",
    "PySide6.QtCore.QOperatingSystemVersionBase.microVersion(self)->int",
    "PySide6.QtCore.QOperatingSystemVersionBase.minorVersion(self)->int",
    "1:PySide6.QtCore.QOperatingSystemVersionBase.name(self)->QString",
    "0:PySide6.QtCore.QOperatingSystemVersionBase.name(osversion:PySide6.QtCore.QOperatingSystemVersionBase)->QString",
    "PySide6.QtCore.QOperatingSystemVersionBase.segmentCount(self)->int",
    "PySide6.QtCore.QOperatingSystemVersionBase.version(self)->PySide6.QtCore.QVersionNumber",
    "PySide6.QtCore.QOperatingSystemVersionBase.__copy__(self)->typing.Self",
    "PySide6.QtCore.QOperatingSystemVersionBase.__lt__(self,rhs:PySide6.QtCore.QOperatingSystemVersionBase)->bool",
    "PySide6.QtCore.QOperatingSystemVersionBase.__le__(self,rhs:PySide6.QtCore.QOperatingSystemVersionBase)->bool",
    "PySide6.QtCore.QOperatingSystemVersionBase.__gt__(self,rhs:PySide6.QtCore.QOperatingSystemVersionBase)->bool",
    "PySide6.QtCore.QOperatingSystemVersionBase.__ge__(self,rhs:PySide6.QtCore.QOperatingSystemVersionBase)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QOperatingSystemVersionBase_SignatureByteSize = 229;
static constexpr uint8_t QOperatingSystemVersionBase_SignatureBytes[229] = {
    0x78, 0xda, 0xbd, 0x52, 0xbd, 0x0e, 0x82, 0x30, 0x10, 0xde, 0x7d, 0x12, 0x48, 0xb0, 0x11, 0x07,
    0x07, 0x07, 0x07, 0xd9, 0x55, 0x42, 0xe2, 0x4a, 0x0a, 0x9e, 0x58, 0x43, 0x7b, 0xe4, 0x5a, 0x48,
    0x78, 0x7b, 0x9b, 0x00, 0x83, 0xc6, 0x18, 0x4e, 0x13, 0xc7, 0x5e, 0xbe, 0xbf, 0xbb, 0xaf, 0xf1,
    0xf6, 0xd4, 0x67, 0xea, 0x02, 0x1b, 0x91, 0xba, 0x04, 0x09, 0x44, 0x7a, 0x6c, 0x80, 0xa4, 0x53,
    0xa6, 0xca, 0x7a, 0xeb, 0x40, 0x9f, 0x81, 0xac, 0x42, 0xb3, 0x97, 0x16, 0x02, 0x0b, 0xf5, 0x35,
    0x5c, 0xac, 0xb8, 0x94, 0xe8, 0x03, 0x80, 0xa1, 0x15, 0x2e, 0xe6, 0x63, 0x45, 0x89, 0xba, 0x91,
    0x04, 0x41, 0x17, 0x33, 0x1c, 0xa2, 0x6e, 0xcd, 0xc9, 0xb3, 0xdc, 0x29, 0xe3, 0x58, 0xa1, 0x5a,
    0x22, 0x30, 0x2e, 0xf0, 0xcc, 0xf9, 0x2c, 0x8e, 0x81, 0x96, 0x77, 0xa4, 0x71, 0x30, 0xb4, 0xc5,
    0xce, 0xa8, 0x55, 0x49, 0xf8, 0xab, 0x84, 0x79, 0x9b, 0x82, 0x53, 0x85, 0x30, 0x52, 0xc3, 0x44,
    0x4e, 0x33, 0x47, 0x1e, 0xc4, 0xfa, 0x79, 0x83, 0x00, 0xda, 0x6e, 0x18, 0xf1, 0x7a, 0x9d, 0x0c,
    0x19, 0x76, 0x16, 0x2a, 0xed, 0xbb, 0x4d, 0xb0, 0xf5, 0x05, 0x7f, 0x77, 0xb7, 0xee, 0xf9, 0x64,
    0xaf, 0xcc, 0x11, 0x7a, 0x68, 0x75, 0x01, 0xc4, 0xd1, 0xcd, 0xf3, 0x12, 0x9b, 0x3e, 0xcf, 0x27,
    0x61, 0xd7, 0x37, 0x1e, 0x27, 0x32, 0xff, 0xe2, 0xc9, 0xd4, 0x6e, 0x14, 0x89, 0xe8, 0x66, 0x79,
    0x17, 0x2d, 0x10, 0x6b, 0xa6, 0x19, 0xfc, 0xd1, 0xac, 0xfa, 0xe7, 0x66, 0xd5, 0x8f, 0x9b, 0x3d,
    0x00, 0x67, 0x04, 0x1d, 0x89
};
#endif

PyTypeObject *init_QOperatingSystemVersionBase(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX].type;

    Shiboken::AutoDecRef Sbk_QOperatingSystemVersionBase_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QOperatingSystemVersionBase_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOperatingSystemVersionBase",
        "QOperatingSystemVersionBase",
        &Sbk_QOperatingSystemVersionBase_spec,
        &Shiboken::callCppDestructor< ::QOperatingSystemVersionBase >,
        Sbk_QOperatingSystemVersionBase_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QOperatingSystemVersionBase_TypeF(); // references _Sbk_QOperatingSystemVersionBase_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOperatingSystemVersionBase_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOperatingSystemVersionBase_SignatureBytes, QOperatingSystemVersionBase_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOperatingSystemVersionBase_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QOperatingSystemVersionBase_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_PTR,
        is_QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_PTR_Convertible,
        QOperatingSystemVersionBase_PTR_CppToPython_QOperatingSystemVersionBase,
        QOperatingSystemVersionBase_COPY_CppToPython_QOperatingSystemVersionBase);

    Shiboken::Conversions::registerConverterName(converter, "QOperatingSystemVersionBase");
    Shiboken::Conversions::registerConverterName(converter, "QOperatingSystemVersionBase*");
    Shiboken::Conversions::registerConverterName(converter, "QOperatingSystemVersionBase&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOperatingSystemVersionBase).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_COPY,
        is_QOperatingSystemVersionBase_PythonToCpp_QOperatingSystemVersionBase_COPY_Convertible);


    return pyType;
}
