// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qregularexpression_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <QStringView>
#include <qnamespace.h>
#include <qregularexpression.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRegularExpression_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRegularExpression >()))
        return -1;

    ::QRegularExpression *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QRegularExpression", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRegularExpression::QRegularExpression()
    // 1: QRegularExpression::QRegularExpression(QRegularExpression)
    // 2: QRegularExpression::QRegularExpression(QString,QFlags<QRegularExpression::PatternOption>=)
    if (numArgs == 0) {
        overloadId = 0; // QRegularExpression()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QRegularExpression(QString,QFlags<QRegularExpression::PatternOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_PatternOption_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 2; // QRegularExpression(QString,QFlags<QRegularExpression::PatternOption>)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QRegularExpression(QRegularExpression)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRegularExpression()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);
            }

            // QRegularExpression()
            cptr = new ::QRegularExpression();
            break;
        }
        case 1: // QRegularExpression(const QRegularExpression &re)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRegularExpression cppArg0_local;
            ::QRegularExpression *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QRegularExpression(QRegularExpression)
                cptr = new ::QRegularExpression(*cppArg0);
            }
            break;
        }
        case 2: // QRegularExpression(const QString &pattern, QFlags<QRegularExpression::PatternOption> options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"options", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_PatternOption_IDX])))->flagsConverter, (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QRegularExpression::PatternOption> cppArg1(QRegularExpression::PatternOption::NoPatternOption);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRegularExpression(QString,QFlags<QRegularExpression::PatternOption>)
                cptr = new ::QRegularExpression(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRegularExpression >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRegularExpressionFunc_anchoredPattern(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QRegularExpression::anchoredPattern(QString)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // anchoredPattern(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "anchoredPattern", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // anchoredPattern(QString)
            QString cppResult = ::QRegularExpression::anchoredPattern(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpressionFunc_captureCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // captureCount()const
        int cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->captureCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpressionFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpressionFunc_escape(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QRegularExpression::escape(QString)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // escape(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "escape", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // escape(QString)
            QString cppResult = ::QRegularExpression::escape(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpressionFunc_fromWildcard(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromWildcard", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:fromWildcard", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRegularExpression::fromWildcard(QStringView,Qt::CaseSensitivity=,QFlags<QRegularExpression::WildcardConversionOption>=)->QRegularExpression
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromWildcard(QStringView,Qt::CaseSensitivity,QFlags<QRegularExpression::WildcardConversionOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CaseSensitivity_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // fromWildcard(QStringView,Qt::CaseSensitivity,QFlags<QRegularExpression::WildcardConversionOption>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_WildcardConversionOption_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 0; // fromWildcard(QStringView,Qt::CaseSensitivity,QFlags<QRegularExpression::WildcardConversionOption>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromWildcard", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"cs", 1}, {"options", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CaseSensitivity_IDX])))->converter, (pyArgs[1]))))
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_WildcardConversionOption_IDX])))->flagsConverter, (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromWildcard", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::CaseSensitivity cppArg1(Qt::CaseInsensitive);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFlags<QRegularExpression::WildcardConversionOption> cppArg2(QRegularExpression::WildcardConversionOption::DefaultWildcardConversion);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromWildcard(QStringView,Qt::CaseSensitivity,QFlags<QRegularExpression::WildcardConversionOption>)
            QRegularExpression cppResult = ::QRegularExpression::fromWildcard(QStringView(cppArg0), cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpressionFunc_globalMatch(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "globalMatch", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:globalMatch", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRegularExpression::globalMatch(QString,qsizetype=,QRegularExpression::MatchType=,QFlags<QRegularExpression::MatchOption>=)const->QRegularExpressionMatchIterator
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // globalMatch(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // globalMatch(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // globalMatch(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->flagsConverter, (pyArgs[3])))) {
                    overloadId = 0; // globalMatch(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "globalMatch", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[3] = {{"offset", 1}, {"matchType", 2}, {"matchOptions", 3}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 3, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2]))))
                || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->flagsConverter, (pyArgs[3]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "globalMatch", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QRegularExpression::MatchType cppArg2(QRegularExpression::MatchType::NormalMatch);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QFlags<QRegularExpression::MatchOption> cppArg3(QRegularExpression::MatchOption::NoMatchOption);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // globalMatch(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            QRegularExpressionMatchIterator cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->globalMatch(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpressionMatchIterator_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpressionFunc_globalMatchView(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "globalMatchView", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:globalMatchView", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRegularExpression::globalMatchView(QStringView,qsizetype=,QRegularExpression::MatchType=,QFlags<QRegularExpression::MatchOption>=)const->QRegularExpressionMatchIterator
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // globalMatchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // globalMatchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // globalMatchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->flagsConverter, (pyArgs[3])))) {
                    overloadId = 0; // globalMatchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "globalMatchView", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[3] = {{"offset", 1}, {"matchType", 2}, {"matchOptions", 3}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 3, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2]))))
                || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->flagsConverter, (pyArgs[3]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "globalMatchView", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QRegularExpression::MatchType cppArg2(QRegularExpression::MatchType::NormalMatch);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QFlags<QRegularExpression::MatchOption> cppArg3(QRegularExpression::MatchOption::NoMatchOption);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // globalMatchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            QRegularExpressionMatchIterator cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->globalMatchView(QStringView(cppArg0), cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpressionMatchIterator_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpressionFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpressionFunc_match(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "match", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:match", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRegularExpression::match(QString,qsizetype=,QRegularExpression::MatchType=,QFlags<QRegularExpression::MatchOption>=)const->QRegularExpressionMatch
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // match(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // match(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // match(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->flagsConverter, (pyArgs[3])))) {
                    overloadId = 0; // match(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "match", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[3] = {{"offset", 1}, {"matchType", 2}, {"matchOptions", 3}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 3, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2]))))
                || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->flagsConverter, (pyArgs[3]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "match", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QRegularExpression::MatchType cppArg2(QRegularExpression::MatchType::NormalMatch);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QFlags<QRegularExpression::MatchOption> cppArg3(QRegularExpression::MatchOption::NoMatchOption);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // match(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            QRegularExpressionMatch cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->match(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpressionMatch_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpressionFunc_matchView(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "matchView", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:matchView", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRegularExpression::matchView(QStringView,qsizetype=,QRegularExpression::MatchType=,QFlags<QRegularExpression::MatchOption>=)const->QRegularExpressionMatch
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // matchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // matchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // matchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->flagsConverter, (pyArgs[3])))) {
                    overloadId = 0; // matchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "matchView", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[3] = {{"offset", 1}, {"matchType", 2}, {"matchOptions", 3}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 3, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2]))))
                || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->flagsConverter, (pyArgs[3]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "matchView", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QRegularExpression::MatchType cppArg2(QRegularExpression::MatchType::NormalMatch);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QFlags<QRegularExpression::MatchOption> cppArg3(QRegularExpression::MatchOption::NoMatchOption);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // matchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            QRegularExpressionMatch cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->matchView(QStringView(cppArg0), cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpressionMatch_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpressionFunc_namedCaptureGroups(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // namedCaptureGroups()const
        QStringList cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->namedCaptureGroups();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpressionFunc_optimize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // optimize()const
        const_cast<const ::QRegularExpression *>(cppSelf)->optimize();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QRegularExpressionFunc_pattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pattern()const
        QString cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->pattern();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpressionFunc_patternErrorOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // patternErrorOffset()const
        qsizetype cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->patternErrorOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpressionFunc_patternOptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // patternOptions()const
        QFlags<QRegularExpression::PatternOption> cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->patternOptions();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_PatternOption_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpressionFunc_setPattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRegularExpression::setPattern(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPattern(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPattern", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPattern(QString)
            cppSelf->setPattern(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QRegularExpressionFunc_setPatternOptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRegularExpression::setPatternOptions(QFlags<QRegularExpression::PatternOption>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_PatternOption_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setPatternOptions(QFlags<QRegularExpression::PatternOption>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPatternOptions", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    // Call function/method
    {
        ::QFlags<QRegularExpression::PatternOption> cppArg0 = QFlags<QRegularExpression::PatternOption>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPatternOptions(QFlags<QRegularExpression::PatternOption>)
            cppSelf->setPatternOptions(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QRegularExpressionFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRegularExpression::swap(QRegularExpression&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QRegularExpression&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegularExpression cppArg0_local;
        ::QRegularExpression *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QRegularExpression&)
            cppSelf->swap(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QRegularExpressionFunc_wildcardToRegularExpression(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "wildcardToRegularExpression", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    if (PyArg_ParseTuple(args, "|OO:wildcardToRegularExpression", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRegularExpression::wildcardToRegularExpression(QString,QFlags<QRegularExpression::WildcardConversionOption>=)->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // wildcardToRegularExpression(QString,QFlags<QRegularExpression::WildcardConversionOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_WildcardConversionOption_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // wildcardToRegularExpression(QString,QFlags<QRegularExpression::WildcardConversionOption>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "wildcardToRegularExpression", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"options", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_WildcardConversionOption_IDX])))->flagsConverter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "wildcardToRegularExpression", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRegularExpression::WildcardConversionOption> cppArg1(QRegularExpression::WildcardConversionOption::DefaultWildcardConversion);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wildcardToRegularExpression(QString,QFlags<QRegularExpression::WildcardConversionOption>)
            QString cppResult = ::QRegularExpression::wildcardToRegularExpression(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRegularExpression__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRegularExpression_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRegularExpression_EnumFlagInfo[] = {
    "MatchOption:Flag:MatchOptions",
    "MatchType:Enum",
    "PatternOption:Flag:PatternOptions",
    "WildcardConversionOption:Flag:WildcardConversionOptions",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRegularExpression_methods[] = {
    {"anchoredPattern", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_anchoredPattern), METH_O|METH_STATIC, nullptr},
    {"captureCount", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_captureCount), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_errorString), METH_NOARGS, nullptr},
    {"escape", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_escape), METH_O|METH_STATIC, nullptr},
    {"fromWildcard", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_fromWildcard), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"globalMatch", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_globalMatch), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"globalMatchView", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_globalMatchView), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_isValid), METH_NOARGS, nullptr},
    {"match", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_match), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"matchView", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_matchView), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"namedCaptureGroups", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_namedCaptureGroups), METH_NOARGS, nullptr},
    {"optimize", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_optimize), METH_NOARGS, nullptr},
    {"pattern", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_pattern), METH_NOARGS, nullptr},
    {"patternErrorOffset", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_patternErrorOffset), METH_NOARGS, nullptr},
    {"patternOptions", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_patternOptions), METH_NOARGS, nullptr},
    {"setPattern", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_setPattern), METH_O, nullptr},
    {"setPatternOptions", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_setPatternOptions), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_swap), METH_O, nullptr},
    {"wildcardToRegularExpression", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_wildcardToRegularExpression), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QRegularExpression__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QRegularExpression_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
                // operator!=(const QRegularExpression &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRegularExpression cppArg0_local;
                ::QRegularExpression *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
                // operator==(const QRegularExpression &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRegularExpression cppArg0_local;
                ::QRegularExpression *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QRegularExpression_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QRegularExpression_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRegularExpression_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QRegularExpression__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRegularExpression_Type = nullptr;
static PyTypeObject *Sbk_QRegularExpression_TypeF(void)
{
    return _Sbk_QRegularExpression_Type;
}

static PyType_Slot Sbk_QRegularExpression_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QRegularExpression__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QRegularExpression_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRegularExpression_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRegularExpression_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QRegularExpression_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRegularExpression_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRegularExpression_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRegularExpression_spec = {
    "2:PySide6.QtCore.QRegularExpression",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRegularExpression_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRegularExpression_PatternOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRegularExpression::PatternOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRegularExpression::PatternOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRegularExpression_PatternOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_PatternOption_IDX])))
        return Enum_PythonToCpp_QRegularExpression_PatternOption;
    return {};
}

static PyObject *QRegularExpression_PatternOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRegularExpression::PatternOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRegularExpression::PatternOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_PatternOption_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QRegularExpression_PatternOption(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QRegularExpression::PatternOption>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QRegularExpression::PatternOption> *>(cppOut) = value;

}

static PyObject *QRegularExpression_PatternOption_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QRegularExpression::PatternOption> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_PatternOption_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QRegularExpression_MatchType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRegularExpression::MatchType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRegularExpression::MatchType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRegularExpression_MatchType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))
        return Enum_PythonToCpp_QRegularExpression_MatchType;
    return {};
}

static PyObject *QRegularExpression_MatchType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRegularExpression::MatchType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRegularExpression::MatchType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRegularExpression_MatchOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRegularExpression::MatchOption>(Shiboken::Enum::getValue(pyIn));
    switch (value) {
    case QRegularExpression::MatchOption::AnchoredMatchOption:
        Shiboken::Warnings::warnDeprecatedEnumValue("QRegularExpression::MatchOption", "AnchoredMatchOption");
        break;
    default:
        break;
    }
    *reinterpret_cast<::QRegularExpression::MatchOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRegularExpression_MatchOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchOption_IDX])))
        return Enum_PythonToCpp_QRegularExpression_MatchOption;
    return {};
}

static PyObject *QRegularExpression_MatchOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRegularExpression::MatchOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRegularExpression::MatchOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchOption_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QRegularExpression_MatchOption(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QRegularExpression::MatchOption>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QRegularExpression::MatchOption> *>(cppOut) = value;

}

static PyObject *QRegularExpression_MatchOption_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QRegularExpression::MatchOption> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchOption_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QRegularExpression_WildcardConversionOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRegularExpression::WildcardConversionOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRegularExpression::WildcardConversionOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRegularExpression_WildcardConversionOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_WildcardConversionOption_IDX])))
        return Enum_PythonToCpp_QRegularExpression_WildcardConversionOption;
    return {};
}

static PyObject *QRegularExpression_WildcardConversionOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRegularExpression::WildcardConversionOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRegularExpression::WildcardConversionOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_WildcardConversionOption_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QRegularExpression_WildcardConversionOption(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QRegularExpression::WildcardConversionOption>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QRegularExpression::WildcardConversionOption> *>(cppOut) = value;

}

static PyObject *QRegularExpression_WildcardConversionOption_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QRegularExpression::WildcardConversionOption> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_WildcardConversionOption_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRegularExpression_PythonToCpp_QRegularExpression_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRegularExpression_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRegularExpression_PythonToCpp_QRegularExpression_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRegularExpression_TypeF()))
        return QRegularExpression_PythonToCpp_QRegularExpression_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRegularExpression_PTR_CppToPython_QRegularExpression(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QRegularExpression_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QRegularExpression_COPY_CppToPython_QRegularExpression(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QRegularExpression *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QRegularExpression_TypeF(), new ::QRegularExpression(*source), true, true);
}

// Python to C++ copy conversion.
static void QRegularExpression_PythonToCpp_QRegularExpression_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRegularExpression *>(cppOut) = *reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QRegularExpression_PythonToCpp_QRegularExpression_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QRegularExpression_TypeF()))
        return QRegularExpression_PythonToCpp_QRegularExpression_COPY;
    return {};
}

// Implicit conversions.
static void constQStringREF_PythonToCpp_QRegularExpression(PyObject *pyIn, void *cppOut)
{
    ::QString cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QRegularExpression *>(cppOut) = ::QRegularExpression(cppIn);
}
static PythonToCppFunc is_constQStringREF_PythonToCpp_QRegularExpression_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return constQStringREF_PythonToCpp_QRegularExpression;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRegularExpression_SignatureStrings[] = {
    "2:PySide6.QtCore.QRegularExpression(self)",
    "1:PySide6.QtCore.QRegularExpression(self,re:PySide6.QtCore.QRegularExpression)",
    "0:PySide6.QtCore.QRegularExpression(self,pattern:QString,options:PySide6.QtCore.QRegularExpression.PatternOption=QRegularExpression.PatternOption.NoPatternOption)",
    "PySide6.QtCore.QRegularExpression.anchoredPattern(expression:QString)->QString",
    "PySide6.QtCore.QRegularExpression.captureCount(self)->int",
    "PySide6.QtCore.QRegularExpression.errorString(self)->QString",
    "PySide6.QtCore.QRegularExpression.escape(str:QString)->QString",
    "PySide6.QtCore.QRegularExpression.fromWildcard(pattern:QString,cs:PySide6.QtCore.Qt.CaseSensitivity=Qt.CaseInsensitive,options:PySide6.QtCore.QRegularExpression.WildcardConversionOption=QRegularExpression.WildcardConversionOption.DefaultWildcardConversion)->PySide6.QtCore.QRegularExpression",
    "PySide6.QtCore.QRegularExpression.globalMatch(self,subject:QString,offset:qsizetype=0,matchType:PySide6.QtCore.QRegularExpression.MatchType=QRegularExpression.MatchType.NormalMatch,matchOptions:PySide6.QtCore.QRegularExpression.MatchOption=QRegularExpression.MatchOption.NoMatchOption)->PySide6.QtCore.QRegularExpressionMatchIterator",
    "PySide6.QtCore.QRegularExpression.globalMatchView(self,subjectView:QString,offset:qsizetype=0,matchType:PySide6.QtCore.QRegularExpression.MatchType=QRegularExpression.MatchType.NormalMatch,matchOptions:PySide6.QtCore.QRegularExpression.MatchOption=QRegularExpression.MatchOption.NoMatchOption)->PySide6.QtCore.QRegularExpressionMatchIterator",
    "PySide6.QtCore.QRegularExpression.isValid(self)->bool",
    "PySide6.QtCore.QRegularExpression.match(self,subject:QString,offset:qsizetype=0,matchType:PySide6.QtCore.QRegularExpression.MatchType=QRegularExpression.MatchType.NormalMatch,matchOptions:PySide6.QtCore.QRegularExpression.MatchOption=QRegularExpression.MatchOption.NoMatchOption)->PySide6.QtCore.QRegularExpressionMatch",
    "PySide6.QtCore.QRegularExpression.matchView(self,subjectView:QString,offset:qsizetype=0,matchType:PySide6.QtCore.QRegularExpression.MatchType=QRegularExpression.MatchType.NormalMatch,matchOptions:PySide6.QtCore.QRegularExpression.MatchOption=QRegularExpression.MatchOption.NoMatchOption)->PySide6.QtCore.QRegularExpressionMatch",
    "PySide6.QtCore.QRegularExpression.namedCaptureGroups(self)->QStringList",
    "PySide6.QtCore.QRegularExpression.optimize(self)",
    "PySide6.QtCore.QRegularExpression.pattern(self)->QString",
    "PySide6.QtCore.QRegularExpression.patternErrorOffset(self)->qsizetype",
    "PySide6.QtCore.QRegularExpression.patternOptions(self)->PySide6.QtCore.QRegularExpression.PatternOption",
    "PySide6.QtCore.QRegularExpression.setPattern(self,pattern:QString)",
    "PySide6.QtCore.QRegularExpression.setPatternOptions(self,options:PySide6.QtCore.QRegularExpression.PatternOption)",
    "PySide6.QtCore.QRegularExpression.swap(self,other:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "PySide6.QtCore.QRegularExpression.wildcardToRegularExpression(str:QString,options:PySide6.QtCore.QRegularExpression.WildcardConversionOption=QRegularExpression.WildcardConversionOption.DefaultWildcardConversion)->QString",
    "PySide6.QtCore.QRegularExpression.__copy__(self)->typing.Self",
    "PySide6.QtCore.QRegularExpression.__ne__(self,rhs:typing.Union[PySide6.QtCore.QRegularExpression, QString])->bool",
    "PySide6.QtCore.QRegularExpression.__eq__(self,rhs:typing.Union[PySide6.QtCore.QRegularExpression, QString])->bool",
    "PySide6.QtCore.QRegularExpression.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QRegularExpression_SignatureByteSize = 519;
static constexpr uint8_t QRegularExpression_SignatureBytes[519] = {
    0x78, 0xda, 0xed, 0x56, 0xc1, 0x6e, 0xdb, 0x30, 0x0c, 0xbd, 0xe7, 0x2b, 0x76, 0x8c, 0x01, 0xd7,
    0xe8, 0x76, 0xd8, 0x21, 0x80, 0x7b, 0xf1, 0x8a, 0xa1, 0xc0, 0xb2, 0x24, 0x4b, 0xd7, 0x1d, 0x8a,
    0xc1, 0x50, 0x6c, 0x26, 0xd6, 0x60, 0x4b, 0x2e, 0x45, 0x37, 0xcb, 0xbe, 0x7e, 0x72, 0x2c, 0x37,
    0x69, 0xba, 0xd4, 0x74, 0x06, 0x0c, 0x3b, 0xe4, 0x66, 0x89, 0x7c, 0x7c, 0xd4, 0x23, 0x61, 0xf2,
    0xdd, 0x68, 0xba, 0x99, 0xcb, 0x14, 0xde, 0x07, 0x33, 0x8a, 0x34, 0x42, 0x30, 0xfb, 0x02, 0xab,
    0x2a, 0x17, 0x78, 0xfd, 0xb3, 0x44, 0x30, 0x46, 0x6a, 0x35, 0x34, 0x90, 0x2f, 0xbd, 0xc1, 0x5b,
    0xa6, 0xa7, 0x8f, 0xd0, 0xed, 0xe9, 0x0d, 0x2e, 0xb9, 0xe1, 0x4a, 0x41, 0x04, 0xa8, 0x46, 0xb3,
    0x39, 0xa1, 0x54, 0x2b, 0x5f, 0x97, 0x64, 0x6d, 0xa6, 0x1b, 0x1e, 0x4c, 0x1b, 0xe4, 0x64, 0x0b,
    0x08, 0xbb, 0x1c, 0x82, 0xcf, 0xfa, 0xd9, 0xd9, 0x1b, 0x74, 0x33, 0x08, 0x95, 0x64, 0xd6, 0x94,
    0x3a, 0xe0, 0x10, 0x9e, 0x4c, 0x6d, 0xba, 0xde, 0xc5, 0x95, 0xfb, 0x62, 0x84, 0x4b, 0x44, 0x49,
    0x15, 0x42, 0xa4, 0x2b, 0x45, 0x8d, 0xea, 0x17, 0x57, 0x52, 0x11, 0x03, 0x09, 0x88, 0x1a, 0x1b,
    0x9e, 0x16, 0xc8, 0xa7, 0x05, 0x63, 0x89, 0x61, 0x68, 0x08, 0x4f, 0xca, 0x7a, 0x89, 0xba, 0xf8,
    0x26, 0xf3, 0x34, 0x11, 0x98, 0x0e, 0x0f, 0xab, 0x95, 0xbc, 0x2c, 0x14, 0x05, 0x91, 0x30, 0x30,
    0x07, 0x65, 0x24, 0xc9, 0x47, 0x49, 0x9b, 0xd0, 0x5d, 0xdd, 0x28, 0xe3, 0x2e, 0xa1, 0x47, 0x95,
    0x5b, 0xea, 0x48, 0xab, 0x47, 0xc0, 0xfa, 0xea, 0x78, 0xc1, 0x8f, 0xf9, 0x06, 0x1f, 0x60, 0x29,
    0xaa, 0x9c, 0x5e, 0xda, 0xad, 0x12, 0x9d, 0x29, 0x30, 0x34, 0x5a, 0xe5, 0x7a, 0x21, 0xf2, 0xb1,
    0xa0, 0x24, 0x6b, 0xba, 0xda, 0x54, 0x8b, 0x1f, 0x90, 0xd0, 0xae, 0xab, 0x97, 0x4b, 0x03, 0x34,
    0x7a, 0x30, 0xf2, 0x17, 0xd0, 0xa6, 0x84, 0xf0, 0xd2, 0x2f, 0x6a, 0xef, 0x5b, 0xfb, 0xcd, 0x10,
    0x61, 0xdc, 0xfa, 0x86, 0xaf, 0x19, 0x6d, 0x8b, 0x63, 0xe1, 0xd2, 0x68, 0xc2, 0x4f, 0xd8, 0x32,
    0x8f, 0x77, 0xee, 0xe1, 0xeb, 0x66, 0xcb, 0xb2, 0x77, 0xe2, 0x08, 0xb8, 0x75, 0xbf, 0xb1, 0x7d,
    0x23, 0x48, 0x63, 0x3f, 0x35, 0xef, 0x24, 0xac, 0x9f, 0x29, 0x5a, 0x5f, 0x9c, 0x55, 0x3d, 0x45,
    0x55, 0x69, 0xee, 0x44, 0x2e, 0xd3, 0xf6, 0xff, 0xb1, 0xd0, 0x3a, 0x67, 0xa0, 0x8a, 0x73, 0x4f,
    0x1f, 0x57, 0x9f, 0xab, 0xdf, 0xb9, 0x8b, 0xff, 0x5a, 0x47, 0x25, 0x0a, 0x48, 0xa3, 0x66, 0x80,
    0x7e, 0x44, 0x5d, 0x95, 0xe6, 0x60, 0x10, 0x7e, 0x92, 0x86, 0x33, 0x49, 0xeb, 0xc1, 0x53, 0x58,
    0xa1, 0xdd, 0xd6, 0xd3, 0x0d, 0x70, 0x13, 0xaf, 0xff, 0xd8, 0x75, 0xc0, 0xeb, 0x7a, 0x74, 0x4f,
    0xb6, 0x25, 0x6e, 0x63, 0x3c, 0x55, 0x9a, 0x1f, 0xc5, 0x15, 0xab, 0x8d, 0xd0, 0x73, 0x39, 0x62,
    0xf0, 0xd8, 0xf4, 0xa6, 0x7b, 0x2f, 0x3d, 0x5c, 0xcb, 0xbc, 0x5e, 0x21, 0xf6, 0xb3, 0x3d, 0x75,
    0xa1, 0x63, 0x31, 0xae, 0x45, 0xe9, 0x48, 0x28, 0x03, 0x1c, 0x59, 0x4d, 0x6d, 0xae, 0xc1, 0x57,
    0x65, 0x8d, 0xf7, 0x9d, 0x70, 0xff, 0x8d, 0x7b, 0xdc, 0x77, 0x0e, 0xd7, 0xda, 0xed, 0x0e, 0xb7,
    0xfa, 0x0f, 0x8b, 0xec, 0x6e, 0xb5, 0xfa, 0x9f, 0x36, 0x1b, 0x7e, 0xaf, 0xc6, 0x71, 0xa2, 0xcb,
    0x4d, 0x1c, 0xb7, 0xfd, 0xe5, 0x84, 0x9c, 0xdb, 0x13, 0x0b, 0xad, 0xc0, 0x61, 0x7d, 0xcc, 0xcc,
    0xe9, 0x65, 0x60, 0x4f, 0xa5, 0x38, 0x86, 0x87, 0x7f, 0xcd, 0x98, 0x09, 0x93, 0xed, 0x14, 0xaa,
    0xf7, 0xf6, 0xdf, 0xb0, 0x91, 0x06, 0x73
};
#endif

PyTypeObject *init_QRegularExpression(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX].type;

    Shiboken::AutoDecRef Sbk_QRegularExpression_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRegularExpression_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRegularExpression",
        "QRegularExpression",
        &Sbk_QRegularExpression_spec,
        &Shiboken::callCppDestructor< ::QRegularExpression >,
        Sbk_QRegularExpression_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QRegularExpression_TypeF(); // references _Sbk_QRegularExpression_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRegularExpression_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRegularExpression_SignatureBytes, QRegularExpression_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRegularExpression_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRegularExpression_PythonToCpp_QRegularExpression_PTR,
        is_QRegularExpression_PythonToCpp_QRegularExpression_PTR_Convertible,
        QRegularExpression_PTR_CppToPython_QRegularExpression,
        QRegularExpression_COPY_CppToPython_QRegularExpression);

    Shiboken::Conversions::registerConverterName(converter, "QRegularExpression");
    Shiboken::Conversions::registerConverterName(converter, "QRegularExpression*");
    Shiboken::Conversions::registerConverterName(converter, "QRegularExpression&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRegularExpression).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QRegularExpression_PythonToCpp_QRegularExpression_COPY,
        is_QRegularExpression_PythonToCpp_QRegularExpression_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQStringREF_PythonToCpp_QRegularExpression,
        is_constQStringREF_PythonToCpp_QRegularExpression_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRegularExpression_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'PatternOption'.
    const char *PatternOption_Initializer[] = {
        "NoPatternOption",
        "CaseInsensitiveOption",
        "DotMatchesEverythingOption",
        "MultilineOption",
        "ExtendedPatternSyntaxOption",
        "InvertedGreedinessOption",
        "DontCaptureOption",
        "UseUnicodePropertiesOption",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PatternOption_InitializerValues[] = {
        uint8_t(QRegularExpression::PatternOption::NoPatternOption),             //  0x00  0
        uint8_t(QRegularExpression::PatternOption::CaseInsensitiveOption),       //  0x01  1
        uint8_t(QRegularExpression::PatternOption::DotMatchesEverythingOption),  //  0x02  2
        uint8_t(QRegularExpression::PatternOption::MultilineOption),             //  0x04  4
        uint8_t(QRegularExpression::PatternOption::ExtendedPatternSyntaxOption), //  0x08  8
        uint8_t(QRegularExpression::PatternOption::InvertedGreedinessOption),    //  0x10  16
        uint8_t(QRegularExpression::PatternOption::DontCaptureOption),           //  0x20  32
        uint8_t(QRegularExpression::PatternOption::UseUnicodePropertiesOption)   //  0x40  64
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRegularExpression_TypeF(),
        "2:PySide6.QtCore.QRegularExpression.PatternOption",
        PatternOption_Initializer, PatternOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_PatternOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_PatternOption_IDX].type =
        EType;
    // Register converter for enum 'QRegularExpression::PatternOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRegularExpression_PatternOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRegularExpression_PatternOption,
            is_Enum_PythonToCpp_QRegularExpression_PatternOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRegularExpression::PatternOption");
        Shiboken::Conversions::registerConverterAlias(converter, "PatternOption");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QRegularExpression_PatternOption_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QRegularExpression_PatternOption,
            is_Enum_PythonToCpp_QRegularExpression_PatternOption_Convertible);
        // Register converter for flag 'QFlags<QRegularExpression::PatternOption>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QRegularExpression::PatternOption>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QRegularExpression::PatternOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'PatternOption' enum/flags.

    // Initialization of enum 'MatchType'.
    const char *MatchType_Initializer[] = {
        "NormalMatch",
        "PartialPreferCompleteMatch",
        "PartialPreferFirstMatch",
        "NoMatch",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MatchType_InitializerValues[] = {
        uint8_t(QRegularExpression::MatchType::NormalMatch),                //  0x00  0
        uint8_t(QRegularExpression::MatchType::PartialPreferCompleteMatch), //  0x01  1
        uint8_t(QRegularExpression::MatchType::PartialPreferFirstMatch),    //  0x02  2
        uint8_t(QRegularExpression::MatchType::NoMatch)                     //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRegularExpression_TypeF(),
        "2:PySide6.QtCore.QRegularExpression.MatchType",
        MatchType_Initializer, MatchType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX].type = EType;
    // Register converter for enum 'QRegularExpression::MatchType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRegularExpression_MatchType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRegularExpression_MatchType,
            is_Enum_PythonToCpp_QRegularExpression_MatchType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRegularExpression::MatchType");
        Shiboken::Conversions::registerConverterAlias(converter, "MatchType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'MatchType' enum.

    // Initialization of enum 'MatchOption'.
    const char *MatchOption_Initializer[] = {
        "NoMatchOption",
        "AnchorAtOffsetMatchOption",
        "AnchoredMatchOption",
        "DontCheckSubjectStringMatchOption",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MatchOption_InitializerValues[] = {
        uint8_t(QRegularExpression::MatchOption::NoMatchOption),                    //  0x00  0
        uint8_t(QRegularExpression::MatchOption::AnchorAtOffsetMatchOption),        //  0x01  1
        uint8_t(QRegularExpression::MatchOption::AnchoredMatchOption),              //  0x01  1
        uint8_t(QRegularExpression::MatchOption::DontCheckSubjectStringMatchOption) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRegularExpression_TypeF(),
        "2:PySide6.QtCore.QRegularExpression.MatchOption",
        MatchOption_Initializer, MatchOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX].type =
        EType;
    // Register converter for enum 'QRegularExpression::MatchOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRegularExpression_MatchOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRegularExpression_MatchOption,
            is_Enum_PythonToCpp_QRegularExpression_MatchOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRegularExpression::MatchOption");
        Shiboken::Conversions::registerConverterAlias(converter, "MatchOption");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QRegularExpression_MatchOption_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QRegularExpression_MatchOption,
            is_Enum_PythonToCpp_QRegularExpression_MatchOption_Convertible);
        // Register converter for flag 'QFlags<QRegularExpression::MatchOption>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QRegularExpression::MatchOption>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QRegularExpression::MatchOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'MatchOption' enum/flags.

    // Initialization of enum 'WildcardConversionOption'.
    const char *WildcardConversionOption_Initializer[] = {
        "DefaultWildcardConversion",
        "UnanchoredWildcardConversion",
        "NonPathWildcardConversion",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t WildcardConversionOption_InitializerValues[] = {
        uint8_t(QRegularExpression::WildcardConversionOption::DefaultWildcardConversion),    //  0x00  0
        uint8_t(QRegularExpression::WildcardConversionOption::UnanchoredWildcardConversion), //  0x01  1
        uint8_t(QRegularExpression::WildcardConversionOption::NonPathWildcardConversion)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRegularExpression_TypeF(),
        "2:PySide6.QtCore.QRegularExpression.WildcardConversionOption",
        WildcardConversionOption_Initializer, WildcardConversionOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_WildcardConversionOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_WildcardConversionOption_IDX].type =
        EType;
    // Register converter for enum 'QRegularExpression::WildcardConversionOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRegularExpression_WildcardConversionOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRegularExpression_WildcardConversionOption,
            is_Enum_PythonToCpp_QRegularExpression_WildcardConversionOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRegularExpression::WildcardConversionOption");
        Shiboken::Conversions::registerConverterAlias(converter, "WildcardConversionOption");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QRegularExpression_WildcardConversionOption_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QRegularExpression_WildcardConversionOption,
            is_Enum_PythonToCpp_QRegularExpression_WildcardConversionOption_Convertible);
        // Register converter for flag 'QFlags<QRegularExpression::WildcardConversionOption>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QRegularExpression::WildcardConversionOption>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QRegularExpression::WildcardConversionOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'WildcardConversionOption' enum/flags.

    qRegisterMetaType< ::QRegularExpression >("QRegularExpression");
    qRegisterMetaType< ::QRegularExpression::PatternOption >("QRegularExpression::PatternOption");
    qRegisterMetaType< ::QRegularExpression::MatchType >("QRegularExpression::MatchType");
    qRegisterMetaType< ::QRegularExpression::MatchOption >("QRegularExpression::MatchOption");
    qRegisterMetaType< ::QRegularExpression::WildcardConversionOption >("QRegularExpression::WildcardConversionOption");

    return pyType;
}
