// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qtcorehelper_qiopipe_wrapper.h"

// Wrappers providing overrides
#include "qobject_wrapper.h"
#include "qtranslator_wrapper.h"

// Argument includes
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace QtCoreHelper;

// Native ---------------------------------------------------------

void QIOPipeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QIOPipeWrapper::QIOPipeWrapper(::QObject * parent) : QtCoreHelper::QIOPipe(parent)
{
}

void QIOPipeWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QTranslatorWrapper::sbk_o_childEvent("QIOPipe", funcName, gil, pyOverride, event);
}

void QIOPipeWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QIOPipe", funcName, gil, pyOverride, signal);
}

void QIOPipeWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QTranslatorWrapper::sbk_o_customEvent("QIOPipe", funcName, gil, pyOverride, event);
}

void QIOPipeWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QIOPipe", funcName, gil, pyOverride, signal);
}

bool QIOPipeWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QTranslatorWrapper::sbk_o_event("QIOPipe", funcName, gil, pyOverride, event);
}

bool QIOPipeWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QTranslatorWrapper::sbk_o_eventFilter("QIOPipe", funcName, gil, pyOverride, watched, event);
}

void QIOPipeWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QTranslatorWrapper::sbk_o_timerEvent("QIOPipe", funcName, gil, pyOverride, event);
}

const QMetaObject *QIOPipeWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QtCoreHelper::QIOPipe::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QIOPipeWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QtCoreHelper::QIOPipe::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QIOPipeWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QIOPipeWrapper *>(this));
    return QtCoreHelper::QIOPipe::qt_metacast(_clname);
}

QIOPipeWrapper::~QIOPipeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QtCoreHelper_QIOPipe_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QtCoreHelper::QIOPipe >()))
        return -1;

    QIOPipeWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QIOPipe", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QIOPipe::QIOPipe(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QIOPipe(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QIOPipe(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QIOPipe_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QIOPipe_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QIOPipe_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QIOPipe(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QIOPipeWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QIOPipeWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QtCoreHelper::QIOPipe >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QIOPipe_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QIOPipe_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QtCoreHelper_QIOPipeFunc_end1(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtCoreHelper::QIOPipe *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QIOPipe_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // end1()const
        QIODevice * cppResult = const_cast<const ::QtCoreHelper::QIOPipe *>(cppSelf)->end1();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QtCoreHelper_QIOPipeFunc_end2(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtCoreHelper::QIOPipe *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QIOPipe_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // end2()const
        QIODevice * cppResult = const_cast<const ::QtCoreHelper::QIOPipe *>(cppSelf)->end2();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QtCoreHelper_QIOPipeFunc_open(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtCoreHelper::QIOPipe *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QIOPipe_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QIOPipe::open(QFlags<QIODeviceBase::OpenModeFlag>)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // open(QFlags<QIODeviceBase::OpenModeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "open", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QIOPipe_IDX]);

    // Call function/method
    {
        ::QFlags<QIODeviceBase::OpenModeFlag> cppArg0 = QFlags<QIODeviceBase::OpenModeFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // open(QFlags<QIODeviceBase::OpenModeFlag>)
            bool cppResult = cppSelf->open(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QtCoreHelper_QIOPipe_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QtCoreHelper_QIOPipe_methods[] = {
    {"end1", reinterpret_cast<PyCFunction>(Sbk_QtCoreHelper_QIOPipeFunc_end1), METH_NOARGS, nullptr},
    {"end2", reinterpret_cast<PyCFunction>(Sbk_QtCoreHelper_QIOPipeFunc_end2), METH_NOARGS, nullptr},
    {"open", reinterpret_cast<PyCFunction>(Sbk_QtCoreHelper_QIOPipeFunc_open), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QtCoreHelper_QIOPipe_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QtCoreHelper::QIOPipe *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QIOPipe_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QIOPipeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QtCoreHelper_QIOPipe_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QtCoreHelper_QIOPipe_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QtCoreHelper_QIOPipe_Type = nullptr;
static PyTypeObject *Sbk_QtCoreHelper_QIOPipe_TypeF(void)
{
    return _Sbk_QtCoreHelper_QIOPipe_Type;
}

static PyType_Slot Sbk_QtCoreHelper_QIOPipe_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QtCoreHelper_QIOPipe_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QtCoreHelper_QIOPipe_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QtCoreHelper_QIOPipe_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QtCoreHelper_QIOPipe_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QtCoreHelper_QIOPipe_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QtCoreHelper_QIOPipe_spec = {
    "2:PySide6.QtCore.QIOPipe",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QtCoreHelper_QIOPipe_slots
};

} //extern "C"

static void *Sbk_QtCoreHelper_QIOPipe_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QtCoreHelper::QIOPipe *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QIOPipe_PythonToCpp_QIOPipe_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QtCoreHelper_QIOPipe_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QIOPipe_PythonToCpp_QIOPipe_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QtCoreHelper_QIOPipe_TypeF()))
        return QIOPipe_PythonToCpp_QIOPipe_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QIOPipe_PTR_CppToPython_QIOPipe(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QtCoreHelper::QIOPipe *>(const_cast<void *>(cppIn)), Sbk_QtCoreHelper_QIOPipe_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QtCoreHelper_QIOPipe_SignatureStrings[] = {
    "PySide6.QtCore.QIOPipe(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtCore.QIOPipe.end1(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtCore.QIOPipe.end2(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtCore.QIOPipe.open(self,mode:PySide6.QtCore.QIODeviceBase.OpenModeFlag)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QtCoreHelper_QIOPipe_SignatureByteSize = 125;
static constexpr uint8_t QtCoreHelper_QIOPipe_SignatureBytes[125] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0xce, 0x2f, 0x4a,
    0xd5, 0x0b, 0xf4, 0xf4, 0x0f, 0xc8, 0x2c, 0x48, 0xd5, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x29, 0x48,
    0x2c, 0x4a, 0xcd, 0x2b, 0xb1, 0x0a, 0x40, 0x53, 0xe2, 0x9f, 0x94, 0x95, 0x9a, 0x5c, 0x62, 0x9b,
    0x57, 0x9a, 0x93, 0x53, 0x50, 0x52, 0xa4, 0xc9, 0x15, 0x80, 0xd5, 0x08, 0xbd, 0xd4, 0xbc, 0x14,
    0x43, 0xb0, 0x39, 0x9a, 0xba, 0x76, 0x98, 0x4a, 0x5c, 0x52, 0xcb, 0x32, 0x93, 0x53, 0xf1, 0xe8,
    0x35, 0x22, 0x57, 0x6f, 0x7e, 0x41, 0x6a, 0x1e, 0xc4, 0xfd, 0xb9, 0xf9, 0x29, 0xa9, 0x56, 0xb8,
    0xb4, 0x3b, 0x25, 0x16, 0xa7, 0xea, 0xf9, 0x03, 0xd5, 0xfa, 0x02, 0x55, 0xb9, 0xe5, 0x24, 0xa6,
    0x03, 0xad, 0x4a, 0xca, 0xcf, 0xcf, 0xe1, 0x02, 0x00, 0xc9, 0xb9, 0x5e, 0x31
};
#endif

PyTypeObject *init_QtCoreHelper_QIOPipe(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QIOPipe_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QIOPipe_IDX].type;

    Shiboken::AutoDecRef Sbk_QtCoreHelper_QIOPipe_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QtCoreHelper_QIOPipe_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QIOPipe",
        "QtCoreHelper::QIOPipe*",
        &Sbk_QtCoreHelper_QIOPipe_spec,
        &Shiboken::callCppDestructor< QtCoreHelper::QIOPipe >,
        Sbk_QtCoreHelper_QIOPipe_Type_bases.object(),
        0);
    auto *pyType = Sbk_QtCoreHelper_QIOPipe_TypeF(); // references _Sbk_QtCoreHelper_QIOPipe_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QtCoreHelper_QIOPipe_SignatureStrings);
#else
    InitSignatureBytes(pyType, QtCoreHelper_QIOPipe_SignatureBytes, QtCoreHelper_QIOPipe_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QtCoreHelper_QIOPipe_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QIOPipe_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QIOPipe_PythonToCpp_QIOPipe_PTR,
        is_QIOPipe_PythonToCpp_QIOPipe_PTR_Convertible,
        QIOPipe_PTR_CppToPython_QIOPipe);

    Shiboken::Conversions::registerConverterName(converter, "QtCoreHelper::QIOPipe");
    Shiboken::Conversions::registerConverterName(converter, "QtCoreHelper::QIOPipe*");
    Shiboken::Conversions::registerConverterName(converter, "QtCoreHelper::QIOPipe&");
    Shiboken::Conversions::registerConverterAlias(converter, "QIOPipe");
    Shiboken::Conversions::registerConverterAlias(converter, "QIOPipe*");
    Shiboken::Conversions::registerConverterAlias(converter, "QIOPipe&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QtCoreHelper::QIOPipe).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QIOPipeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QtCoreHelper_QIOPipe_TypeF(), &Sbk_QtCoreHelper_QIOPipe_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QtCoreHelper::QIOPipe::staticMetaObject, sizeof(QIOPipeWrapper));

    return pyType;
}
