// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "quuid_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QString>
#include <qbytearray.h>
#include <qbytearrayview.h>
#include <qsysinfo.h>
#include <quuid.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QUuid_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QUuid >()))
        return -1;

    ::QUuid *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[11];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5 || numArgs == 6 || numArgs == 7 || numArgs == 8 || numArgs == 9 || numArgs == 10)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);

    if (PyArg_UnpackTuple(args, "QUuid", 0, 11, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9]), &(pyArgs[10])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QUuid::QUuid()
    // 1: QUuid::QUuid(QAnyStringView)
    // 2: QUuid::QUuid(QUuid)
    // 3: QUuid::QUuid(uint,ushort,ushort,uchar,uchar,uchar,uchar,uchar,uchar,uchar,uchar)
    if (numArgs == 0) {
        overloadId = 0; // QUuid()
    } else if (numArgs == 11
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[2])))
        && SbkChar_Check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[3])))
        && SbkChar_Check(pyArgs[4]) && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[4])))
        && SbkChar_Check(pyArgs[5]) && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[5])))
        && SbkChar_Check(pyArgs[6]) && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[6])))
        && SbkChar_Check(pyArgs[7]) && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[7])))
        && SbkChar_Check(pyArgs[8]) && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[8])))
        && SbkChar_Check(pyArgs[9]) && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[9])))
        && SbkChar_Check(pyArgs[10]) && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[10])))) {
        overloadId = 3; // QUuid(uint,ushort,ushort,uchar,uchar,uchar,uchar,uchar,uchar,uchar,uchar)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QUuid(QUuid)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // QUuid(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QUuid()
        {

            // QUuid()
            cptr = new ::QUuid();
            break;
        }
        case 1: // QUuid(QAnyStringView string)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QUuid(QAnyStringView)
                cptr = new ::QUuid(QAnyStringView(cppArg0));
            }
            break;
        }
        case 2: // QUuid(const QUuid &QUuid)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUuid cppArg0_local;
            ::QUuid *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QUuid(QUuid)
                cptr = new ::QUuid(*cppArg0);
            }
            break;
        }
        case 3: // QUuid(uint l, ushort w1, ushort w2, uchar b1, uchar b2, uchar b3, uchar b4, uchar b5, uchar b6, uchar b7, uchar b8)
        {
            uint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ushort cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ushort cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            uchar cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            uchar cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            uchar cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            uchar cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            uchar cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);
            uchar cppArg8;
            pythonToCpp[8](pyArgs[8], &cppArg8);
            uchar cppArg9;
            pythonToCpp[9](pyArgs[9], &cppArg9);
            uchar cppArg10;
            pythonToCpp[10](pyArgs[10], &cppArg10);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QUuid(uint,ushort,ushort,uchar,uchar,uchar,uchar,uchar,uchar,uchar,uchar)
                cptr = new ::QUuid(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QUuid >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QUuidFunc___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // TEMPLATE - reduce_code - START
        pyResult = Py_BuildValue("(N(s))", PyObject_Type(self), qPrintable(cppSelf->toString()));
        // TEMPLATE - reduce_code - END
        // End of code injection

    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuidFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_code - START
        QString format = QString::asprintf("%s('%s')",
            Py_TYPE(self)->tp_name, qPrintable(cppSelf->toString()));
        pyResult = Shiboken::String::fromCString(qPrintable(format));
        // TEMPLATE - repr_code - END
        // End of code injection

    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuidFunc_createUuid(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createUuid()
        QUuid cppResult = ::QUuid::createUuid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuidFunc_createUuidV3(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createUuidV3", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QUuid::createUuidV3(QUuid,QByteArrayView)->QUuid
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // createUuidV3(QUuid,QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createUuidV3", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUuid cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createUuidV3(QUuid,QByteArrayView)
            QUuid cppResult = ::QUuid::createUuidV3(cppArg0, QByteArrayView(cppArg1));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuidFunc_createUuidV5(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createUuidV5", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QUuid::createUuidV5(QUuid,QByteArrayView)->QUuid
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // createUuidV5(QUuid,QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createUuidV5", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUuid cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createUuidV5(QUuid,QByteArrayView)
            QUuid cppResult = ::QUuid::createUuidV5(cppArg0, QByteArrayView(cppArg1));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuidFunc_createUuidV7(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createUuidV7()
        QUuid cppResult = ::QUuid::createUuidV7();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuidFunc_fromBytes(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromBytes", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fromBytes", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QUuid::fromBytes(const void*,QSysInfo::Endian=)->QUuid
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromBytes(const void*,QSysInfo::Endian)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_Endian_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // fromBytes(const void*,QSysInfo::Endian)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromBytes", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"order", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_Endian_IDX])))->converter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromBytes", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);
            }
        }
        void* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QSysInfo::Endian cppArg1(QSysInfo::BigEndian);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromBytes(const void*,QSysInfo::Endian)
            QUuid cppResult = ::QUuid::fromBytes(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuidFunc_fromRfc4122(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QUuid::fromRfc4122(QByteArrayView)->QUuid
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // fromRfc4122(QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromRfc4122", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromRfc4122(QByteArrayView)
            QUuid cppResult = ::QUuid::fromRfc4122(QByteArrayView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuidFunc_fromString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QUuid::fromString(QAnyStringView)->QUuid
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // fromString(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromString(QAnyStringView)
            QUuid cppResult = ::QUuid::fromString(QAnyStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuidFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QUuid *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuidFunc_toByteArray(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toByteArray", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);

    if (PyArg_ParseTuple(args, "|O:toByteArray", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUuid::toByteArray(QUuid::StringFormat=)const->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // toByteArray(QUuid::StringFormat)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_StringFormat_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // toByteArray(QUuid::StringFormat)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toByteArray", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"mode", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_StringFormat_IDX])))->converter, (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "toByteArray", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);
            }
        }
        ::QUuid::StringFormat cppArg0(QUuid::StringFormat::WithBraces);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toByteArray(QUuid::StringFormat)const
            QByteArray cppResult = const_cast<const ::QUuid *>(cppSelf)->toByteArray(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuidFunc_toRfc4122(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toRfc4122()const
        QByteArray cppResult = const_cast<const ::QUuid *>(cppSelf)->toRfc4122();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuidFunc_toString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);

    if (PyArg_ParseTuple(args, "|O:toString", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUuid::toString(QUuid::StringFormat=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // toString(QUuid::StringFormat)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_StringFormat_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // toString(QUuid::StringFormat)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"mode", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_StringFormat_IDX])))->converter, (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]);
            }
        }
        ::QUuid::StringFormat cppArg0(QUuid::StringFormat::WithBraces);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toString(QUuid::StringFormat)const
            QString cppResult = const_cast<const ::QUuid *>(cppSelf)->toString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuidFunc_variant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // variant()const
        QUuid::Variant cppResult = const_cast<const ::QUuid *>(cppSelf)->variant();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_Variant_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuidFunc_version(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // version()const
        QUuid::Version cppResult = const_cast<const ::QUuid *>(cppSelf)->version();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_Version_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QUuid__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QUuid_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QUuid_EnumFlagInfo[] = {
    "StringFormat:Enum",
    "Variant:Enum",
    "Version:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QUuid_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QUuidFunc___reduce__), METH_NOARGS, nullptr},
    {"createUuid", reinterpret_cast<PyCFunction>(Sbk_QUuidFunc_createUuid), METH_NOARGS|METH_STATIC, nullptr},
    {"createUuidV3", reinterpret_cast<PyCFunction>(Sbk_QUuidFunc_createUuidV3), METH_VARARGS|METH_STATIC, nullptr},
    {"createUuidV5", reinterpret_cast<PyCFunction>(Sbk_QUuidFunc_createUuidV5), METH_VARARGS|METH_STATIC, nullptr},
    {"createUuidV7", reinterpret_cast<PyCFunction>(Sbk_QUuidFunc_createUuidV7), METH_NOARGS|METH_STATIC, nullptr},
    {"fromBytes", reinterpret_cast<PyCFunction>(Sbk_QUuidFunc_fromBytes), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromRfc4122", reinterpret_cast<PyCFunction>(Sbk_QUuidFunc_fromRfc4122), METH_O|METH_STATIC, nullptr},
    {"fromString", reinterpret_cast<PyCFunction>(Sbk_QUuidFunc_fromString), METH_O|METH_STATIC, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QUuidFunc_isNull), METH_NOARGS, nullptr},
    {"toByteArray", reinterpret_cast<PyCFunction>(Sbk_QUuidFunc_toByteArray), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toRfc4122", reinterpret_cast<PyCFunction>(Sbk_QUuidFunc_toRfc4122), METH_NOARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QUuidFunc_toString), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"variant", reinterpret_cast<PyCFunction>(Sbk_QUuidFunc_variant), METH_NOARGS, nullptr},
    {"version", reinterpret_cast<PyCFunction>(Sbk_QUuidFunc_version), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QUuid__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QUuid___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QUuid_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArg)))) {
                // operator!=(const QUuid &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUuid cppArg0_local;
                ::QUuid *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArg)))) {
                // operator<(const QUuid &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUuid cppArg0_local;
                ::QUuid *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArg)))) {
                // operator<=(const QUuid &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUuid cppArg0_local;
                ::QUuid *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArg)))) {
                // operator==(const QUuid &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUuid cppArg0_local;
                ::QUuid *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArg)))) {
                // operator>(const QUuid &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUuid cppArg0_local;
                ::QUuid *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArg)))) {
                // operator>=(const QUuid &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUuid cppArg0_local;
                ::QUuid *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QUuid_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QUuid_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QUuid_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QUuid_Type = nullptr;
static PyTypeObject *Sbk_QUuid_TypeF(void)
{
    return _Sbk_QUuid_Type;
}

static PyType_Slot Sbk_QUuid_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QUuidFunc___repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QUuid_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QUuid_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QUuid_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QUuid_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QUuid_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QUuid_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QUuid___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QUuid_spec = {
    "2:PySide6.QtCore.QUuid",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QUuid_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QUuid_Variant(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QUuid::Variant>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QUuid::Variant *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QUuid_Variant_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_Variant_IDX])))
        return Enum_PythonToCpp_QUuid_Variant;
    return {};
}

static PyObject *QUuid_Variant_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QUuid::Variant>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QUuid::Variant *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_Variant_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QUuid_Version(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QUuid::Version>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QUuid::Version *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QUuid_Version_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_Version_IDX])))
        return Enum_PythonToCpp_QUuid_Version;
    return {};
}

static PyObject *QUuid_Version_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QUuid::Version>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QUuid::Version *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_Version_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QUuid_StringFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QUuid::StringFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QUuid::StringFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QUuid_StringFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_StringFormat_IDX])))
        return Enum_PythonToCpp_QUuid_StringFormat;
    return {};
}

static PyObject *QUuid_StringFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QUuid::StringFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QUuid::StringFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_StringFormat_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QUuid_PythonToCpp_QUuid_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QUuid_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QUuid_PythonToCpp_QUuid_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QUuid_TypeF()))
        return QUuid_PythonToCpp_QUuid_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QUuid_PTR_CppToPython_QUuid(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QUuid_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QUuid_COPY_CppToPython_QUuid(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QUuid *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QUuid_TypeF(), new ::QUuid(*source), true, true);
}

// Python to C++ copy conversion.
static void QUuid_PythonToCpp_QUuid_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QUuid *>(cppOut) = *reinterpret_cast< ::QUuid *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QUuid_PythonToCpp_QUuid_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QUuid_TypeF()))
        return QUuid_PythonToCpp_QUuid_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QUuid_SignatureStrings[] = {
    "3:PySide6.QtCore.QUuid(self)",
    "2:PySide6.QtCore.QUuid(self,string:QString)",
    "1:PySide6.QtCore.QUuid(self,QUuid:PySide6.QtCore.QUuid)",
    "0:PySide6.QtCore.QUuid(self,l:uint,w1:ushort,w2:ushort,b1:uchar,b2:uchar,b3:uchar,b4:uchar,b5:uchar,b6:uchar,b7:uchar,b8:uchar)",
    "PySide6.QtCore.QUuid.__reduce__(self)->str",
    "PySide6.QtCore.QUuid.__repr__(self)->str",
    "PySide6.QtCore.QUuid.createUuid()->PySide6.QtCore.QUuid",
    "PySide6.QtCore.QUuid.createUuidV3(ns:PySide6.QtCore.QUuid,baseData:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QUuid",
    "PySide6.QtCore.QUuid.createUuidV5(ns:PySide6.QtCore.QUuid,baseData:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QUuid",
    "PySide6.QtCore.QUuid.createUuidV7()->PySide6.QtCore.QUuid",
    "PySide6.QtCore.QUuid.fromBytes(bytes:void,order:PySide6.QtCore.QSysInfo.Endian=QSysInfo.BigEndian)->PySide6.QtCore.QUuid",
    "PySide6.QtCore.QUuid.fromRfc4122(arg__1:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QUuid",
    "PySide6.QtCore.QUuid.fromString(string:QString)->PySide6.QtCore.QUuid",
    "PySide6.QtCore.QUuid.isNull(self)->bool",
    "PySide6.QtCore.QUuid.toByteArray(self,mode:PySide6.QtCore.QUuid.StringFormat=QUuid.StringFormat.WithBraces)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QUuid.toRfc4122(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QUuid.toString(self,mode:PySide6.QtCore.QUuid.StringFormat=QUuid.StringFormat.WithBraces)->QString",
    "PySide6.QtCore.QUuid.variant(self)->PySide6.QtCore.QUuid.Variant",
    "PySide6.QtCore.QUuid.version(self)->PySide6.QtCore.QUuid.Version",
    "PySide6.QtCore.QUuid.__copy__(self)->typing.Self",
    "PySide6.QtCore.QUuid.__ne__(self,rhs:PySide6.QtCore.QUuid)->bool",
    "PySide6.QtCore.QUuid.__lt__(self,rhs:PySide6.QtCore.QUuid)->bool",
    "PySide6.QtCore.QUuid.__le__(self,rhs:PySide6.QtCore.QUuid)->bool",
    "PySide6.QtCore.QUuid.__eq__(self,rhs:PySide6.QtCore.QUuid)->bool",
    "PySide6.QtCore.QUuid.__gt__(self,rhs:PySide6.QtCore.QUuid)->bool",
    "PySide6.QtCore.QUuid.__ge__(self,rhs:PySide6.QtCore.QUuid)->bool",
    "PySide6.QtCore.QUuid.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QUuid_SignatureByteSize = 419;
static constexpr uint8_t QUuid_SignatureBytes[419] = {
    0x78, 0xda, 0xcd, 0x55, 0xdf, 0x4f, 0x83, 0x30, 0x10, 0x7e, 0xe7, 0xaf, 0xf0, 0x91, 0x19, 0x24,
    0x8e, 0x6d, 0xce, 0x90, 0xcc, 0xc4, 0xf9, 0x23, 0xf1, 0xc5, 0x38, 0xc9, 0xe6, 0x83, 0x31, 0xa4,
    0x40, 0x07, 0x4d, 0x58, 0x3b, 0xaf, 0x65, 0x86, 0xff, 0xde, 0x6e, 0x5d, 0xb7, 0x64, 0x2b, 0x28,
    0xa2, 0x89, 0x2f, 0xf0, 0xb5, 0xfd, 0xee, 0xee, 0xbb, 0xe3, 0x7a, 0xf4, 0xfc, 0xa7, 0x32, 0x20,
    0x09, 0xbe, 0x70, 0x27, 0xe2, 0x86, 0x01, 0x76, 0x27, 0xd3, 0x82, 0x24, 0x36, 0xc7, 0xf9, 0xbc,
    0x63, 0x79, 0xd5, 0x87, 0x0e, 0x17, 0x40, 0x68, 0xea, 0x4f, 0x82, 0xcd, 0xbb, 0x63, 0x75, 0x6b,
    0xb8, 0x1b, 0x68, 0x3c, 0xef, 0x58, 0xe7, 0x35, 0x76, 0xb9, 0x5f, 0x10, 0x2a, 0x9c, 0x8f, 0xae,
    0x5f, 0xf0, 0x8c, 0x81, 0x44, 0x9e, 0x46, 0x91, 0xdc, 0x8b, 0x33, 0x04, 0x4e, 0xe4, 0x69, 0xd0,
    0xd3, 0xa0, 0xaf, 0xc1, 0x40, 0x83, 0x0b, 0x0d, 0x86, 0x1a, 0x5c, 0x2a, 0xd0, 0xb1, 0x4c, 0xd1,
    0xdd, 0x30, 0x04, 0x9c, 0x14, 0x31, 0x0e, 0x43, 0x55, 0x89, 0xb3, 0x2b, 0x99, 0x6e, 0x35, 0x75,
    0x09, 0xdf, 0x20, 0xc6, 0x80, 0x91, 0xc0, 0x9b, 0xe4, 0x24, 0xcd, 0x44, 0xf9, 0xca, 0x6e, 0xd6,
    0xb3, 0x29, 0x37, 0x96, 0xcb, 0x89, 0x10, 0xc7, 0xb7, 0x48, 0x20, 0x5f, 0x94, 0x4b, 0xf9, 0x39,
    0xdc, 0x29, 0x25, 0x8c, 0xbe, 0x1e, 0x52, 0xc7, 0xa5, 0xc0, 0xd7, 0x00, 0xa8, 0x74, 0x4e, 0xd6,
    0xc9, 0x9f, 0xbe, 0xfd, 0x54, 0xc8, 0xe0, 0xbf, 0x08, 0x19, 0x36, 0xab, 0xe5, 0x1c, 0xd8, 0x62,
    0x1d, 0x9b, 0xdb, 0xd1, 0xfa, 0xe9, 0xaf, 0x98, 0x94, 0xcc, 0x20, 0xc1, 0x70, 0x94, 0x4d, 0x50,
    0xf2, 0x07, 0x3a, 0x67, 0xee, 0x1d, 0x4d, 0x08, 0xa2, 0xa3, 0xdd, 0x7a, 0x4c, 0x52, 0xb5, 0xd5,
    0x38, 0xf0, 0xf3, 0x3c, 0xee, 0x77, 0x3d, 0xcf, 0x46, 0x90, 0x86, 0x61, 0xf7, 0x2f, 0x0b, 0xb4,
    0x8e, 0xa6, 0xee, 0xa5, 0x7d, 0x70, 0x4d, 0x9b, 0x78, 0x21, 0xfc, 0xb1, 0xc8, 0x73, 0xdd, 0xd7,
    0x11, 0x63, 0xb9, 0x99, 0x27, 0xd8, 0x4e, 0xad, 0xba, 0xb6, 0x0b, 0x96, 0x60, 0x63, 0x77, 0xb8,
    0x4a, 0xc5, 0x3d, 0x83, 0x05, 0x12, 0xa3, 0xe3, 0x2d, 0xf7, 0x85, 0x88, 0x6c, 0x0c, 0x28, 0xc6,
    0xdc, 0xa0, 0x74, 0x17, 0xa5, 0x4a, 0x86, 0x2e, 0xf0, 0x56, 0x71, 0x63, 0x7b, 0x5d, 0xb2, 0x5f,
    0xcc, 0x61, 0x5b, 0x77, 0x73, 0xc4, 0x15, 0x02, 0xd9, 0x47, 0xa2, 0x4a, 0xef, 0x86, 0x33, 0x53,
    0x9c, 0x0a, 0x07, 0x18, 0xb8, 0xec, 0x9e, 0x7a, 0x07, 0x8a, 0x53, 0x35, 0xbc, 0x62, 0xb6, 0x2c,
    0xf7, 0xc3, 0x6b, 0xdb, 0x93, 0x81, 0x5c, 0x55, 0x19, 0x50, 0x3d, 0x14, 0x1d, 0xc8, 0xcc, 0x33,
    0xa0, 0xb6, 0x59, 0xc2, 0x30, 0x17, 0x6d, 0x1d, 0xb4, 0x55, 0x80, 0xdf, 0x5b, 0x3a, 0x48, 0xdb,
    0xa6, 0x90, 0xb6, 0x4d, 0x21, 0x43, 0x3c, 0xdb, 0x7f, 0x36, 0xf9, 0x93, 0xb4, 0x3e, 0x01, 0xa0,
    0xac, 0xb7, 0x3d
};
#endif

PyTypeObject *init_QUuid(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX].type;

    Shiboken::AutoDecRef Sbk_QUuid_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QUuid_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QUuid",
        "QUuid",
        &Sbk_QUuid_spec,
        &Shiboken::callCppDestructor< ::QUuid >,
        Sbk_QUuid_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QUuid_TypeF(); // references _Sbk_QUuid_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QUuid_SignatureStrings);
#else
    InitSignatureBytes(pyType, QUuid_SignatureBytes, QUuid_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QUuid_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QUuid_PythonToCpp_QUuid_PTR,
        is_QUuid_PythonToCpp_QUuid_PTR_Convertible,
        QUuid_PTR_CppToPython_QUuid,
        QUuid_COPY_CppToPython_QUuid);

    Shiboken::Conversions::registerConverterName(converter, "QUuid");
    Shiboken::Conversions::registerConverterName(converter, "QUuid*");
    Shiboken::Conversions::registerConverterName(converter, "QUuid&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QUuid).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QUuid_PythonToCpp_QUuid_COPY,
        is_QUuid_PythonToCpp_QUuid_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QUuid_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Variant'.
    const char *Variant_Initializer[] = {
        "VarUnknown",
        "NCS",
        "DCE",
        "Microsoft",
        "Reserved",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Variant_InitializerValues[] = {
        int8_t(QUuid::Variant::VarUnknown), // -0x01 -1
        int8_t(QUuid::Variant::NCS),        //  0x00  0
        int8_t(QUuid::Variant::DCE),        //  0x02  2
        int8_t(QUuid::Variant::Microsoft),  //  0x06  6
        int8_t(QUuid::Variant::Reserved)    //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QUuid_TypeF(),
        "2:PySide6.QtCore.QUuid.Variant",
        Variant_Initializer, Variant_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QUuid_Variant_IDX].type = EType;
    // Register converter for enum 'QUuid::Variant'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QUuid_Variant_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QUuid_Variant,
            is_Enum_PythonToCpp_QUuid_Variant_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QUuid::Variant");
        Shiboken::Conversions::registerConverterAlias(converter, "Variant");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Variant' enum.

    // Initialization of enum 'Version'.
    const char *Version_Initializer[] = {
        "VerUnknown",
        "Time",
        "EmbeddedPOSIX",
        "Md5",
        "Name",
        "Random",
        "Sha1",
        "UnixEpoch",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Version_InitializerValues[] = {
        int8_t(QUuid::Version::VerUnknown),    // -0x01 -1
        int8_t(QUuid::Version::Time),          //  0x01  1
        int8_t(QUuid::Version::EmbeddedPOSIX), //  0x02  2
        int8_t(QUuid::Version::Md5),           //  0x03  3
        int8_t(QUuid::Version::Name),          //  0x03  3
        int8_t(QUuid::Version::Random),        //  0x04  4
        int8_t(QUuid::Version::Sha1),          //  0x05  5
        int8_t(QUuid::Version::UnixEpoch)      //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QUuid_TypeF(),
        "2:PySide6.QtCore.QUuid.Version",
        Version_Initializer, Version_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QUuid_Version_IDX].type = EType;
    // Register converter for enum 'QUuid::Version'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QUuid_Version_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QUuid_Version,
            is_Enum_PythonToCpp_QUuid_Version_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QUuid::Version");
        Shiboken::Conversions::registerConverterAlias(converter, "Version");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Version' enum.

    // Initialization of enum 'StringFormat'.
    const char *StringFormat_Initializer[] = {
        "WithBraces",
        "WithoutBraces",
        "Id128",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StringFormat_InitializerValues[] = {
        uint8_t(QUuid::StringFormat::WithBraces),    //  0x00  0
        uint8_t(QUuid::StringFormat::WithoutBraces), //  0x01  1
        uint8_t(QUuid::StringFormat::Id128)          //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QUuid_TypeF(),
        "2:PySide6.QtCore.QUuid.StringFormat",
        StringFormat_Initializer, StringFormat_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QUuid_StringFormat_IDX].type = EType;
    // Register converter for enum 'QUuid::StringFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QUuid_StringFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QUuid_StringFormat,
            is_Enum_PythonToCpp_QUuid_StringFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QUuid::StringFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "StringFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StringFormat' enum.

    qRegisterMetaType< ::QUuid >("QUuid");
    qRegisterMetaType< ::QUuid::Variant >("QUuid::Variant");
    qRegisterMetaType< ::QUuid::Version >("QUuid::Version");
    qRegisterMetaType< ::QUuid::StringFormat >("QUuid::StringFormat");

    return pyType;
}
