// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QVARIANTANIMATIONWRAPPER_H
#define SBK_QVARIANTANIMATIONWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <qvariantanimation.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QVariantAnimationWrapper : public QVariantAnimation
{
public:
    QVariantAnimationWrapper(::QObject * parent = nullptr);
    QVariantAnimationWrapper(const QVariantAnimationWrapper &) = delete;
    QVariantAnimationWrapper& operator=(const QVariantAnimationWrapper &) = delete;
    QVariantAnimationWrapper(QVariantAnimationWrapper &&) = delete;
    QVariantAnimationWrapper& operator=(QVariantAnimationWrapper &&) = delete;
    ~QVariantAnimationWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    int duration() const override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QVariant interpolated(const ::QVariant & from, const ::QVariant & to, qreal progress) const override;
    static ::QVariant sbk_o_interpolated(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QVariant & from, const ::QVariant & to, qreal progress);
    void timerEvent(::QTimerEvent * event) override;
    void updateCurrentTime(int arg__1) override;
    void updateCurrentValue(const ::QVariant & value) override;
    static void sbk_o_updateCurrentValue(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QVariant & value);
    void updateDirection(::QAbstractAnimation::Direction direction) override;
    void updateState(::QAbstractAnimation::State newState, ::QAbstractAnimation::State oldState) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[13] = {false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QVARIANTANIMATIONWRAPPER_H
