// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdbus_python.h"

// main header
#include "qdbusabstractinterfacebase_wrapper.h"

// Wrappers providing overrides
#include "qdbusvirtualobject_wrapper.h"

// Argument includes
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDBusAbstractInterfaceBaseWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QDBusAbstractInterfaceBaseWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QDBusVirtualObjectWrapper::sbk_o_childEvent("QDBusAbstractInterfaceBase", funcName, gil, pyOverride, event);
}

void QDBusAbstractInterfaceBaseWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QDBusVirtualObjectWrapper::sbk_o_connectNotify("QDBusAbstractInterfaceBase", funcName, gil, pyOverride, signal);
}

void QDBusAbstractInterfaceBaseWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QDBusVirtualObjectWrapper::sbk_o_customEvent("QDBusAbstractInterfaceBase", funcName, gil, pyOverride, event);
}

void QDBusAbstractInterfaceBaseWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QDBusVirtualObjectWrapper::sbk_o_connectNotify("QDBusAbstractInterfaceBase", funcName, gil, pyOverride, signal);
}

bool QDBusAbstractInterfaceBaseWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QDBusVirtualObjectWrapper::sbk_o_event("QDBusAbstractInterfaceBase", funcName, gil, pyOverride, event);
}

bool QDBusAbstractInterfaceBaseWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QDBusVirtualObjectWrapper::sbk_o_eventFilter("QDBusAbstractInterfaceBase", funcName, gil, pyOverride, watched, event);
}

void QDBusAbstractInterfaceBaseWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QDBusVirtualObjectWrapper::sbk_o_timerEvent("QDBusAbstractInterfaceBase", funcName, gil, pyOverride, event);
}

const QMetaObject *QDBusAbstractInterfaceBaseWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QDBusAbstractInterfaceBase::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QDBusAbstractInterfaceBaseWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QDBusAbstractInterfaceBase::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QDBusAbstractInterfaceBaseWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QDBusAbstractInterfaceBaseWrapper *>(this));
    return QDBusAbstractInterfaceBase::qt_metacast(_clname);
}

QDBusAbstractInterfaceBaseWrapper::~QDBusAbstractInterfaceBaseWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_QDBusAbstractInterfaceBase_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QDBusAbstractInterfaceBase");
    return -1;
}


static const char *Sbk_QDBusAbstractInterfaceBase_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDBusAbstractInterfaceBase_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDBusAbstractInterfaceBase_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDBusAbstractInterfaceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterfaceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDBusAbstractInterfaceBaseWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDBusAbstractInterfaceBase_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDBusAbstractInterfaceBase_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDBusAbstractInterfaceBase_Type = nullptr;
static PyTypeObject *Sbk_QDBusAbstractInterfaceBase_TypeF(void)
{
    return _Sbk_QDBusAbstractInterfaceBase_Type;
}

static PyType_Slot Sbk_QDBusAbstractInterfaceBase_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDBusAbstractInterfaceBase_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDBusAbstractInterfaceBase_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDBusAbstractInterfaceBase_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDBusAbstractInterfaceBase_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDBusAbstractInterfaceBase_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDBusAbstractInterfaceBase_spec = {
    "2:PySide6.QtDBus.QDBusAbstractInterfaceBase",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDBusAbstractInterfaceBase_slots
};

} //extern "C"

static void *Sbk_QDBusAbstractInterfaceBase_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QDBusAbstractInterfaceBase *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDBusAbstractInterfaceBase_PythonToCpp_QDBusAbstractInterfaceBase_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDBusAbstractInterfaceBase_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDBusAbstractInterfaceBase_PythonToCpp_QDBusAbstractInterfaceBase_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusAbstractInterfaceBase_TypeF()))
        return QDBusAbstractInterfaceBase_PythonToCpp_QDBusAbstractInterfaceBase_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDBusAbstractInterfaceBase_PTR_CppToPython_QDBusAbstractInterfaceBase(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QDBusAbstractInterfaceBase *>(const_cast<void *>(cppIn)), Sbk_QDBusAbstractInterfaceBase_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDBusAbstractInterfaceBase_SignatureStrings[] = {
    nullptr}; // Sentinel
#else
static constexpr size_t QDBusAbstractInterfaceBase_SignatureByteSize = 0;
static constexpr uint8_t QDBusAbstractInterfaceBase_SignatureBytes[1] = {
    0x00
};
#endif

PyTypeObject *init_QDBusAbstractInterfaceBase(PyObject *module)
{
    if (SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterfaceBase_IDX].type != nullptr)
        return SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterfaceBase_IDX].type;

    Shiboken::AutoDecRef Sbk_QDBusAbstractInterfaceBase_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QDBusAbstractInterfaceBase_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDBusAbstractInterfaceBase",
        "QDBusAbstractInterfaceBase*",
        &Sbk_QDBusAbstractInterfaceBase_spec,
        &Shiboken::callCppDestructor< QDBusAbstractInterfaceBase >,
        Sbk_QDBusAbstractInterfaceBase_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDBusAbstractInterfaceBase_TypeF(); // references _Sbk_QDBusAbstractInterfaceBase_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDBusAbstractInterfaceBase_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDBusAbstractInterfaceBase_SignatureBytes, QDBusAbstractInterfaceBase_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDBusAbstractInterfaceBase_PropertyStrings);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterfaceBase_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDBusAbstractInterfaceBase_PythonToCpp_QDBusAbstractInterfaceBase_PTR,
        is_QDBusAbstractInterfaceBase_PythonToCpp_QDBusAbstractInterfaceBase_PTR_Convertible,
        QDBusAbstractInterfaceBase_PTR_CppToPython_QDBusAbstractInterfaceBase);

    Shiboken::Conversions::registerConverterName(converter, "QDBusAbstractInterfaceBase");
    Shiboken::Conversions::registerConverterName(converter, "QDBusAbstractInterfaceBase*");
    Shiboken::Conversions::registerConverterName(converter, "QDBusAbstractInterfaceBase&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDBusAbstractInterfaceBase).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDBusAbstractInterfaceBaseWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDBusAbstractInterfaceBase_TypeF(), &Sbk_QDBusAbstractInterfaceBase_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QDBusAbstractInterfaceBase::staticMetaObject, sizeof(QDBusAbstractInterfaceBaseWrapper));

    return pyType;
}
