// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdatavisualization_python.h"

// main header
#include "qlogvalue3daxisformatter_wrapper.h"

// Wrappers providing overrides
#include "qvalue3daxisformatter_wrapper.h"
#include "qabstract3dgraph_wrapper.h"

// Argument includes
#include <QString>
#include <QtDataVisualization/qvalue3daxisformatter.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QLogValue3DAxisFormatterWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QLogValue3DAxisFormatterWrapper::QLogValue3DAxisFormatterWrapper(::QObject * parent) : QLogValue3DAxisFormatter(parent)
{
}

void QLogValue3DAxisFormatterWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_childEvent("QLogValue3DAxisFormatter", funcName, gil, pyOverride, event);
}

void QLogValue3DAxisFormatterWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QAbstract3DGraphWrapper::sbk_o_connectNotify("QLogValue3DAxisFormatter", funcName, gil, pyOverride, signal);
}

::QValue3DAxisFormatter * QLogValue3DAxisFormatterWrapper::createNewInstance() const
{
    static const char *funcName = "createNewInstance";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLogValue3DAxisFormatter::createNewInstance();
    }
    return sbk_o_createNewInstance("QLogValue3DAxisFormatter", funcName, gil, pyOverride);
}

::QValue3DAxisFormatter * QLogValue3DAxisFormatterWrapper::sbk_o_createNewInstance(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QValue3DAxisFormatter_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QValue3DAxisFormatter >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QValue3DAxisFormatter *cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (Shiboken::Object::checkType(pyResult))
        Shiboken::Object::releaseOwnership(pyResult);
    return cppResult;
}

void QLogValue3DAxisFormatterWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_customEvent("QLogValue3DAxisFormatter", funcName, gil, pyOverride, event);
}

void QLogValue3DAxisFormatterWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QAbstract3DGraphWrapper::sbk_o_connectNotify("QLogValue3DAxisFormatter", funcName, gil, pyOverride, signal);
}

bool QLogValue3DAxisFormatterWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QAbstract3DGraphWrapper::sbk_o_event("QLogValue3DAxisFormatter", funcName, gil, pyOverride, event);
}

bool QLogValue3DAxisFormatterWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QAbstract3DGraphWrapper::sbk_o_eventFilter("QLogValue3DAxisFormatter", funcName, gil, pyOverride, watched, event);
}

void QLogValue3DAxisFormatterWrapper::populateCopy(::QValue3DAxisFormatter & copy) const
{
    static const char *funcName = "populateCopy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLogValue3DAxisFormatter::populateCopy(copy);
    }
    sbk_o_populateCopy("QLogValue3DAxisFormatter", funcName, gil, pyOverride, copy);
}

void QLogValue3DAxisFormatterWrapper::sbk_o_populateCopy(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QValue3DAxisFormatter & copy)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QValue3DAxisFormatter_IDX]), &copy)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QValue3DAxisFormatter_IDX]), &copy)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

float QLogValue3DAxisFormatterWrapper::positionAt(float value) const
{
    static const char *funcName = "positionAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLogValue3DAxisFormatter::positionAt(value);
    }
    return QValue3DAxisFormatterWrapper::sbk_o_positionAt("QLogValue3DAxisFormatter", funcName, gil, pyOverride, value);
}

void QLogValue3DAxisFormatterWrapper::recalculate()
{
    static const char *funcName = "recalculate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLogValue3DAxisFormatter::recalculate();
    }
    QValue3DAxisFormatterWrapper::sbk_o_recalculate("QLogValue3DAxisFormatter", funcName, gil, pyOverride);
}

::QString QLogValue3DAxisFormatterWrapper::stringForValue(qreal value, const ::QString & format) const
{
    static const char *funcName = "stringForValue";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QValue3DAxisFormatter::stringForValue(value, format);
    }
    return QValue3DAxisFormatterWrapper::sbk_o_stringForValue("QLogValue3DAxisFormatter", funcName, gil, pyOverride, value, format);
}

void QLogValue3DAxisFormatterWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_timerEvent("QLogValue3DAxisFormatter", funcName, gil, pyOverride, event);
}

float QLogValue3DAxisFormatterWrapper::valueAt(float position) const
{
    static const char *funcName = "valueAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLogValue3DAxisFormatter::valueAt(position);
    }
    return QValue3DAxisFormatterWrapper::sbk_o_positionAt("QLogValue3DAxisFormatter", funcName, gil, pyOverride, position);
}

const QMetaObject *QLogValue3DAxisFormatterWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QLogValue3DAxisFormatter::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QLogValue3DAxisFormatterWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QLogValue3DAxisFormatter::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QLogValue3DAxisFormatterWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QLogValue3DAxisFormatterWrapper *>(this));
    return QLogValue3DAxisFormatter::qt_metacast(_clname);
}

QLogValue3DAxisFormatterWrapper::~QLogValue3DAxisFormatterWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLogValue3DAxisFormatter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLogValue3DAxisFormatter >()))
        return -1;

    QLogValue3DAxisFormatterWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QLogValue3DAxisFormatter", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLogValue3DAxisFormatter::QLogValue3DAxisFormatter(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QLogValue3DAxisFormatter(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QLogValue3DAxisFormatter(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QLogValue3DAxisFormatter(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QLogValue3DAxisFormatterWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QLogValue3DAxisFormatterWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QLogValue3DAxisFormatter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QLogValue3DAxisFormatterFunc_autoSubGrid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLogValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoSubGrid()const
        bool cppResult = const_cast<const ::QLogValue3DAxisFormatter *>(cppSelf)->autoSubGrid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLogValue3DAxisFormatterFunc_base(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLogValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // base()const
        qreal cppResult = const_cast<const ::QLogValue3DAxisFormatter *>(cppSelf)->base();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLogValue3DAxisFormatterFunc_createNewInstance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLogValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createNewInstance()const
        QValue3DAxisFormatter * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QLogValue3DAxisFormatter *>(cppSelf)->::QLogValue3DAxisFormatter::createNewInstance()
            : const_cast<const ::QLogValue3DAxisFormatter *>(cppSelf)->createNewInstance();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QValue3DAxisFormatter_IDX]), cppResult);

        // Ownership transferences.
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLogValue3DAxisFormatterFunc_populateCopy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLogValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::populateCopy(QValue3DAxisFormatter&)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QValue3DAxisFormatter_IDX]), (pyArg)))) {
        overloadId = 0; // populateCopy(QValue3DAxisFormatter&)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "populateCopy", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QValue3DAxisFormatter *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // populateCopy(QValue3DAxisFormatter&)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QLogValue3DAxisFormatter *>(cppSelf)->::QLogValue3DAxisFormatter::populateCopy(*cppArg0)
                : const_cast<const ::QLogValue3DAxisFormatter *>(cppSelf)->populateCopy(*cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLogValue3DAxisFormatterFunc_positionAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLogValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::positionAt(float)const->float
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // positionAt(float)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "positionAt", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // positionAt(float)const
            float cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QLogValue3DAxisFormatter *>(cppSelf)->::QLogValue3DAxisFormatter::positionAt(cppArg0)
                : const_cast<const ::QLogValue3DAxisFormatter *>(cppSelf)->positionAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLogValue3DAxisFormatterFunc_recalculate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLogValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // recalculate()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QLogValue3DAxisFormatter::recalculate()
            : cppSelf->recalculate();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLogValue3DAxisFormatterFunc_setAutoSubGrid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLogValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLogValue3DAxisFormatter::setAutoSubGrid(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoSubGrid(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoSubGrid", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoSubGrid(bool)
            cppSelf->setAutoSubGrid(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLogValue3DAxisFormatterFunc_setBase(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLogValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLogValue3DAxisFormatter::setBase(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setBase(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBase", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBase(qreal)
            cppSelf->setBase(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLogValue3DAxisFormatterFunc_setShowEdgeLabels(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLogValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLogValue3DAxisFormatter::setShowEdgeLabels(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setShowEdgeLabels(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShowEdgeLabels", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShowEdgeLabels(bool)
            cppSelf->setShowEdgeLabels(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QLogValue3DAxisFormatterFunc_showEdgeLabels(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLogValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showEdgeLabels()const
        bool cppResult = const_cast<const ::QLogValue3DAxisFormatter *>(cppSelf)->showEdgeLabels();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QLogValue3DAxisFormatterFunc_valueAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLogValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QValue3DAxisFormatter::valueAt(float)const->float
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // valueAt(float)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "valueAt", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // valueAt(float)const
            float cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QLogValue3DAxisFormatter *>(cppSelf)->::QLogValue3DAxisFormatter::valueAt(cppArg0)
                : const_cast<const ::QLogValue3DAxisFormatter *>(cppSelf)->valueAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QLogValue3DAxisFormatter_PropertyStrings[] = {
    "autoSubGrid::",
    "base::",
    "showEdgeLabels::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLogValue3DAxisFormatter_methods[] = {
    {"autoSubGrid", reinterpret_cast<PyCFunction>(Sbk_QLogValue3DAxisFormatterFunc_autoSubGrid), METH_NOARGS, nullptr},
    {"base", reinterpret_cast<PyCFunction>(Sbk_QLogValue3DAxisFormatterFunc_base), METH_NOARGS, nullptr},
    {"createNewInstance", reinterpret_cast<PyCFunction>(Sbk_QLogValue3DAxisFormatterFunc_createNewInstance), METH_NOARGS, nullptr},
    {"populateCopy", reinterpret_cast<PyCFunction>(Sbk_QLogValue3DAxisFormatterFunc_populateCopy), METH_O, nullptr},
    {"positionAt", reinterpret_cast<PyCFunction>(Sbk_QLogValue3DAxisFormatterFunc_positionAt), METH_O, nullptr},
    {"recalculate", reinterpret_cast<PyCFunction>(Sbk_QLogValue3DAxisFormatterFunc_recalculate), METH_NOARGS, nullptr},
    {"setAutoSubGrid", reinterpret_cast<PyCFunction>(Sbk_QLogValue3DAxisFormatterFunc_setAutoSubGrid), METH_O, nullptr},
    {"setBase", reinterpret_cast<PyCFunction>(Sbk_QLogValue3DAxisFormatterFunc_setBase), METH_O, nullptr},
    {"setShowEdgeLabels", reinterpret_cast<PyCFunction>(Sbk_QLogValue3DAxisFormatterFunc_setShowEdgeLabels), METH_O, nullptr},
    {"showEdgeLabels", reinterpret_cast<PyCFunction>(Sbk_QLogValue3DAxisFormatterFunc_showEdgeLabels), METH_NOARGS, nullptr},
    {"valueAt", reinterpret_cast<PyCFunction>(Sbk_QLogValue3DAxisFormatterFunc_valueAt), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QLogValue3DAxisFormatter_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QLogValue3DAxisFormatter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QLogValue3DAxisFormatterWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QLogValue3DAxisFormatter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLogValue3DAxisFormatter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLogValue3DAxisFormatter_Type = nullptr;
static PyTypeObject *Sbk_QLogValue3DAxisFormatter_TypeF(void)
{
    return _Sbk_QLogValue3DAxisFormatter_Type;
}

static PyType_Slot Sbk_QLogValue3DAxisFormatter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QLogValue3DAxisFormatter_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLogValue3DAxisFormatter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLogValue3DAxisFormatter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLogValue3DAxisFormatter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLogValue3DAxisFormatter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLogValue3DAxisFormatter_spec = {
    "2:PySide6.QtDataVisualization.QLogValue3DAxisFormatter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLogValue3DAxisFormatter_slots
};

} //extern "C"

static void *Sbk_QLogValue3DAxisFormatter_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QLogValue3DAxisFormatter *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLogValue3DAxisFormatter_PythonToCpp_QLogValue3DAxisFormatter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLogValue3DAxisFormatter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLogValue3DAxisFormatter_PythonToCpp_QLogValue3DAxisFormatter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLogValue3DAxisFormatter_TypeF()))
        return QLogValue3DAxisFormatter_PythonToCpp_QLogValue3DAxisFormatter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLogValue3DAxisFormatter_PTR_CppToPython_QLogValue3DAxisFormatter(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QLogValue3DAxisFormatter *>(const_cast<void *>(cppIn)), Sbk_QLogValue3DAxisFormatter_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QLogValue3DAxisFormatter_SignatureStrings[] = {
    "PySide6.QtDataVisualization.QLogValue3DAxisFormatter(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,base:qreal=None,autoSubGrid:bool=None,showEdgeLabels:bool=None)",
    "PySide6.QtDataVisualization.QLogValue3DAxisFormatter.autoSubGrid(self)->bool",
    "PySide6.QtDataVisualization.QLogValue3DAxisFormatter.base(self)->qreal",
    "PySide6.QtDataVisualization.QLogValue3DAxisFormatter.createNewInstance(self)->PySide6.QtDataVisualization.QValue3DAxisFormatter",
    "PySide6.QtDataVisualization.QLogValue3DAxisFormatter.populateCopy(self,copy:PySide6.QtDataVisualization.QValue3DAxisFormatter)",
    "PySide6.QtDataVisualization.QLogValue3DAxisFormatter.positionAt(self,value:float)->float",
    "PySide6.QtDataVisualization.QLogValue3DAxisFormatter.recalculate(self)",
    "PySide6.QtDataVisualization.QLogValue3DAxisFormatter.setAutoSubGrid(self,enabled:bool)",
    "PySide6.QtDataVisualization.QLogValue3DAxisFormatter.setBase(self,base:qreal)",
    "PySide6.QtDataVisualization.QLogValue3DAxisFormatter.setShowEdgeLabels(self,enabled:bool)",
    "PySide6.QtDataVisualization.QLogValue3DAxisFormatter.showEdgeLabels(self)->bool",
    "PySide6.QtDataVisualization.QLogValue3DAxisFormatter.valueAt(self,position:float)->float",
    nullptr}; // Sentinel
#else
static constexpr size_t QLogValue3DAxisFormatter_SignatureByteSize = 291;
static constexpr uint8_t QLogValue3DAxisFormatter_SignatureBytes[291] = {
    0x78, 0xda, 0xad, 0x93, 0x4d, 0x4f, 0xc3, 0x30, 0x0c, 0x86, 0xef, 0xfc, 0x12, 0x86, 0x4a, 0x2f,
    0x48, 0x1c, 0x22, 0x0d, 0xa9, 0x6c, 0x80, 0x10, 0xd3, 0xd6, 0xaa, 0xd2, 0xee, 0x6e, 0xea, 0x8d,
    0xa0, 0x10, 0x97, 0xc4, 0xa1, 0x94, 0x5f, 0x4f, 0x3f, 0xe8, 0x18, 0x03, 0x21, 0x11, 0x38, 0xe5,
    0xfb, 0x79, 0xed, 0xbc, 0x76, 0xda, 0xe4, 0xaa, 0xc4, 0xf3, 0x38, 0xe3, 0x39, 0x30, 0xac, 0x95,
    0xf3, 0xa0, 0xd5, 0x2b, 0xb0, 0x22, 0x13, 0x67, 0x0b, 0xda, 0xae, 0x41, 0x7b, 0x3c, 0x9b, 0x27,
    0x2f, 0xca, 0x5d, 0x93, 0x7d, 0x04, 0x66, 0xb4, 0xc7, 0x0e, 0xf5, 0x26, 0xaa, 0xc0, 0xa2, 0x61,
    0x91, 0xee, 0x00, 0x33, 0xb2, 0x18, 0x67, 0xab, 0xe2, 0x01, 0x25, 0x4f, 0x8d, 0xd7, 0xba, 0x62,
    0x1b, 0x9d, 0x88, 0x3b, 0x6c, 0x6a, 0xb2, 0xe5, 0xca, 0xe8, 0x66, 0xba, 0x24, 0x83, 0x51, 0x01,
    0x0e, 0xc5, 0x93, 0x45, 0xd0, 0xc3, 0x1a, 0x3c, 0x53, 0xee, 0x8b, 0x1b, 0xab, 0x4a, 0x51, 0x10,
    0xbd, 0xef, 0xba, 0x7b, 0xaa, 0xaf, 0xca, 0x2d, 0x2e, 0xa0, 0x40, 0xed, 0x3e, 0x0e, 0x26, 0x47,
    0x69, 0x40, 0xc8, 0xf1, 0x9e, 0x48, 0x1f, 0xfe, 0xe4, 0xf4, 0xa2, 0x43, 0x86, 0xc1, 0xba, 0x0c,
    0x46, 0x4a, 0x9f, 0x48, 0x18, 0x46, 0xb6, 0x4f, 0x19, 0x97, 0x58, 0xdf, 0x1a, 0xc7, 0x60, 0xe4,
    0x8e, 0xf9, 0x23, 0xed, 0x3b, 0x54, 0x98, 0x7e, 0x45, 0x95, 0xd7, 0x6d, 0x04, 0x33, 0xaa, 0x9a,
    0xc1, 0x53, 0xd9, 0xce, 0xc4, 0xaf, 0xd5, 0x27, 0xa1, 0xf2, 0x4e, 0x75, 0x37, 0x12, 0x1e, 0xc4,
    0x9f, 0xbb, 0x4b, 0x62, 0xa3, 0x09, 0xb8, 0xfd, 0x83, 0x7e, 0x0c, 0x03, 0x5b, 0x94, 0xa0, 0x65,
    0x9f, 0xda, 0xf0, 0xa3, 0x61, 0x18, 0x87, 0x9c, 0x1c, 0x54, 0x4d, 0x84, 0x06, 0x0a, 0x8d, 0x43,
    0x9d, 0x86, 0x63, 0x2f, 0xc7, 0xfa, 0xd9, 0xeb, 0x85, 0x70, 0x5a, 0xfe, 0xa9, 0x53, 0xfe, 0x2f,
    0xce, 0xaf, 0xd8, 0x3f, 0x35, 0x4d, 0x6f, 0xef, 0xe8, 0xf5, 0xe8, 0xfd, 0x81, 0xdd, 0x6f, 0x81,
    0x90, 0xb1, 0xa8
};
#endif

PyTypeObject *init_QLogValue3DAxisFormatter(PyObject *module)
{
    if (SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX].type != nullptr)
        return SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX].type;

    Shiboken::AutoDecRef Sbk_QLogValue3DAxisFormatter_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QValue3DAxisFormatter_IDX]))));

    _Sbk_QLogValue3DAxisFormatter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLogValue3DAxisFormatter",
        "QLogValue3DAxisFormatter*",
        &Sbk_QLogValue3DAxisFormatter_spec,
        &Shiboken::callCppDestructor< QLogValue3DAxisFormatter >,
        Sbk_QLogValue3DAxisFormatter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QLogValue3DAxisFormatter_TypeF(); // references _Sbk_QLogValue3DAxisFormatter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QLogValue3DAxisFormatter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QLogValue3DAxisFormatter_SignatureBytes, QLogValue3DAxisFormatter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLogValue3DAxisFormatter_PropertyStrings);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_QLogValue3DAxisFormatter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLogValue3DAxisFormatter_PythonToCpp_QLogValue3DAxisFormatter_PTR,
        is_QLogValue3DAxisFormatter_PythonToCpp_QLogValue3DAxisFormatter_PTR_Convertible,
        QLogValue3DAxisFormatter_PTR_CppToPython_QLogValue3DAxisFormatter);

    Shiboken::Conversions::registerConverterName(converter, "QLogValue3DAxisFormatter");
    Shiboken::Conversions::registerConverterName(converter, "QLogValue3DAxisFormatter*");
    Shiboken::Conversions::registerConverterName(converter, "QLogValue3DAxisFormatter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLogValue3DAxisFormatter).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QLogValue3DAxisFormatterWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QLogValue3DAxisFormatter_TypeF(), &Sbk_QLogValue3DAxisFormatter_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QLogValue3DAxisFormatter::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QLogValue3DAxisFormatter::staticMetaObject, sizeof(QLogValue3DAxisFormatterWrapper));

    return pyType;
}
