// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdatavisualization_python.h"

// main header
#include "qtouch3dinputhandler_wrapper.h"

// Wrappers providing overrides
#include "qabstract3dinputhandler_wrapper.h"
#include "qabstract3dgraph_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QTouch3DInputHandlerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QTouch3DInputHandlerWrapper::QTouch3DInputHandlerWrapper(::QObject * parent) : QTouch3DInputHandler(parent)
{
}

void QTouch3DInputHandlerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_childEvent("QTouch3DInputHandler", funcName, gil, pyOverride, event);
}

void QTouch3DInputHandlerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QAbstract3DGraphWrapper::sbk_o_connectNotify("QTouch3DInputHandler", funcName, gil, pyOverride, signal);
}

void QTouch3DInputHandlerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_customEvent("QTouch3DInputHandler", funcName, gil, pyOverride, event);
}

void QTouch3DInputHandlerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QAbstract3DGraphWrapper::sbk_o_connectNotify("QTouch3DInputHandler", funcName, gil, pyOverride, signal);
}

bool QTouch3DInputHandlerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QAbstract3DGraphWrapper::sbk_o_event("QTouch3DInputHandler", funcName, gil, pyOverride, event);
}

bool QTouch3DInputHandlerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QAbstract3DGraphWrapper::sbk_o_eventFilter("QTouch3DInputHandler", funcName, gil, pyOverride, watched, event);
}

void QTouch3DInputHandlerWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstract3DInputHandler::mouseDoubleClickEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_mouseDoubleClickEvent("QTouch3DInputHandler", funcName, gil, pyOverride, event);
}

void QTouch3DInputHandlerWrapper::mouseMoveEvent(::QMouseEvent * event, const ::QPoint & mousePos)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::Q3DInputHandler::mouseMoveEvent(event, mousePos);
    }
    QAbstract3DInputHandlerWrapper::sbk_o_mouseMoveEvent("QTouch3DInputHandler", funcName, gil, pyOverride, event, mousePos);
}

void QTouch3DInputHandlerWrapper::mousePressEvent(::QMouseEvent * event, const ::QPoint & mousePos)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::Q3DInputHandler::mousePressEvent(event, mousePos);
    }
    QAbstract3DInputHandlerWrapper::sbk_o_mouseMoveEvent("QTouch3DInputHandler", funcName, gil, pyOverride, event, mousePos);
}

void QTouch3DInputHandlerWrapper::mouseReleaseEvent(::QMouseEvent * event, const ::QPoint & mousePos)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::Q3DInputHandler::mouseReleaseEvent(event, mousePos);
    }
    QAbstract3DInputHandlerWrapper::sbk_o_mouseMoveEvent("QTouch3DInputHandler", funcName, gil, pyOverride, event, mousePos);
}

void QTouch3DInputHandlerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_timerEvent("QTouch3DInputHandler", funcName, gil, pyOverride, event);
}

void QTouch3DInputHandlerWrapper::touchEvent(::QTouchEvent * event)
{
    static const char *funcName = "touchEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTouch3DInputHandler::touchEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_touchEvent("QTouch3DInputHandler", funcName, gil, pyOverride, event);
}

void QTouch3DInputHandlerWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::Q3DInputHandler::wheelEvent(event);
    }
    QAbstract3DGraphWrapper::sbk_o_wheelEvent("QTouch3DInputHandler", funcName, gil, pyOverride, event);
}

const QMetaObject *QTouch3DInputHandlerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QTouch3DInputHandler::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QTouch3DInputHandlerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QTouch3DInputHandler::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QTouch3DInputHandlerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QTouch3DInputHandlerWrapper *>(this));
    return QTouch3DInputHandler::qt_metacast(_clname);
}

QTouch3DInputHandlerWrapper::~QTouch3DInputHandlerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTouch3DInputHandler_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTouch3DInputHandler >()))
        return -1;

    QTouch3DInputHandlerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QTouch3DInputHandler", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTouch3DInputHandler::QTouch3DInputHandler(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QTouch3DInputHandler(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QTouch3DInputHandler(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QTouch3DInputHandler_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QTouch3DInputHandler_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QTouch3DInputHandler_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QTouch3DInputHandler(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QTouch3DInputHandlerWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QTouch3DInputHandlerWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QTouch3DInputHandler >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QTouch3DInputHandler_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QTouch3DInputHandler_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QTouch3DInputHandlerFunc_touchEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTouch3DInputHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QTouch3DInputHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DInputHandler::touchEvent(QTouchEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTouchEvent_IDX]), (pyArg)))) {
        overloadId = 0; // touchEvent(QTouchEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "touchEvent", errInfo, SbkPySide6_QtDataVisualizationTypeStructs[SBK_QTouch3DInputHandler_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTouchEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // touchEvent(QTouchEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QTouch3DInputHandler::touchEvent(cppArg0)
                : cppSelf->touchEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QTouch3DInputHandler_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTouch3DInputHandler_methods[] = {
    {"touchEvent", reinterpret_cast<PyCFunction>(Sbk_QTouch3DInputHandlerFunc_touchEvent), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QTouch3DInputHandler_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QTouch3DInputHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QTouch3DInputHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QTouch3DInputHandlerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QTouch3DInputHandler_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTouch3DInputHandler_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTouch3DInputHandler_Type = nullptr;
static PyTypeObject *Sbk_QTouch3DInputHandler_TypeF(void)
{
    return _Sbk_QTouch3DInputHandler_Type;
}

static PyType_Slot Sbk_QTouch3DInputHandler_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QTouch3DInputHandler_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTouch3DInputHandler_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTouch3DInputHandler_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTouch3DInputHandler_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTouch3DInputHandler_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTouch3DInputHandler_spec = {
    "2:PySide6.QtDataVisualization.QTouch3DInputHandler",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTouch3DInputHandler_slots
};

} //extern "C"

static void *Sbk_QTouch3DInputHandler_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QTouch3DInputHandler *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTouch3DInputHandler_PythonToCpp_QTouch3DInputHandler_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTouch3DInputHandler_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTouch3DInputHandler_PythonToCpp_QTouch3DInputHandler_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTouch3DInputHandler_TypeF()))
        return QTouch3DInputHandler_PythonToCpp_QTouch3DInputHandler_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTouch3DInputHandler_PTR_CppToPython_QTouch3DInputHandler(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QTouch3DInputHandler *>(const_cast<void *>(cppIn)), Sbk_QTouch3DInputHandler_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTouch3DInputHandler_SignatureStrings[] = {
    "PySide6.QtDataVisualization.QTouch3DInputHandler(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtDataVisualization.QTouch3DInputHandler.touchEvent(self,event:PySide6.QtGui.QTouchEvent)",
    nullptr}; // Sentinel
#else
static constexpr size_t QTouch3DInputHandler_SignatureByteSize = 121;
static constexpr uint8_t QTouch3DInputHandler_SignatureBytes[121] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x49, 0x2c, 0x49,
    0x0c, 0xcb, 0x2c, 0x2e, 0x4d, 0xcc, 0xc9, 0xac, 0x4a, 0x2c, 0xc9, 0xcc, 0xcf, 0xd3, 0x0b, 0x0c,
    0xc9, 0x2f, 0x4d, 0xce, 0x30, 0x76, 0xf1, 0xcc, 0x2b, 0x28, 0x2d, 0xf1, 0x48, 0xcc, 0x4b, 0xc9,
    0x49, 0x2d, 0xd2, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x29, 0x48, 0x2c, 0x4a, 0xcd, 0x2b, 0xb1, 0x0a,
    0x80, 0x6b, 0x76, 0xce, 0x2f, 0x4a, 0xd5, 0x0b, 0xf4, 0x4f, 0xca, 0x4a, 0x4d, 0x2e, 0xb1, 0xcd,
    0x2b, 0xcd, 0xc9, 0x29, 0x28, 0x29, 0xd2, 0xe4, 0x0a, 0x20, 0xd1, 0x70, 0xbd, 0x12, 0x90, 0x98,
    0x6b, 0x19, 0xd0, 0x6c, 0x88, 0x3d, 0xa9, 0x65, 0xa8, 0xd6, 0xb8, 0x97, 0x66, 0x42, 0x35, 0x82,
    0x15, 0x69, 0x72, 0x01, 0x00, 0x96, 0x70, 0x46, 0x6e
};
#endif

PyTypeObject *init_QTouch3DInputHandler(PyObject *module)
{
    if (SbkPySide6_QtDataVisualizationTypeStructs[SBK_QTouch3DInputHandler_IDX].type != nullptr)
        return SbkPySide6_QtDataVisualizationTypeStructs[SBK_QTouch3DInputHandler_IDX].type;

    Shiboken::AutoDecRef Sbk_QTouch3DInputHandler_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_Q3DInputHandler_IDX]))));

    _Sbk_QTouch3DInputHandler_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTouch3DInputHandler",
        "QTouch3DInputHandler*",
        &Sbk_QTouch3DInputHandler_spec,
        &Shiboken::callCppDestructor< QTouch3DInputHandler >,
        Sbk_QTouch3DInputHandler_Type_bases.object(),
        0);
    auto *pyType = Sbk_QTouch3DInputHandler_TypeF(); // references _Sbk_QTouch3DInputHandler_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTouch3DInputHandler_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTouch3DInputHandler_SignatureBytes, QTouch3DInputHandler_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTouch3DInputHandler_PropertyStrings);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_QTouch3DInputHandler_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTouch3DInputHandler_PythonToCpp_QTouch3DInputHandler_PTR,
        is_QTouch3DInputHandler_PythonToCpp_QTouch3DInputHandler_PTR_Convertible,
        QTouch3DInputHandler_PTR_CppToPython_QTouch3DInputHandler);

    Shiboken::Conversions::registerConverterName(converter, "QTouch3DInputHandler");
    Shiboken::Conversions::registerConverterName(converter, "QTouch3DInputHandler*");
    Shiboken::Conversions::registerConverterName(converter, "QTouch3DInputHandler&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTouch3DInputHandler).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QTouch3DInputHandlerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QTouch3DInputHandler_TypeF(), &Sbk_QTouch3DInputHandler_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QTouch3DInputHandler::staticMetaObject, sizeof(QTouch3DInputHandlerWrapper));

    return pyType;
}
