// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdesigner_python.h"

// main header
#include "qdesigneractioneditorinterface_wrapper.h"

// Wrappers providing overrides
#include "qdesignerobjectinspectorinterface_wrapper.h"
#include "qdesignerpropertyeditorinterface_wrapper.h"
#include "qdesignerpropertysheetextension_wrapper.h"
#include "qdesignerformwindowcursorinterface_wrapper.h"
#include "qdesignerwidgetboxinterface_wrapper.h"
#include "qabstractformbuilder_wrapper.h"

// Argument includes
#include <QtDesigner/abstractformeditor.h>
#include <QtDesigner/abstractformwindow.h>
#include <QtGui/qaction.h>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDesignerActionEditorInterfaceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDesignerActionEditorInterfaceWrapper::QDesignerActionEditorInterfaceWrapper(::QWidget * parent, ::QFlags<Qt::WindowType> flags) : QDesignerActionEditorInterface(parent, flags)
{
}

void QDesignerActionEditorInterfaceWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_actionEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::changeEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_changeEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_childEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_closeEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_connectNotify("QDesignerActionEditorInterface", funcName, gil, pyOverride, signal);
}

void QDesignerActionEditorInterfaceWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::contextMenuEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_contextMenuEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

::QDesignerFormEditorInterface * QDesignerActionEditorInterfaceWrapper::core() const
{
    static const char *funcName = "core";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDesignerActionEditorInterface::core();
    }
    return QDesignerPropertyEditorInterfaceWrapper::sbk_o_core("QDesignerActionEditorInterface", funcName, gil, pyOverride);
}

void QDesignerActionEditorInterfaceWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_customEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

int QDesignerActionEditorInterfaceWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QDesignerPropertySheetExtensionWrapper::sbk_o_count("QDesignerActionEditorInterface", funcName, gil, pyOverride);
}

void QDesignerActionEditorInterfaceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_connectNotify("QDesignerActionEditorInterface", funcName, gil, pyOverride, signal);
}

void QDesignerActionEditorInterfaceWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_dragEnterEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_dragLeaveEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_dragMoveEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_dropEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_enterEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerActionEditorInterfaceWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::event(event);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_event("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerActionEditorInterfaceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_eventFilter("QDesignerActionEditorInterface", funcName, gil, pyOverride, watched, event);
}

void QDesignerActionEditorInterfaceWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusInEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_focusInEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerActionEditorInterfaceWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_focusNextPrevChild("QDesignerActionEditorInterface", funcName, gil, pyOverride, next);
}

void QDesignerActionEditorInterfaceWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusOutEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_focusOutEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerActionEditorInterfaceWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QDesignerFormWindowCursorInterfaceWrapper::sbk_o_hasSelection("QDesignerActionEditorInterface", funcName, gil, pyOverride);
}

int QDesignerActionEditorInterfaceWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_heightForWidth("QDesignerActionEditorInterface", funcName, gil, pyOverride, arg__1);
}

void QDesignerActionEditorInterfaceWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_hideEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_initPainter("QDesignerActionEditorInterface", funcName, gil, pyOverride, painter);
}

void QDesignerActionEditorInterfaceWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_inputMethodEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

::QVariant QDesignerActionEditorInterfaceWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodQuery(arg__1);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_inputMethodQuery("QDesignerActionEditorInterface", funcName, gil, pyOverride, arg__1);
}

void QDesignerActionEditorInterfaceWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyPressEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_keyPressEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_keyReleaseEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_leaveEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::manageAction(::QAction * action)
{
    static const char *funcName = "manageAction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerActionEditorInterface.manageAction");
        return;
    }
    QAbstractFormBuilderWrapper::sbk_o_addMenuAction("QDesignerActionEditorInterface", funcName, gil, pyOverride, action);
}

int QDesignerActionEditorInterfaceWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_metric("QDesignerActionEditorInterface", funcName, gil, pyOverride, arg__1);
}

::QSize QDesignerActionEditorInterfaceWrapper::minimumSizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::minimumSizeHint();
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_minimumSizeHint("QDesignerActionEditorInterface", funcName, gil, pyOverride);
}

void QDesignerActionEditorInterfaceWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_mouseDoubleClickEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_mouseMoveEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mousePressEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_mousePressEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_mouseReleaseEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_moveEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerActionEditorInterfaceWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_nativeEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QDesignerActionEditorInterfaceWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_paintEngine("QDesignerActionEditorInterface", funcName, gil, pyOverride);
}

void QDesignerActionEditorInterfaceWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_paintEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

::QPaintDevice * QDesignerActionEditorInterfaceWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_redirected("QDesignerActionEditorInterface", funcName, gil, pyOverride, offset);
}

void QDesignerActionEditorInterfaceWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::resizeEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_resizeEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::setFormWindow(::QDesignerFormWindowInterface * formWindow)
{
    static const char *funcName = "setFormWindow";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerActionEditorInterface.setFormWindow");
        return;
    }
    QDesignerObjectInspectorInterfaceWrapper::sbk_o_setFormWindow("QDesignerActionEditorInterface", funcName, gil, pyOverride, formWindow);
}

void QDesignerActionEditorInterfaceWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_setVisible("QDesignerActionEditorInterface", funcName, gil, pyOverride, visible);
}

::QPainter * QDesignerActionEditorInterfaceWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_sharedPainter("QDesignerActionEditorInterface", funcName, gil, pyOverride);
}

void QDesignerActionEditorInterfaceWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_showEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

::QSize QDesignerActionEditorInterfaceWrapper::sizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sizeHint();
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_minimumSizeHint("QDesignerActionEditorInterface", funcName, gil, pyOverride);
}

void QDesignerActionEditorInterfaceWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_tabletEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_timerEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

void QDesignerActionEditorInterfaceWrapper::unmanageAction(::QAction * action)
{
    static const char *funcName = "unmanageAction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerActionEditorInterface.unmanageAction");
        return;
    }
    QAbstractFormBuilderWrapper::sbk_o_addMenuAction("QDesignerActionEditorInterface", funcName, gil, pyOverride, action);
}

void QDesignerActionEditorInterfaceWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::wheelEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_wheelEvent("QDesignerActionEditorInterface", funcName, gil, pyOverride, event);
}

const QMetaObject *QDesignerActionEditorInterfaceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QDesignerActionEditorInterface::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QDesignerActionEditorInterfaceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QDesignerActionEditorInterface::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QDesignerActionEditorInterfaceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QDesignerActionEditorInterfaceWrapper *>(this));
    return QDesignerActionEditorInterface::qt_metacast(_clname);
}

QDesignerActionEditorInterfaceWrapper::~QDesignerActionEditorInterfaceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDesignerActionEditorInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QDesignerActionEditorInterface");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDesignerActionEditorInterface >()))
        return -1;

    QDesignerActionEditorInterfaceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QDesignerActionEditorInterface", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDesignerActionEditorInterface::QDesignerActionEditorInterface(QWidget*,QFlags<Qt::WindowType>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QDesignerActionEditorInterface(QWidget*,QFlags<Qt::WindowType>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // QDesignerActionEditorInterface(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"flags", 1}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::WindowType> cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QDesignerActionEditorInterface(QWidget*,QFlags<Qt::WindowType>)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QDesignerActionEditorInterfaceWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QDesignerActionEditorInterfaceWrapper(cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QDesignerActionEditorInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QDesignerActionEditorInterfaceFunc_core(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerActionEditorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // core()const
        QDesignerFormEditorInterface * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QDesignerActionEditorInterface *>(cppSelf)->::QDesignerActionEditorInterface::core()
            : const_cast<const ::QDesignerActionEditorInterface *>(cppSelf)->core();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormEditorInterface_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerActionEditorInterfaceFunc_manageAction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerActionEditorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerActionEditorInterface::manageAction(QAction*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), (pyArg)))) {
        overloadId = 0; // manageAction(QAction*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "manageAction", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAction *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // manageAction(QAction*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerActionEditorInterface.manageAction");
                return {};
            }
            cppSelf->manageAction(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDesignerActionEditorInterfaceFunc_setFormWindow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerActionEditorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerActionEditorInterface::setFormWindow(QDesignerFormWindowInterface*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), (pyArg)))) {
        overloadId = 0; // setFormWindow(QDesignerFormWindowInterface*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFormWindow", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDesignerFormWindowInterface *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFormWindow(QDesignerFormWindowInterface*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerActionEditorInterface.setFormWindow");
                return {};
            }
            cppSelf->setFormWindow(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDesignerActionEditorInterfaceFunc_unmanageAction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerActionEditorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerActionEditorInterface::unmanageAction(QAction*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), (pyArg)))) {
        overloadId = 0; // unmanageAction(QAction*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "unmanageAction", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAction *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unmanageAction(QAction*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerActionEditorInterface.unmanageAction");
                return {};
            }
            cppSelf->unmanageAction(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QDesignerActionEditorInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDesignerActionEditorInterface_methods[] = {
    {"core", reinterpret_cast<PyCFunction>(Sbk_QDesignerActionEditorInterfaceFunc_core), METH_NOARGS, nullptr},
    {"manageAction", reinterpret_cast<PyCFunction>(Sbk_QDesignerActionEditorInterfaceFunc_manageAction), METH_O, nullptr},
    {"setFormWindow", reinterpret_cast<PyCFunction>(Sbk_QDesignerActionEditorInterfaceFunc_setFormWindow), METH_O, nullptr},
    {"unmanageAction", reinterpret_cast<PyCFunction>(Sbk_QDesignerActionEditorInterfaceFunc_unmanageAction), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDesignerActionEditorInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDesignerActionEditorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDesignerActionEditorInterfaceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDesignerActionEditorInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDesignerActionEditorInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QDesignerActionEditorInterfaceSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QDesignerActionEditorInterface *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDesignerActionEditorInterface_Type = nullptr;
static PyTypeObject *Sbk_QDesignerActionEditorInterface_TypeF(void)
{
    return _Sbk_QDesignerActionEditorInterface_Type;
}

static PyType_Slot Sbk_QDesignerActionEditorInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDesignerActionEditorInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDesignerActionEditorInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDesignerActionEditorInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDesignerActionEditorInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDesignerActionEditorInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDesignerActionEditorInterface_spec = {
    "2:PySide6.QtDesigner.QDesignerActionEditorInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDesignerActionEditorInterface_slots
};

} //extern "C"

static void *Sbk_QDesignerActionEditorInterface_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QDesignerActionEditorInterface *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QDesignerActionEditorInterface *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QDesignerActionEditorInterface *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDesignerActionEditorInterface_PythonToCpp_QDesignerActionEditorInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDesignerActionEditorInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDesignerActionEditorInterface_PythonToCpp_QDesignerActionEditorInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDesignerActionEditorInterface_TypeF()))
        return QDesignerActionEditorInterface_PythonToCpp_QDesignerActionEditorInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDesignerActionEditorInterface_PTR_CppToPython_QDesignerActionEditorInterface(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QDesignerActionEditorInterface *>(const_cast<void *>(cppIn)), Sbk_QDesignerActionEditorInterface_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDesignerActionEditorInterface_SignatureStrings[] = {
    "PySide6.QtDesigner.QDesignerActionEditorInterface(self,parent:PySide6.QtWidgets.QWidget,flags:PySide6.QtCore.Qt.WindowType={})",
    "PySide6.QtDesigner.QDesignerActionEditorInterface.core(self)->PySide6.QtDesigner.QDesignerFormEditorInterface",
    "PySide6.QtDesigner.QDesignerActionEditorInterface.manageAction(self,action:PySide6.QtGui.QAction)",
    "PySide6.QtDesigner.QDesignerActionEditorInterface.setFormWindow(self,formWindow:PySide6.QtDesigner.QDesignerFormWindowInterface)",
    "PySide6.QtDesigner.QDesignerActionEditorInterface.unmanageAction(self,action:PySide6.QtGui.QAction)",
    nullptr}; // Sentinel
#else
static constexpr size_t QDesignerActionEditorInterface_SignatureByteSize = 179;
static constexpr uint8_t QDesignerActionEditorInterface_SignatureBytes[179] = {
    0x78, 0xda, 0x9d, 0x50, 0x4d, 0x0b, 0xc2, 0x30, 0x0c, 0xbd, 0xfb, 0x4b, 0x1c, 0xcc, 0x1e, 0x3d,
    0x0c, 0x14, 0xc4, 0x2f, 0xbc, 0xb5, 0x28, 0xec, 0x5c, 0xd6, 0xb4, 0x04, 0xb6, 0x76, 0xb4, 0x1d,
    0x32, 0xc4, 0xff, 0xee, 0x5c, 0x70, 0x0c, 0x0f, 0xca, 0x76, 0xca, 0x0b, 0xc9, 0xcb, 0x7b, 0x2f,
    0xbc, 0xbd, 0xa2, 0x82, 0x35, 0x13, 0xf1, 0x00, 0x01, 0x8d, 0x05, 0xcf, 0xc4, 0x07, 0xed, 0x8a,
    0x88, 0xce, 0x1e, 0x15, 0x46, 0xe7, 0x2f, 0x36, 0x82, 0xd7, 0xb2, 0x80, 0x65, 0x80, 0x52, 0xa7,
    0xb5, 0xf4, 0x60, 0x63, 0xc6, 0x07, 0x76, 0x8e, 0xca, 0x40, 0x0c, 0x4c, 0x10, 0x48, 0x75, 0x29,
    0x4d, 0x18, 0xcd, 0xf7, 0xce, 0x43, 0x57, 0x58, 0x8e, 0x56, 0xb9, 0xfb, 0xad, 0xad, 0x61, 0xf3,
    0x78, 0x26, 0x0b, 0x3e, 0x55, 0x9e, 0x15, 0xdd, 0xa1, 0xde, 0x43, 0xb2, 0xda, 0xfe, 0x62, 0x9f,
    0x9c, 0xaf, 0xbe, 0xb8, 0x33, 0xd4, 0x2a, 0x69, 0xa5, 0x01, 0x9a, 0x51, 0x72, 0xd9, 0xe3, 0x51,
    0xb2, 0x73, 0x83, 0x4c, 0xd0, 0xc6, 0x9c, 0x3c, 0x01, 0xe2, 0xdb, 0x2a, 0xfd, 0x85, 0x24, 0xf4,
    0xd0, 0x67, 0xff, 0x12, 0xd2, 0xda, 0x70, 0x6d, 0x8e, 0x81, 0xc6, 0x4e, 0x0d, 0xf9, 0x02, 0xd4,
    0x68, 0xd1, 0x3e
};
#endif

PyTypeObject *init_QDesignerActionEditorInterface(PyObject *module)
{
    if (SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX].type != nullptr)
        return SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QDesignerActionEditorInterface_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))));

    _Sbk_QDesignerActionEditorInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDesignerActionEditorInterface",
        "QDesignerActionEditorInterface*",
        &Sbk_QDesignerActionEditorInterface_spec,
        &Shiboken::callCppDestructor< QDesignerActionEditorInterface >,
        Sbk_QDesignerActionEditorInterface_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QDesignerActionEditorInterface_TypeF(); // references _Sbk_QDesignerActionEditorInterface_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDesignerActionEditorInterface_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDesignerActionEditorInterface_SignatureBytes, QDesignerActionEditorInterface_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDesignerActionEditorInterface_PropertyStrings);
    SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerActionEditorInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDesignerActionEditorInterface_PythonToCpp_QDesignerActionEditorInterface_PTR,
        is_QDesignerActionEditorInterface_PythonToCpp_QDesignerActionEditorInterface_PTR_Convertible,
        QDesignerActionEditorInterface_PTR_CppToPython_QDesignerActionEditorInterface);

    Shiboken::Conversions::registerConverterName(converter, "QDesignerActionEditorInterface");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerActionEditorInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerActionEditorInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDesignerActionEditorInterface).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDesignerActionEditorInterfaceWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QDesignerActionEditorInterface_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QDesignerActionEditorInterface_TypeF(), &Sbk_QDesignerActionEditorInterfaceSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDesignerActionEditorInterface_TypeF(), &Sbk_QDesignerActionEditorInterface_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QDesignerActionEditorInterface::staticMetaObject, sizeof(QDesignerActionEditorInterfaceWrapper));

    return pyType;
}
