// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QDESIGNERCONTAINEREXTENSIONWRAPPER_H
#define SBK_QDESIGNERCONTAINEREXTENSIONWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtDesigner/container.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QDesignerContainerExtensionWrapper : public QDesignerContainerExtension
{
public:
    QDesignerContainerExtensionWrapper() noexcept;
    QDesignerContainerExtensionWrapper(const QDesignerContainerExtensionWrapper &) = delete;
    QDesignerContainerExtensionWrapper& operator=(const QDesignerContainerExtensionWrapper &) = delete;
    QDesignerContainerExtensionWrapper(QDesignerContainerExtensionWrapper &&) = delete;
    QDesignerContainerExtensionWrapper& operator=(QDesignerContainerExtensionWrapper &&) = delete;
    ~QDesignerContainerExtensionWrapper() override;

    void addWidget(::QWidget * widget) override;
    static void sbk_o_addWidget(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * widget);
    bool canAddWidget() const override;
    bool canRemove(int index) const override;
    int count() const override;
    int currentIndex() const override;
    void insertWidget(int index, ::QWidget * widget) override;
    static void sbk_o_insertWidget(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int index, ::QWidget * widget);
    void remove(int index) override;
    static void sbk_o_remove(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int index);
    void setCurrentIndex(int index) override;
    ::QWidget * widget(int index) const override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[9] = {false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QDESIGNERCONTAINEREXTENSIONWRAPPER_H
