// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdesigner_python.h"

// main header
#include "qdesignercustomwidgetinterface_wrapper.h"

// Wrappers providing overrides
#include "qdesignerformwindowcursorinterface_wrapper.h"
#include "qdesignercustomwidgetinterface_wrapper.h"

// Argument includes
#include <QString>
#include <QtDesigner/abstractformeditor.h>
#include <QtGui/qicon.h>
#include <QtWidgets/qwidget.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDesignerCustomWidgetInterfaceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDesignerCustomWidgetInterfaceWrapper::QDesignerCustomWidgetInterfaceWrapper()
{
}

::QString QDesignerCustomWidgetInterfaceWrapper::codeTemplate() const
{
    static const char *funcName = "codeTemplate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDesignerCustomWidgetInterface::codeTemplate();
    }
    return sbk_o_codeTemplate("QDesignerCustomWidgetInterface", funcName, gil, pyOverride);
}

::QString QDesignerCustomWidgetInterfaceWrapper::sbk_o_codeTemplate(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QString();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QString", Py_TYPE(pyResult)->tp_name);
        return ::QString();
    }
    ::QString cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QWidget * QDesignerCustomWidgetInterfaceWrapper::createWidget(::QWidget * parent)
{
    static const char *funcName = "createWidget";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.createWidget");
        return nullptr;
    }
    return sbk_o_createWidget("QDesignerCustomWidgetInterface", funcName, gil, pyOverride, parent);
}

::QWidget * QDesignerCustomWidgetInterfaceWrapper::sbk_o_createWidget(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * parent)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), parent)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), parent)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QWidget >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QWidget *cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (Shiboken::Object::checkType(pyResult))
        Shiboken::Object::releaseOwnership(pyResult);
    return cppResult;
}

::QString QDesignerCustomWidgetInterfaceWrapper::domXml() const
{
    static const char *funcName = "domXml";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDesignerCustomWidgetInterface::domXml();
    }
    return QDesignerCustomWidgetInterfaceWrapper::sbk_o_codeTemplate("QDesignerCustomWidgetInterface", funcName, gil, pyOverride);
}

::QString QDesignerCustomWidgetInterfaceWrapper::group() const
{
    static const char *funcName = "group";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.group");
        return ::QString();
    }
    return QDesignerCustomWidgetInterfaceWrapper::sbk_o_codeTemplate("QDesignerCustomWidgetInterface", funcName, gil, pyOverride);
}

::QIcon QDesignerCustomWidgetInterfaceWrapper::icon() const
{
    static const char *funcName = "icon";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.icon");
        return {};
    }
    return sbk_o_icon("QDesignerCustomWidgetInterface", funcName, gil, pyOverride);
}

::QIcon QDesignerCustomWidgetInterfaceWrapper::sbk_o_icon(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QIcon >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QIcon cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QString QDesignerCustomWidgetInterfaceWrapper::includeFile() const
{
    static const char *funcName = "includeFile";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.includeFile");
        return ::QString();
    }
    return QDesignerCustomWidgetInterfaceWrapper::sbk_o_codeTemplate("QDesignerCustomWidgetInterface", funcName, gil, pyOverride);
}

void QDesignerCustomWidgetInterfaceWrapper::initialize(::QDesignerFormEditorInterface * core)
{
    static const char *funcName = "initialize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDesignerCustomWidgetInterface::initialize(core);
    }
    sbk_o_initialize("QDesignerCustomWidgetInterface", funcName, gil, pyOverride, core);
}

void QDesignerCustomWidgetInterfaceWrapper::sbk_o_initialize(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QDesignerFormEditorInterface * core)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormEditorInterface_IDX]), core)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormEditorInterface_IDX]), core)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

bool QDesignerCustomWidgetInterfaceWrapper::isContainer() const
{
    static const char *funcName = "isContainer";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.isContainer");
        return false;
    }
    return QDesignerFormWindowCursorInterfaceWrapper::sbk_o_hasSelection("QDesignerCustomWidgetInterface", funcName, gil, pyOverride);
}

bool QDesignerCustomWidgetInterfaceWrapper::isInitialized() const
{
    static const char *funcName = "isInitialized";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDesignerCustomWidgetInterface::isInitialized();
    }
    return QDesignerFormWindowCursorInterfaceWrapper::sbk_o_hasSelection("QDesignerCustomWidgetInterface", funcName, gil, pyOverride);
}

::QString QDesignerCustomWidgetInterfaceWrapper::name() const
{
    static const char *funcName = "name";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.name");
        return ::QString();
    }
    return QDesignerCustomWidgetInterfaceWrapper::sbk_o_codeTemplate("QDesignerCustomWidgetInterface", funcName, gil, pyOverride);
}

::QString QDesignerCustomWidgetInterfaceWrapper::toolTip() const
{
    static const char *funcName = "toolTip";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.toolTip");
        return ::QString();
    }
    return QDesignerCustomWidgetInterfaceWrapper::sbk_o_codeTemplate("QDesignerCustomWidgetInterface", funcName, gil, pyOverride);
}

::QString QDesignerCustomWidgetInterfaceWrapper::whatsThis() const
{
    static const char *funcName = "whatsThis";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.whatsThis");
        return ::QString();
    }
    return QDesignerCustomWidgetInterfaceWrapper::sbk_o_codeTemplate("QDesignerCustomWidgetInterface", funcName, gil, pyOverride);
}

QDesignerCustomWidgetInterfaceWrapper::~QDesignerCustomWidgetInterfaceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDesignerCustomWidgetInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QDesignerCustomWidgetInterface");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDesignerCustomWidgetInterface >()))
        return -1;

    QDesignerCustomWidgetInterfaceWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QDesignerCustomWidgetInterface()
        cptr = new QDesignerCustomWidgetInterfaceWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QDesignerCustomWidgetInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDesignerCustomWidgetInterfaceFunc_codeTemplate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerCustomWidgetInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // codeTemplate()const
        QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QDesignerCustomWidgetInterface *>(cppSelf)->::QDesignerCustomWidgetInterface::codeTemplate()
            : const_cast<const ::QDesignerCustomWidgetInterface *>(cppSelf)->codeTemplate();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerCustomWidgetInterfaceFunc_createWidget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerCustomWidgetInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerCustomWidgetInterface::createWidget(QWidget*)->QWidget*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // createWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createWidget", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createWidget(QWidget*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.createWidget");
                return {};
            }
            QWidget * cppResult = cppSelf->createWidget(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerCustomWidgetInterfaceFunc_domXml(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerCustomWidgetInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // domXml()const
        QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QDesignerCustomWidgetInterface *>(cppSelf)->::QDesignerCustomWidgetInterface::domXml()
            : const_cast<const ::QDesignerCustomWidgetInterface *>(cppSelf)->domXml();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerCustomWidgetInterfaceFunc_group(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerCustomWidgetInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // group()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.group");
            return {};
        }
        QString cppResult = const_cast<const ::QDesignerCustomWidgetInterface *>(cppSelf)->group();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerCustomWidgetInterfaceFunc_icon(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerCustomWidgetInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // icon()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.icon");
            return {};
        }
        QIcon cppResult = const_cast<const ::QDesignerCustomWidgetInterface *>(cppSelf)->icon();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerCustomWidgetInterfaceFunc_includeFile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerCustomWidgetInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // includeFile()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.includeFile");
            return {};
        }
        QString cppResult = const_cast<const ::QDesignerCustomWidgetInterface *>(cppSelf)->includeFile();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerCustomWidgetInterfaceFunc_initialize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerCustomWidgetInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerCustomWidgetInterface::initialize(QDesignerFormEditorInterface*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormEditorInterface_IDX]), (pyArg)))) {
        overloadId = 0; // initialize(QDesignerFormEditorInterface*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "initialize", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDesignerFormEditorInterface *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // initialize(QDesignerFormEditorInterface*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDesignerCustomWidgetInterface::initialize(cppArg0)
                : cppSelf->initialize(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDesignerCustomWidgetInterfaceFunc_isContainer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerCustomWidgetInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isContainer()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.isContainer");
            return {};
        }
        bool cppResult = const_cast<const ::QDesignerCustomWidgetInterface *>(cppSelf)->isContainer();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerCustomWidgetInterfaceFunc_isInitialized(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerCustomWidgetInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isInitialized()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QDesignerCustomWidgetInterface *>(cppSelf)->::QDesignerCustomWidgetInterface::isInitialized()
            : const_cast<const ::QDesignerCustomWidgetInterface *>(cppSelf)->isInitialized();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerCustomWidgetInterfaceFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerCustomWidgetInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.name");
            return {};
        }
        QString cppResult = const_cast<const ::QDesignerCustomWidgetInterface *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerCustomWidgetInterfaceFunc_toolTip(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerCustomWidgetInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toolTip()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.toolTip");
            return {};
        }
        QString cppResult = const_cast<const ::QDesignerCustomWidgetInterface *>(cppSelf)->toolTip();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerCustomWidgetInterfaceFunc_whatsThis(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerCustomWidgetInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // whatsThis()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QDesignerCustomWidgetInterface.whatsThis");
            return {};
        }
        QString cppResult = const_cast<const ::QDesignerCustomWidgetInterface *>(cppSelf)->whatsThis();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QDesignerCustomWidgetInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDesignerCustomWidgetInterface_methods[] = {
    {"codeTemplate", reinterpret_cast<PyCFunction>(Sbk_QDesignerCustomWidgetInterfaceFunc_codeTemplate), METH_NOARGS, nullptr},
    {"createWidget", reinterpret_cast<PyCFunction>(Sbk_QDesignerCustomWidgetInterfaceFunc_createWidget), METH_O, nullptr},
    {"domXml", reinterpret_cast<PyCFunction>(Sbk_QDesignerCustomWidgetInterfaceFunc_domXml), METH_NOARGS, nullptr},
    {"group", reinterpret_cast<PyCFunction>(Sbk_QDesignerCustomWidgetInterfaceFunc_group), METH_NOARGS, nullptr},
    {"icon", reinterpret_cast<PyCFunction>(Sbk_QDesignerCustomWidgetInterfaceFunc_icon), METH_NOARGS, nullptr},
    {"includeFile", reinterpret_cast<PyCFunction>(Sbk_QDesignerCustomWidgetInterfaceFunc_includeFile), METH_NOARGS, nullptr},
    {"initialize", reinterpret_cast<PyCFunction>(Sbk_QDesignerCustomWidgetInterfaceFunc_initialize), METH_O, nullptr},
    {"isContainer", reinterpret_cast<PyCFunction>(Sbk_QDesignerCustomWidgetInterfaceFunc_isContainer), METH_NOARGS, nullptr},
    {"isInitialized", reinterpret_cast<PyCFunction>(Sbk_QDesignerCustomWidgetInterfaceFunc_isInitialized), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QDesignerCustomWidgetInterfaceFunc_name), METH_NOARGS, nullptr},
    {"toolTip", reinterpret_cast<PyCFunction>(Sbk_QDesignerCustomWidgetInterfaceFunc_toolTip), METH_NOARGS, nullptr},
    {"whatsThis", reinterpret_cast<PyCFunction>(Sbk_QDesignerCustomWidgetInterfaceFunc_whatsThis), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDesignerCustomWidgetInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDesignerCustomWidgetInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDesignerCustomWidgetInterfaceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDesignerCustomWidgetInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDesignerCustomWidgetInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDesignerCustomWidgetInterface_Type = nullptr;
static PyTypeObject *Sbk_QDesignerCustomWidgetInterface_TypeF(void)
{
    return _Sbk_QDesignerCustomWidgetInterface_Type;
}

static PyType_Slot Sbk_QDesignerCustomWidgetInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDesignerCustomWidgetInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDesignerCustomWidgetInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDesignerCustomWidgetInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDesignerCustomWidgetInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDesignerCustomWidgetInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDesignerCustomWidgetInterface_spec = {
    "2:PySide6.QtDesigner.QDesignerCustomWidgetInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDesignerCustomWidgetInterface_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDesignerCustomWidgetInterface_PythonToCpp_QDesignerCustomWidgetInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDesignerCustomWidgetInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDesignerCustomWidgetInterface_PythonToCpp_QDesignerCustomWidgetInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDesignerCustomWidgetInterface_TypeF()))
        return QDesignerCustomWidgetInterface_PythonToCpp_QDesignerCustomWidgetInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDesignerCustomWidgetInterface_PTR_CppToPython_QDesignerCustomWidgetInterface(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QDesignerCustomWidgetInterface *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QDesignerCustomWidgetInterface_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDesignerCustomWidgetInterface_SignatureStrings[] = {
    "PySide6.QtDesigner.QDesignerCustomWidgetInterface(self)",
    "PySide6.QtDesigner.QDesignerCustomWidgetInterface.codeTemplate(self)->QString",
    "PySide6.QtDesigner.QDesignerCustomWidgetInterface.createWidget(self,parent:PySide6.QtWidgets.QWidget)->PySide6.QtWidgets.QWidget",
    "PySide6.QtDesigner.QDesignerCustomWidgetInterface.domXml(self)->QString",
    "PySide6.QtDesigner.QDesignerCustomWidgetInterface.group(self)->QString",
    "PySide6.QtDesigner.QDesignerCustomWidgetInterface.icon(self)->PySide6.QtGui.QIcon",
    "PySide6.QtDesigner.QDesignerCustomWidgetInterface.includeFile(self)->QString",
    "PySide6.QtDesigner.QDesignerCustomWidgetInterface.initialize(self,core:PySide6.QtDesigner.QDesignerFormEditorInterface)",
    "PySide6.QtDesigner.QDesignerCustomWidgetInterface.isContainer(self)->bool",
    "PySide6.QtDesigner.QDesignerCustomWidgetInterface.isInitialized(self)->bool",
    "PySide6.QtDesigner.QDesignerCustomWidgetInterface.name(self)->QString",
    "PySide6.QtDesigner.QDesignerCustomWidgetInterface.toolTip(self)->QString",
    "PySide6.QtDesigner.QDesignerCustomWidgetInterface.whatsThis(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QDesignerCustomWidgetInterface_SignatureByteSize = 228;
static constexpr uint8_t QDesignerCustomWidgetInterface_SignatureBytes[228] = {
    0x78, 0xda, 0xad, 0xd2, 0xc1, 0x4e, 0xc3, 0x30, 0x0c, 0x00, 0xd0, 0x3b, 0x5f, 0x02, 0xd2, 0xc8,
    0x91, 0xc3, 0x0e, 0x5c, 0x06, 0x43, 0xbd, 0x2d, 0x5a, 0xa5, 0x71, 0x0d, 0x89, 0xd7, 0x59, 0x4a,
    0xec, 0xca, 0x71, 0x85, 0xc6, 0xd7, 0x13, 0x51, 0xba, 0x49, 0x48, 0x20, 0x91, 0xf6, 0x66, 0xc5,
    0xf1, 0x4b, 0x9c, 0x78, 0x77, 0xde, 0x63, 0x80, 0x07, 0x63, 0xf5, 0x09, 0x32, 0x76, 0x04, 0x62,
    0xec, 0x14, 0x6d, 0x86, 0xac, 0x9c, 0x0e, 0x18, 0x3a, 0xd0, 0x86, 0x14, 0xe4, 0xe8, 0x3c, 0xdc,
    0x66, 0x88, 0xc7, 0xbb, 0x9b, 0xdd, 0x7f, 0xeb, 0x8c, 0xe7, 0x00, 0x2d, 0xa4, 0x3e, 0x3a, 0xfd,
    0x46, 0xee, 0x1f, 0xed, 0x5e, 0x05, 0xa9, 0xab, 0xd1, 0x04, 0x8a, 0x33, 0xae, 0x7e, 0x69, 0xab,
    0xde, 0x09, 0x90, 0xae, 0xaf, 0xd4, 0x98, 0xcc, 0xc6, 0x8e, 0x41, 0x39, 0xee, 0xd7, 0x5c, 0xc5,
    0x05, 0x02, 0xa7, 0xd7, 0x14, 0xe7, 0x37, 0xd2, 0x09, 0x0f, 0xfd, 0x7c, 0x06, 0x3d, 0xd3, 0xa4,
    0x5c, 0xab, 0x5f, 0x06, 0x34, 0xb6, 0x29, 0xa9, 0x1a, 0x91, 0x7c, 0x1c, 0x02, 0x6c, 0x31, 0x2e,
    0xf0, 0x5d, 0x48, 0xa8, 0xe8, 0x22, 0x7e, 0x8c, 0xd6, 0xca, 0xb3, 0xc0, 0xfa, 0x2f, 0x66, 0xcb,
    0x92, 0x9e, 0x03, 0x2a, 0xcb, 0x05, 0xa9, 0x19, 0x3a, 0xcc, 0x1b, 0x26, 0x75, 0x58, 0x36, 0x4c,
    0x4d, 0xbc, 0x31, 0xc7, 0x2a, 0xa9, 0xb9, 0xf4, 0x10, 0x66, 0x5a, 0xe4, 0xd2, 0x02, 0x6f, 0xaa,
    0xe5, 0xf0, 0x16, 0x17, 0x98, 0x9d, 0xf7, 0x93, 0xd3, 0xdc, 0x9e, 0x30, 0xff, 0xa4, 0x3e, 0x01,
    0xf6, 0x75, 0x86, 0x9b
};
#endif

PyTypeObject *init_QDesignerCustomWidgetInterface(PyObject *module)
{
    if (SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX].type != nullptr)
        return SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QDesignerCustomWidgetInterface_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDesignerCustomWidgetInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDesignerCustomWidgetInterface",
        "QDesignerCustomWidgetInterface*",
        &Sbk_QDesignerCustomWidgetInterface_spec,
        &Shiboken::callCppDestructor< QDesignerCustomWidgetInterface >,
        Sbk_QDesignerCustomWidgetInterface_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDesignerCustomWidgetInterface_TypeF(); // references _Sbk_QDesignerCustomWidgetInterface_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDesignerCustomWidgetInterface_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDesignerCustomWidgetInterface_SignatureBytes, QDesignerCustomWidgetInterface_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDesignerCustomWidgetInterface_PropertyStrings);
    SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerCustomWidgetInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDesignerCustomWidgetInterface_PythonToCpp_QDesignerCustomWidgetInterface_PTR,
        is_QDesignerCustomWidgetInterface_PythonToCpp_QDesignerCustomWidgetInterface_PTR_Convertible,
        QDesignerCustomWidgetInterface_PTR_CppToPython_QDesignerCustomWidgetInterface);

    Shiboken::Conversions::registerConverterName(converter, "QDesignerCustomWidgetInterface");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerCustomWidgetInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerCustomWidgetInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDesignerCustomWidgetInterface).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDesignerCustomWidgetInterfaceWrapper).name());

    qRegisterMetaType< ::QDesignerCustomWidgetInterface *>();

    return pyType;
}
