// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdesigner_python.h"

// main header
#include "qdesignerobjectinspectorinterface_wrapper.h"

// Wrappers providing overrides
#include "qdesignerpropertyeditorinterface_wrapper.h"
#include "qdesignerpropertysheetextension_wrapper.h"
#include "qdesignerformwindowcursorinterface_wrapper.h"
#include "qdesignerwidgetboxinterface_wrapper.h"

// Argument includes
#include <QtDesigner/abstractformeditor.h>
#include <QtDesigner/abstractformwindow.h>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDesignerObjectInspectorInterfaceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDesignerObjectInspectorInterfaceWrapper::QDesignerObjectInspectorInterfaceWrapper(::QWidget * parent, ::QFlags<Qt::WindowType> flags) : QDesignerObjectInspectorInterface(parent, flags)
{
}

void QDesignerObjectInspectorInterfaceWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_actionEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::changeEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_changeEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_childEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_closeEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_connectNotify("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, signal);
}

void QDesignerObjectInspectorInterfaceWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::contextMenuEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_contextMenuEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

::QDesignerFormEditorInterface * QDesignerObjectInspectorInterfaceWrapper::core() const
{
    static const char *funcName = "core";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDesignerObjectInspectorInterface::core();
    }
    return QDesignerPropertyEditorInterfaceWrapper::sbk_o_core("QDesignerObjectInspectorInterface", funcName, gil, pyOverride);
}

void QDesignerObjectInspectorInterfaceWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_customEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

int QDesignerObjectInspectorInterfaceWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QDesignerPropertySheetExtensionWrapper::sbk_o_count("QDesignerObjectInspectorInterface", funcName, gil, pyOverride);
}

void QDesignerObjectInspectorInterfaceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_connectNotify("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, signal);
}

void QDesignerObjectInspectorInterfaceWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_dragEnterEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_dragLeaveEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_dragMoveEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_dropEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_enterEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerObjectInspectorInterfaceWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::event(event);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_event("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerObjectInspectorInterfaceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_eventFilter("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, watched, event);
}

void QDesignerObjectInspectorInterfaceWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusInEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_focusInEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerObjectInspectorInterfaceWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_focusNextPrevChild("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, next);
}

void QDesignerObjectInspectorInterfaceWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusOutEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_focusOutEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerObjectInspectorInterfaceWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QDesignerFormWindowCursorInterfaceWrapper::sbk_o_hasSelection("QDesignerObjectInspectorInterface", funcName, gil, pyOverride);
}

int QDesignerObjectInspectorInterfaceWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_heightForWidth("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, arg__1);
}

void QDesignerObjectInspectorInterfaceWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_hideEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_initPainter("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, painter);
}

void QDesignerObjectInspectorInterfaceWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_inputMethodEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

::QVariant QDesignerObjectInspectorInterfaceWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodQuery(arg__1);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_inputMethodQuery("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, arg__1);
}

void QDesignerObjectInspectorInterfaceWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyPressEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_keyPressEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_keyReleaseEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_leaveEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

int QDesignerObjectInspectorInterfaceWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_metric("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, arg__1);
}

::QSize QDesignerObjectInspectorInterfaceWrapper::minimumSizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::minimumSizeHint();
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_minimumSizeHint("QDesignerObjectInspectorInterface", funcName, gil, pyOverride);
}

void QDesignerObjectInspectorInterfaceWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_mouseDoubleClickEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_mouseMoveEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mousePressEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_mousePressEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_mouseReleaseEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_moveEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

bool QDesignerObjectInspectorInterfaceWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_nativeEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QDesignerObjectInspectorInterfaceWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_paintEngine("QDesignerObjectInspectorInterface", funcName, gil, pyOverride);
}

void QDesignerObjectInspectorInterfaceWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_paintEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

::QPaintDevice * QDesignerObjectInspectorInterfaceWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_redirected("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, offset);
}

void QDesignerObjectInspectorInterfaceWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::resizeEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_resizeEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::setFormWindow(::QDesignerFormWindowInterface * formWindow)
{
    static const char *funcName = "setFormWindow";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QDesignerObjectInspectorInterface.setFormWindow");
        return;
    }
    sbk_o_setFormWindow("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, formWindow);
}

void QDesignerObjectInspectorInterfaceWrapper::sbk_o_setFormWindow(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QDesignerFormWindowInterface * formWindow)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), formWindow)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), formWindow)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QDesignerObjectInspectorInterfaceWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_setVisible("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, visible);
}

::QPainter * QDesignerObjectInspectorInterfaceWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_sharedPainter("QDesignerObjectInspectorInterface", funcName, gil, pyOverride);
}

void QDesignerObjectInspectorInterfaceWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_showEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

::QSize QDesignerObjectInspectorInterfaceWrapper::sizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sizeHint();
    }
    return QDesignerWidgetBoxInterfaceWrapper::sbk_o_minimumSizeHint("QDesignerObjectInspectorInterface", funcName, gil, pyOverride);
}

void QDesignerObjectInspectorInterfaceWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_tabletEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_timerEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

void QDesignerObjectInspectorInterfaceWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::wheelEvent(event);
    }
    QDesignerWidgetBoxInterfaceWrapper::sbk_o_wheelEvent("QDesignerObjectInspectorInterface", funcName, gil, pyOverride, event);
}

const QMetaObject *QDesignerObjectInspectorInterfaceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QDesignerObjectInspectorInterface::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QDesignerObjectInspectorInterfaceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QDesignerObjectInspectorInterface::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QDesignerObjectInspectorInterfaceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QDesignerObjectInspectorInterfaceWrapper *>(this));
    return QDesignerObjectInspectorInterface::qt_metacast(_clname);
}

QDesignerObjectInspectorInterfaceWrapper::~QDesignerObjectInspectorInterfaceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDesignerObjectInspectorInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerObjectInspectorInterface_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QDesignerObjectInspectorInterface");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDesignerObjectInspectorInterface >()))
        return -1;

    QDesignerObjectInspectorInterfaceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QDesignerObjectInspectorInterface", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDesignerObjectInspectorInterface::QDesignerObjectInspectorInterface(QWidget*,QFlags<Qt::WindowType>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QDesignerObjectInspectorInterface(QWidget*,QFlags<Qt::WindowType>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // QDesignerObjectInspectorInterface(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerObjectInspectorInterface_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerObjectInspectorInterface_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"flags", 1}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerObjectInspectorInterface_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::WindowType> cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QDesignerObjectInspectorInterface(QWidget*,QFlags<Qt::WindowType>)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QDesignerObjectInspectorInterfaceWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QDesignerObjectInspectorInterfaceWrapper(cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QDesignerObjectInspectorInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerObjectInspectorInterface_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerObjectInspectorInterface_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QDesignerObjectInspectorInterfaceFunc_core(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerObjectInspectorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerObjectInspectorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // core()const
        QDesignerFormEditorInterface * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QDesignerObjectInspectorInterface *>(cppSelf)->::QDesignerObjectInspectorInterface::core()
            : const_cast<const ::QDesignerObjectInspectorInterface *>(cppSelf)->core();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormEditorInterface_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDesignerObjectInspectorInterfaceFunc_setFormWindow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerObjectInspectorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerObjectInspectorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerObjectInspectorInterface::setFormWindow(QDesignerFormWindowInterface*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), (pyArg)))) {
        overloadId = 0; // setFormWindow(QDesignerFormWindowInterface*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFormWindow", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerObjectInspectorInterface_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDesignerFormWindowInterface *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFormWindow(QDesignerFormWindowInterface*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerObjectInspectorInterface.setFormWindow");
                return {};
            }
            cppSelf->setFormWindow(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QDesignerObjectInspectorInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDesignerObjectInspectorInterface_methods[] = {
    {"core", reinterpret_cast<PyCFunction>(Sbk_QDesignerObjectInspectorInterfaceFunc_core), METH_NOARGS, nullptr},
    {"setFormWindow", reinterpret_cast<PyCFunction>(Sbk_QDesignerObjectInspectorInterfaceFunc_setFormWindow), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDesignerObjectInspectorInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDesignerObjectInspectorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerObjectInspectorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDesignerObjectInspectorInterfaceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDesignerObjectInspectorInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDesignerObjectInspectorInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QDesignerObjectInspectorInterfaceSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QDesignerObjectInspectorInterface *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDesignerObjectInspectorInterface_Type = nullptr;
static PyTypeObject *Sbk_QDesignerObjectInspectorInterface_TypeF(void)
{
    return _Sbk_QDesignerObjectInspectorInterface_Type;
}

static PyType_Slot Sbk_QDesignerObjectInspectorInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDesignerObjectInspectorInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDesignerObjectInspectorInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDesignerObjectInspectorInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDesignerObjectInspectorInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDesignerObjectInspectorInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDesignerObjectInspectorInterface_spec = {
    "2:PySide6.QtDesigner.QDesignerObjectInspectorInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDesignerObjectInspectorInterface_slots
};

} //extern "C"

static void *Sbk_QDesignerObjectInspectorInterface_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QDesignerObjectInspectorInterface *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QDesignerObjectInspectorInterface *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QDesignerObjectInspectorInterface *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDesignerObjectInspectorInterface_PythonToCpp_QDesignerObjectInspectorInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDesignerObjectInspectorInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDesignerObjectInspectorInterface_PythonToCpp_QDesignerObjectInspectorInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDesignerObjectInspectorInterface_TypeF()))
        return QDesignerObjectInspectorInterface_PythonToCpp_QDesignerObjectInspectorInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDesignerObjectInspectorInterface_PTR_CppToPython_QDesignerObjectInspectorInterface(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QDesignerObjectInspectorInterface *>(const_cast<void *>(cppIn)), Sbk_QDesignerObjectInspectorInterface_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDesignerObjectInspectorInterface_SignatureStrings[] = {
    "PySide6.QtDesigner.QDesignerObjectInspectorInterface(self,parent:PySide6.QtWidgets.QWidget,flags:PySide6.QtCore.Qt.WindowType={})",
    "PySide6.QtDesigner.QDesignerObjectInspectorInterface.core(self)->PySide6.QtDesigner.QDesignerFormEditorInterface",
    "PySide6.QtDesigner.QDesignerObjectInspectorInterface.setFormWindow(self,formWindow:PySide6.QtDesigner.QDesignerFormWindowInterface)",
    nullptr}; // Sentinel
#else
static constexpr size_t QDesignerObjectInspectorInterface_SignatureByteSize = 158;
static constexpr uint8_t QDesignerObjectInspectorInterface_SignatureBytes[158] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x49, 0x2d, 0xce,
    0x4c, 0xcf, 0x4b, 0x2d, 0xd2, 0x0b, 0x84, 0xb1, 0xfc, 0x93, 0xb2, 0x52, 0x93, 0x4b, 0x3c, 0xf3,
    0x8a, 0x0b, 0x80, 0x54, 0x7e, 0x91, 0x67, 0x5e, 0x49, 0x6a, 0x51, 0x5a, 0x62, 0x72, 0xaa, 0x46,
    0x71, 0x6a, 0x4e, 0x9a, 0x4e, 0x41, 0x62, 0x51, 0x6a, 0x5e, 0x89, 0x55, 0x00, 0xdc, 0x80, 0xf0,
    0xcc, 0x94, 0xf4, 0xd4, 0x92, 0x62, 0xbd, 0x40, 0x08, 0x43, 0x27, 0x2d, 0x27, 0x31, 0xbd, 0x18,
    0x49, 0xde, 0x39, 0xbf, 0x28, 0x15, 0x48, 0xe9, 0x85, 0x67, 0xe6, 0xa5, 0xe4, 0x97, 0x87, 0x54,
    0x16, 0xa4, 0xda, 0x56, 0xd7, 0x6a, 0x72, 0x05, 0x90, 0xe1, 0x02, 0xbd, 0x64, 0xa0, 0x59, 0x60,
    0x67, 0x68, 0xea, 0xda, 0xe1, 0x33, 0xc0, 0x2d, 0xbf, 0x28, 0xd7, 0x35, 0x25, 0x13, 0x59, 0x2f,
    0x79, 0x16, 0x16, 0xa7, 0x96, 0x80, 0xcc, 0x82, 0xb8, 0x1d, 0x12, 0x00, 0x69, 0x70, 0xbe, 0x15,
    0x21, 0x27, 0x40, 0x94, 0xc1, 0x4d, 0xd3, 0xe4, 0x02, 0x00, 0x8f, 0x2f, 0x8c, 0x2c
};
#endif

PyTypeObject *init_QDesignerObjectInspectorInterface(PyObject *module)
{
    if (SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerObjectInspectorInterface_IDX].type != nullptr)
        return SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerObjectInspectorInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QDesignerObjectInspectorInterface_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))));

    _Sbk_QDesignerObjectInspectorInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDesignerObjectInspectorInterface",
        "QDesignerObjectInspectorInterface*",
        &Sbk_QDesignerObjectInspectorInterface_spec,
        &Shiboken::callCppDestructor< QDesignerObjectInspectorInterface >,
        Sbk_QDesignerObjectInspectorInterface_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QDesignerObjectInspectorInterface_TypeF(); // references _Sbk_QDesignerObjectInspectorInterface_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDesignerObjectInspectorInterface_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDesignerObjectInspectorInterface_SignatureBytes, QDesignerObjectInspectorInterface_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDesignerObjectInspectorInterface_PropertyStrings);
    SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerObjectInspectorInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDesignerObjectInspectorInterface_PythonToCpp_QDesignerObjectInspectorInterface_PTR,
        is_QDesignerObjectInspectorInterface_PythonToCpp_QDesignerObjectInspectorInterface_PTR_Convertible,
        QDesignerObjectInspectorInterface_PTR_CppToPython_QDesignerObjectInspectorInterface);

    Shiboken::Conversions::registerConverterName(converter, "QDesignerObjectInspectorInterface");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerObjectInspectorInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerObjectInspectorInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDesignerObjectInspectorInterface).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDesignerObjectInspectorInterfaceWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QDesignerObjectInspectorInterface_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QDesignerObjectInspectorInterface_TypeF(), &Sbk_QDesignerObjectInspectorInterfaceSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDesignerObjectInspectorInterface_TypeF(), &Sbk_QDesignerObjectInspectorInterface_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QDesignerObjectInspectorInterface::staticMetaObject, sizeof(QDesignerObjectInspectorInterfaceWrapper));

    return pyType;
}
