// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QDESIGNERPROPERTYSHEETEXTENSIONWRAPPER_H
#define SBK_QDESIGNERPROPERTYSHEETEXTENSIONWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtDesigner/propertysheet.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QDesignerPropertySheetExtensionWrapper : public QDesignerPropertySheetExtension
{
public:
    QDesignerPropertySheetExtensionWrapper() noexcept;
    QDesignerPropertySheetExtensionWrapper(const QDesignerPropertySheetExtensionWrapper &) = delete;
    QDesignerPropertySheetExtensionWrapper& operator=(const QDesignerPropertySheetExtensionWrapper &) = delete;
    QDesignerPropertySheetExtensionWrapper(QDesignerPropertySheetExtensionWrapper &&) = delete;
    QDesignerPropertySheetExtensionWrapper& operator=(QDesignerPropertySheetExtensionWrapper &&) = delete;
    ~QDesignerPropertySheetExtensionWrapper() override;

    int count() const override;
    static int sbk_o_count(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool hasReset(int index) const override;
    static bool sbk_o_hasReset(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int index);
    int indexOf(const ::QString & name) const override;
    static int sbk_o_indexOf(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & name);
    bool isAttribute(int index) const override;
    bool isChanged(int index) const override;
    bool isEnabled(int index) const override;
    bool isVisible(int index) const override;
    ::QVariant property(int index) const override;
    static ::QVariant sbk_o_property(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int index);
    ::QString propertyGroup(int index) const override;
    static ::QString sbk_o_propertyGroup(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int index);
    ::QString propertyName(int index) const override;
    bool reset(int index) override;
    void setAttribute(int index, bool b) override;
    static void sbk_o_setAttribute(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int index, bool b);
    void setChanged(int index, bool changed) override;
    void setProperty(int index, const ::QVariant & value) override;
    static void sbk_o_setProperty(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int index, const ::QVariant & value);
    void setPropertyGroup(int index, const ::QString & group) override;
    static void sbk_o_setPropertyGroup(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int index, const ::QString & group);
    void setVisible(int index, bool b) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[16] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QDESIGNERPROPERTYSHEETEXTENSIONWRAPPER_H
