// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdesigner_python.h"

// main header
#include "qformbuilder_wrapper.h"

// Wrappers providing overrides
#include "qabstractformbuilder_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGui/qaction.h>
#include <QtGui/qactiongroup.h>
#include <QtUiPlugin/customwidget.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qwidget.h>
#include <qiodevice.h>
#include <qobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QFormBuilderWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QFormBuilderWrapper::QFormBuilderWrapper()
{
}

void QFormBuilderWrapper::addMenuAction(::QAction * action)
{
    static const char *funcName = "addMenuAction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractFormBuilder::addMenuAction(action);
    }
    QAbstractFormBuilderWrapper::sbk_o_addMenuAction("QFormBuilder", funcName, gil, pyOverride, action);
}

bool QFormBuilderWrapper::checkProperty(::QObject * obj, const ::QString & prop) const
{
    static const char *funcName = "checkProperty";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractFormBuilder::checkProperty(obj, prop);
    }
    return QAbstractFormBuilderWrapper::sbk_o_checkProperty("QFormBuilder", funcName, gil, pyOverride, obj, prop);
}

::QAction * QFormBuilderWrapper::createAction(::QObject * parent, const ::QString & name)
{
    static const char *funcName = "createAction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractFormBuilder::createAction(parent, name);
    }
    return QAbstractFormBuilderWrapper::sbk_o_createAction("QFormBuilder", funcName, gil, pyOverride, parent, name);
}

::QActionGroup * QFormBuilderWrapper::createActionGroup(::QObject * parent, const ::QString & name)
{
    static const char *funcName = "createActionGroup";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractFormBuilder::createActionGroup(parent, name);
    }
    return QAbstractFormBuilderWrapper::sbk_o_createActionGroup("QFormBuilder", funcName, gil, pyOverride, parent, name);
}

::QLayout * QFormBuilderWrapper::createLayout(const ::QString & layoutName, ::QObject * parent, const ::QString & name)
{
    static const char *funcName = "createLayout";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFormBuilder::createLayout(layoutName, parent, name);
    }
    return QAbstractFormBuilderWrapper::sbk_o_createLayout("QFormBuilder", funcName, gil, pyOverride, layoutName, parent, name);
}

::QWidget * QFormBuilderWrapper::createWidget(const ::QString & widgetName, ::QWidget * parentWidget, const ::QString & name)
{
    static const char *funcName = "createWidget";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFormBuilder::createWidget(widgetName, parentWidget, name);
    }
    return QAbstractFormBuilderWrapper::sbk_o_createWidget("QFormBuilder", funcName, gil, pyOverride, widgetName, parentWidget, name);
}

::QWidget * QFormBuilderWrapper::load(::QIODevice * dev, ::QWidget * parentWidget)
{
    static const char *funcName = "load";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractFormBuilder::load(dev, parentWidget);
    }
    return QAbstractFormBuilderWrapper::sbk_o_load("QFormBuilder", funcName, gil, pyOverride, dev, parentWidget);
}

void QFormBuilderWrapper::save(::QIODevice * dev, ::QWidget * widget)
{
    static const char *funcName = "save";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractFormBuilder::save(dev, widget);
    }
    QAbstractFormBuilderWrapper::sbk_o_save("QFormBuilder", funcName, gil, pyOverride, dev, widget);
}

void QFormBuilderWrapper::updateCustomWidgets()
{
    static const char *funcName = "updateCustomWidgets";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFormBuilder::updateCustomWidgets();
    }
    sbk_o_updateCustomWidgets("QFormBuilder", funcName, gil, pyOverride);
}

void QFormBuilderWrapper::sbk_o_updateCustomWidgets(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

QFormBuilderWrapper::~QFormBuilderWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFormBuilder_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFormBuilder >()))
        return -1;

    QFormBuilderWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QFormBuilder()
        cptr = new QFormBuilderWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QFormBuilder >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QFormBuilderFunc_addPluginPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFormBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFormBuilder::addPluginPath(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // addPluginPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addPluginPath", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addPluginPath(QString)
            cppSelf->addPluginPath(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QFormBuilderFunc_clearPluginPaths(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFormBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearPluginPaths()
        cppSelf->clearPluginPaths();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QFormBuilderFunc_createLayout(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFormBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createLayout", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractFormBuilder::createLayout(QString,QObject*,QString)->QLayout*
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // createLayout(QString,QObject*,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createLayout", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QObject *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createLayout(QString,QObject*,QString)
            QLayout * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QFormBuilder::createLayout(cppArg0, cppArg1, cppArg2)
                : cppSelf->createLayout(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLayout_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFormBuilderFunc_createWidget(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFormBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createWidget", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractFormBuilder::createWidget(QString,QWidget*,QString)->QWidget*
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // createWidget(QString,QWidget*,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createWidget", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QWidget *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createWidget(QString,QWidget*,QString)
            QWidget * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QFormBuilder::createWidget(cppArg0, cppArg1, cppArg2)
                : cppSelf->createWidget(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFormBuilderFunc_customWidgets(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFormBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // customWidgets()const
        QList<QDesignerCustomWidgetInterface*> cppResult = const_cast<const ::QFormBuilder *>(cppSelf)->customWidgets();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtDesignerTypeConverters[SBK_QtDesigner_QList_QDesignerCustomWidgetInterfacePTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFormBuilderFunc_pluginPaths(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFormBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pluginPaths()const
        QStringList cppResult = const_cast<const ::QFormBuilder *>(cppSelf)->pluginPaths();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QFormBuilderFunc_setPluginPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFormBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFormBuilder::setPluginPath(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setPluginPath(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPluginPath", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPluginPath(QStringList)
            cppSelf->setPluginPath(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QFormBuilderFunc_updateCustomWidgets(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFormBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // updateCustomWidgets()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QFormBuilder::updateCustomWidgets()
            : cppSelf->updateCustomWidgets();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QFormBuilderFunc_widgetByName(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "widgetByName", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QFormBuilder::widgetByName(QWidget*,QString)->QWidget*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // widgetByName(QWidget*,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "widgetByName", errInfo, SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // widgetByName(QWidget*,QString)
            QWidget * cppResult = ::QFormBuilder::widgetByName(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QFormBuilder_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFormBuilder_methods[] = {
    {"addPluginPath", reinterpret_cast<PyCFunction>(Sbk_QFormBuilderFunc_addPluginPath), METH_O, nullptr},
    {"clearPluginPaths", reinterpret_cast<PyCFunction>(Sbk_QFormBuilderFunc_clearPluginPaths), METH_NOARGS, nullptr},
    {"createLayout", reinterpret_cast<PyCFunction>(Sbk_QFormBuilderFunc_createLayout), METH_VARARGS, nullptr},
    {"createWidget", reinterpret_cast<PyCFunction>(Sbk_QFormBuilderFunc_createWidget), METH_VARARGS, nullptr},
    {"customWidgets", reinterpret_cast<PyCFunction>(Sbk_QFormBuilderFunc_customWidgets), METH_NOARGS, nullptr},
    {"pluginPaths", reinterpret_cast<PyCFunction>(Sbk_QFormBuilderFunc_pluginPaths), METH_NOARGS, nullptr},
    {"setPluginPath", reinterpret_cast<PyCFunction>(Sbk_QFormBuilderFunc_setPluginPath), METH_O, nullptr},
    {"updateCustomWidgets", reinterpret_cast<PyCFunction>(Sbk_QFormBuilderFunc_updateCustomWidgets), METH_NOARGS, nullptr},
    {"widgetByName", reinterpret_cast<PyCFunction>(Sbk_QFormBuilderFunc_widgetByName), METH_VARARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QFormBuilder_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QFormBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QFormBuilderWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QFormBuilder_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFormBuilder_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFormBuilder_Type = nullptr;
static PyTypeObject *Sbk_QFormBuilder_TypeF(void)
{
    return _Sbk_QFormBuilder_Type;
}

static PyType_Slot Sbk_QFormBuilder_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QFormBuilder_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFormBuilder_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFormBuilder_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFormBuilder_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFormBuilder_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFormBuilder_spec = {
    "2:PySide6.QtDesigner.QFormBuilder",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFormBuilder_slots
};

} //extern "C"

static void *Sbk_QFormBuilder_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QAbstractFormBuilder >())
        return dynamic_cast< ::QFormBuilder *>(reinterpret_cast< ::QAbstractFormBuilder *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFormBuilder_PythonToCpp_QFormBuilder_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFormBuilder_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFormBuilder_PythonToCpp_QFormBuilder_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFormBuilder_TypeF()))
        return QFormBuilder_PythonToCpp_QFormBuilder_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFormBuilder_PTR_CppToPython_QFormBuilder(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QFormBuilder *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QFormBuilder_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFormBuilder_SignatureStrings[] = {
    "PySide6.QtDesigner.QFormBuilder(self)",
    "PySide6.QtDesigner.QFormBuilder.addPluginPath(self,pluginPath:QString)",
    "PySide6.QtDesigner.QFormBuilder.clearPluginPaths(self)",
    "PySide6.QtDesigner.QFormBuilder.createLayout(self,layoutName:QString,parent:PySide6.QtCore.QObject,name:QString)->PySide6.QtWidgets.QLayout",
    "PySide6.QtDesigner.QFormBuilder.createWidget(self,widgetName:QString,parentWidget:PySide6.QtWidgets.QWidget,name:QString)->PySide6.QtWidgets.QWidget",
    "PySide6.QtDesigner.QFormBuilder.customWidgets(self)->QList[PySide6.QtDesigner.QDesignerCustomWidgetInterface]",
    "PySide6.QtDesigner.QFormBuilder.pluginPaths(self)->QStringList",
    "PySide6.QtDesigner.QFormBuilder.setPluginPath(self,pluginPaths:QStringList)",
    "PySide6.QtDesigner.QFormBuilder.updateCustomWidgets(self)",
    "PySide6.QtDesigner.QFormBuilder.widgetByName(topLevel:PySide6.QtWidgets.QWidget,name:QString)->PySide6.QtWidgets.QWidget",
    nullptr}; // Sentinel
#else
static constexpr size_t QFormBuilder_SignatureByteSize = 254;
static constexpr uint8_t QFormBuilder_SignatureBytes[254] = {
    0x78, 0xda, 0xad, 0x52, 0x3d, 0x4f, 0xc3, 0x30, 0x10, 0xdd, 0xf9, 0x25, 0xad, 0x94, 0x7a, 0x64,
    0xc8, 0xd0, 0xa1, 0x41, 0x48, 0x48, 0x51, 0x1b, 0xab, 0x03, 0x03, 0x62, 0x70, 0xe3, 0x6b, 0x70,
    0xe5, 0xd8, 0x96, 0x7d, 0x06, 0xe5, 0xdf, 0xd3, 0xe6, 0x5a, 0x12, 0x41, 0xc0, 0x19, 0xd8, 0x9e,
    0xa5, 0x7b, 0x1f, 0xe7, 0x77, 0x55, 0xb7, 0x57, 0x12, 0xee, 0x19, 0xc7, 0x07, 0x08, 0xaa, 0x31,
    0xe0, 0x19, 0x7f, 0xb4, 0xbe, 0xdd, 0x44, 0xa5, 0x25, 0xf8, 0x45, 0x00, 0x7d, 0x5c, 0xde, 0x55,
    0x7f, 0x4f, 0x31, 0x21, 0x65, 0xa5, 0x63, 0xa3, 0x4c, 0x25, 0xf0, 0xad, 0xe7, 0x64, 0xee, 0xeb,
    0x9d, 0xf3, 0x3d, 0x7a, 0x65, 0x9a, 0xb4, 0x4c, 0xad, 0x41, 0xf8, 0x41, 0x28, 0xcc, 0x74, 0xaf,
    0x3d, 0x08, 0x84, 0x52, 0x74, 0x36, 0x22, 0x99, 0xeb, 0x1e, 0x6f, 0x45, 0x0b, 0x37, 0xf3, 0xcc,
    0x09, 0x0f, 0x06, 0xf3, 0x41, 0xab, 0xb0, 0x1e, 0x18, 0xdf, 0x1d, 0x4e, 0x50, 0x63, 0x66, 0x46,
    0xa3, 0xcb, 0xd5, 0x7a, 0x98, 0x7a, 0x56, 0xb2, 0x01, 0x0c, 0x8c, 0x93, 0xfc, 0xcc, 0x2c, 0xc4,
    0xa2, 0x2c, 0x1f, 0x3d, 0x9e, 0xc8, 0x42, 0x43, 0xf9, 0x84, 0x17, 0x81, 0x19, 0xa1, 0x08, 0xa4,
    0x43, 0xc5, 0x80, 0xb6, 0xbd, 0xb2, 0xe8, 0x53, 0x57, 0x6b, 0x5e, 0xaa, 0x80, 0x2f, 0x53, 0xd4,
    0x1b, 0x2a, 0x46, 0xb4, 0x27, 0x83, 0xe0, 0x8f, 0xa2, 0x86, 0xd7, 0xa4, 0x9b, 0xfb, 0x5e, 0xe0,
    0xd9, 0x8b, 0x96, 0xb8, 0x38, 0x26, 0xe9, 0x01, 0xf0, 0xf7, 0x5b, 0x0a, 0xf9, 0x48, 0x2a, 0x7d,
    0x19, 0xd1, 0xc9, 0x73, 0x1b, 0xc5, 0xcf, 0xf5, 0x93, 0x4c, 0x6a, 0x6d, 0xd3, 0x5d, 0x7a, 0x5b,
    0xa0, 0x75, 0x25, 0xbc, 0x83, 0xfe, 0x8f, 0xae, 0x3e, 0x01, 0x66, 0x68, 0x43, 0xb3
};
#endif

PyTypeObject *init_QFormBuilder(PyObject *module)
{
    if (SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX].type != nullptr)
        return SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX].type;

    Shiboken::AutoDecRef Sbk_QFormBuilder_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QAbstractFormBuilder_IDX]))));

    _Sbk_QFormBuilder_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFormBuilder",
        "QFormBuilder*",
        &Sbk_QFormBuilder_spec,
        &Shiboken::callCppDestructor< QFormBuilder >,
        Sbk_QFormBuilder_Type_bases.object(),
        0);
    auto *pyType = Sbk_QFormBuilder_TypeF(); // references _Sbk_QFormBuilder_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFormBuilder_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFormBuilder_SignatureBytes, QFormBuilder_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFormBuilder_PropertyStrings);
    SbkPySide6_QtDesignerTypeStructs[SBK_QFormBuilder_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFormBuilder_PythonToCpp_QFormBuilder_PTR,
        is_QFormBuilder_PythonToCpp_QFormBuilder_PTR_Convertible,
        QFormBuilder_PTR_CppToPython_QFormBuilder);

    Shiboken::Conversions::registerConverterName(converter, "QFormBuilder");
    Shiboken::Conversions::registerConverterName(converter, "QFormBuilder*");
    Shiboken::Conversions::registerConverterName(converter, "QFormBuilder&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFormBuilder).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QFormBuilderWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QFormBuilder_TypeF(), &Sbk_QFormBuilder_typeDiscovery);

    qRegisterMetaType< ::QFormBuilder *>();

    return pyType;
}
