// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qabstract3daxis_wrapper.h"

// Wrappers providing overrides
#include "qxymodelmapper_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <QtGraphs/qabstract3daxis.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstract3DAxisWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QAbstract3DAxisWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_childEvent("QAbstract3DAxis", funcName, gil, pyOverride, event);
}

void QAbstract3DAxisWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QAbstract3DAxis", funcName, gil, pyOverride, signal);
}

void QAbstract3DAxisWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_customEvent("QAbstract3DAxis", funcName, gil, pyOverride, event);
}

void QAbstract3DAxisWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QAbstract3DAxis", funcName, gil, pyOverride, signal);
}

bool QAbstract3DAxisWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QXYModelMapperWrapper::sbk_o_event("QAbstract3DAxis", funcName, gil, pyOverride, event);
}

bool QAbstract3DAxisWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QXYModelMapperWrapper::sbk_o_eventFilter("QAbstract3DAxis", funcName, gil, pyOverride, watched, event);
}

void QAbstract3DAxisWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_timerEvent("QAbstract3DAxis", funcName, gil, pyOverride, event);
}

const QMetaObject *QAbstract3DAxisWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QAbstract3DAxis::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstract3DAxisWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QAbstract3DAxis::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstract3DAxisWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstract3DAxisWrapper *>(this));
    return QAbstract3DAxis::qt_metacast(_clname);
}

QAbstract3DAxisWrapper::~QAbstract3DAxisWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_QAbstract3DAxis_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QAbstract3DAxis");
    return -1;
}

static PyObject *Sbk_QAbstract3DAxisFunc_isAutoAdjustRange(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAutoAdjustRange()const
        bool cppResult = const_cast<const ::QAbstract3DAxis *>(cppSelf)->isAutoAdjustRange();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstract3DAxisFunc_isScaleLabelsByCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isScaleLabelsByCount()const
        bool cppResult = const_cast<const ::QAbstract3DAxis *>(cppSelf)->isScaleLabelsByCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstract3DAxisFunc_isTitleFixed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isTitleFixed()const
        bool cppResult = const_cast<const ::QAbstract3DAxis *>(cppSelf)->isTitleFixed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstract3DAxisFunc_isTitleVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isTitleVisible()const
        bool cppResult = const_cast<const ::QAbstract3DAxis *>(cppSelf)->isTitleVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstract3DAxisFunc_labelAutoAngle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelAutoAngle()const
        float cppResult = const_cast<const ::QAbstract3DAxis *>(cppSelf)->labelAutoAngle();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstract3DAxisFunc_labelSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelSize()const
        qreal cppResult = const_cast<const ::QAbstract3DAxis *>(cppSelf)->labelSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstract3DAxisFunc_labels(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labels()const
        QStringList cppResult = const_cast<const ::QAbstract3DAxis *>(cppSelf)->labels();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstract3DAxisFunc_labelsVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelsVisible()const
        bool cppResult = const_cast<const ::QAbstract3DAxis *>(cppSelf)->labelsVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstract3DAxisFunc_max(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // max()const
        float cppResult = const_cast<const ::QAbstract3DAxis *>(cppSelf)->max();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstract3DAxisFunc_min(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // min()const
        float cppResult = const_cast<const ::QAbstract3DAxis *>(cppSelf)->min();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstract3DAxisFunc_orientation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // orientation()const
        QAbstract3DAxis::AxisOrientation cppResult = const_cast<const ::QAbstract3DAxis *>(cppSelf)->orientation();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_AxisOrientation_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstract3DAxisFunc_setAutoAdjustRange(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DAxis::setAutoAdjustRange(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoAdjustRange(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoAdjustRange", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoAdjustRange(bool)
            cppSelf->setAutoAdjustRange(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstract3DAxisFunc_setLabelAutoAngle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DAxis::setLabelAutoAngle(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setLabelAutoAngle(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelAutoAngle", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelAutoAngle(float)
            cppSelf->setLabelAutoAngle(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstract3DAxisFunc_setLabelSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DAxis::setLabelSize(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setLabelSize(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelSize", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelSize(qreal)
            cppSelf->setLabelSize(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstract3DAxisFunc_setLabels(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DAxis::setLabels(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setLabels(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabels", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabels(QStringList)
            cppSelf->setLabels(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstract3DAxisFunc_setLabelsVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DAxis::setLabelsVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setLabelsVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelsVisible", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelsVisible(bool)
            cppSelf->setLabelsVisible(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstract3DAxisFunc_setMax(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DAxis::setMax(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMax(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMax", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMax(float)
            cppSelf->setMax(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstract3DAxisFunc_setMin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DAxis::setMin(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMin(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMin", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMin(float)
            cppSelf->setMin(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstract3DAxisFunc_setRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstract3DAxis::setRange(float,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // setRange(float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRange", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRange(float,float)
            cppSelf->setRange(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstract3DAxisFunc_setScaleLabelsByCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DAxis::setScaleLabelsByCount(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setScaleLabelsByCount(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setScaleLabelsByCount", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setScaleLabelsByCount(bool)
            cppSelf->setScaleLabelsByCount(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstract3DAxisFunc_setTitle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DAxis::setTitle(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setTitle(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTitle", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTitle(QString)
            cppSelf->setTitle(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstract3DAxisFunc_setTitleFixed(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DAxis::setTitleFixed(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setTitleFixed(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTitleFixed", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTitleFixed(bool)
            cppSelf->setTitleFixed(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstract3DAxisFunc_setTitleOffset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DAxis::setTitleOffset(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setTitleOffset(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTitleOffset", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTitleOffset(float)
            cppSelf->setTitleOffset(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstract3DAxisFunc_setTitleVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DAxis::setTitleVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setTitleVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTitleVisible", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTitleVisible(bool)
            cppSelf->setTitleVisible(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstract3DAxisFunc_title(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // title()const
        QString cppResult = const_cast<const ::QAbstract3DAxis *>(cppSelf)->title();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstract3DAxisFunc_titleOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // titleOffset()const
        float cppResult = const_cast<const ::QAbstract3DAxis *>(cppSelf)->titleOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstract3DAxisFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QAbstract3DAxis::AxisType cppResult = const_cast<const ::QAbstract3DAxis *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_AxisType_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QAbstract3DAxis_PropertyStrings[] = {
    "autoAdjustRange:isAutoAdjustRange:",
    "labelAutoAngle::",
    "labelSize::",
    "labels::",
    "labelsVisible::",
    "max::",
    "min::",
    "orientation:",
    "scaleLabelsByCount:isScaleLabelsByCount:",
    "title::",
    "titleFixed:isTitleFixed:",
    "titleOffset::",
    "titleVisible:isTitleVisible:",
    "type:",
    nullptr // Sentinel
};

static const char *Sbk_QAbstract3DAxis_EnumFlagInfo[] = {
    "AxisOrientation:Enum",
    "AxisType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstract3DAxis_methods[] = {
    {"isAutoAdjustRange", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_isAutoAdjustRange), METH_NOARGS, nullptr},
    {"isScaleLabelsByCount", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_isScaleLabelsByCount), METH_NOARGS, nullptr},
    {"isTitleFixed", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_isTitleFixed), METH_NOARGS, nullptr},
    {"isTitleVisible", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_isTitleVisible), METH_NOARGS, nullptr},
    {"labelAutoAngle", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_labelAutoAngle), METH_NOARGS, nullptr},
    {"labelSize", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_labelSize), METH_NOARGS, nullptr},
    {"labels", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_labels), METH_NOARGS, nullptr},
    {"labelsVisible", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_labelsVisible), METH_NOARGS, nullptr},
    {"max", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_max), METH_NOARGS, nullptr},
    {"min", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_min), METH_NOARGS, nullptr},
    {"orientation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_orientation), METH_NOARGS, nullptr},
    {"setAutoAdjustRange", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_setAutoAdjustRange), METH_O, nullptr},
    {"setLabelAutoAngle", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_setLabelAutoAngle), METH_O, nullptr},
    {"setLabelSize", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_setLabelSize), METH_O, nullptr},
    {"setLabels", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_setLabels), METH_O, nullptr},
    {"setLabelsVisible", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_setLabelsVisible), METH_O, nullptr},
    {"setMax", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_setMax), METH_O, nullptr},
    {"setMin", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_setMin), METH_O, nullptr},
    {"setRange", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_setRange), METH_VARARGS, nullptr},
    {"setScaleLabelsByCount", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_setScaleLabelsByCount), METH_O, nullptr},
    {"setTitle", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_setTitle), METH_O, nullptr},
    {"setTitleFixed", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_setTitleFixed), METH_O, nullptr},
    {"setTitleOffset", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_setTitleOffset), METH_O, nullptr},
    {"setTitleVisible", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_setTitleVisible), METH_O, nullptr},
    {"title", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_title), METH_NOARGS, nullptr},
    {"titleOffset", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_titleOffset), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DAxisFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstract3DAxis_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstract3DAxis *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstract3DAxisWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstract3DAxis_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstract3DAxis_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstract3DAxis_Type = nullptr;
static PyTypeObject *Sbk_QAbstract3DAxis_TypeF(void)
{
    return _Sbk_QAbstract3DAxis_Type;
}

static PyType_Slot Sbk_QAbstract3DAxis_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstract3DAxis_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstract3DAxis_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstract3DAxis_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstract3DAxis_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstract3DAxis_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstract3DAxis_spec = {
    "2:PySide6.QtGraphs.QAbstract3DAxis",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstract3DAxis_slots
};

} //extern "C"

static void *Sbk_QAbstract3DAxis_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAbstract3DAxis *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAbstract3DAxis_AxisOrientation(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstract3DAxis::AxisOrientation>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstract3DAxis::AxisOrientation *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstract3DAxis_AxisOrientation_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_AxisOrientation_IDX])))
        return Enum_PythonToCpp_QAbstract3DAxis_AxisOrientation;
    return {};
}

static PyObject *QAbstract3DAxis_AxisOrientation_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstract3DAxis::AxisOrientation>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstract3DAxis::AxisOrientation *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_AxisOrientation_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstract3DAxis_AxisType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstract3DAxis::AxisType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstract3DAxis::AxisType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstract3DAxis_AxisType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_AxisType_IDX])))
        return Enum_PythonToCpp_QAbstract3DAxis_AxisType;
    return {};
}

static PyObject *QAbstract3DAxis_AxisType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstract3DAxis::AxisType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstract3DAxis::AxisType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_AxisType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstract3DAxis_PythonToCpp_QAbstract3DAxis_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstract3DAxis_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstract3DAxis_PythonToCpp_QAbstract3DAxis_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstract3DAxis_TypeF()))
        return QAbstract3DAxis_PythonToCpp_QAbstract3DAxis_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstract3DAxis_PTR_CppToPython_QAbstract3DAxis(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAbstract3DAxis *>(const_cast<void *>(cppIn)), Sbk_QAbstract3DAxis_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstract3DAxis_SignatureStrings[] = {
    "PySide6.QtGraphs.QAbstract3DAxis.isAutoAdjustRange(self)->bool",
    "PySide6.QtGraphs.QAbstract3DAxis.isScaleLabelsByCount(self)->bool",
    "PySide6.QtGraphs.QAbstract3DAxis.isTitleFixed(self)->bool",
    "PySide6.QtGraphs.QAbstract3DAxis.isTitleVisible(self)->bool",
    "PySide6.QtGraphs.QAbstract3DAxis.labelAutoAngle(self)->float",
    "PySide6.QtGraphs.QAbstract3DAxis.labelSize(self)->qreal",
    "PySide6.QtGraphs.QAbstract3DAxis.labels(self)->QStringList",
    "PySide6.QtGraphs.QAbstract3DAxis.labelsVisible(self)->bool",
    "PySide6.QtGraphs.QAbstract3DAxis.max(self)->float",
    "PySide6.QtGraphs.QAbstract3DAxis.min(self)->float",
    "PySide6.QtGraphs.QAbstract3DAxis.orientation(self)->PySide6.QtGraphs.QAbstract3DAxis.AxisOrientation",
    "PySide6.QtGraphs.QAbstract3DAxis.setAutoAdjustRange(self,autoAdjust:bool)",
    "PySide6.QtGraphs.QAbstract3DAxis.setLabelAutoAngle(self,degree:float)",
    "PySide6.QtGraphs.QAbstract3DAxis.setLabelSize(self,size:qreal)",
    "PySide6.QtGraphs.QAbstract3DAxis.setLabels(self,labels:QStringList)",
    "PySide6.QtGraphs.QAbstract3DAxis.setLabelsVisible(self,visible:bool)",
    "PySide6.QtGraphs.QAbstract3DAxis.setMax(self,max:float)",
    "PySide6.QtGraphs.QAbstract3DAxis.setMin(self,min:float)",
    "PySide6.QtGraphs.QAbstract3DAxis.setRange(self,min:float,max:float)",
    "PySide6.QtGraphs.QAbstract3DAxis.setScaleLabelsByCount(self,adjust:bool)",
    "PySide6.QtGraphs.QAbstract3DAxis.setTitle(self,title:QString)",
    "PySide6.QtGraphs.QAbstract3DAxis.setTitleFixed(self,fixed:bool)",
    "PySide6.QtGraphs.QAbstract3DAxis.setTitleOffset(self,offset:float)",
    "PySide6.QtGraphs.QAbstract3DAxis.setTitleVisible(self,visible:bool)",
    "PySide6.QtGraphs.QAbstract3DAxis.title(self)->QString",
    "PySide6.QtGraphs.QAbstract3DAxis.titleOffset(self)->float",
    "PySide6.QtGraphs.QAbstract3DAxis.type(self)->PySide6.QtGraphs.QAbstract3DAxis.AxisType",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstract3DAxis_SignatureByteSize = 324;
static constexpr uint8_t QAbstract3DAxis_SignatureBytes[324] = {
    0x78, 0xda, 0x9d, 0x94, 0x4d, 0x4f, 0x83, 0x40, 0x10, 0x86, 0xef, 0xfd, 0x25, 0x36, 0x59, 0xb9,
    0x98, 0x78, 0xe0, 0x60, 0x82, 0x1a, 0xbd, 0xd0, 0xb4, 0x48, 0xe3, 0x7d, 0x29, 0x03, 0x8e, 0xd9,
    0xee, 0x56, 0x66, 0x30, 0xe0, 0xaf, 0x97, 0x8f, 0x16, 0x48, 0xaa, 0x29, 0xd3, 0x0b, 0x19, 0x36,
    0x79, 0xe6, 0xf3, 0xcd, 0xbb, 0xa9, 0x63, 0x4c, 0xe1, 0xde, 0x8b, 0xf8, 0xb5, 0xd0, 0x87, 0x0f,
    0xf2, 0xa2, 0x20, 0x21, 0x2e, 0xf4, 0x8e, 0xef, 0x9e, 0x83, 0x0a, 0xc9, 0x43, 0x0a, 0x4a, 0x76,
    0x41, 0xfa, 0x59, 0x12, 0xbf, 0x69, 0x9b, 0xc3, 0x0d, 0x81, 0xc9, 0x96, 0xb7, 0x0f, 0x89, 0x73,
    0x66, 0xb1, 0xb9, 0x8c, 0xc7, 0x3b, 0x6d, 0x20, 0xd4, 0x09, 0x18, 0x7a, 0xac, 0x9f, 0x5c, 0x69,
    0x59, 0x9a, 0x61, 0x8b, 0x6c, 0xe0, 0x05, 0x2b, 0x48, 0xaf, 0x22, 0xdf, 0x91, 0x30, 0x31, 0xc2,
    0xbe, 0x4d, 0xdb, 0x70, 0x37, 0xb9, 0xcd, 0x47, 0x36, 0x33, 0x4e, 0xf3, 0x4c, 0x38, 0xc6, 0x9f,
    0x81, 0xfb, 0x2a, 0x40, 0xcf, 0x2d, 0x4a, 0x27, 0x28, 0x8a, 0xb9, 0x40, 0x9b, 0x87, 0x48, 0x73,
    0x4b, 0xd2, 0x55, 0xa3, 0xee, 0x75, 0x25, 0x9c, 0x6f, 0x8f, 0x56, 0x48, 0xb8, 0x02, 0xc1, 0xb2,
    0x66, 0x74, 0x03, 0x79, 0x91, 0x69, 0x3f, 0xeb, 0x91, 0xbb, 0x5c, 0x84, 0x80, 0xff, 0xd2, 0xaa,
    0xd2, 0xc3, 0xa3, 0xdf, 0x6e, 0x64, 0x39, 0x2b, 0x53, 0x78, 0x2e, 0x00, 0x95, 0x42, 0x5e, 0x00,
    0xf8, 0xdd, 0xcc, 0x82, 0x2c, 0x83, 0x12, 0x14, 0x35, 0x91, 0xdf, 0x89, 0x41, 0x80, 0xf7, 0x82,
    0x50, 0xfd, 0x85, 0xfd, 0x89, 0x2a, 0x24, 0x39, 0xa6, 0xca, 0x50, 0xdf, 0xfd, 0x8f, 0x60, 0x1b,
    0xab, 0xa3, 0x46, 0x54, 0x23, 0x16, 0xc9, 0xfc, 0xab, 0xa3, 0x52, 0x54, 0x23, 0x19, 0x09, 0x37,
    0xb9, 0xde, 0x40, 0x4a, 0x6b, 0xff, 0x63, 0x3c, 0x4a, 0x4b, 0xa5, 0xd0, 0xb9, 0x48, 0xcf, 0x72,
    0x1b, 0x9e, 0x6e, 0x20, 0xa0, 0x47, 0xf7, 0x52, 0x59, 0x1b, 0x4a, 0xab, 0xaf, 0xb3, 0xac, 0x09,
    0xfb, 0x04, 0xae, 0x8b, 0x25, 0x9b, 0x38, 0xb3, 0x41, 0xa9, 0x02, 0x78, 0xd8, 0xc0, 0xe8, 0x4b,
    0x33, 0xa9, 0x49, 0xe7, 0xf3, 0xed, 0x82, 0xeb, 0x03, 0x88, 0x7c, 0x62, 0xdb, 0x00, 0x8b, 0x5f,
    0x5e, 0x02, 0x73, 0x4c
};
#endif

PyTypeObject *init_QAbstract3DAxis(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstract3DAxis_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QAbstract3DAxis_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstract3DAxis",
        "QAbstract3DAxis*",
        &Sbk_QAbstract3DAxis_spec,
        &Shiboken::callCppDestructor< QAbstract3DAxis >,
        Sbk_QAbstract3DAxis_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAbstract3DAxis_TypeF(); // references _Sbk_QAbstract3DAxis_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstract3DAxis_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstract3DAxis_SignatureBytes, QAbstract3DAxis_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstract3DAxis_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstract3DAxis_PythonToCpp_QAbstract3DAxis_PTR,
        is_QAbstract3DAxis_PythonToCpp_QAbstract3DAxis_PTR_Convertible,
        QAbstract3DAxis_PTR_CppToPython_QAbstract3DAxis);

    Shiboken::Conversions::registerConverterName(converter, "QAbstract3DAxis");
    Shiboken::Conversions::registerConverterName(converter, "QAbstract3DAxis*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstract3DAxis&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstract3DAxis).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstract3DAxisWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAbstract3DAxis_TypeF(), &Sbk_QAbstract3DAxis_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAbstract3DAxis_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'AxisOrientation'.
    const char *AxisOrientation_Initializer[] = {
        "None_",
        "X",
        "Y",
        "Z",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t AxisOrientation_InitializerValues[] = {
        int8_t(QAbstract3DAxis::AxisOrientation::None), //  0x00  0
        int8_t(QAbstract3DAxis::AxisOrientation::X),    //  0x01  1
        int8_t(QAbstract3DAxis::AxisOrientation::Y),    //  0x02  2
        int8_t(QAbstract3DAxis::AxisOrientation::Z)     //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstract3DAxis_TypeF(),
        "2:PySide6.QtGraphs.QAbstract3DAxis.AxisOrientation",
        AxisOrientation_Initializer, AxisOrientation_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_AxisOrientation_IDX].type = EType;
    // Register converter for enum 'QAbstract3DAxis::AxisOrientation'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstract3DAxis_AxisOrientation_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstract3DAxis_AxisOrientation,
            is_Enum_PythonToCpp_QAbstract3DAxis_AxisOrientation_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstract3DAxis::AxisOrientation");
        Shiboken::Conversions::registerConverterAlias(converter, "AxisOrientation");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AxisOrientation' enum.

    // Initialization of enum 'AxisType'.
    const char *AxisType_Initializer[] = {
        "None_",
        "Category",
        "Value",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t AxisType_InitializerValues[] = {
        int8_t(QAbstract3DAxis::AxisType::None),     //  0x00  0
        int8_t(QAbstract3DAxis::AxisType::Category), //  0x01  1
        int8_t(QAbstract3DAxis::AxisType::Value)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstract3DAxis_TypeF(),
        "2:PySide6.QtGraphs.QAbstract3DAxis.AxisType",
        AxisType_Initializer, AxisType_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_AxisType_IDX].type = EType;
    // Register converter for enum 'QAbstract3DAxis::AxisType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstract3DAxis_AxisType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstract3DAxis_AxisType,
            is_Enum_PythonToCpp_QAbstract3DAxis_AxisType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstract3DAxis::AxisType");
        Shiboken::Conversions::registerConverterAlias(converter, "AxisType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AxisType' enum.

    PySide::Signal::registerSignals(pyType, &::QAbstract3DAxis::staticMetaObject);
    qRegisterMetaType< ::QAbstract3DAxis::AxisOrientation >("QAbstract3DAxis::AxisOrientation");
    qRegisterMetaType< ::QAbstract3DAxis::AxisType >("QAbstract3DAxis::AxisType");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAbstract3DAxis::staticMetaObject, sizeof(QAbstract3DAxisWrapper));

    return pyType;
}
