// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qbar3dseries_wrapper.h"

// Wrappers providing overrides
#include "qxymodelmapper_wrapper.h"

// Argument includes
#include <QList>
#include <QStringList>
#include <QtGraphs/qbardataitem.h>
#include <QtGraphs/qbardataproxy.h>
#include <QtGui/qcolor.h>
#include <QtGui/qquaternion.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QBar3DSeriesWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QBar3DSeriesWrapper::QBar3DSeriesWrapper(::QBarDataProxy * dataProxy, ::QObject * parent) : QBar3DSeries(dataProxy, parent)
{
}

QBar3DSeriesWrapper::QBar3DSeriesWrapper(::QObject * parent) : QBar3DSeries(parent)
{
}

void QBar3DSeriesWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_childEvent("QBar3DSeries", funcName, gil, pyOverride, event);
}

void QBar3DSeriesWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QBar3DSeries", funcName, gil, pyOverride, signal);
}

void QBar3DSeriesWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_customEvent("QBar3DSeries", funcName, gil, pyOverride, event);
}

void QBar3DSeriesWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QBar3DSeries", funcName, gil, pyOverride, signal);
}

bool QBar3DSeriesWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QXYModelMapperWrapper::sbk_o_event("QBar3DSeries", funcName, gil, pyOverride, event);
}

bool QBar3DSeriesWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QXYModelMapperWrapper::sbk_o_eventFilter("QBar3DSeries", funcName, gil, pyOverride, watched, event);
}

void QBar3DSeriesWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_timerEvent("QBar3DSeries", funcName, gil, pyOverride, event);
}

const QMetaObject *QBar3DSeriesWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QBar3DSeries::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QBar3DSeriesWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QBar3DSeries::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QBar3DSeriesWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QBar3DSeriesWrapper *>(this));
    return QBar3DSeries::qt_metacast(_clname);
}

QBar3DSeriesWrapper::~QBar3DSeriesWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBar3DSeries_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBar3DSeries >()))
        return -1;

    QBar3DSeriesWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QBar3DSeries", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBar3DSeries::QBar3DSeries(QBarDataProxy*,QObject*=)
    // 1: QBar3DSeries::QBar3DSeries(QObject*=)
    if (numArgs == 0) {
        overloadId = 1; // QBar3DSeries(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QBar3DSeries(QBarDataProxy*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QBar3DSeries(QBarDataProxy*,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QBar3DSeries(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QBar3DSeries(QBarDataProxy *dataProxy, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBarDataProxy *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBar3DSeries(QBarDataProxy*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QBar3DSeriesWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QBar3DSeriesWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 1: // QBar3DSeries(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBar3DSeries(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QBar3DSeriesWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QBar3DSeriesWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QBar3DSeries >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QBar3DSeriesFunc_clearArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearArray()
        cppSelf->clearArray();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBar3DSeriesFunc_clearRow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBar3DSeries::clearRow(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // clearRow(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "clearRow", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // clearRow(qsizetype)
            cppSelf->clearRow(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBar3DSeriesFunc_columnLabels(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnLabels()const
        QStringList cppResult = const_cast<const ::QBar3DSeries *>(cppSelf)->columnLabels();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBar3DSeriesFunc_dataArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dataArray()
        QList<QList<QBarDataItem>> cppResult = cppSelf->dataArray();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QList_QBarDataItem_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBar3DSeriesFunc_dataProxy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dataProxy()const
        QBarDataProxy * cppResult = const_cast<const ::QBar3DSeries *>(cppSelf)->dataProxy();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBar3DSeriesFunc_invalidSelectionPosition(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invalidSelectionPosition()
        QPoint cppResult = ::QBar3DSeries::invalidSelectionPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBar3DSeriesFunc_isValueColoringEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValueColoringEnabled()const
        bool cppResult = const_cast<const ::QBar3DSeries *>(cppSelf)->isValueColoringEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBar3DSeriesFunc_meshAngle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // meshAngle()const
        float cppResult = const_cast<const ::QBar3DSeries *>(cppSelf)->meshAngle();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBar3DSeriesFunc_rowColors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowColors()const
        QList<QColor> cppResult = const_cast<const ::QBar3DSeries *>(cppSelf)->rowColors();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QColor_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBar3DSeriesFunc_rowLabels(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rowLabels()const
        QStringList cppResult = const_cast<const ::QBar3DSeries *>(cppSelf)->rowLabels();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBar3DSeriesFunc_selectedBar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedBar()const
        QPoint cppResult = const_cast<const ::QBar3DSeries *>(cppSelf)->selectedBar();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QBar3DSeriesFunc_setColumnLabels(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBar3DSeries::setColumnLabels(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setColumnLabels(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColumnLabels", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColumnLabels(QStringList)
            cppSelf->setColumnLabels(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBar3DSeriesFunc_setDataArray(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBar3DSeries::setDataArray(QList<QList<QBarDataItem>>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QList_QBarDataItem_IDX], (pyArg)))) {
        overloadId = 0; // setDataArray(QList<QList<QBarDataItem>>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDataArray", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);

    // Call function/method
    {
        ::QList<QList<QBarDataItem>> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDataArray(QList<QList<QBarDataItem>>)
            cppSelf->setDataArray(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBar3DSeriesFunc_setDataProxy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBar3DSeries::setDataProxy(QBarDataProxy*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBarDataProxy_IDX]), (pyArg)))) {
        overloadId = 0; // setDataProxy(QBarDataProxy*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDataProxy", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBarDataProxy *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDataProxy(QBarDataProxy*)
            cppSelf->setDataProxy(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBar3DSeriesFunc_setMeshAngle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBar3DSeries::setMeshAngle(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMeshAngle(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMeshAngle", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMeshAngle(float)
            cppSelf->setMeshAngle(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBar3DSeriesFunc_setRowColors(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBar3DSeries::setRowColors(QList<QColor>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QColor_IDX], (pyArg)))) {
        overloadId = 0; // setRowColors(QList<QColor>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRowColors", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);

    // Call function/method
    {
        ::QList<QColor> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRowColors(QList<QColor>)
            cppSelf->setRowColors(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBar3DSeriesFunc_setRowLabels(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBar3DSeries::setRowLabels(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setRowLabels(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRowLabels", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRowLabels(QStringList)
            cppSelf->setRowLabels(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBar3DSeriesFunc_setSelectedBar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBar3DSeries::setSelectedBar(QPoint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // setSelectedBar(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelectedBar", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectedBar(QPoint)
            cppSelf->setSelectedBar(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QBar3DSeriesFunc_setValueColoringEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBar3DSeries::setValueColoringEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setValueColoringEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setValueColoringEnabled", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValueColoringEnabled(bool)
            cppSelf->setValueColoringEnabled(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QBar3DSeries_PropertyStrings[] = {
    "columnLabels::",
    "dataArray::",
    "dataProxy::",
    "meshAngle::",
    "rowColors::",
    "rowLabels::",
    "selectedBar::",
    "valueColoringEnabled:isValueColoringEnabled:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBar3DSeries_methods[] = {
    {"clearArray", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_clearArray), METH_NOARGS, nullptr},
    {"clearRow", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_clearRow), METH_O, nullptr},
    {"columnLabels", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_columnLabels), METH_NOARGS, nullptr},
    {"dataArray", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_dataArray), METH_NOARGS, nullptr},
    {"dataProxy", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_dataProxy), METH_NOARGS, nullptr},
    {"invalidSelectionPosition", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_invalidSelectionPosition), METH_NOARGS|METH_STATIC, nullptr},
    {"isValueColoringEnabled", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_isValueColoringEnabled), METH_NOARGS, nullptr},
    {"meshAngle", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_meshAngle), METH_NOARGS, nullptr},
    {"rowColors", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_rowColors), METH_NOARGS, nullptr},
    {"rowLabels", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_rowLabels), METH_NOARGS, nullptr},
    {"selectedBar", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_selectedBar), METH_NOARGS, nullptr},
    {"setColumnLabels", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_setColumnLabels), METH_O, nullptr},
    {"setDataArray", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_setDataArray), METH_O, nullptr},
    {"setDataProxy", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_setDataProxy), METH_O, nullptr},
    {"setMeshAngle", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_setMeshAngle), METH_O, nullptr},
    {"setRowColors", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_setRowColors), METH_O, nullptr},
    {"setRowLabels", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_setRowLabels), METH_O, nullptr},
    {"setSelectedBar", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_setSelectedBar), METH_O, nullptr},
    {"setValueColoringEnabled", reinterpret_cast<PyCFunction>(Sbk_QBar3DSeriesFunc_setValueColoringEnabled), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QBar3DSeries_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QBar3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QBar3DSeriesWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QBar3DSeries_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBar3DSeries_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBar3DSeries_Type = nullptr;
static PyTypeObject *Sbk_QBar3DSeries_TypeF(void)
{
    return _Sbk_QBar3DSeries_Type;
}

static PyType_Slot Sbk_QBar3DSeries_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QBar3DSeries_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBar3DSeries_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBar3DSeries_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBar3DSeries_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBar3DSeries_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBar3DSeries_spec = {
    "2:PySide6.QtGraphs.QBar3DSeries",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBar3DSeries_slots
};

} //extern "C"

static void *Sbk_QBar3DSeries_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QBar3DSeries *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBar3DSeries_PythonToCpp_QBar3DSeries_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBar3DSeries_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBar3DSeries_PythonToCpp_QBar3DSeries_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBar3DSeries_TypeF()))
        return QBar3DSeries_PythonToCpp_QBar3DSeries_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBar3DSeries_PTR_CppToPython_QBar3DSeries(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QBar3DSeries *>(const_cast<void *>(cppIn)), Sbk_QBar3DSeries_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QBar3DSeries_SignatureStrings[] = {
    "1:PySide6.QtGraphs.QBar3DSeries(self,dataProxy:PySide6.QtGraphs.QBarDataProxy,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,dataProxy:QBarDataProxy=None,selectedBar:QPoint=None,meshAngle:float=None,rowColors:QList[PySide6.QtGui.QColor]=None,rowLabels:QStringList=None,columnLabels:QStringList=None,dataArray:QList[QList[PySide6.QtGraphs.QBarDataItem]]=None,valueColoringEnabled:bool=None)",
    "0:PySide6.QtGraphs.QBar3DSeries(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,dataProxy:QBarDataProxy=None,selectedBar:QPoint=None,meshAngle:float=None,rowColors:QList[PySide6.QtGui.QColor]=None,rowLabels:QStringList=None,columnLabels:QStringList=None,dataArray:QList[QList[PySide6.QtGraphs.QBarDataItem]]=None,valueColoringEnabled:bool=None)",
    "PySide6.QtGraphs.QBar3DSeries.clearArray(self)",
    "PySide6.QtGraphs.QBar3DSeries.clearRow(self,rowIndex:qsizetype)",
    "PySide6.QtGraphs.QBar3DSeries.columnLabels(self)->QStringList",
    "PySide6.QtGraphs.QBar3DSeries.dataArray(self)->QList[QList[PySide6.QtGraphs.QBarDataItem]]",
    "PySide6.QtGraphs.QBar3DSeries.dataProxy(self)->PySide6.QtGraphs.QBarDataProxy",
    "PySide6.QtGraphs.QBar3DSeries.invalidSelectionPosition()->PySide6.QtCore.QPoint",
    "PySide6.QtGraphs.QBar3DSeries.isValueColoringEnabled(self)->bool",
    "PySide6.QtGraphs.QBar3DSeries.meshAngle(self)->float",
    "PySide6.QtGraphs.QBar3DSeries.rowColors(self)->QList[PySide6.QtGui.QColor]",
    "PySide6.QtGraphs.QBar3DSeries.rowLabels(self)->QStringList",
    "PySide6.QtGraphs.QBar3DSeries.selectedBar(self)->PySide6.QtCore.QPoint",
    "PySide6.QtGraphs.QBar3DSeries.setColumnLabels(self,labels:QStringList)",
    "PySide6.QtGraphs.QBar3DSeries.setDataArray(self,newDataArray:QList[QList[PySide6.QtGraphs.QBarDataItem]])",
    "PySide6.QtGraphs.QBar3DSeries.setDataProxy(self,proxy:PySide6.QtGraphs.QBarDataProxy)",
    "PySide6.QtGraphs.QBar3DSeries.setMeshAngle(self,angle:float)",
    "PySide6.QtGraphs.QBar3DSeries.setRowColors(self,colors:QList[PySide6.QtGui.QColor])",
    "PySide6.QtGraphs.QBar3DSeries.setRowLabels(self,labels:QStringList)",
    "PySide6.QtGraphs.QBar3DSeries.setSelectedBar(self,position:PySide6.QtCore.QPoint)",
    "PySide6.QtGraphs.QBar3DSeries.setValueColoringEnabled(self,enabled:bool)",
    nullptr}; // Sentinel
#else
static constexpr size_t QBar3DSeries_SignatureByteSize = 438;
static constexpr uint8_t QBar3DSeries_SignatureBytes[438] = {
    0x78, 0xda, 0xed, 0x55, 0x4d, 0x4f, 0xc2, 0x40, 0x10, 0xbd, 0xf3, 0x4b, 0xc0, 0xac, 0x8d, 0xc6,
    0xc4, 0x43, 0x13, 0x4c, 0x14, 0x8c, 0x21, 0xa2, 0x50, 0x9a, 0x78, 0x31, 0x1c, 0x16, 0x3a, 0xc0,
    0x9a, 0x65, 0xb7, 0xee, 0x6e, 0x85, 0xfa, 0xeb, 0x6d, 0xb7, 0x1f, 0xb4, 0x50, 0xd8, 0x0d, 0x5c,
    0x3d, 0x35, 0xe9, 0xcc, 0xbc, 0x37, 0x7d, 0xf3, 0x66, 0x7a, 0xeb, 0x8e, 0x63, 0x9f, 0x04, 0x70,
    0xef, 0x78, 0xea, 0x45, 0xe0, 0x70, 0x25, 0x1d, 0xef, 0x09, 0x8b, 0xbb, 0xbe, 0x0f, 0x82, 0x80,
    0x6c, 0x4b, 0xa0, 0x0b, 0x14, 0x60, 0x85, 0xc7, 0x82, 0x6f, 0xe3, 0xe6, 0xe4, 0x7e, 0x11, 0x46,
    0x21, 0x16, 0xc0, 0x54, 0x25, 0xab, 0xc7, 0x05, 0x38, 0xde, 0x68, 0xf6, 0x05, 0x73, 0xd5, 0x65,
    0x11, 0xa5, 0xa1, 0x12, 0xe8, 0xca, 0x7d, 0x85, 0x78, 0xc3, 0x45, 0x30, 0x62, 0x34, 0xee, 0xbe,
    0x73, 0x06, 0x15, 0x86, 0x1a, 0x60, 0x16, 0x4c, 0x7a, 0x48, 0xca, 0x21, 0x48, 0x22, 0xae, 0x37,
    0xe6, 0x84, 0xa9, 0xec, 0xfd, 0x1a, 0xe4, 0xea, 0x91, 0x2d, 0x29, 0xb8, 0x0b, 0xca, 0x71, 0xfe,
    0x52, 0xf0, 0x4d, 0x8f, 0x53, 0x2e, 0xa4, 0xeb, 0x0d, 0x89, 0x54, 0x9f, 0x95, 0x8e, 0x23, 0xe2,
    0x78, 0x3a, 0x36, 0x2d, 0x53, 0x87, 0x78, 0x06, 0x34, 0x49, 0xf5, 0x95, 0x20, 0x6c, 0x99, 0x16,
    0x64, 0xa1, 0x39, 0xa7, 0xd1, 0x9a, 0x1d, 0x8b, 0xa6, 0xdd, 0x3e, 0x0a, 0x81, 0xe3, 0x9c, 0xe3,
    0x80, 0xa9, 0xae, 0xcd, 0x40, 0xc1, 0x7a, 0x9a, 0x73, 0xfe, 0x60, 0x1a, 0x81, 0x6e, 0x22, 0x41,
    0x7c, 0x66, 0x78, 0x46, 0x21, 0x70, 0x67, 0x9c, 0x53, 0x1d, 0xee, 0xb4, 0x6e, 0x6c, 0xe6, 0xf1,
    0x2f, 0xf3, 0xa5, 0x32, 0x9f, 0x14, 0xd9, 0x99, 0x53, 0xc0, 0x42, 0x33, 0x6b, 0xbd, 0xad, 0xd2,
    0x27, 0x7c, 0x93, 0x0d, 0x27, 0xf9, 0xdc, 0x01, 0x0b, 0x60, 0xeb, 0x7e, 0x4b, 0xf2, 0x0b, 0x2a,
    0x0e, 0xcd, 0x74, 0x15, 0x15, 0x32, 0xc2, 0xeb, 0x87, 0x8a, 0x18, 0x86, 0xea, 0x52, 0xa5, 0xb2,
    0xd4, 0x5e, 0x2c, 0x0b, 0x68, 0x6d, 0x90, 0x02, 0xfa, 0xf4, 0xfa, 0x1b, 0xd0, 0x08, 0x4b, 0xa6,
    0x42, 0x02, 0x5f, 0xdb, 0x8c, 0x70, 0x36, 0xe6, 0x92, 0xa4, 0xcf, 0x76, 0x0d, 0x38, 0xb3, 0xb2,
    0xb6, 0x9f, 0x09, 0x4f, 0x7e, 0x34, 0x4c, 0xb9, 0x68, 0x35, 0x1d, 0xb6, 0x01, 0xa0, 0x34, 0x76,
    0x51, 0xa3, 0xfd, 0x6d, 0x28, 0x2a, 0x8d, 0x5f, 0x97, 0xbb, 0xd1, 0xff, 0x66, 0xa8, 0x73, 0x87,
    0x5e, 0xd9, 0xd5, 0xc3, 0xd9, 0xd8, 0x4b, 0x28, 0x21, 0x49, 0xde, 0x33, 0x1f, 0xa2, 0x07, 0xeb,
    0xd8, 0x31, 0xc3, 0xf4, 0x6b, 0x2e, 0x44, 0x0c, 0x36, 0xfd, 0x73, 0xb6, 0xd7, 0x92, 0x69, 0x67,
    0x4a, 0x14, 0x5a, 0xfc, 0x97, 0x2c, 0x50, 0xdf, 0x6a, 0x5e, 0x40, 0x78, 0x77, 0xef, 0x2c, 0x8a,
    0x27, 0x35, 0x4f, 0xa4, 0x57, 0xcd, 0x70, 0x18, 0xed, 0x30, 0x2f, 0x1e, 0x8a, 0xbf, 0xe7, 0x12,
    0x14, 0xe6, 0x2b, 0xe7, 0x36, 0x9a, 0xc5, 0x02, 0xf1, 0xe8, 0xc6, 0x21, 0xa8, 0x1c, 0xd9, 0x4e,
    0xeb, 0x0f, 0x69, 0x1c, 0x04, 0xf7
};
#endif

PyTypeObject *init_QBar3DSeries(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX].type;

    Shiboken::AutoDecRef Sbk_QBar3DSeries_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DSeries_IDX]))));

    _Sbk_QBar3DSeries_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBar3DSeries",
        "QBar3DSeries*",
        &Sbk_QBar3DSeries_spec,
        &Shiboken::callCppDestructor< QBar3DSeries >,
        Sbk_QBar3DSeries_Type_bases.object(),
        0);
    auto *pyType = Sbk_QBar3DSeries_TypeF(); // references _Sbk_QBar3DSeries_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QBar3DSeries_SignatureStrings);
#else
    InitSignatureBytes(pyType, QBar3DSeries_SignatureBytes, QBar3DSeries_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBar3DSeries_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QBar3DSeries_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBar3DSeries_PythonToCpp_QBar3DSeries_PTR,
        is_QBar3DSeries_PythonToCpp_QBar3DSeries_PTR_Convertible,
        QBar3DSeries_PTR_CppToPython_QBar3DSeries);

    Shiboken::Conversions::registerConverterName(converter, "QBar3DSeries");
    Shiboken::Conversions::registerConverterName(converter, "QBar3DSeries*");
    Shiboken::Conversions::registerConverterName(converter, "QBar3DSeries&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBar3DSeries).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QBar3DSeriesWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QBar3DSeries_TypeF(), &Sbk_QBar3DSeries_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QBar3DSeries::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QBar3DSeries::staticMetaObject, sizeof(QBar3DSeriesWrapper));

    return pyType;
}
