// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qspline3dseries_wrapper.h"

// Wrappers providing overrides
#include "qxymodelmapper_wrapper.h"

// Argument includes
#include <QtGraphs/qscatterdataproxy.h>
#include <QtGui/qcolor.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSpline3DSeriesWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSpline3DSeriesWrapper::QSpline3DSeriesWrapper(::QObject * parent) : QSpline3DSeries(parent)
{
}

QSpline3DSeriesWrapper::QSpline3DSeriesWrapper(::QScatterDataProxy * dataProxy, ::QObject * parent) : QSpline3DSeries(dataProxy, parent)
{
}

void QSpline3DSeriesWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_childEvent("QSpline3DSeries", funcName, gil, pyOverride, event);
}

void QSpline3DSeriesWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QSpline3DSeries", funcName, gil, pyOverride, signal);
}

void QSpline3DSeriesWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_customEvent("QSpline3DSeries", funcName, gil, pyOverride, event);
}

void QSpline3DSeriesWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QSpline3DSeries", funcName, gil, pyOverride, signal);
}

bool QSpline3DSeriesWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QXYModelMapperWrapper::sbk_o_event("QSpline3DSeries", funcName, gil, pyOverride, event);
}

bool QSpline3DSeriesWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QXYModelMapperWrapper::sbk_o_eventFilter("QSpline3DSeries", funcName, gil, pyOverride, watched, event);
}

void QSpline3DSeriesWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_timerEvent("QSpline3DSeries", funcName, gil, pyOverride, event);
}

const QMetaObject *QSpline3DSeriesWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSpline3DSeries::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSpline3DSeriesWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSpline3DSeries::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSpline3DSeriesWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QSpline3DSeriesWrapper *>(this));
    return QSpline3DSeries::qt_metacast(_clname);
}

QSpline3DSeriesWrapper::~QSpline3DSeriesWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSpline3DSeries_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSpline3DSeries >()))
        return -1;

    QSpline3DSeriesWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QSpline3DSeries", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSpline3DSeries::QSpline3DSeries(QObject*=)
    // 1: QSpline3DSeries::QSpline3DSeries(QScatterDataProxy*,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QSpline3DSeries(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatterDataProxy_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QSpline3DSeries(QScatterDataProxy*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QSpline3DSeries(QScatterDataProxy*,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSpline3DSeries(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSpline3DSeries(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSpline3DSeries(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSpline3DSeriesWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSpline3DSeriesWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QSpline3DSeries(QScatterDataProxy *dataProxy, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScatterDataProxy *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSpline3DSeries(QScatterDataProxy*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSpline3DSeriesWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSpline3DSeriesWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSpline3DSeries >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QSpline3DSeriesFunc_isSplineLooping(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpline3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSplineLooping()const
        bool cppResult = const_cast<const ::QSpline3DSeries *>(cppSelf)->isSplineLooping();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSpline3DSeriesFunc_isSplineVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpline3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSplineVisible()const
        bool cppResult = const_cast<const ::QSpline3DSeries *>(cppSelf)->isSplineVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSpline3DSeriesFunc_setSplineColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpline3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpline3DSeries::setSplineColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setSplineColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSplineColor", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSplineColor(QColor)
            cppSelf->setSplineColor(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSpline3DSeriesFunc_setSplineKnotting(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpline3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpline3DSeries::setSplineKnotting(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setSplineKnotting(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSplineKnotting", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSplineKnotting(qreal)
            cppSelf->setSplineKnotting(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSpline3DSeriesFunc_setSplineLooping(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpline3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpline3DSeries::setSplineLooping(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSplineLooping(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSplineLooping", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSplineLooping(bool)
            cppSelf->setSplineLooping(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSpline3DSeriesFunc_setSplineResolution(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpline3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpline3DSeries::setSplineResolution(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSplineResolution(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSplineResolution", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSplineResolution(int)
            cppSelf->setSplineResolution(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSpline3DSeriesFunc_setSplineTension(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpline3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpline3DSeries::setSplineTension(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setSplineTension(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSplineTension", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSplineTension(qreal)
            cppSelf->setSplineTension(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSpline3DSeriesFunc_setSplineVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpline3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSpline3DSeries::setSplineVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSplineVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSplineVisible", errInfo, SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSplineVisible(bool)
            cppSelf->setSplineVisible(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSpline3DSeriesFunc_splineColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpline3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // splineColor()const
        QColor cppResult = const_cast<const ::QSpline3DSeries *>(cppSelf)->splineColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSpline3DSeriesFunc_splineKnotting(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpline3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // splineKnotting()const
        qreal cppResult = const_cast<const ::QSpline3DSeries *>(cppSelf)->splineKnotting();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSpline3DSeriesFunc_splineResolution(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpline3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // splineResolution()const
        int cppResult = const_cast<const ::QSpline3DSeries *>(cppSelf)->splineResolution();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSpline3DSeriesFunc_splineTension(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpline3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // splineTension()const
        qreal cppResult = const_cast<const ::QSpline3DSeries *>(cppSelf)->splineTension();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QSpline3DSeries_PropertyStrings[] = {
    "splineColor::",
    "splineKnotting::",
    "splineLooping:isSplineLooping:",
    "splineResolution::",
    "splineTension::",
    "splineVisible:isSplineVisible:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSpline3DSeries_methods[] = {
    {"isSplineLooping", reinterpret_cast<PyCFunction>(Sbk_QSpline3DSeriesFunc_isSplineLooping), METH_NOARGS, nullptr},
    {"isSplineVisible", reinterpret_cast<PyCFunction>(Sbk_QSpline3DSeriesFunc_isSplineVisible), METH_NOARGS, nullptr},
    {"setSplineColor", reinterpret_cast<PyCFunction>(Sbk_QSpline3DSeriesFunc_setSplineColor), METH_O, nullptr},
    {"setSplineKnotting", reinterpret_cast<PyCFunction>(Sbk_QSpline3DSeriesFunc_setSplineKnotting), METH_O, nullptr},
    {"setSplineLooping", reinterpret_cast<PyCFunction>(Sbk_QSpline3DSeriesFunc_setSplineLooping), METH_O, nullptr},
    {"setSplineResolution", reinterpret_cast<PyCFunction>(Sbk_QSpline3DSeriesFunc_setSplineResolution), METH_O, nullptr},
    {"setSplineTension", reinterpret_cast<PyCFunction>(Sbk_QSpline3DSeriesFunc_setSplineTension), METH_O, nullptr},
    {"setSplineVisible", reinterpret_cast<PyCFunction>(Sbk_QSpline3DSeriesFunc_setSplineVisible), METH_O, nullptr},
    {"splineColor", reinterpret_cast<PyCFunction>(Sbk_QSpline3DSeriesFunc_splineColor), METH_NOARGS, nullptr},
    {"splineKnotting", reinterpret_cast<PyCFunction>(Sbk_QSpline3DSeriesFunc_splineKnotting), METH_NOARGS, nullptr},
    {"splineResolution", reinterpret_cast<PyCFunction>(Sbk_QSpline3DSeriesFunc_splineResolution), METH_NOARGS, nullptr},
    {"splineTension", reinterpret_cast<PyCFunction>(Sbk_QSpline3DSeriesFunc_splineTension), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSpline3DSeries_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSpline3DSeries *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSpline3DSeriesWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSpline3DSeries_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSpline3DSeries_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSpline3DSeries_Type = nullptr;
static PyTypeObject *Sbk_QSpline3DSeries_TypeF(void)
{
    return _Sbk_QSpline3DSeries_Type;
}

static PyType_Slot Sbk_QSpline3DSeries_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSpline3DSeries_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSpline3DSeries_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSpline3DSeries_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSpline3DSeries_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSpline3DSeries_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSpline3DSeries_spec = {
    "2:PySide6.QtGraphs.QSpline3DSeries",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSpline3DSeries_slots
};

} //extern "C"

static void *Sbk_QSpline3DSeries_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSpline3DSeries *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSpline3DSeries_PythonToCpp_QSpline3DSeries_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSpline3DSeries_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSpline3DSeries_PythonToCpp_QSpline3DSeries_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSpline3DSeries_TypeF()))
        return QSpline3DSeries_PythonToCpp_QSpline3DSeries_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSpline3DSeries_PTR_CppToPython_QSpline3DSeries(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSpline3DSeries *>(const_cast<void *>(cppIn)), Sbk_QSpline3DSeries_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSpline3DSeries_SignatureStrings[] = {
    "1:PySide6.QtGraphs.QSpline3DSeries(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,splineVisible:bool=None,splineTension:qreal=None,splineKnotting:qreal=None,splineLooping:bool=None,splineColor:QColor=None,splineResolution:int=None)",
    "0:PySide6.QtGraphs.QSpline3DSeries(self,dataProxy:PySide6.QtGraphs.QScatterDataProxy,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,splineVisible:bool=None,splineTension:qreal=None,splineKnotting:qreal=None,splineLooping:bool=None,splineColor:QColor=None,splineResolution:int=None)",
    "PySide6.QtGraphs.QSpline3DSeries.isSplineLooping(self)->bool",
    "PySide6.QtGraphs.QSpline3DSeries.isSplineVisible(self)->bool",
    "PySide6.QtGraphs.QSpline3DSeries.setSplineColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGraphs.QSpline3DSeries.setSplineKnotting(self,knotting:qreal)",
    "PySide6.QtGraphs.QSpline3DSeries.setSplineLooping(self,looping:bool)",
    "PySide6.QtGraphs.QSpline3DSeries.setSplineResolution(self,resolution:int)",
    "PySide6.QtGraphs.QSpline3DSeries.setSplineTension(self,tension:qreal)",
    "PySide6.QtGraphs.QSpline3DSeries.setSplineVisible(self,draw:bool)",
    "PySide6.QtGraphs.QSpline3DSeries.splineColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtGraphs.QSpline3DSeries.splineKnotting(self)->qreal",
    "PySide6.QtGraphs.QSpline3DSeries.splineResolution(self)->int",
    "PySide6.QtGraphs.QSpline3DSeries.splineTension(self)->qreal",
    nullptr}; // Sentinel
#else
static constexpr size_t QSpline3DSeries_SignatureByteSize = 360;
static constexpr uint8_t QSpline3DSeries_SignatureBytes[360] = {
    0x78, 0xda, 0xdd, 0x52, 0x3d, 0x4f, 0xc3, 0x30, 0x10, 0xdd, 0xf9, 0x15, 0x1d, 0x29, 0x32, 0x16,
    0x15, 0xa8, 0x43, 0xa4, 0xb2, 0xb4, 0x52, 0x87, 0x56, 0xb4, 0x69, 0xa0, 0x0b, 0x62, 0x70, 0x9a,
    0xa3, 0x18, 0x2c, 0x3b, 0x9c, 0x2f, 0x2a, 0xf9, 0xf7, 0x38, 0x49, 0x43, 0x9d, 0x50, 0x89, 0x64,
    0x65, 0x8a, 0xe4, 0x7b, 0xf7, 0x2e, 0xef, 0x63, 0x14, 0xac, 0xf3, 0x48, 0x26, 0x30, 0xe6, 0x21,
    0xcd, 0x51, 0xa4, 0x6f, 0x96, 0x87, 0x51, 0xaa, 0xa4, 0x86, 0xdb, 0x59, 0x04, 0x28, 0xc1, 0x5e,
    0x5a, 0x50, 0xaf, 0x2c, 0x15, 0x08, 0x9a, 0x3c, 0xf0, 0xd4, 0x20, 0xf0, 0x70, 0x15, 0xbf, 0xc3,
    0x8e, 0x26, 0x3a, 0x53, 0x2a, 0x25, 0x64, 0x57, 0xc1, 0x02, 0xf2, 0x83, 0xc1, 0x64, 0xa5, 0x55,
    0x3e, 0x79, 0x30, 0x1a, 0x98, 0x2d, 0xc9, 0xb6, 0xd2, 0xca, 0x58, 0x41, 0x10, 0x1b, 0xa3, 0xfc,
    0xf7, 0x47, 0xd0, 0x56, 0x1a, 0x1d, 0x7c, 0x22, 0x88, 0xc6, 0x60, 0xa1, 0x0d, 0x91, 0xd4, 0xfb,
    0xdf, 0x93, 0xa5, 0x31, 0x69, 0x31, 0x68, 0x53, 0x4d, 0x8d, 0x32, 0x18, 0x84, 0xe5, 0xc7, 0x7f,
    0xdf, 0x80, 0x35, 0x2a, 0xa3, 0xe2, 0x8a, 0xd4, 0x54, 0x4e, 0x86, 0x17, 0x37, 0x1d, 0x65, 0x27,
    0x82, 0xc4, 0x1a, 0xcd, 0x57, 0x7e, 0x0e, 0xbf, 0x13, 0x44, 0x80, 0xb3, 0x1a, 0xf2, 0xdf, 0x3c,
    0xfa, 0xcb, 0x21, 0x2e, 0x6d, 0xe4, 0x5f, 0x2b, 0x1d, 0x1b, 0x5e, 0xdf, 0x17, 0x47, 0xbb, 0x2f,
    0x1f, 0x55, 0xf7, 0x5b, 0xb6, 0x40, 0xd1, 0x49, 0x50, 0x15, 0xd5, 0xae, 0xd4, 0x46, 0x79, 0xf1,
    0x2b, 0xfc, 0x49, 0x3b, 0x2d, 0xcf, 0x1e, 0x4f, 0x26, 0x79, 0x25, 0x9b, 0x0d, 0xc2, 0xa5, 0x70,
    0xae, 0x8d, 0x22, 0x42, 0x87, 0x64, 0x83, 0x16, 0x68, 0xb3, 0x8f, 0xc5, 0xf8, 0xce, 0xa1, 0xb6,
    0x02, 0xa5, 0xd0, 0xe4, 0x03, 0xaa, 0x3c, 0x89, 0xcf, 0x95, 0x89, 0x85, 0xaa, 0xe9, 0x6a, 0xa2,
    0xcc, 0xc5, 0xb4, 0xd7, 0x90, 0x0c, 0x9c, 0x85, 0x2f, 0xc3, 0x1e, 0x22, 0xea, 0x1c, 0x2b, 0x1d,
    0x1f, 0x8d, 0x54, 0xfb, 0xf0, 0xf8, 0x39, 0x30, 0xe5, 0x55, 0xa0, 0x0f, 0xc9, 0xa9, 0x0a, 0x15,
    0x0f, 0x36, 0xaa, 0xd1, 0x87, 0xe9, 0xd8, 0xdb, 0x8a, 0x86, 0xfc, 0x12, 0xf7, 0x61, 0xf1, 0xfb,
    0xc1, 0x12, 0x14, 0x87, 0xce, 0x8a, 0x5a, 0x05, 0x71, 0xe5, 0x3a, 0xd7, 0x87, 0xae, 0x44, 0x8d,
    0x90, 0x1c, 0x57, 0x29, 0xa4, 0xeb, 0x72, 0xcb, 0x54, 0xb7, 0xee, 0xbc, 0xec, 0xba, 0xec, 0xfb,
    0xf8, 0x73, 0xf8, 0x1b, 0x8c, 0xd1, 0x1a, 0x59
};
#endif

PyTypeObject *init_QSpline3DSeries(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX].type;

    Shiboken::AutoDecRef Sbk_QSpline3DSeries_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QScatter3DSeries_IDX]))));

    _Sbk_QSpline3DSeries_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSpline3DSeries",
        "QSpline3DSeries*",
        &Sbk_QSpline3DSeries_spec,
        &Shiboken::callCppDestructor< QSpline3DSeries >,
        Sbk_QSpline3DSeries_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSpline3DSeries_TypeF(); // references _Sbk_QSpline3DSeries_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSpline3DSeries_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSpline3DSeries_SignatureBytes, QSpline3DSeries_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSpline3DSeries_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QSpline3DSeries_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSpline3DSeries_PythonToCpp_QSpline3DSeries_PTR,
        is_QSpline3DSeries_PythonToCpp_QSpline3DSeries_PTR_Convertible,
        QSpline3DSeries_PTR_CppToPython_QSpline3DSeries);

    Shiboken::Conversions::registerConverterName(converter, "QSpline3DSeries");
    Shiboken::Conversions::registerConverterName(converter, "QSpline3DSeries*");
    Shiboken::Conversions::registerConverterName(converter, "QSpline3DSeries&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSpline3DSeries).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSpline3DSeriesWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSpline3DSeries_TypeF(), &Sbk_QSpline3DSeries_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QSpline3DSeries::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSpline3DSeries::staticMetaObject, sizeof(QSpline3DSeriesWrapper));

    return pyType;
}
