// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QACCESSIBLEACTIONINTERFACEWRAPPER_H
#define SBK_QACCESSIBLEACTIONINTERFACEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qaccessible.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QAccessibleActionInterfaceWrapper : public QAccessibleActionInterface
{
public:
    QAccessibleActionInterfaceWrapper();
    QAccessibleActionInterfaceWrapper(const QAccessibleActionInterfaceWrapper &) = delete;
    QAccessibleActionInterfaceWrapper& operator=(const QAccessibleActionInterfaceWrapper &) = delete;
    QAccessibleActionInterfaceWrapper(QAccessibleActionInterfaceWrapper &&) = delete;
    QAccessibleActionInterfaceWrapper& operator=(QAccessibleActionInterfaceWrapper &&) = delete;
    ~QAccessibleActionInterfaceWrapper() override;

    ::QStringList actionNames() const override;
    static ::QStringList sbk_o_actionNames(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void doAction(const ::QString & actionName) override;
    static void sbk_o_doAction(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & actionName);
    ::QStringList keyBindingsForAction(const ::QString & actionName) const override;
    static ::QStringList sbk_o_keyBindingsForAction(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & actionName);
    ::QString localizedActionDescription(const ::QString & name) const override;
    static ::QString sbk_o_localizedActionDescription(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & name);
    ::QString localizedActionName(const ::QString & name) const override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[5] = {false, false, false, false, false};
};

#endif // SBK_QACCESSIBLEACTIONINTERFACEWRAPPER_H
