// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QACCESSIBLEINTERFACEWRAPPER_H
#define SBK_QACCESSIBLEINTERFACEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qaccessible.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QAccessibleInterfaceWrapper : public QAccessibleInterface
{
public:
    QAccessibleInterfaceWrapper();
    QAccessibleInterfaceWrapper(const QAccessibleInterfaceWrapper &) = delete;
    QAccessibleInterfaceWrapper& operator=(const QAccessibleInterfaceWrapper &) = delete;
    QAccessibleInterfaceWrapper(QAccessibleInterfaceWrapper &&) = delete;
    QAccessibleInterfaceWrapper& operator=(QAccessibleInterfaceWrapper &&) = delete;
    ~QAccessibleInterfaceWrapper() override;

    ::QColor backgroundColor() const override;
    static ::QColor sbk_o_backgroundColor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QAccessibleInterface * child(int index) const override;
    ::QAccessibleInterface * childAt(int x, int y) const override;
    static ::QAccessibleInterface * sbk_o_childAt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int x, int y);
    int childCount() const override;
    ::QAccessibleInterface * focusChild() const override;
    ::QColor foregroundColor() const override;
    int indexOfChild(const ::QAccessibleInterface * arg__1) const override;
    static int sbk_o_indexOfChild(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QAccessibleInterface * arg__1);
    void * interface_cast(::QAccessible::InterfaceType arg__1) override;
    static void * sbk_o_interface_cast(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAccessible::InterfaceType arg__1);
    bool isValid() const override;
    ::QObject * object() const override;
    static ::QObject * sbk_o_object(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QAccessibleInterface * parent() const override;
    ::QRect rect() const override;
    ::QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>> relations(::QFlags<QAccessible::RelationFlag> match = QAccessible::AllRelations) const override;
    static ::QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>> sbk_o_relations(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<QAccessible::RelationFlag> match = QAccessible::AllRelations);
    ::QAccessible::Role role() const override;
    static ::QAccessible::Role sbk_o_role(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void setText(::QAccessible::Text t, const ::QString & text) override;
    static void sbk_o_setText(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAccessible::Text t, const ::QString & text);
    ::QAccessible::State state() const override;
    static ::QAccessible::State sbk_o_state(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QString text(::QAccessible::Text t) const override;
    static ::QString sbk_o_text(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAccessible::Text t);
    void virtual_hook(int id, void * data) override;
    static void sbk_o_virtual_hook(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int id, void * data);
    ::QWindow * window() const override;
    static ::QWindow * sbk_o_window(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[19] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QACCESSIBLEINTERFACEWRAPPER_H
