// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QACCESSIBLESELECTIONINTERFACEWRAPPER_H
#define SBK_QACCESSIBLESELECTIONINTERFACEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qaccessible.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QAccessibleSelectionInterfaceWrapper : public QAccessibleSelectionInterface
{
public:
    QAccessibleSelectionInterfaceWrapper();
    QAccessibleSelectionInterfaceWrapper(const QAccessibleSelectionInterfaceWrapper &) = delete;
    QAccessibleSelectionInterfaceWrapper& operator=(const QAccessibleSelectionInterfaceWrapper &) = delete;
    QAccessibleSelectionInterfaceWrapper(QAccessibleSelectionInterfaceWrapper &&) = delete;
    QAccessibleSelectionInterfaceWrapper& operator=(QAccessibleSelectionInterfaceWrapper &&) = delete;
    ~QAccessibleSelectionInterfaceWrapper() override;

    bool clear() override;
    bool isSelected(::QAccessibleInterface * childItem) const override;
    static bool sbk_o_isSelected(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAccessibleInterface * childItem);
    bool select(::QAccessibleInterface * childItem) override;
    bool selectAll() override;
    ::QAccessibleInterface * selectedItem(int selectionIndex) const override;
    static ::QAccessibleInterface * sbk_o_selectedItem(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int selectionIndex);
    int selectedItemCount() const override;
    ::QList<QAccessibleInterface*> selectedItems() const override;
    bool unselect(::QAccessibleInterface * childItem) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[8] = {false, false, false, false, false, false, false, false};
};

#endif // SBK_QACCESSIBLESELECTIONINTERFACEWRAPPER_H
