// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QACCESSIBLETEXTINTERFACEWRAPPER_H
#define SBK_QACCESSIBLETEXTINTERFACEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qaccessible.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QAccessibleTextInterfaceWrapper : public QAccessibleTextInterface
{
public:
    QAccessibleTextInterfaceWrapper();
    QAccessibleTextInterfaceWrapper(const QAccessibleTextInterfaceWrapper &) = delete;
    QAccessibleTextInterfaceWrapper& operator=(const QAccessibleTextInterfaceWrapper &) = delete;
    QAccessibleTextInterfaceWrapper(QAccessibleTextInterfaceWrapper &&) = delete;
    QAccessibleTextInterfaceWrapper& operator=(QAccessibleTextInterfaceWrapper &&) = delete;
    ~QAccessibleTextInterfaceWrapper() override;

    void addSelection(int startOffset, int endOffset) override;
    static void sbk_o_addSelection(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int startOffset, int endOffset);
    ::QString attributes(int offset, int * startOffset, int * endOffset) const override;
    static ::QString sbk_o_attributes(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int offset, int * startOffset, int * endOffset);
    int characterCount() const override;
    ::QRect characterRect(int offset) const override;
    static ::QRect sbk_o_characterRect(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int offset);
    int cursorPosition() const override;
    int offsetAtPoint(const ::QPoint & point) const override;
    static int sbk_o_offsetAtPoint(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPoint & point);
    void removeSelection(int selectionIndex) override;
    static void sbk_o_removeSelection(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int selectionIndex);
    void scrollToSubstring(int startIndex, int endIndex) override;
    void selection(int selectionIndex, int * startOffset, int * endOffset) const override;
    static void sbk_o_selection(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int selectionIndex, int * startOffset, int * endOffset);
    int selectionCount() const override;
    void setCursorPosition(int position) override;
    void setSelection(int selectionIndex, int startOffset, int endOffset) override;
    static void sbk_o_setSelection(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int selectionIndex, int startOffset, int endOffset);
    ::QString text(int startOffset, int endOffset) const override;
    static ::QString sbk_o_text(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int startOffset, int endOffset);
    ::QString textAfterOffset(int offset, ::QAccessible::TextBoundaryType boundaryType, int * startOffset, int * endOffset) const override;
    static ::QString sbk_o_textAfterOffset(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int offset, ::QAccessible::TextBoundaryType boundaryType, int * startOffset, int * endOffset);
    ::QString textAtOffset(int offset, ::QAccessible::TextBoundaryType boundaryType, int * startOffset, int * endOffset) const override;
    ::QString textBeforeOffset(int offset, ::QAccessible::TextBoundaryType boundaryType, int * startOffset, int * endOffset) const override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[16] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QACCESSIBLETEXTINTERFACEWRAPPER_H
