// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QDROPEVENTWRAPPER_H
#define SBK_QDROPEVENTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QDropEventWrapper : public QDropEvent
{
public:
    QDropEventWrapper(const ::QPointF & pos, ::QFlags<Qt::DropAction> actions, const ::QMimeData * data, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, ::QEvent::Type type = QEvent::Type::Drop);
    QDropEventWrapper(const QDropEventWrapper &) = delete;
    QDropEventWrapper(const QDropEvent& self) : QDropEvent(self)
    {
    }
    QDropEventWrapper& operator=(const QDropEventWrapper &) = delete;
    QDropEventWrapper(QDropEventWrapper &&) = delete;
    QDropEventWrapper& operator=(QDropEventWrapper &&) = delete;
    ~QDropEventWrapper() override;

    ::QDropEvent * clone() const override;
    static ::QDropEvent * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void setAccepted(bool accepted) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[2] = {false, false};
};

#endif // SBK_QDROPEVENTWRAPPER_H
