// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QHOVEREVENTWRAPPER_H
#define SBK_QHOVEREVENTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QHoverEventWrapper : public QHoverEvent
{
public:
    QHoverEventWrapper(::QEvent::Type type, const ::QPointF & pos, const ::QPointF & oldPos, ::QFlags<Qt::KeyboardModifier> modifiers = Qt::NoModifier, const ::QPointingDevice * device = QPointingDevice::primaryPointingDevice());
    QHoverEventWrapper(::QEvent::Type type, const ::QPointF & scenePos, const ::QPointF & globalPos, const ::QPointF & oldPos, ::QFlags<Qt::KeyboardModifier> modifiers = Qt::NoModifier, const ::QPointingDevice * device = QPointingDevice::primaryPointingDevice());
    QHoverEventWrapper(const QHoverEventWrapper &) = delete;
    QHoverEventWrapper(const QHoverEvent& self) : QHoverEvent(self)
    {
    }
    QHoverEventWrapper& operator=(const QHoverEventWrapper &) = delete;
    QHoverEventWrapper(QHoverEventWrapper &&) = delete;
    QHoverEventWrapper& operator=(QHoverEventWrapper &&) = delete;
    ~QHoverEventWrapper() override;

    ::QHoverEvent * clone() const override;
    static ::QHoverEvent * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted) override;
    void setTimestamp(quint64 timestamp) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QHOVEREVENTWRAPPER_H
