// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QICONENGINEWRAPPER_H
#define SBK_QICONENGINEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qiconengine.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QIconEngineWrapper : public QIconEngine
{
public:
    QIconEngineWrapper();
    QIconEngineWrapper(const QIconEngineWrapper &) = delete;
    QIconEngineWrapper(const QIconEngine& self) : QIconEngine(self)
    {
    }
    QIconEngineWrapper& operator=(const QIconEngineWrapper &) = delete;
    QIconEngineWrapper(QIconEngineWrapper &&) = delete;
    QIconEngineWrapper& operator=(QIconEngineWrapper &&) = delete;
    ~QIconEngineWrapper() override;

    ::QSize actualSize(const ::QSize & size, ::QIcon::Mode mode, ::QIcon::State state) override;
    static ::QSize sbk_o_actualSize(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QSize & size, ::QIcon::Mode mode, ::QIcon::State state);
    void addFile(const ::QString & fileName, const ::QSize & size, ::QIcon::Mode mode, ::QIcon::State state) override;
    static void sbk_o_addFile(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & fileName, const ::QSize & size, ::QIcon::Mode mode, ::QIcon::State state);
    void addPixmap(const ::QPixmap & pixmap, ::QIcon::Mode mode, ::QIcon::State state) override;
    static void sbk_o_addPixmap(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPixmap & pixmap, ::QIcon::Mode mode, ::QIcon::State state);
    ::QList<QSize> availableSizes(::QIcon::Mode mode = QIcon::Normal, ::QIcon::State state = QIcon::Off) override;
    static ::QList<QSize> sbk_o_availableSizes(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QIcon::Mode mode = QIcon::Normal, ::QIcon::State state = QIcon::Off);
    ::QIconEngine * clone() const override;
    static ::QIconEngine * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QString iconName() override;
    static ::QString sbk_o_iconName(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isNull() override;
    ::QString key() const override;
    void paint(::QPainter * painter, const ::QRect & rect, ::QIcon::Mode mode, ::QIcon::State state) override;
    static void sbk_o_paint(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QRect & rect, ::QIcon::Mode mode, ::QIcon::State state);
    ::QPixmap pixmap(const ::QSize & size, ::QIcon::Mode mode, ::QIcon::State state) override;
    static ::QPixmap sbk_o_pixmap(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QSize & size, ::QIcon::Mode mode, ::QIcon::State state);
    bool read(::QDataStream & in) override;
    static bool sbk_o_read(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QDataStream & in);
    ::QPixmap scaledPixmap(const ::QSize & size, ::QIcon::Mode mode, ::QIcon::State state, qreal scale) override;
    static ::QPixmap sbk_o_scaledPixmap(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QSize & size, ::QIcon::Mode mode, ::QIcon::State state, qreal scale);
    bool write(::QDataStream & out) const override;
    static bool sbk_o_write(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QDataStream & out);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[13] = {false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QICONENGINEWRAPPER_H
