// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QIMAGEIOHANDLERWRAPPER_H
#define SBK_QIMAGEIOHANDLERWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qimageiohandler.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QImageIOHandlerWrapper : public QImageIOHandler
{
public:
    QImageIOHandlerWrapper();
    QImageIOHandlerWrapper(const QImageIOHandlerWrapper &) = delete;
    QImageIOHandlerWrapper& operator=(const QImageIOHandlerWrapper &) = delete;
    QImageIOHandlerWrapper(QImageIOHandlerWrapper &&) = delete;
    QImageIOHandlerWrapper& operator=(QImageIOHandlerWrapper &&) = delete;
    ~QImageIOHandlerWrapper() override;

    bool canRead() const override;
    int currentImageNumber() const override;
    ::QRect currentImageRect() const override;
    static ::QRect sbk_o_currentImageRect(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    int imageCount() const override;
    bool jumpToImage(int imageNumber) override;
    static bool sbk_o_jumpToImage(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int imageNumber);
    bool jumpToNextImage() override;
    int loopCount() const override;
    int nextImageDelay() const override;
    ::QVariant option(::QImageIOHandler::ImageOption option) const override;
    static ::QVariant sbk_o_option(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QImageIOHandler::ImageOption option);
    bool read(::QImage * image) override;
    static bool sbk_o_read(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QImage * image);
    void setOption(::QImageIOHandler::ImageOption option, const ::QVariant & value) override;
    static void sbk_o_setOption(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QImageIOHandler::ImageOption option, const ::QVariant & value);
    bool supportsOption(::QImageIOHandler::ImageOption option) const override;
    static bool sbk_o_supportsOption(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QImageIOHandler::ImageOption option);
    bool write(const ::QImage & image) override;
    static bool sbk_o_write(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QImage & image);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[13] = {false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QIMAGEIOHANDLERWRAPPER_H
