// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QINPUTEVENTWRAPPER_H
#define SBK_QINPUTEVENTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QInputEventWrapper : public QInputEvent
{
public:
    QInputEventWrapper(::QEvent::Type type, const ::QInputDevice * m_dev, ::QFlags<Qt::KeyboardModifier> modifiers = Qt::NoModifier);
    QInputEventWrapper(const QInputEventWrapper &) = delete;
    QInputEventWrapper(const QInputEvent& self) : QInputEvent(self)
    {
    }
    QInputEventWrapper& operator=(const QInputEventWrapper &) = delete;
    QInputEventWrapper(QInputEventWrapper &&) = delete;
    QInputEventWrapper& operator=(QInputEventWrapper &&) = delete;
    ~QInputEventWrapper() override;

    ::QInputEvent * clone() const override;
    static ::QInputEvent * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void setAccepted(bool accepted) override;
    void setTimestamp(quint64 timestamp) override;
    static void sbk_o_setTimestamp(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, quint64 timestamp);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[3] = {false, false, false};
};

#endif // SBK_QINPUTEVENTWRAPPER_H
