// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QKEYEVENTWRAPPER_H
#define SBK_QKEYEVENTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QKeyEventWrapper : public QKeyEvent
{
public:
    QKeyEventWrapper(::QEvent::Type type, int key, ::QFlags<Qt::KeyboardModifier> modifiers, const ::QString & text = QString(), bool autorep = false, quint16 count = 1);
    QKeyEventWrapper(::QEvent::Type type, int key, ::QFlags<Qt::KeyboardModifier> modifiers, quint32 nativeScanCode, quint32 nativeVirtualKey, quint32 nativeModifiers, const ::QString & text = QString(), bool autorep = false, quint16 count = 1, const ::QInputDevice * device = QInputDevice::primaryKeyboard());
    QKeyEventWrapper(const QKeyEventWrapper &) = delete;
    QKeyEventWrapper(const QKeyEvent& self) : QKeyEvent(self)
    {
    }
    QKeyEventWrapper& operator=(const QKeyEventWrapper &) = delete;
    QKeyEventWrapper(QKeyEventWrapper &&) = delete;
    QKeyEventWrapper& operator=(QKeyEventWrapper &&) = delete;
    ~QKeyEventWrapper() override;

    ::QKeyEvent * clone() const override;
    static ::QKeyEvent * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void setAccepted(bool accepted) override;
    void setTimestamp(quint64 timestamp) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[3] = {false, false, false};
};

#endif // SBK_QKEYEVENTWRAPPER_H
