// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qmatrix4x4_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qgenericmatrix.h>
#include <QtGui/qmatrix4x4.h>
#include <QtGui/qquaternion.h>
#include <QtGui/qtransform.h>
#include <QtGui/qvectornd.h>
#include <qdatastream.h>
#include <qpoint.h>
#include <qrect.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMatrix4x4_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMatrix4x4 >()))
        return -1;

    ::QMatrix4x4 *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[16];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5 || numArgs == 6 || numArgs == 7 || numArgs == 8 || numArgs == 9 || numArgs == 10 || numArgs == 11 || numArgs == 12 || numArgs == 13 || numArgs == 14 || numArgs == 15)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    if (PyArg_UnpackTuple(args, "QMatrix4x4", 0, 16, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9]), &(pyArgs[10]), &(pyArgs[11]), &(pyArgs[12]), &(pyArgs[13]), &(pyArgs[14]), &(pyArgs[15])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMatrix4x4::QMatrix4x4()
    // 1: QMatrix4x4::QMatrix4x4(QMatrix4x4)
    // 2: QMatrix4x4::QMatrix4x4(QTransform)
    // 3: QMatrix4x4::QMatrix4x4(PySequence)
    // 4: QMatrix4x4::QMatrix4x4(float,float,float,float,float,float,float,float,float,float,float,float,float,float,float,float)
    if (numArgs == 0) {
        overloadId = 0; // QMatrix4x4()
    } else if (numArgs == 16
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[7])))
        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[8])))
        && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[9])))
        && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[10])))
        && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[11])))
        && (pythonToCpp[12] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[12])))
        && (pythonToCpp[13] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[13])))
        && (pythonToCpp[14] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[14])))
        && (pythonToCpp[15] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[15])))) {
        overloadId = 4; // QMatrix4x4(float,float,float,float,float,float,float,float,float,float,float,float,float,float,float,float)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QMatrix4x4(QTransform)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QMatrix4x4(QMatrix4x4)
    } else if (numArgs == 1
        && Shiboken::String::checkIterableArgument(pyArgs[0])) {
        overloadId = 3; // QMatrix4x4(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QMatrix4x4()
        {

            // QMatrix4x4()
            cptr = new ::QMatrix4x4();
            break;
        }
        case 1: // QMatrix4x4(const QMatrix4x4 &QMatrix4x4)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QMatrix4x4 cppArg0_local;
            ::QMatrix4x4 *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QMatrix4x4(QMatrix4x4)
                cptr = new ::QMatrix4x4(*cppArg0);
            }
            break;
        }
        case 2: // QMatrix4x4(const QTransform &transform)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTransform cppArg0_local;
            ::QTransform *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QMatrix4x4(QTransform)
                cptr = new ::QMatrix4x4(*cppArg0);
            }
            break;
        }
        case 3: // QMatrix4x4(const float *values)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMatrix4x4(const float*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qmatrix4x4)]
                // PYSIDE-795: All PySequences can be made iterable with PySequence_Fast.
                Shiboken::AutoDecRef seq(PySequence_Fast(pyArgs[1-1], "Can't turn into sequence"));
                if (PySequence_Size(seq) == 16) {
                    float values[16];
                    for (Py_ssize_t i = 0; i < 16; ++i) {
                        Shiboken::AutoDecRef pv(PySequence_GetItem(seq.object(), i));
                        values[i] = PyFloat_AsDouble(pv);
                    }

                    cptr = new QMatrix4x4(values[0], values[1], values[2], values[3],
                                   values[4], values[5], values[6], values[7],
                                   values[8], values[9], values[10], values[11],
                                   values[12], values[13], values[14], values[15]);
                }
                // END of custom code block [file: ../glue/qtgui.cpp (qmatrix4x4)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 4: // QMatrix4x4(float m11, float m12, float m13, float m14, float m21, float m22, float m23, float m24, float m31, float m32, float m33, float m34, float m41, float m42, float m43, float m44)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            float cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            float cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            float cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            float cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);
            float cppArg8;
            pythonToCpp[8](pyArgs[8], &cppArg8);
            float cppArg9;
            pythonToCpp[9](pyArgs[9], &cppArg9);
            float cppArg10;
            pythonToCpp[10](pyArgs[10], &cppArg10);
            float cppArg11;
            pythonToCpp[11](pyArgs[11], &cppArg11);
            float cppArg12;
            pythonToCpp[12](pyArgs[12], &cppArg12);
            float cppArg13;
            pythonToCpp[13](pyArgs[13], &cppArg13);
            float cppArg14;
            pythonToCpp[14](pyArgs[14], &cppArg14);
            float cppArg15;
            pythonToCpp[15](pyArgs[15], &cppArg15);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMatrix4x4(float,float,float,float,float,float,float,float,float,float,float,float,float,float,float,float)
                cptr = new ::QMatrix4x4(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12, cppArg13, cppArg14, cppArg15);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMatrix4x4 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMatrix4x4Func___dummy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix4x4::__dummy(QList<float>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_float_IDX], (pyArg)))) {
        overloadId = 0; // __dummy(QList<float>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "__dummy", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        ::QList<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // __dummy(QList<float>)
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // TEMPLATE - reduce_code_matrix - START
        float data[16];
        cppSelf->copyDataTo(data);
        QList<float> cppArgs(data, data + 16);
        PyObject *type = PyObject_Type(self);
        PyObject *args = Py_BuildValue("(N)",
                                       Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_float_IDX], &cppArgs));
        pyResult = Py_BuildValue("(NN)", type, args);
        // TEMPLATE - reduce_code_matrix - END
        // End of code injection

    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - repr_code_matrix - START
        QByteArray format(Py_TYPE(self)->tp_name);
        format += QByteArrayLiteral("((");
        float data[16];
        cppSelf->copyDataTo(data);
        for (int i = 0; i < 16; ++i) {
            if (i > 0)
                format += ", ";
            format += QByteArray::number(data[i]);
        }
        format += "))";

        pyResult = Shiboken::String::fromStringAndSize(format, format.size());
        // TEMPLATE - repr_code_matrix - END
        // End of code injection

    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_column(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix4x4::column(int)const->QVector4D
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // column(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "column", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // column(int)const
            QVector4D cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->column(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_copyDataTo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // copyDataTo(float*)const
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qmatrix4x4-copydatato)]
            float values[16];
            cppSelf->copyDataTo(values);
            pyResult = PyTuple_New(16);
            for (Py_ssize_t i = 0; i < 16; ++i) {
              PyObject *v = PyFloat_FromDouble(values[i]);
              PyTuple_SetItem(pyResult, i, v);
            }
            // END of custom code block [file: ../glue/qtgui.cpp (qmatrix4x4-copydatato)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()
        // Begin code injection
        // TEMPLATE - matrix_data_function - START
        PyObject *pyData = PyTuple_New(16);
        if (const float *data = cppSelf->constData()) {
            for (int i = 0; i < 16; ++i)
                PyTuple_SetItem(pyData, i, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &data[i]));
        }
        return pyData;
        // TEMPLATE - matrix_data_function - END
        // End of code injection

        float * cppResult = cppSelf->data();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_determinant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // determinant()const
        double cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->determinant();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_fill(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix4x4::fill(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // fill(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fill", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fill(float)
            cppSelf->fill(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QMatrix4x4::Flag> cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QMatrix4x4_Flag_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_flipCoordinates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flipCoordinates()
        cppSelf->flipCoordinates();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func_frustum(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "frustum", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMatrix4x4::frustum(float,float,float,float,float,float)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[5])))) {
        overloadId = 0; // frustum(float,float,float,float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "frustum", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        float cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        float cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // frustum(float,float,float,float,float,float)
            cppSelf->frustum(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func_inverted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        bool* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // inverted(bool*)const
            // Begin code injection
            // TEMPLATE - fix_bool* - START
            bool ok_;
            ::QMatrix4x4 retval_ = cppSelf->inverted(&ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool* - END
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_isAffine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAffine()const
        bool cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->isAffine();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_isIdentity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isIdentity()const
        bool cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->isIdentity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_lookAt(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "lookAt", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMatrix4x4::lookAt(QVector3D,QVector3D,QVector3D)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[2])))) {
        overloadId = 0; // lookAt(QVector3D,QVector3D,QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "lookAt", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVector3D cppArg1_local;
        ::QVector3D *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QVector3D cppArg2_local;
        ::QVector3D *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // lookAt(QVector3D,QVector3D,QVector3D)
            cppSelf->lookAt(*cppArg0, *cppArg1, *cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func_map(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix4x4::map(QPoint)const->QPoint
    // 1: QMatrix4x4::map(QPointF)const->QPointF
    // 2: QMatrix4x4::map(QVector3D)const->QVector3D
    // 3: QMatrix4x4::map(QVector4D)const->QVector4D
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArg)))) {
        overloadId = 3; // map(QVector4D)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 2; // map(QVector3D)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // map(QPoint)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 1; // map(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "map", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // map(const QPoint &point) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QPoint)const
                QPoint cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->map(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
            }
            break;
        }
        case 1: // map(const QPointF &point) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QPointF)const
                QPointF cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->map(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
            }
            break;
        }
        case 2: // map(const QVector3D &point) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QVector3D cppArg0_local;
            ::QVector3D *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QVector3D)const
                QVector3D cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->map(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
            }
            break;
        }
        case 3: // map(const QVector4D &point) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QVector4D cppArg0_local;
            ::QVector4D *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // map(QVector4D)const
                QVector4D cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->map(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_mapRect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix4x4::mapRect(QRect)const->QRect
    // 1: QMatrix4x4::mapRect(QRectF)const->QRectF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArg)))) {
        overloadId = 0; // mapRect(QRect)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
        overloadId = 1; // mapRect(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mapRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mapRect(const QRect &rect) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // mapRect(QRect)const
                QRect cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->mapRect(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
            }
            break;
        }
        case 1: // mapRect(const QRectF &rect) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // mapRect(QRectF)const
                QRectF cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->mapRect(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_mapVector(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix4x4::mapVector(QVector3D)const->QVector3D
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // mapVector(QVector3D)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mapVector", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mapVector(QVector3D)const
            QVector3D cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->mapVector(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_normalMatrix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // normalMatrix()const
        QMatrix3x3 cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->normalMatrix();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x3_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_optimize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // optimize()
        cppSelf->optimize();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func_ortho(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5)
        return Shiboken::returnWrongArguments(args, "ortho", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    if (PyArg_UnpackTuple(args, "ortho", 1, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMatrix4x4::ortho(QRect)
    // 1: QMatrix4x4::ortho(QRectF)
    // 2: QMatrix4x4::ortho(float,float,float,float,float,float)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[5])))) {
        overloadId = 2; // ortho(float,float,float,float,float,float)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))) {
        overloadId = 0; // ortho(QRect)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        overloadId = 1; // ortho(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "ortho", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // ortho(const QRect &rect)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // ortho(QRect)
                cppSelf->ortho(*cppArg0);
            }
            break;
        }
        case 1: // ortho(const QRectF &rect)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // ortho(QRectF)
                cppSelf->ortho(*cppArg0);
            }
            break;
        }
        case 2: // ortho(float left, float right, float bottom, float top, float nearPlane, float farPlane)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            float cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            float cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // ortho(float,float,float,float,float,float)
                cppSelf->ortho(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func_perspective(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "perspective", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMatrix4x4::perspective(float,float,float,float)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 0; // perspective(float,float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "perspective", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // perspective(float,float,float,float)
            cppSelf->perspective(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func_projectedRotate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "projectedRotate", 4, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMatrix4x4::projectedRotate(float,float,float,float)
    // 1: QMatrix4x4::projectedRotate(float,float,float,float,float)
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 0; // projectedRotate(float,float,float,float)
        } else if (numArgs == 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4])))) {
            overloadId = 1; // projectedRotate(float,float,float,float,float)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "projectedRotate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // projectedRotate(float angle, float x, float y, float z)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // projectedRotate(float,float,float,float)
                cppSelf->projectedRotate(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 1: // projectedRotate(float angle, float x, float y, float z, float distanceToPlane)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            float cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // projectedRotate(float,float,float,float,float)
                cppSelf->projectedRotate(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func_rotate(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "rotate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:rotate", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMatrix4x4::rotate(QQuaternion)
    // 1: QMatrix4x4::rotate(float,QVector3D)
    // 2: QMatrix4x4::rotate(float,float,float,float=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 2; // rotate(float,float,float,float)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
                overloadId = 2; // rotate(float,float,float,float)
            }
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))) {
            overloadId = 1; // rotate(float,QVector3D)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArgs[0])))) {
        overloadId = 0; // rotate(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rotate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // rotate(const QQuaternion &quaternion)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "rotate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQuaternion cppArg0_local;
            ::QQuaternion *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // rotate(QQuaternion)
                cppSelf->rotate(*cppArg0);
            }
            break;
        }
        case 1: // rotate(float angle, const QVector3D &vector)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "rotate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);
            }
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector3D cppArg1_local;
            ::QVector3D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // rotate(float,QVector3D)
                cppSelf->rotate(cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // rotate(float angle, float x, float y, float z)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"z", 3}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "rotate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);
                }
            }
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3 = 0.0f;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // rotate(float,float,float,float)
                cppSelf->rotate(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func_row(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix4x4::row(int)const->QVector4D
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // row(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "row", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // row(int)const
            QVector4D cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->row(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_scale(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "scale", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMatrix4x4::scale(QVector3D)
    // 1: QMatrix4x4::scale(float)
    // 2: QMatrix4x4::scale(float,float)
    // 3: QMatrix4x4::scale(float,float,float)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // scale(float)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // scale(float,float)
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
                overloadId = 3; // scale(float,float,float)
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))) {
        overloadId = 0; // scale(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scale", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // scale(const QVector3D &vector)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector3D cppArg0_local;
            ::QVector3D *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // scale(QVector3D)
                cppSelf->scale(*cppArg0);
            }
            break;
        }
        case 1: // scale(float factor)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // scale(float)
                cppSelf->scale(cppArg0);
            }
            break;
        }
        case 2: // scale(float x, float y)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // scale(float,float)
                cppSelf->scale(cppArg0, cppArg1);
            }
            break;
        }
        case 3: // scale(float x, float y, float z)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // scale(float,float,float)
                cppSelf->scale(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func_setColumn(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setColumn", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMatrix4x4::setColumn(int,QVector4D)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setColumn(int,QVector4D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setColumn", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVector4D cppArg1_local;
        ::QVector4D *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setColumn(int,QVector4D)
            cppSelf->setColumn(cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func_setRow(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setRow", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMatrix4x4::setRow(int,QVector4D)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setRow(int,QVector4D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QVector4D cppArg1_local;
        ::QVector4D *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRow(int,QVector4D)
            cppSelf->setRow(cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func_setToIdentity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // setToIdentity()
        cppSelf->setToIdentity();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func_toTransform(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "toTransform", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMatrix4x4::toTransform()const->QTransform
    // 1: QMatrix4x4::toTransform(float)const->QTransform
    if (numArgs == 0) {
        overloadId = 0; // toTransform()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))) {
        overloadId = 1; // toTransform(float)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toTransform", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // toTransform() const
        {

            // toTransform()const
            QTransform cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->toTransform();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
            break;
        }
        case 1: // toTransform(float distanceToPlane) const
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toTransform(float)const
                QTransform cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->toTransform(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_translate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "translate", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMatrix4x4::translate(QVector3D)
    // 1: QMatrix4x4::translate(float,float)
    // 2: QMatrix4x4::translate(float,float,float)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // translate(float,float)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
            overloadId = 2; // translate(float,float,float)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))) {
        overloadId = 0; // translate(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "translate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // translate(const QVector3D &vector)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector3D cppArg0_local;
            ::QVector3D *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // translate(QVector3D)
                cppSelf->translate(*cppArg0);
            }
            break;
        }
        case 1: // translate(float x, float y)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // translate(float,float)
                cppSelf->translate(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // translate(float x, float y, float z)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // translate(float,float,float)
                cppSelf->translate(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4Func_transposed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transposed()const
        QMatrix4x4 cppResult = const_cast<const ::QMatrix4x4 *>(cppSelf)->transposed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func_viewport(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "viewport", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, "viewport", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:viewport", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMatrix4x4::viewport(QRectF)
    // 1: QMatrix4x4::viewport(float,float,float,float,float=,float=)
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 1; // viewport(float,float,float,float,float,float)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4])))) {
            if (numArgs == 5) {
                overloadId = 1; // viewport(float,float,float,float,float,float)
            } else if (numArgs >= 6
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[5])))) {
                overloadId = 1; // viewport(float,float,float,float,float,float)
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // viewport(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "viewport", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // viewport(const QRectF &rect)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "viewport", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // viewport(QRectF)
                cppSelf->viewport(*cppArg0);
            }
            break;
        }
        case 1: // viewport(float left, float bottom, float width, float height, float nearPlane, float farPlane)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"nearPlane", 4}, {"farPlane", 5}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4]))))
                    || (pyArgs[5] != nullptr && !(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[5]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "viewport", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);
                }
            }
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            float cppArg4 = 0.0f;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            float cppArg5 = 1.0f;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // viewport(float,float,float,float,float,float)
                cppSelf->viewport(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMatrix4x4__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMatrix4x4_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QMatrix4x4_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMatrix4x4_methods[] = {
    {"__dummy", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func___dummy), METH_O, nullptr},
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func___reduce__), METH_NOARGS, nullptr},
    {"column", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_column), METH_O, nullptr},
    {"copyDataTo", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_copyDataTo), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_data), METH_NOARGS, nullptr},
    {"determinant", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_determinant), METH_NOARGS, nullptr},
    {"fill", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_fill), METH_O, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_flags), METH_NOARGS, nullptr},
    {"flipCoordinates", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_flipCoordinates), METH_NOARGS, nullptr},
    {"frustum", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_frustum), METH_VARARGS, nullptr},
    {"inverted", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_inverted), METH_NOARGS, nullptr},
    {"isAffine", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_isAffine), METH_NOARGS, nullptr},
    {"isIdentity", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_isIdentity), METH_NOARGS, nullptr},
    {"lookAt", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_lookAt), METH_VARARGS, nullptr},
    {"map", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_map), METH_O, nullptr},
    {"mapRect", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_mapRect), METH_O, nullptr},
    {"mapVector", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_mapVector), METH_O, nullptr},
    {"normalMatrix", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_normalMatrix), METH_NOARGS, nullptr},
    {"optimize", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_optimize), METH_NOARGS, nullptr},
    {"ortho", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_ortho), METH_VARARGS, nullptr},
    {"perspective", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_perspective), METH_VARARGS, nullptr},
    {"projectedRotate", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_projectedRotate), METH_VARARGS, nullptr},
    {"rotate", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_rotate), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"row", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_row), METH_O, nullptr},
    {"scale", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_scale), METH_VARARGS, nullptr},
    {"setColumn", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_setColumn), METH_VARARGS, nullptr},
    {"setRow", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_setRow), METH_VARARGS, nullptr},
    {"setToIdentity", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_setToIdentity), METH_NOARGS, nullptr},
    {"toTransform", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_toTransform), METH_VARARGS, nullptr},
    {"translate", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_translate), METH_VARARGS, nullptr},
    {"transposed", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_transposed), METH_NOARGS, nullptr},
    {"viewport", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4Func_viewport), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QMatrix4x4__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QMatrix4x4Func___mul__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix4x4::operator*(QMatrix4x4)->QMatrix4x4
    // 1: QMatrix4x4::operator*(QPoint)->QPoint
    // 2: QMatrix4x4::operator*(QPointF)->QPointF
    // 3: QMatrix4x4::operator*(float)->QMatrix4x4
    // 4: QMatrix4x4::operator*(float)->QMatrix4x4
    if (isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 4; // operator*(float,QMatrix4x4)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 3; // operator*(QMatrix4x4,float)
    } else if (isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 1; // operator*(QPoint,QMatrix4x4)
    } else if (isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 2; // operator*(QPointF,QMatrix4x4)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArg)))) {
        overloadId = 0; // operator*(QMatrix4x4,QMatrix4x4)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator*", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // operator*(const QMatrix4x4 &m2)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QMatrix4x4 cppArg0_local;
            ::QMatrix4x4 *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QMatrix4x4,QMatrix4x4)
                QMatrix4x4 cppResult = (*cppSelf) * (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
            }
            break;
        }
        case 1: // operator*(const QPoint &point)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QPoint,QMatrix4x4) [reverse operator]
                QPoint cppResult = (*cppArg0) * (*cppSelf);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
            }
            break;
        }
        case 2: // operator*(const QPointF &point)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QPointF,QMatrix4x4) [reverse operator]
                QPointF cppResult = (*cppArg0) * (*cppSelf);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
            }
            break;
        }
        case 3: // operator*(float factor)
        {
            float cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(QMatrix4x4,float)
                QMatrix4x4 cppResult = (*cppSelf) * cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
            }
            break;
        }
        case 4: // operator*(float factor)
        {
            float cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*(float,QMatrix4x4) [reverse operator]
                QMatrix4x4 cppResult = cppArg0 * (*cppSelf);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func___imul__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix4x4::operator*=(QMatrix4x4)->QMatrix4x4&
    // 1: QMatrix4x4::operator*=(float)->QMatrix4x4&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 1; // operator*=(float)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArg)))) {
        overloadId = 0; // operator*=(QMatrix4x4)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator*=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // operator*=(const QMatrix4x4 &other)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QMatrix4x4 cppArg0_local;
            ::QMatrix4x4 *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*=(QMatrix4x4)
                (*cppSelf) *= (*cppArg0);
            }
            break;
        }
        case 1: // operator*=(float factor)
        {
            float cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator*=(float)
                (*cppSelf) *= cppArg0;
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Self(self);
}

static PyObject *Sbk_QMatrix4x4Func___add__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix4x4::operator+(QMatrix4x4)->QMatrix4x4
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArg)))) {
        overloadId = 0; // operator+(QMatrix4x4,QMatrix4x4)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMatrix4x4 cppArg0_local;
        ::QMatrix4x4 *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+(QMatrix4x4,QMatrix4x4)
            QMatrix4x4 cppResult = (*cppSelf) + (*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix4x4::operator+=(QMatrix4x4)->QMatrix4x4&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArg)))) {
        overloadId = 0; // operator+=(QMatrix4x4)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMatrix4x4 cppArg0_local;
        ::QMatrix4x4 *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+=(QMatrix4x4)
            (*cppSelf) += (*cppArg0);
        }
    }

    return Sbk_ReturnFromPython_Self(self);
}

static PyObject *Sbk_QMatrix4x4Func___neg__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // operator-(QMatrix4x4)
        QMatrix4x4 cppResult = - (*cppSelf);
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func___sub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix4x4::operator-(QMatrix4x4)->QMatrix4x4
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArg)))) {
        overloadId = 0; // operator-(QMatrix4x4,QMatrix4x4)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMatrix4x4 cppArg0_local;
        ::QMatrix4x4 *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-(QMatrix4x4,QMatrix4x4)
            QMatrix4x4 cppResult = (*cppSelf) - (*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func___isub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix4x4::operator-=(QMatrix4x4)->QMatrix4x4&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArg)))) {
        overloadId = 0; // operator-=(QMatrix4x4)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-=", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMatrix4x4 cppArg0_local;
        ::QMatrix4x4 *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-=(QMatrix4x4)
            (*cppSelf) -= (*cppArg0);
        }
    }

    return Sbk_ReturnFromPython_Self(self);
}

static PyObject *Sbk_QMatrix4x4Func___div__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMatrix4x4::operator/(float)->QMatrix4x4
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // operator/(QMatrix4x4,float)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator/", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator/(QMatrix4x4,float)
            QMatrix4x4 cppResult = (*cppSelf) / cppArg0;
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QMatrix4x4::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QMatrix4x4)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QMatrix4x4) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMatrix4x4Func___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QMatrix4x4::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QMatrix4x4&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QMatrix4x4&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    return Sbk_ReturnFromPython_Result(pyResult);
}

PyObject* Sbk_QMatrix4x4Func___mgetitem__(PyObject *self, PyObject *_key)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtgui.cpp (qmatrix4x4-mgetitem)]
    if (PySequence_Check(_key)) {
        Shiboken::AutoDecRef key(PySequence_Fast(_key, "Invalid matrix index."));
        if (PySequence_Size(key.object()) == 2) {
            Shiboken::AutoDecRef posx(PySequence_GetItem(key.object(), 0));
            Shiboken::AutoDecRef posy(PySequence_GetItem(key.object(), 1));
            Py_ssize_t x = PyLong_AsSsize_t(posx);
            Py_ssize_t y = PyLong_AsSsize_t(posy);
            float ret = (*cppSelf)(x,y);
            return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &ret);
        }
    }
    PyErr_SetString(PyExc_IndexError, "Invalid matrix index.");
    return 0;
    // END of custom code block [file: ../glue/qtgui.cpp (qmatrix4x4-mgetitem)]
    // ========================================================================
    // End of code injection

}

// Rich comparison
static PyObject * Sbk_QMatrix4x4_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArg)))) {
                // operator!=(const QMatrix4x4 &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMatrix4x4 cppArg0_local;
                ::QMatrix4x4 *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArg)))) {
                // operator==(const QMatrix4x4 &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMatrix4x4 cppArg0_local;
                ::QMatrix4x4 *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QMatrix4x4_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMatrix4x4_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMatrix4x4_Type = nullptr;
static PyTypeObject *Sbk_QMatrix4x4_TypeF(void)
{
    return _Sbk_QMatrix4x4_Type;
}

static PyType_Slot Sbk_QMatrix4x4_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QMatrix4x4Func___repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMatrix4x4_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMatrix4x4_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QMatrix4x4_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMatrix4x4_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMatrix4x4_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports mapping protocol
    {Py_mp_subscript,   reinterpret_cast<void *>(reinterpret_cast<void *>(&Sbk_QMatrix4x4Func___mgetitem__))},
    // type supports number protocol
    {Py_nb_inplace_subtract,reinterpret_cast<void *>(Sbk_QMatrix4x4Func___isub__)},
    {Py_nb_negative,    reinterpret_cast<void *>(Sbk_QMatrix4x4Func___neg__)},
    {Py_nb_true_divide, reinterpret_cast<void *>(Sbk_QMatrix4x4Func___div__)},
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QMatrix4x4Func___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QMatrix4x4Func___rshift__)},
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QMatrix4x4Func___iadd__)},
    {Py_nb_subtract,    reinterpret_cast<void *>(Sbk_QMatrix4x4Func___sub__)},
    {Py_nb_add,         reinterpret_cast<void *>(Sbk_QMatrix4x4Func___add__)},
    {Py_nb_multiply,    reinterpret_cast<void *>(Sbk_QMatrix4x4Func___mul__)},
    {Py_nb_inplace_multiply,reinterpret_cast<void *>(Sbk_QMatrix4x4Func___imul__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMatrix4x4_spec = {
    "2:PySide6.QtGui.QMatrix4x4",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMatrix4x4_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QMatrix4x4_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMatrix4x4::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMatrix4x4::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMatrix4x4_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_Flag_IDX])))
        return Enum_PythonToCpp_QMatrix4x4_Flag;
    return {};
}

static PyObject *QMatrix4x4_Flag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMatrix4x4::Flag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMatrix4x4::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_Flag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QMatrix4x4_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QMatrix4x4::Flag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QMatrix4x4::Flag> *>(cppOut) = value;

}

static PyObject *QMatrix4x4_Flag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QMatrix4x4::Flag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_Flag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMatrix4x4_PythonToCpp_QMatrix4x4_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMatrix4x4_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMatrix4x4_PythonToCpp_QMatrix4x4_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMatrix4x4_TypeF()))
        return QMatrix4x4_PythonToCpp_QMatrix4x4_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMatrix4x4_PTR_CppToPython_QMatrix4x4(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QMatrix4x4_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QMatrix4x4_COPY_CppToPython_QMatrix4x4(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QMatrix4x4 *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QMatrix4x4_TypeF(), new ::QMatrix4x4(*source), true, true);
}

// Python to C++ copy conversion.
static void QMatrix4x4_PythonToCpp_QMatrix4x4_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QMatrix4x4 *>(cppOut) = *reinterpret_cast< ::QMatrix4x4 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QMatrix4x4_PythonToCpp_QMatrix4x4_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QMatrix4x4_TypeF()))
        return QMatrix4x4_PythonToCpp_QMatrix4x4_COPY;
    return {};
}

// Implicit conversions.
static void constQTransformREF_PythonToCpp_QMatrix4x4(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QMatrix4x4 *>(cppOut) = ::QMatrix4x4( *reinterpret_cast< ::QTransform *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQTransformREF_PythonToCpp_QMatrix4x4_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), pyIn))
        return constQTransformREF_PythonToCpp_QMatrix4x4;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMatrix4x4_SignatureStrings[] = {
    "4:PySide6.QtGui.QMatrix4x4(self)",
    "3:PySide6.QtGui.QMatrix4x4(self,QMatrix4x4:PySide6.QtGui.QMatrix4x4)",
    "2:PySide6.QtGui.QMatrix4x4(self,transform:PySide6.QtGui.QTransform)",
    "1:PySide6.QtGui.QMatrix4x4(self,values:PySequence)",
    "0:PySide6.QtGui.QMatrix4x4(self,m11:float,m12:float,m13:float,m14:float,m21:float,m22:float,m23:float,m24:float,m31:float,m32:float,m33:float,m34:float,m41:float,m42:float,m43:float,m44:float)",
    "PySide6.QtGui.QMatrix4x4.__dummy(self,arg__1:QList[float])",
    "PySide6.QtGui.QMatrix4x4.__reduce__(self)->str",
    "PySide6.QtGui.QMatrix4x4.__repr__(self)->str",
    "PySide6.QtGui.QMatrix4x4.column(self,index:int)->PySide6.QtGui.QVector4D",
    "PySide6.QtGui.QMatrix4x4.copyDataTo(self)->Tuple",
    "PySide6.QtGui.QMatrix4x4.data(self)->float*",
    "PySide6.QtGui.QMatrix4x4.determinant(self)->double",
    "PySide6.QtGui.QMatrix4x4.fill(self,value:float)",
    "PySide6.QtGui.QMatrix4x4.flags(self)->PySide6.QtGui.QMatrix4x4.Flag",
    "PySide6.QtGui.QMatrix4x4.flipCoordinates(self)",
    "PySide6.QtGui.QMatrix4x4.frustum(self,left:float,right:float,bottom:float,top:float,nearPlane:float,farPlane:float)",
    "PySide6.QtGui.QMatrix4x4.inverted(self)->Tuple[PySide6.QtGui.QMatrix4x4, bool]",
    "PySide6.QtGui.QMatrix4x4.isAffine(self)->bool",
    "PySide6.QtGui.QMatrix4x4.isIdentity(self)->bool",
    "PySide6.QtGui.QMatrix4x4.lookAt(self,eye:PySide6.QtGui.QVector3D,center:PySide6.QtGui.QVector3D,up:PySide6.QtGui.QVector3D)",
    "3:PySide6.QtGui.QMatrix4x4.map(self,point:PySide6.QtCore.QPoint)->PySide6.QtCore.QPoint",
    "2:PySide6.QtGui.QMatrix4x4.map(self,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->PySide6.QtCore.QPointF",
    "1:PySide6.QtGui.QMatrix4x4.map(self,point:PySide6.QtGui.QVector3D)->PySide6.QtGui.QVector3D",
    "0:PySide6.QtGui.QMatrix4x4.map(self,point:PySide6.QtGui.QVector4D)->PySide6.QtGui.QVector4D",
    "1:PySide6.QtGui.QMatrix4x4.mapRect(self,rect:PySide6.QtCore.QRect)->PySide6.QtCore.QRect",
    "0:PySide6.QtGui.QMatrix4x4.mapRect(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QMatrix4x4.mapVector(self,vector:PySide6.QtGui.QVector3D)->PySide6.QtGui.QVector3D",
    "PySide6.QtGui.QMatrix4x4.normalMatrix(self)->PySide6.QtGui.QMatrix3x3",
    "PySide6.QtGui.QMatrix4x4.optimize(self)",
    "2:PySide6.QtGui.QMatrix4x4.ortho(self,rect:PySide6.QtCore.QRect)",
    "1:PySide6.QtGui.QMatrix4x4.ortho(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "0:PySide6.QtGui.QMatrix4x4.ortho(self,left:float,right:float,bottom:float,top:float,nearPlane:float,farPlane:float)",
    "PySide6.QtGui.QMatrix4x4.perspective(self,verticalAngle:float,aspectRatio:float,nearPlane:float,farPlane:float)",
    "1:PySide6.QtGui.QMatrix4x4.projectedRotate(self,angle:float,x:float,y:float,z:float)",
    "0:PySide6.QtGui.QMatrix4x4.projectedRotate(self,angle:float,x:float,y:float,z:float,distanceToPlane:float)",
    "2:PySide6.QtGui.QMatrix4x4.rotate(self,quaternion:PySide6.QtGui.QQuaternion)",
    "1:PySide6.QtGui.QMatrix4x4.rotate(self,angle:float,vector:PySide6.QtGui.QVector3D)",
    "0:PySide6.QtGui.QMatrix4x4.rotate(self,angle:float,x:float,y:float,z:float=0.0f)",
    "PySide6.QtGui.QMatrix4x4.row(self,index:int)->PySide6.QtGui.QVector4D",
    "3:PySide6.QtGui.QMatrix4x4.scale(self,vector:PySide6.QtGui.QVector3D)",
    "2:PySide6.QtGui.QMatrix4x4.scale(self,factor:float)",
    "1:PySide6.QtGui.QMatrix4x4.scale(self,x:float,y:float)",
    "0:PySide6.QtGui.QMatrix4x4.scale(self,x:float,y:float,z:float)",
    "PySide6.QtGui.QMatrix4x4.setColumn(self,index:int,value:PySide6.QtGui.QVector4D)",
    "PySide6.QtGui.QMatrix4x4.setRow(self,index:int,value:PySide6.QtGui.QVector4D)",
    "PySide6.QtGui.QMatrix4x4.setToIdentity(self)",
    "1:PySide6.QtGui.QMatrix4x4.toTransform(self)->PySide6.QtGui.QTransform",
    "0:PySide6.QtGui.QMatrix4x4.toTransform(self,distanceToPlane:float)->PySide6.QtGui.QTransform",
    "2:PySide6.QtGui.QMatrix4x4.translate(self,vector:PySide6.QtGui.QVector3D)",
    "1:PySide6.QtGui.QMatrix4x4.translate(self,x:float,y:float)",
    "0:PySide6.QtGui.QMatrix4x4.translate(self,x:float,y:float,z:float)",
    "PySide6.QtGui.QMatrix4x4.transposed(self)->PySide6.QtGui.QMatrix4x4",
    "1:PySide6.QtGui.QMatrix4x4.viewport(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "0:PySide6.QtGui.QMatrix4x4.viewport(self,left:float,bottom:float,width:float,height:float,nearPlane:float=0.0f,farPlane:float=1.0f)",
    "PySide6.QtGui.QMatrix4x4.__copy__(self)->typing.Self",
    "4:PySide6.QtGui.QMatrix4x4.__mul__(self,m2:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])->PySide6.QtGui.QMatrix4x4",
    "3:PySide6.QtGui.QMatrix4x4.__mul__(self,point:PySide6.QtCore.QPoint)->PySide6.QtCore.QPoint",
    "2:PySide6.QtGui.QMatrix4x4.__mul__(self,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->PySide6.QtCore.QPointF",
    "1:PySide6.QtGui.QMatrix4x4.__mul__(self,factor:float)->PySide6.QtGui.QMatrix4x4",
    "0:PySide6.QtGui.QMatrix4x4.__mul__(self,factor:float)->PySide6.QtGui.QMatrix4x4",
    "1:PySide6.QtGui.QMatrix4x4.__imul__(self,other:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])->PySide6.QtGui.QMatrix4x4",
    "0:PySide6.QtGui.QMatrix4x4.__imul__(self,factor:float)->PySide6.QtGui.QMatrix4x4",
    "PySide6.QtGui.QMatrix4x4.__add__(self,m2:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])->PySide6.QtGui.QMatrix4x4",
    "PySide6.QtGui.QMatrix4x4.__iadd__(self,other:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])->PySide6.QtGui.QMatrix4x4",
    "PySide6.QtGui.QMatrix4x4.__neg__(self)->PySide6.QtGui.QMatrix4x4",
    "PySide6.QtGui.QMatrix4x4.__sub__(self,m2:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])->PySide6.QtGui.QMatrix4x4",
    "PySide6.QtGui.QMatrix4x4.__isub__(self,other:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])->PySide6.QtGui.QMatrix4x4",
    "PySide6.QtGui.QMatrix4x4.__div__(self,divisor:float)->PySide6.QtGui.QMatrix4x4",
    "PySide6.QtGui.QMatrix4x4.__lshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QMatrix4x4.__rshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QMatrix4x4.__ne__(self,other:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])->bool",
    "PySide6.QtGui.QMatrix4x4.__eq__(self,other:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QMatrix4x4_SignatureByteSize = 987;
static constexpr uint8_t QMatrix4x4_SignatureBytes[987] = {
    0x78, 0xda, 0xcd, 0x58, 0xdf, 0x6f, 0xda, 0x30, 0x10, 0x7e, 0xe7, 0xaf, 0xe8, 0xe3, 0x98, 0x18,
    0x02, 0x12, 0xed, 0x01, 0xa9, 0x93, 0xaa, 0xb1, 0x4e, 0x93, 0x36, 0x09, 0x5a, 0xb6, 0x97, 0x0a,
    0x45, 0x2e, 0xb9, 0x80, 0x37, 0xc7, 0x4e, 0x1d, 0x87, 0x42, 0xff, 0xfa, 0x39, 0xbf, 0x4c, 0x92,
    0xe2, 0x4b, 0xd6, 0xb5, 0xdd, 0x9e, 0xe2, 0xc4, 0xdf, 0x7d, 0x77, 0xbe, 0x3b, 0xdf, 0xd9, 0x71,
    0xa7, 0xf3, 0xc3, 0x35, 0xf5, 0xe1, 0xfd, 0x70, 0xa1, 0x3e, 0x27, 0x74, 0xb8, 0xf8, 0x46, 0x94,
    0xa4, 0x7b, 0x77, 0xef, 0xbe, 0x89, 0x81, 0x05, 0xfd, 0x9e, 0x83, 0x03, 0x06, 0xc7, 0x77, 0x2b,
    0xb0, 0xdf, 0x9b, 0xb4, 0x90, 0x28, 0x49, 0x78, 0x1c, 0x08, 0x19, 0x36, 0x71, 0xcb, 0x72, 0xa2,
    0xdf, 0x1b, 0xb7, 0x70, 0xec, 0x08, 0x4b, 0x20, 0x4e, 0x41, 0x70, 0x97, 0x00, 0x5f, 0x43, 0xbf,
    0x37, 0x6a, 0x11, 0x09, 0xc7, 0xe3, 0x69, 0xc0, 0x04, 0x51, 0x7a, 0x34, 0x31, 0x23, 0xc7, 0x8c,
    0xdc, 0x72, 0x34, 0x31, 0xb8, 0x89, 0xc1, 0x4d, 0x0c, 0x6e, 0x62, 0x70, 0x8e, 0xc1, 0x39, 0x06,
    0xe7, 0x18, 0x9c, 0x63, 0x70, 0xae, 0xc1, 0xb9, 0x06, 0xe7, 0x1a, 0x9c, 0x5b, 0xe0, 0xfa, 0x3d,
    0x9b, 0xf9, 0x43, 0xcf, 0xf3, 0x93, 0x30, 0x3c, 0xe4, 0xcb, 0x20, 0x72, 0xe3, 0x79, 0xe3, 0xe9,
    0xe2, 0x2b, 0x8d, 0xd5, 0x4d, 0x26, 0xb9, 0x42, 0x45, 0x25, 0xf8, 0xc9, 0x1a, 0x3c, 0x2f, 0x8f,
    0xf0, 0xbb, 0x0f, 0xb1, 0x92, 0x38, 0x3c, 0x92, 0x1d, 0xc1, 0x6b, 0xc1, 0x92, 0x90, 0xe7, 0x56,
    0x51, 0xee, 0xc3, 0x7e, 0x4a, 0xb9, 0xd2, 0x42, 0x0d, 0x81, 0x1f, 0xb0, 0x56, 0x42, 0xba, 0x33,
    0x8c, 0x28, 0x3a, 0xcc, 0x88, 0x22, 0x4b, 0x51, 0xea, 0x5d, 0x26, 0x11, 0x03, 0xbb, 0x80, 0xaf,
    0xc1, 0x25, 0x34, 0x73, 0xc1, 0x5b, 0x04, 0x0b, 0x0a, 0x64, 0x48, 0x39, 0xe1, 0xaa, 0x14, 0xf1,
    0x45, 0x72, 0x8b, 0xd1, 0x07, 0x94, 0xb1, 0x4a, 0x9a, 0xb5, 0xc6, 0x27, 0x60, 0x64, 0x13, 0x97,
    0xe4, 0x56, 0xd4, 0xa5, 0x46, 0x61, 0x1c, 0x34, 0xfa, 0x28, 0x84, 0xf4, 0xb5, 0xa5, 0x0a, 0x0a,
    0x36, 0x04, 0x2e, 0x93, 0x58, 0x25, 0x61, 0x6e, 0x25, 0x83, 0x40, 0x15, 0xe9, 0x24, 0xe9, 0x66,
    0x5b, 0x8e, 0x6f, 0x85, 0x52, 0x22, 0x2c, 0x5e, 0x94, 0x88, 0x8a, 0x11, 0x07, 0x22, 0xe7, 0x8c,
    0xf0, 0x62, 0x5d, 0x83, 0xa0, 0xf6, 0x8a, 0xe8, 0xa4, 0x7c, 0x07, 0x52, 0x81, 0x5f, 0x0b, 0xd2,
    0x8d, 0x0d, 0x3e, 0x38, 0xbb, 0x15, 0x82, 0xad, 0x10, 0xba, 0xf8, 0x22, 0x08, 0x28, 0x87, 0x92,
    0x2e, 0x85, 0x63, 0xe8, 0x2f, 0x3e, 0x70, 0x45, 0xd5, 0xa1, 0x1b, 0x9e, 0x09, 0xf1, 0xeb, 0x22,
    0x8f, 0xf8, 0x00, 0x0e, 0x30, 0x3d, 0x99, 0x94, 0xce, 0x6c, 0xb0, 0xd6, 0xa4, 0x20, 0xad, 0xd3,
    0x49, 0x64, 0x9b, 0xc2, 0x8a, 0xe5, 0x30, 0x24, 0x51, 0xae, 0x3a, 0x12, 0x7a, 0x4f, 0x54, 0x70,
    0x1f, 0x85, 0x84, 0xe1, 0x62, 0x2e, 0x9a, 0x3b, 0xa5, 0xf2, 0x1d, 0xa9, 0x9f, 0x4d, 0x5e, 0x75,
    0x88, 0x28, 0xdf, 0x0c, 0xbf, 0x73, 0x2a, 0xf8, 0xcd, 0x49, 0xb2, 0xcb, 0xc1, 0xd9, 0xc9, 0xef,
    0xd5, 0xcf, 0x99, 0x8e, 0x39, 0xa1, 0xa9, 0x23, 0xe6, 0x44, 0x6d, 0x87, 0x9f, 0x18, 0x84, 0xda,
    0x2d, 0x2b, 0x9b, 0x85, 0x97, 0x48, 0x79, 0xb6, 0x2f, 0xbd, 0xee, 0x3d, 0x4b, 0x99, 0x70, 0x66,
    0x48, 0x1d, 0xef, 0xc4, 0xed, 0xce, 0x90, 0x12, 0x84, 0xdb, 0x7d, 0xa5, 0x61, 0x39, 0xbf, 0xd4,
    0xa3, 0x47, 0x51, 0x4b, 0xa7, 0x4f, 0xb8, 0x24, 0xfd, 0xdc, 0x62, 0x74, 0x83, 0x18, 0x0d, 0x5b,
    0x8a, 0x3d, 0x11, 0xb5, 0xf4, 0xf3, 0xca, 0xa2, 0xfd, 0xb2, 0x87, 0x29, 0xcf, 0x17, 0x5f, 0xd4,
    0xb3, 0x6c, 0xfc, 0x84, 0xa0, 0x58, 0x15, 0x70, 0xdd, 0xae, 0x09, 0xcb, 0xdf, 0xd1, 0x12, 0xe8,
    0xec, 0x1d, 0x3b, 0x8b, 0x88, 0x14, 0x0d, 0xe9, 0x43, 0x51, 0x0b, 0xb0, 0x1d, 0x20, 0xa4, 0xda,
    0x8a, 0xb6, 0x20, 0x61, 0x71, 0x6e, 0x12, 0x3c, 0x3d, 0x18, 0x58, 0xd0, 0x2b, 0x5a, 0x5e, 0xa9,
    0x3a, 0x47, 0x20, 0xe3, 0x48, 0xdb, 0x45, 0x77, 0x50, 0xc6, 0x5a, 0x2a, 0xba, 0x26, 0xec, 0x82,
    0x6f, 0x58, 0xc9, 0x46, 0x32, 0xc8, 0x15, 0x51, 0x54, 0x74, 0xd4, 0x87, 0x78, 0x32, 0x92, 0xe2,
    0xa7, 0x66, 0x03, 0xff, 0x4a, 0x28, 0xdd, 0xb3, 0x8a, 0xe3, 0x49, 0x45, 0xdb, 0xbe, 0x78, 0x1e,
    0x8a, 0xe7, 0x43, 0x49, 0x3a, 0x7a, 0x7e, 0xd2, 0x81, 0xaf, 0xcf, 0x43, 0x44, 0x1f, 0x04, 0x97,
    0xa2, 0x66, 0x3f, 0x92, 0x4a, 0xb2, 0xa2, 0xe1, 0x2e, 0xd1, 0x43, 0x99, 0xe6, 0x40, 0x13, 0xbf,
    0x30, 0x33, 0xa8, 0x33, 0xa4, 0xc5, 0xdc, 0x96, 0x1d, 0x87, 0xb9, 0x42, 0xfe, 0x99, 0x07, 0xce,
    0x47, 0xc3, 0x11, 0x76, 0x64, 0x90, 0xe2, 0xbe, 0xfb, 0x59, 0x0d, 0xe9, 0x6d, 0xb1, 0xce, 0x29,
    0xe8, 0x54, 0x4e, 0x30, 0xe7, 0x57, 0x58, 0x02, 0x92, 0xb1, 0xb4, 0x27, 0x5c, 0x45, 0xa6, 0xe1,
    0x03, 0xd4, 0x8f, 0x76, 0xb1, 0x63, 0x46, 0xda, 0x85, 0x41, 0xef, 0xf9, 0x13, 0xe7, 0xdc, 0xe2,
    0x68, 0x68, 0x6b, 0x41, 0x28, 0xe1, 0xd5, 0xa3, 0x48, 0xfc, 0x0d, 0xdb, 0x52, 0xd4, 0x4f, 0x46,
    0x98, 0x07, 0x95, 0x30, 0x77, 0x2c, 0x4b, 0xb1, 0x36, 0xf3, 0x98, 0x47, 0x9b, 0x34, 0x96, 0xcd,
    0x87, 0x90, 0x23, 0x99, 0x91, 0x5d, 0x0f, 0x99, 0xc9, 0xfc, 0xb6, 0x1c, 0x1b, 0x77, 0x66, 0xfa,
    0x93, 0x9c, 0xc1, 0x45, 0x3b, 0xe4, 0x4d, 0x46, 0x10, 0x89, 0xf8, 0x78, 0x5c, 0xb6, 0x41, 0xb1,
    0x15, 0xec, 0x28, 0xdc, 0x47, 0xba, 0x97, 0xbc, 0x78, 0xbf, 0xaa, 0x2b, 0xaa, 0xb4, 0xac, 0x5a,
    0x9b, 0xba, 0xa7, 0xbe, 0xda, 0x16, 0xe3, 0x2d, 0x54, 0x9a, 0x59, 0xa3, 0x8b, 0x64, 0xa5, 0xa8,
    0xd1, 0x4a, 0xce, 0xc7, 0x78, 0x79, 0xf2, 0xbc, 0xf4, 0x1a, 0x78, 0xbc, 0x7a, 0x16, 0xeb, 0xbc,
    0xd6, 0x6f, 0x3d, 0xfb, 0xdf, 0x06, 0x2d, 0x16, 0x26, 0xac, 0x90, 0xd2, 0x97, 0x73, 0x9b, 0x7b,
    0x9a, 0x77, 0x13, 0x5b, 0x62, 0xae, 0xb0, 0x40, 0x39, 0x1d, 0xcd, 0x78, 0xe6, 0x43, 0xff, 0x09,
    0xee, 0xff, 0xf1, 0xe0, 0x5f, 0x33, 0xb3, 0x56, 0xd3, 0x11, 0x97, 0x8e, 0x9e, 0x99, 0x0f, 0xb5,
    0x8f, 0x56, 0x08, 0x85, 0xda, 0xea, 0x6b, 0xdf, 0x4b, 0x66, 0xcb, 0xa8, 0xab, 0x29, 0x5d, 0xd7,
    0x86, 0xd0, 0x11, 0xdf, 0x7f, 0xa5, 0x3d, 0x80, 0xad, 0xa9, 0x62, 0xc5, 0xcb, 0xbb, 0x17, 0x31,
    0x84, 0xc3, 0xe6, 0x58, 0x47, 0x9e, 0x42, 0x10, 0x27, 0xb7, 0xff, 0x81, 0x3b, 0x2b, 0x56, 0xfc,
    0x53, 0x77, 0xfa, 0x74, 0x57, 0xda, 0xa1, 0x87, 0x34, 0xfe, 0xcb, 0x5c, 0x65, 0xf1, 0x96, 0x06,
    0xaa, 0x64, 0x2c, 0x7e, 0x67, 0x36, 0xcb, 0x4d, 0xfa, 0x3b, 0xf0, 0x5a, 0x49, 0x20, 0xe1, 0x89,
    0x5a, 0x74, 0x9c, 0x44, 0xff, 0x64, 0xbe, 0x92, 0x1e, 0x0e, 0xcf, 0x1e, 0x25, 0xfc, 0xd7, 0x96,
    0xe7, 0xc1, 0xdd, 0xcb, 0xa8, 0xfc, 0x0d, 0x20, 0xb4, 0x72, 0xe2
};
#endif

PyTypeObject *init_QMatrix4x4(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX].type;

    Shiboken::AutoDecRef Sbk_QMatrix4x4_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QMatrix4x4_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMatrix4x4",
        "QMatrix4x4",
        &Sbk_QMatrix4x4_spec,
        &Shiboken::callCppDestructor< ::QMatrix4x4 >,
        Sbk_QMatrix4x4_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QMatrix4x4_TypeF(); // references _Sbk_QMatrix4x4_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMatrix4x4_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMatrix4x4_SignatureBytes, QMatrix4x4_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMatrix4x4_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMatrix4x4_PythonToCpp_QMatrix4x4_PTR,
        is_QMatrix4x4_PythonToCpp_QMatrix4x4_PTR_Convertible,
        QMatrix4x4_PTR_CppToPython_QMatrix4x4,
        QMatrix4x4_COPY_CppToPython_QMatrix4x4);

    Shiboken::Conversions::registerConverterName(converter, "QMatrix4x4");
    Shiboken::Conversions::registerConverterName(converter, "QMatrix4x4*");
    Shiboken::Conversions::registerConverterName(converter, "QMatrix4x4&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMatrix4x4).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QMatrix4x4_PythonToCpp_QMatrix4x4_COPY,
        is_QMatrix4x4_PythonToCpp_QMatrix4x4_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQTransformREF_PythonToCpp_QMatrix4x4,
        is_constQTransformREF_PythonToCpp_QMatrix4x4_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QMatrix4x4_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "Identity",
        "Translation",
        "Scale",
        "Rotation2D",
        "Rotation",
        "Perspective",
        "General",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Flag_InitializerValues[] = {
        uint8_t(QMatrix4x4::Flag::Identity),    //  0x00  0
        uint8_t(QMatrix4x4::Flag::Translation), //  0x01  1
        uint8_t(QMatrix4x4::Flag::Scale),       //  0x02  2
        uint8_t(QMatrix4x4::Flag::Rotation2D),  //  0x04  4
        uint8_t(QMatrix4x4::Flag::Rotation),    //  0x08  8
        uint8_t(QMatrix4x4::Flag::Perspective), //  0x10  16
        uint8_t(QMatrix4x4::Flag::General)      //  0x1f  31
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMatrix4x4_TypeF(),
        "2:PySide6.QtGui.QMatrix4x4.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QMatrix4x4_Flag_IDX].type =
        EType;
    // Register converter for enum 'QMatrix4x4::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMatrix4x4_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMatrix4x4_Flag,
            is_Enum_PythonToCpp_QMatrix4x4_Flag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMatrix4x4::Flag");
        Shiboken::Conversions::registerConverterAlias(converter, "Flag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QMatrix4x4_Flag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QMatrix4x4_Flag,
            is_Enum_PythonToCpp_QMatrix4x4_Flag_Convertible);
        // Register converter for flag 'QFlags<QMatrix4x4::Flag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QMatrix4x4::Flag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QMatrix4x4::Flags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Flag' enum/flags.

    qRegisterMetaType< ::QMatrix4x4 >("QMatrix4x4");
    qRegisterMetaType< ::QMatrix4x4::Flag >("QMatrix4x4::Flag");

    return pyType;
}
