// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QPAGEDPAINTDEVICEWRAPPER_H
#define SBK_QPAGEDPAINTDEVICEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qpagedpaintdevice.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QPagedPaintDeviceWrapper : public QPagedPaintDevice
{
public:
    QPagedPaintDeviceWrapper(const QPagedPaintDeviceWrapper &) = delete;
    QPagedPaintDeviceWrapper& operator=(const QPagedPaintDeviceWrapper &) = delete;
    QPagedPaintDeviceWrapper(QPagedPaintDeviceWrapper &&) = delete;
    QPagedPaintDeviceWrapper& operator=(QPagedPaintDeviceWrapper &&) = delete;
    ~QPagedPaintDeviceWrapper() override;

    int devType() const override;
    void initPainter(::QPainter * painter) const override;
    int metric(::QPaintDevice::PaintDeviceMetric metric) const override;
    bool newPage() override;
    ::QPaintEngine * paintEngine() const override;
    ::QPaintDevice * redirected(::QPoint * offset) const override;
    bool setPageLayout(const ::QPageLayout & pageLayout) override;
    static bool sbk_o_setPageLayout(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPageLayout & pageLayout);
    bool setPageMargins(const ::QMarginsF & margins, ::QPageLayout::Unit units = QPageLayout::Millimeter) override;
    static bool sbk_o_setPageMargins(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QMarginsF & margins, ::QPageLayout::Unit units = QPageLayout::Millimeter);
    bool setPageOrientation(::QPageLayout::Orientation orientation) override;
    static bool sbk_o_setPageOrientation(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPageLayout::Orientation orientation);
    void setPageRanges(const ::QPageRanges & ranges) override;
    static void sbk_o_setPageRanges(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPageRanges & ranges);
    bool setPageSize(const ::QPageSize & pageSize) override;
    static bool sbk_o_setPageSize(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPageSize & pageSize);
    ::QPainter * sharedPainter() const override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[12] = {false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QPAGEDPAINTDEVICEWRAPPER_H
