// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qpaintdevicewindow_wrapper.h"

// Wrappers providing overrides
#include "qwindow_wrapper.h"
#include "qundocommand_wrapper.h"
#include "qsurface_wrapper.h"
#include "qaccessibletablecellinterface_wrapper.h"
#include "qaccessibleinterface_wrapper.h"
#include "qpaintdevice_wrapper.h"

// Argument includes
#include <QtGui/qaccessible.h>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qregion.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPaintDeviceWindowWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

::QAccessibleInterface * QPaintDeviceWindowWrapper::accessibleRoot() const
{
    static const char *funcName = "accessibleRoot";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::accessibleRoot();
    }
    return QAccessibleTableCellInterfaceWrapper::sbk_o_table("QPaintDeviceWindow", funcName, gil, pyOverride);
}

void QPaintDeviceWindowWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWindowWrapper::sbk_o_childEvent("QPaintDeviceWindow", funcName, gil, pyOverride, event);
}

void QPaintDeviceWindowWrapper::closeEvent(::QCloseEvent * arg__1)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::closeEvent(arg__1);
    }
    QWindowWrapper::sbk_o_closeEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

void QPaintDeviceWindowWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWindowWrapper::sbk_o_connectNotify("QPaintDeviceWindow", funcName, gil, pyOverride, signal);
}

void QPaintDeviceWindowWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWindowWrapper::sbk_o_customEvent("QPaintDeviceWindow", funcName, gil, pyOverride, event);
}

int QPaintDeviceWindowWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDevice::devType();
    }
    return QUndoCommandWrapper::sbk_o_id("QPaintDeviceWindow", funcName, gil, pyOverride);
}

void QPaintDeviceWindowWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWindowWrapper::sbk_o_connectNotify("QPaintDeviceWindow", funcName, gil, pyOverride, signal);
}

bool QPaintDeviceWindowWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDeviceWindow::event(event);
    }
    return QWindowWrapper::sbk_o_event("QPaintDeviceWindow", funcName, gil, pyOverride, event);
}

bool QPaintDeviceWindowWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWindowWrapper::sbk_o_eventFilter("QPaintDeviceWindow", funcName, gil, pyOverride, watched, event);
}

void QPaintDeviceWindowWrapper::exposeEvent(::QExposeEvent * arg__1)
{
    static const char *funcName = "exposeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDeviceWindow::exposeEvent(arg__1);
    }
    QWindowWrapper::sbk_o_exposeEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

void QPaintDeviceWindowWrapper::focusInEvent(::QFocusEvent * arg__1)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::focusInEvent(arg__1);
    }
    QWindowWrapper::sbk_o_focusInEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

::QObject * QPaintDeviceWindowWrapper::focusObject() const
{
    static const char *funcName = "focusObject";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::focusObject();
    }
    return QAccessibleInterfaceWrapper::sbk_o_object("QPaintDeviceWindow", funcName, gil, pyOverride);
}

void QPaintDeviceWindowWrapper::focusOutEvent(::QFocusEvent * arg__1)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::focusOutEvent(arg__1);
    }
    QWindowWrapper::sbk_o_focusInEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

::QSurfaceFormat QPaintDeviceWindowWrapper::format() const
{
    static const char *funcName = "format";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::format();
    }
    return QSurfaceWrapper::sbk_o_format("QPaintDeviceWindow", funcName, gil, pyOverride);
}

void QPaintDeviceWindowWrapper::hideEvent(::QHideEvent * arg__1)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::hideEvent(arg__1);
    }
    QWindowWrapper::sbk_o_hideEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

void QPaintDeviceWindowWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDevice::initPainter(painter);
    }
    QPaintDeviceWrapper::sbk_o_initPainter("QPaintDeviceWindow", funcName, gil, pyOverride, painter);
}

void QPaintDeviceWindowWrapper::keyPressEvent(::QKeyEvent * arg__1)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::keyPressEvent(arg__1);
    }
    QWindowWrapper::sbk_o_keyPressEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

void QPaintDeviceWindowWrapper::keyReleaseEvent(::QKeyEvent * arg__1)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::keyReleaseEvent(arg__1);
    }
    QWindowWrapper::sbk_o_keyPressEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

int QPaintDeviceWindowWrapper::metric(::QPaintDevice::PaintDeviceMetric metric) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDeviceWindow::metric(metric);
    }
    return QPaintDeviceWrapper::sbk_o_metric("QPaintDeviceWindow", funcName, gil, pyOverride, metric);
}

void QPaintDeviceWindowWrapper::mouseDoubleClickEvent(::QMouseEvent * arg__1)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::mouseDoubleClickEvent(arg__1);
    }
    QWindowWrapper::sbk_o_mouseDoubleClickEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

void QPaintDeviceWindowWrapper::mouseMoveEvent(::QMouseEvent * arg__1)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::mouseMoveEvent(arg__1);
    }
    QWindowWrapper::sbk_o_mouseDoubleClickEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

void QPaintDeviceWindowWrapper::mousePressEvent(::QMouseEvent * arg__1)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::mousePressEvent(arg__1);
    }
    QWindowWrapper::sbk_o_mouseDoubleClickEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

void QPaintDeviceWindowWrapper::mouseReleaseEvent(::QMouseEvent * arg__1)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::mouseReleaseEvent(arg__1);
    }
    QWindowWrapper::sbk_o_mouseDoubleClickEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

void QPaintDeviceWindowWrapper::moveEvent(::QMoveEvent * arg__1)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::moveEvent(arg__1);
    }
    QWindowWrapper::sbk_o_moveEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

bool QPaintDeviceWindowWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::nativeEvent(eventType, message, result);
    }
    return sbk_o_nativeEvent("QPaintDeviceWindow", funcName, gil, pyOverride, eventType, message, result);
}

bool QPaintDeviceWindowWrapper::sbk_o_nativeEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &eventType),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), message)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Begin code injection
    // TEMPLATE - return_native_eventfilter_conversion - START
    bool cppResult = false;
    if (PySequence_Check(pyResult.object()) != 0 && PySequence_Size(pyResult.object()) == 2) {
        Shiboken::AutoDecRef pyItem(PySequence_GetItem(pyResult.object(), 0));
        Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyItem, &(cppResult));
        if (result) {
            Shiboken::AutoDecRef pyResultItem(PySequence_GetItem(pyResult, 1));
            Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX], pyResultItem, (result));
        }
    }
    // TEMPLATE - return_native_eventfilter_conversion - END
    // End of code injection


    return cppResult;
}

void QPaintDeviceWindowWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDeviceWindow::paintEvent(event);
    }
    QWindowWrapper::sbk_o_paintEvent("QPaintDeviceWindow", funcName, gil, pyOverride, event);
}

::QPaintDevice * QPaintDeviceWindowWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDevice::redirected(offset);
    }
    return QPaintDeviceWrapper::sbk_o_redirected("QPaintDeviceWindow", funcName, gil, pyOverride, offset);
}

void QPaintDeviceWindowWrapper::resizeEvent(::QResizeEvent * arg__1)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::resizeEvent(arg__1);
    }
    QWindowWrapper::sbk_o_resizeEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

::QPainter * QPaintDeviceWindowWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDevice::sharedPainter();
    }
    return QPaintDeviceWrapper::sbk_o_sharedPainter("QPaintDeviceWindow", funcName, gil, pyOverride);
}

void QPaintDeviceWindowWrapper::showEvent(::QShowEvent * arg__1)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::showEvent(arg__1);
    }
    QWindowWrapper::sbk_o_showEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

::QSize QPaintDeviceWindowWrapper::size() const
{
    static const char *funcName = "size";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::size();
    }
    return QSurfaceWrapper::sbk_o_size("QPaintDeviceWindow", funcName, gil, pyOverride);
}

::QSurface::SurfaceType QPaintDeviceWindowWrapper::surfaceType() const
{
    static const char *funcName = "surfaceType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::surfaceType();
    }
    return QSurfaceWrapper::sbk_o_surfaceType("QPaintDeviceWindow", funcName, gil, pyOverride);
}

void QPaintDeviceWindowWrapper::tabletEvent(::QTabletEvent * arg__1)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::tabletEvent(arg__1);
    }
    QWindowWrapper::sbk_o_tabletEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

void QPaintDeviceWindowWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWindowWrapper::sbk_o_timerEvent("QPaintDeviceWindow", funcName, gil, pyOverride, event);
}

void QPaintDeviceWindowWrapper::touchEvent(::QTouchEvent * arg__1)
{
    static const char *funcName = "touchEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::touchEvent(arg__1);
    }
    QWindowWrapper::sbk_o_touchEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

void QPaintDeviceWindowWrapper::wheelEvent(::QWheelEvent * arg__1)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::wheelEvent(arg__1);
    }
    QWindowWrapper::sbk_o_wheelEvent("QPaintDeviceWindow", funcName, gil, pyOverride, arg__1);
}

const QMetaObject *QPaintDeviceWindowWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QPaintDeviceWindow::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QPaintDeviceWindowWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QPaintDeviceWindow::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QPaintDeviceWindowWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QPaintDeviceWindowWrapper *>(this));
    return QPaintDeviceWindow::qt_metacast(_clname);
}

QPaintDeviceWindowWrapper::~QPaintDeviceWindowWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_QPaintDeviceWindow_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QPaintDeviceWindow");
    return -1;
}

static PyObject *Sbk_QPaintDeviceWindowFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintDeviceWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPaintDeviceWindow::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPaintDeviceWindowFunc_exposeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintDeviceWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWindow::exposeEvent(QExposeEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QExposeEvent_IDX]), (pyArg)))) {
        overloadId = 0; // exposeEvent(QExposeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "exposeEvent", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QExposeEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // exposeEvent(QExposeEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPaintDeviceWindow::exposeEvent(cppArg0)
                : cppSelf->exposeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPaintDeviceWindowFunc_metric(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintDeviceWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintDevice::metric(QPaintDevice::PaintDeviceMetric)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "metric", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]);

    // Call function/method
    {
        ::QPaintDevice::PaintDeviceMetric cppArg0 = static_cast< ::QPaintDevice::PaintDeviceMetric>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // metric(QPaintDevice::PaintDeviceMetric)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QPaintDeviceWindow *>(cppSelf)->::QPaintDeviceWindow::metric(cppArg0)
                : const_cast<const ::QPaintDeviceWindow *>(cppSelf)->metric(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPaintDeviceWindowFunc_paintEngine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintDeviceWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("paintEngine() const");
        return {};
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPaintDeviceWindowFunc_paintEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintDeviceWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWindow::paintEvent(QPaintEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), (pyArg)))) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "paintEvent", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPaintEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paintEvent(QPaintEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPaintDeviceWindow::paintEvent(cppArg0)
                : cppSelf->paintEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPaintDeviceWindowFunc_update(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintDeviceWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "update", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPaintDeviceWindow::update()
    // 1: QPaintDeviceWindow::update(QRect)
    // 2: QPaintDeviceWindow::update(QRegion)
    if (numArgs == 0) {
        overloadId = 0; // update()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))) {
        overloadId = 1; // update(QRect)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), (pyArgs[0])))) {
        overloadId = 2; // update(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "update", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // update()
        {

            // update()
            cppSelf->update();
            break;
        }
        case 1: // update(const QRect &rect)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // update(QRect)
                cppSelf->update(*cppArg0);
            }
            break;
        }
        case 2: // update(const QRegion &region)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRegion cppArg0_local;
            ::QRegion *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // update(QRegion)
                cppSelf->update(*cppArg0);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QPaintDeviceWindow_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPaintDeviceWindow_methods[] = {
    {"event", reinterpret_cast<PyCFunction>(Sbk_QPaintDeviceWindowFunc_event), METH_O, nullptr},
    {"exposeEvent", reinterpret_cast<PyCFunction>(Sbk_QPaintDeviceWindowFunc_exposeEvent), METH_O, nullptr},
    {"metric", reinterpret_cast<PyCFunction>(Sbk_QPaintDeviceWindowFunc_metric), METH_O, nullptr},
    {"paintEngine", reinterpret_cast<PyCFunction>(Sbk_QPaintDeviceWindowFunc_paintEngine), METH_NOARGS, nullptr},
    {"paintEvent", reinterpret_cast<PyCFunction>(Sbk_QPaintDeviceWindowFunc_paintEvent), METH_O, nullptr},
    {"update", reinterpret_cast<PyCFunction>(Sbk_QPaintDeviceWindowFunc_update), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPaintDeviceWindow_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPaintDeviceWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPaintDeviceWindowWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPaintDeviceWindow_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPaintDeviceWindow_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
int *
Sbk_QPaintDeviceWindow_mi_init(const void *cptr)
{
    static int mi_offsets[] = {-2, 0, 0, 0, 0, 0, 0, 0, 0};
    if (mi_offsets[0] == -2) {
        const auto *class_ptr = reinterpret_cast<const QPaintDeviceWindow *>(cptr);
        const auto base = reinterpret_cast<uintptr_t>(class_ptr);
        int *p = mi_offsets;
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QWindow *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QWindow *>(static_cast<const QPaintDeviceWindow *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QPaintDevice *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QPaintDevice *>(static_cast<const QPaintDeviceWindow *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(static_cast<const QWindow *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QSurface *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QSurface *>(static_cast<const QWindow *>(static_cast<const void *>(class_ptr)))) - base);
        std::sort(mi_offsets, p);
        auto *end = std::unique(mi_offsets, p);
        *end++ = -1;
        if (mi_offsets[0] == 0)
            std::memmove(&mi_offsets[0], &mi_offsets[1], (end - mi_offsets  - 1) * sizeof(int));
    }
    return mi_offsets;
}
static void * Sbk_QPaintDeviceWindowSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QPaintDeviceWindow *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]))
        return static_cast< ::QWindow *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX]))
        return static_cast< ::QSurface *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPaintDeviceWindow_Type = nullptr;
static PyTypeObject *Sbk_QPaintDeviceWindow_TypeF(void)
{
    return _Sbk_QPaintDeviceWindow_Type;
}

static PyType_Slot Sbk_QPaintDeviceWindow_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPaintDeviceWindow_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPaintDeviceWindow_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPaintDeviceWindow_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPaintDeviceWindow_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPaintDeviceWindow_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPaintDeviceWindow_spec = {
    "2:PySide6.QtGui.QPaintDeviceWindow",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPaintDeviceWindow_slots
};

} //extern "C"

static void *Sbk_QPaintDeviceWindow_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWindow >())
        return dynamic_cast< ::QPaintDeviceWindow *>(reinterpret_cast< ::QWindow *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QPaintDeviceWindow *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QSurface >())
        return dynamic_cast< ::QPaintDeviceWindow *>(reinterpret_cast< ::QSurface *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QPaintDeviceWindow *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPaintDeviceWindow_PythonToCpp_QPaintDeviceWindow_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPaintDeviceWindow_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPaintDeviceWindow_PythonToCpp_QPaintDeviceWindow_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPaintDeviceWindow_TypeF()))
        return QPaintDeviceWindow_PythonToCpp_QPaintDeviceWindow_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPaintDeviceWindow_PTR_CppToPython_QPaintDeviceWindow(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QPaintDeviceWindow *>(const_cast<void *>(cppIn)), Sbk_QPaintDeviceWindow_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPaintDeviceWindow_SignatureStrings[] = {
    "PySide6.QtGui.QPaintDeviceWindow.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtGui.QPaintDeviceWindow.exposeEvent(self,arg__1:PySide6.QtGui.QExposeEvent)",
    "PySide6.QtGui.QPaintDeviceWindow.metric(self,metric:PySide6.QtGui.QPaintDevice.PaintDeviceMetric)->int",
    "PySide6.QtGui.QPaintDeviceWindow.paintEngine(self)->PySide6.QtGui.QPaintEngine",
    "PySide6.QtGui.QPaintDeviceWindow.paintEvent(self,event:PySide6.QtGui.QPaintEvent)",
    "2:PySide6.QtGui.QPaintDeviceWindow.update(self)",
    "1:PySide6.QtGui.QPaintDeviceWindow.update(self,rect:PySide6.QtCore.QRect)",
    "0:PySide6.QtGui.QPaintDeviceWindow.update(self,region:typing.Union[PySide6.QtGui.QRegion, PySide6.QtGui.QBitmap, PySide6.QtGui.QPolygon, PySide6.QtCore.QRect])",
    nullptr}; // Sentinel
#else
static constexpr size_t QPaintDeviceWindow_SignatureByteSize = 224;
static constexpr uint8_t QPaintDeviceWindow_SignatureBytes[224] = {
    0x78, 0xda, 0x95, 0x91, 0x3f, 0x0b, 0xc2, 0x30, 0x10, 0xc5, 0xf7, 0x7e, 0x0a, 0x47, 0x0b, 0x35,
    0xa8, 0x83, 0x43, 0x06, 0x07, 0x35, 0x38, 0x09, 0xa9, 0x22, 0x0e, 0x22, 0x52, 0xdb, 0x33, 0x1c,
    0xd4, 0x24, 0xd4, 0xf8, 0xa7, 0xdf, 0xde, 0xd8, 0x8a, 0xad, 0xad, 0x52, 0xbb, 0x5d, 0x1e, 0xef,
    0xfd, 0xee, 0x71, 0xe1, 0xe9, 0x0a, 0x23, 0x18, 0x11, 0xdf, 0xcc, 0x2f, 0x48, 0x7c, 0x1e, 0xa0,
    0x34, 0x33, 0xb8, 0x62, 0x08, 0x1b, 0x94, 0x91, 0xba, 0x11, 0xb8, 0x82, 0x34, 0xdd, 0x33, 0xc4,
    0x47, 0x2f, 0x1b, 0x29, 0x7f, 0x27, 0xa6, 0x2a, 0x01, 0xe2, 0xb3, 0xa7, 0xea, 0xf6, 0xc6, 0x07,
    0xa5, 0x62, 0x87, 0x37, 0xe2, 0xee, 0x5a, 0x9d, 0x81, 0x15, 0xd0, 0x20, 0x11, 0xfb, 0xfd, 0x80,
    0x56, 0x82, 0xac, 0xb0, 0xb9, 0xcd, 0xd0, 0x13, 0x98, 0x04, 0xc3, 0x9c, 0x97, 0xcf, 0xf4, 0x77,
    0x86, 0x94, 0xe6, 0x45, 0x66, 0xb6, 0xe5, 0xad, 0xd2, 0xbc, 0x46, 0x3f, 0x15, 0x26, 0x05, 0x4a,
    0xc8, 0x76, 0xd9, 0xdc, 0xb7, 0x4c, 0xee, 0xf8, 0x17, 0xf7, 0xfb, 0xbc, 0x25, 0x62, 0x7e, 0x87,
    0x21, 0x6d, 0x64, 0x5e, 0x74, 0x14, 0x98, 0x57, 0x3b, 0x67, 0xd0, 0xca, 0xef, 0x25, 0x10, 0xd6,
    0x7f, 0x77, 0x69, 0x45, 0xd7, 0xe9, 0xb7, 0x25, 0x09, 0x54, 0x92, 0x9a, 0x54, 0xa3, 0x14, 0x64,
    0x2d, 0xed, 0x63, 0x5b, 0x01, 0x2c, 0x33, 0x8b, 0xd7, 0xa9, 0xc8, 0x13, 0x34, 0xa7, 0x40, 0xd7,
    0x64, 0xae, 0xe2, 0x54, 0x7c, 0xda, 0x8b, 0x7a, 0x3b, 0xd7, 0x79, 0x00, 0xce, 0xe2, 0xfe, 0x45
};
#endif

PyTypeObject *init_QPaintDeviceWindow(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX].type;

    Shiboken::AutoDecRef Sbk_QPaintDeviceWindow_Type_bases(PyTuple_Pack(2,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX])),
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))));

    _Sbk_QPaintDeviceWindow_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPaintDeviceWindow",
        "QPaintDeviceWindow*",
        &Sbk_QPaintDeviceWindow_spec,
        &Shiboken::callCppDestructor< QPaintDeviceWindow >,
        Sbk_QPaintDeviceWindow_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QPaintDeviceWindow_TypeF(); // references _Sbk_QPaintDeviceWindow_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPaintDeviceWindow_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPaintDeviceWindow_SignatureBytes, QPaintDeviceWindow_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPaintDeviceWindow_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPaintDeviceWindow_PythonToCpp_QPaintDeviceWindow_PTR,
        is_QPaintDeviceWindow_PythonToCpp_QPaintDeviceWindow_PTR_Convertible,
        QPaintDeviceWindow_PTR_CppToPython_QPaintDeviceWindow);

    Shiboken::Conversions::registerConverterName(converter, "QPaintDeviceWindow");
    Shiboken::Conversions::registerConverterName(converter, "QPaintDeviceWindow*");
    Shiboken::Conversions::registerConverterName(converter, "QPaintDeviceWindow&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPaintDeviceWindow).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPaintDeviceWindowWrapper).name());

    MultipleInheritanceInitFunction func = Sbk_QPaintDeviceWindow_mi_init;
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QPaintDeviceWindow_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QPaintDeviceWindow_TypeF(), &Sbk_QPaintDeviceWindowSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPaintDeviceWindow_TypeF(), &Sbk_QPaintDeviceWindow_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QPaintDeviceWindow::staticMetaObject, sizeof(QPaintDeviceWindowWrapper));

    return pyType;
}
