// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QPAINTENGINEWRAPPER_H
#define SBK_QPAINTENGINEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qpaintengine.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QPaintEngineWrapper : public QPaintEngine
{
public:
    QPaintEngineWrapper(::QFlags<QPaintEngine::PaintEngineFeature> features = QPaintEngine::PaintEngineFeatures());
    QPaintEngineWrapper(const QPaintEngineWrapper &) = delete;
    QPaintEngineWrapper& operator=(const QPaintEngineWrapper &) = delete;
    QPaintEngineWrapper(QPaintEngineWrapper &&) = delete;
    QPaintEngineWrapper& operator=(QPaintEngineWrapper &&) = delete;
    ~QPaintEngineWrapper() override;

    bool begin(::QPaintDevice * pdev) override;
    static bool sbk_o_begin(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPaintDevice * pdev);
    ::QPoint coordinateOffset() const override;
    static ::QPoint sbk_o_coordinateOffset(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QPixmap createPixmap(::QSize size) override;
    static ::QPixmap sbk_o_createPixmap(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSize size);
    ::QPixmap createPixmapFromImage(::QImage image, ::QFlags<Qt::ImageConversionFlag> flags = Qt::AutoColor) override;
    static ::QPixmap sbk_o_createPixmapFromImage(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QImage image, ::QFlags<Qt::ImageConversionFlag> flags = Qt::AutoColor);
    void drawEllipse(const ::QRect & r) override;
    static void sbk_o_drawEllipse(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRect & r);
    void drawEllipse(const ::QRectF & r) override;
    static void sbk_o_drawEllipse(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRectF & r);
    void drawImage(const ::QRectF & r, const ::QImage & pm, const ::QRectF & sr, ::QFlags<Qt::ImageConversionFlag> flags = Qt::AutoColor) override;
    static void sbk_o_drawImage(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRectF & r, const ::QImage & pm, const ::QRectF & sr, ::QFlags<Qt::ImageConversionFlag> flags = Qt::AutoColor);
    void drawLines(const ::QLine * lines, int lineCount) override;
    static void sbk_o_drawLines(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QLine * lines, int lineCount);
    void drawLines(const ::QLineF * lines, int lineCount) override;
    static void sbk_o_drawLines(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QLineF * lines, int lineCount);
    void drawPath(const ::QPainterPath & path) override;
    static void sbk_o_drawPath(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPainterPath & path);
    void drawPixmap(const ::QRectF & r, const ::QPixmap & pm, const ::QRectF & sr) override;
    static void sbk_o_drawPixmap(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRectF & r, const ::QPixmap & pm, const ::QRectF & sr);
    void drawPoints(const ::QPoint * points, int pointCount) override;
    static void sbk_o_drawPoints(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPoint * points, int pointCount);
    void drawPoints(const ::QPointF * points, int pointCount) override;
    static void sbk_o_drawPoints(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPointF * points, int pointCount);
    void drawPolygon(const ::QPoint * points, int pointCount, ::QPaintEngine::PolygonDrawMode mode) override;
    static void sbk_o_drawPolygon(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPoint * points, int pointCount, ::QPaintEngine::PolygonDrawMode mode);
    void drawPolygon(const ::QPointF * points, int pointCount, ::QPaintEngine::PolygonDrawMode mode) override;
    static void sbk_o_drawPolygon(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPointF * points, int pointCount, ::QPaintEngine::PolygonDrawMode mode);
    void drawRects(const ::QRect * rects, int rectCount) override;
    static void sbk_o_drawRects(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRect * rects, int rectCount);
    void drawRects(const ::QRectF * rects, int rectCount) override;
    static void sbk_o_drawRects(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRectF * rects, int rectCount);
    void drawTextItem(const ::QPointF & p, const ::QTextItem & textItem) override;
    static void sbk_o_drawTextItem(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPointF & p, const ::QTextItem & textItem);
    void drawTiledPixmap(const ::QRectF & r, const ::QPixmap & pixmap, const ::QPointF & s) override;
    static void sbk_o_drawTiledPixmap(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRectF & r, const ::QPixmap & pixmap, const ::QPointF & s);
    bool end() override;
    static bool sbk_o_end(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QPaintEngine::Type type() const override;
    static ::QPaintEngine::Type sbk_o_type(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void updateState(const ::QPaintEngineState & state) override;
    static void sbk_o_updateState(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPaintEngineState & state);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[22] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QPAINTENGINEWRAPPER_H
