// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qpainterstateguard_wrapper.h"

// Argument includes
#include <QtGui/qpainter.h>
#include <QtGui/qpainterstateguard.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPainterStateGuard_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPainterStateGuard >()))
        return -1;

    ::QPainterStateGuard *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QPainterStateGuard", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPainterStateGuard::QPainterStateGuard(QPainter*,QPainterStateGuard::InitialState=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QPainterStateGuard(QPainter*,QPainterStateGuard::InitialState)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_InitialState_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // QPainterStateGuard(QPainter*,QPainterStateGuard::InitialState)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"state", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_InitialState_IDX])))->converter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QPainterStateGuard::InitialState cppArg1(QPainterStateGuard::InitialState::Save);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPainterStateGuard(QPainter*,QPainterStateGuard::InitialState)
            cptr = new ::QPainterStateGuard(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPainterStateGuard >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPainterStateGuardFunc___enter__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterStateGuard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __enter__()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtcore.cpp (default-enter)]
        Py_INCREF(self);
        pyResult = self;
        // END of custom code block [file: ../glue/qtcore.cpp (default-enter)]
        // ========================================================================
        // End of code injection

    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPainterStateGuardFunc___exit__(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterStateGuard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "__exit__", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainterStateGuard::__exit__(PyObject*,PyObject*,PyObject*)
    if (numArgs == 3
        && true
        && true
        && true) {
        overloadId = 0; // __exit__(PyObject*,PyObject*,PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "__exit__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __exit__(PyObject*,PyObject*,PyObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qpainterstateguard-restore)]
            cppSelf->restore();
            // END of custom code block [file: ../glue/qtgui.cpp (qpainterstateguard-restore)]
            // ========================================================================
            // End of code injection

        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPainterStateGuardFunc_restore(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterStateGuard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // restore()
        cppSelf->restore();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPainterStateGuardFunc_save(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterStateGuard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // save()
        cppSelf->save();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPainterStateGuardFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainterStateGuard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainterStateGuard::swap(QPainterStateGuard&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QPainterStateGuard&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPainterStateGuard *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QPainterStateGuard&)
            cppSelf->swap(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QPainterStateGuard_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QPainterStateGuard_EnumFlagInfo[] = {
    "InitialState:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPainterStateGuard_methods[] = {
    {"__enter__", reinterpret_cast<PyCFunction>(Sbk_QPainterStateGuardFunc___enter__), METH_NOARGS, nullptr},
    {"__exit__", reinterpret_cast<PyCFunction>(Sbk_QPainterStateGuardFunc___exit__), METH_VARARGS, nullptr},
    {"restore", reinterpret_cast<PyCFunction>(Sbk_QPainterStateGuardFunc_restore), METH_NOARGS, nullptr},
    {"save", reinterpret_cast<PyCFunction>(Sbk_QPainterStateGuardFunc_save), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QPainterStateGuardFunc_swap), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QPainterStateGuard_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPainterStateGuard_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPainterStateGuard_Type = nullptr;
static PyTypeObject *Sbk_QPainterStateGuard_TypeF(void)
{
    return _Sbk_QPainterStateGuard_Type;
}

static PyType_Slot Sbk_QPainterStateGuard_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPainterStateGuard_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPainterStateGuard_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPainterStateGuard_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPainterStateGuard_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPainterStateGuard_spec = {
    "2:PySide6.QtGui.QPainterStateGuard",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPainterStateGuard_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QPainterStateGuard_InitialState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPainterStateGuard::InitialState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPainterStateGuard::InitialState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPainterStateGuard_InitialState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_InitialState_IDX])))
        return Enum_PythonToCpp_QPainterStateGuard_InitialState;
    return {};
}

static PyObject *QPainterStateGuard_InitialState_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPainterStateGuard::InitialState>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPainterStateGuard::InitialState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_InitialState_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPainterStateGuard_PythonToCpp_QPainterStateGuard_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPainterStateGuard_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPainterStateGuard_PythonToCpp_QPainterStateGuard_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPainterStateGuard_TypeF()))
        return QPainterStateGuard_PythonToCpp_QPainterStateGuard_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPainterStateGuard_PTR_CppToPython_QPainterStateGuard(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPainterStateGuard_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPainterStateGuard_SignatureStrings[] = {
    "PySide6.QtGui.QPainterStateGuard(self,painter:PySide6.QtGui.QPainter,state:PySide6.QtGui.QPainterStateGuard.InitialState=QPainterStateGuard.InitialState.Save)",
    "PySide6.QtGui.QPainterStateGuard.__enter__(self)->PySide6.QtGui.QPainterStateGuard",
    "PySide6.QtGui.QPainterStateGuard.__exit__(self,arg__1:PyObject,arg__2:PyObject,arg__3:PyObject)",
    "PySide6.QtGui.QPainterStateGuard.restore(self)",
    "PySide6.QtGui.QPainterStateGuard.save(self)",
    "PySide6.QtGui.QPainterStateGuard.swap(self,other:PySide6.QtGui.QPainterStateGuard)",
    nullptr}; // Sentinel
#else
static constexpr size_t QPainterStateGuard_SignatureByteSize = 163;
static constexpr uint8_t QPainterStateGuard_SignatureBytes[163] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x71, 0x2f, 0xcd, 0xd4,
    0x0b, 0x0c, 0x48, 0xcc, 0xcc, 0x2b, 0x49, 0x2d, 0x0a, 0x2e, 0x49, 0x2c, 0x49, 0x75, 0x2f, 0x4d,
    0x2c, 0x4a, 0xd1, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x29, 0x80, 0x08, 0x5b, 0x05, 0x60, 0x55, 0xad,
    0x53, 0x0c, 0x52, 0x8e, 0x43, 0x12, 0x61, 0x94, 0x9e, 0x67, 0x5e, 0x66, 0x49, 0x66, 0x62, 0x0e,
    0x58, 0xc4, 0x96, 0x80, 0xbc, 0x5e, 0x70, 0x62, 0x59, 0xaa, 0x26, 0x17, 0x41, 0x33, 0xe3, 0xe3,
    0x53, 0x41, 0x22, 0xf1, 0xf1, 0x60, 0x87, 0x6a, 0xea, 0xda, 0x11, 0xd2, 0x41, 0x94, 0x91, 0x15,
    0x99, 0x25, 0x50, 0x13, 0x75, 0x12, 0x8b, 0xd2, 0xe3, 0xe3, 0x0d, 0x81, 0x9e, 0xf3, 0x4f, 0xca,
    0x4a, 0x4d, 0x2e, 0x81, 0xf0, 0x8d, 0xd0, 0xf8, 0xc6, 0x70, 0x3e, 0x11, 0x4e, 0x2e, 0x4a, 0x2d,
    0x2e, 0xc9, 0x2f, 0x4a, 0x85, 0x38, 0x98, 0xb0, 0xf2, 0x62, 0x60, 0x40, 0x10, 0xad, 0xb6, 0x3c,
    0xb1, 0x00, 0xe2, 0xec, 0xfc, 0x92, 0x0c, 0x9c, 0xf1, 0x85, 0xd0, 0xa0, 0xc9, 0x05, 0x00, 0x45,
    0x67, 0xba, 0x0a
};
#endif

PyTypeObject *init_QPainterStateGuard(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX].type;

    Shiboken::AutoDecRef Sbk_QPainterStateGuard_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPainterStateGuard_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPainterStateGuard",
        "QPainterStateGuard*",
        &Sbk_QPainterStateGuard_spec,
        &Shiboken::callCppDestructor< ::QPainterStateGuard >,
        Sbk_QPainterStateGuard_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPainterStateGuard_TypeF(); // references _Sbk_QPainterStateGuard_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPainterStateGuard_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPainterStateGuard_SignatureBytes, QPainterStateGuard_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPainterStateGuard_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPainterStateGuard_PythonToCpp_QPainterStateGuard_PTR,
        is_QPainterStateGuard_PythonToCpp_QPainterStateGuard_PTR_Convertible,
        QPainterStateGuard_PTR_CppToPython_QPainterStateGuard);

    Shiboken::Conversions::registerConverterName(converter, "QPainterStateGuard");
    Shiboken::Conversions::registerConverterName(converter, "QPainterStateGuard*");
    Shiboken::Conversions::registerConverterName(converter, "QPainterStateGuard&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPainterStateGuard).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPainterStateGuard_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'InitialState'.
    const char *InitialState_Initializer[] = {
        "Save",
        "NoSave",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t InitialState_InitializerValues[] = {
        uint8_t(QPainterStateGuard::InitialState::Save),  //  0x00  0
        uint8_t(QPainterStateGuard::InitialState::NoSave) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPainterStateGuard_TypeF(),
        "2:PySide6.QtGui.QPainterStateGuard.InitialState",
        InitialState_Initializer, InitialState_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QPainterStateGuard_InitialState_IDX].type = EType;
    // Register converter for enum 'QPainterStateGuard::InitialState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPainterStateGuard_InitialState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPainterStateGuard_InitialState,
            is_Enum_PythonToCpp_QPainterStateGuard_InitialState_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPainterStateGuard::InitialState");
        Shiboken::Conversions::registerConverterAlias(converter, "InitialState");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'InitialState' enum.

    qRegisterMetaType< ::QPainterStateGuard *>();
    qRegisterMetaType< ::QPainterStateGuard::InitialState >("QPainterStateGuard::InitialState");

    return pyType;
}
