// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrasterwindow_wrapper.h"

// Wrappers providing overrides
#include "qpaintdevicewindow_wrapper.h"
#include "qwindow_wrapper.h"
#include "qundocommand_wrapper.h"
#include "qsurface_wrapper.h"
#include "qaccessibletablecellinterface_wrapper.h"
#include "qaccessibleinterface_wrapper.h"
#include "qpaintdevice_wrapper.h"

// Argument includes
#include <QtGui/qaccessible.h>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <QtGui/qwindow.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRasterWindowWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QRasterWindowWrapper::QRasterWindowWrapper(::QWindow * parent) : QRasterWindow(parent)
{
}

::QAccessibleInterface * QRasterWindowWrapper::accessibleRoot() const
{
    static const char *funcName = "accessibleRoot";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::accessibleRoot();
    }
    return QAccessibleTableCellInterfaceWrapper::sbk_o_table("QRasterWindow", funcName, gil, pyOverride);
}

void QRasterWindowWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWindowWrapper::sbk_o_childEvent("QRasterWindow", funcName, gil, pyOverride, event);
}

void QRasterWindowWrapper::closeEvent(::QCloseEvent * arg__1)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::closeEvent(arg__1);
    }
    QWindowWrapper::sbk_o_closeEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

void QRasterWindowWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWindowWrapper::sbk_o_connectNotify("QRasterWindow", funcName, gil, pyOverride, signal);
}

void QRasterWindowWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWindowWrapper::sbk_o_customEvent("QRasterWindow", funcName, gil, pyOverride, event);
}

int QRasterWindowWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDevice::devType();
    }
    return QUndoCommandWrapper::sbk_o_id("QRasterWindow", funcName, gil, pyOverride);
}

void QRasterWindowWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWindowWrapper::sbk_o_connectNotify("QRasterWindow", funcName, gil, pyOverride, signal);
}

bool QRasterWindowWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDeviceWindow::event(event);
    }
    return QWindowWrapper::sbk_o_event("QRasterWindow", funcName, gil, pyOverride, event);
}

bool QRasterWindowWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWindowWrapper::sbk_o_eventFilter("QRasterWindow", funcName, gil, pyOverride, watched, event);
}

void QRasterWindowWrapper::exposeEvent(::QExposeEvent * arg__1)
{
    static const char *funcName = "exposeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDeviceWindow::exposeEvent(arg__1);
    }
    QWindowWrapper::sbk_o_exposeEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

void QRasterWindowWrapper::focusInEvent(::QFocusEvent * arg__1)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::focusInEvent(arg__1);
    }
    QWindowWrapper::sbk_o_focusInEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

::QObject * QRasterWindowWrapper::focusObject() const
{
    static const char *funcName = "focusObject";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::focusObject();
    }
    return QAccessibleInterfaceWrapper::sbk_o_object("QRasterWindow", funcName, gil, pyOverride);
}

void QRasterWindowWrapper::focusOutEvent(::QFocusEvent * arg__1)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::focusOutEvent(arg__1);
    }
    QWindowWrapper::sbk_o_focusInEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

::QSurfaceFormat QRasterWindowWrapper::format() const
{
    static const char *funcName = "format";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::format();
    }
    return QSurfaceWrapper::sbk_o_format("QRasterWindow", funcName, gil, pyOverride);
}

void QRasterWindowWrapper::hideEvent(::QHideEvent * arg__1)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::hideEvent(arg__1);
    }
    QWindowWrapper::sbk_o_hideEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

void QRasterWindowWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDevice::initPainter(painter);
    }
    QPaintDeviceWrapper::sbk_o_initPainter("QRasterWindow", funcName, gil, pyOverride, painter);
}

void QRasterWindowWrapper::keyPressEvent(::QKeyEvent * arg__1)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::keyPressEvent(arg__1);
    }
    QWindowWrapper::sbk_o_keyPressEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

void QRasterWindowWrapper::keyReleaseEvent(::QKeyEvent * arg__1)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::keyReleaseEvent(arg__1);
    }
    QWindowWrapper::sbk_o_keyPressEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

int QRasterWindowWrapper::metric(::QPaintDevice::PaintDeviceMetric metric) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRasterWindow::metric(metric);
    }
    return QPaintDeviceWrapper::sbk_o_metric("QRasterWindow", funcName, gil, pyOverride, metric);
}

void QRasterWindowWrapper::mouseDoubleClickEvent(::QMouseEvent * arg__1)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::mouseDoubleClickEvent(arg__1);
    }
    QWindowWrapper::sbk_o_mouseDoubleClickEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

void QRasterWindowWrapper::mouseMoveEvent(::QMouseEvent * arg__1)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::mouseMoveEvent(arg__1);
    }
    QWindowWrapper::sbk_o_mouseDoubleClickEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

void QRasterWindowWrapper::mousePressEvent(::QMouseEvent * arg__1)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::mousePressEvent(arg__1);
    }
    QWindowWrapper::sbk_o_mouseDoubleClickEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

void QRasterWindowWrapper::mouseReleaseEvent(::QMouseEvent * arg__1)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::mouseReleaseEvent(arg__1);
    }
    QWindowWrapper::sbk_o_mouseDoubleClickEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

void QRasterWindowWrapper::moveEvent(::QMoveEvent * arg__1)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::moveEvent(arg__1);
    }
    QWindowWrapper::sbk_o_moveEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

bool QRasterWindowWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::nativeEvent(eventType, message, result);
    }
    return QPaintDeviceWindowWrapper::sbk_o_nativeEvent("QRasterWindow", funcName, gil, pyOverride, eventType, message, result);
}

void QRasterWindowWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDeviceWindow::paintEvent(event);
    }
    QWindowWrapper::sbk_o_paintEvent("QRasterWindow", funcName, gil, pyOverride, event);
}

::QPaintDevice * QRasterWindowWrapper::redirected(::QPoint * arg__1) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRasterWindow::redirected(arg__1);
    }
    return QPaintDeviceWrapper::sbk_o_redirected("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

void QRasterWindowWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRasterWindow::resizeEvent(event);
    }
    QWindowWrapper::sbk_o_resizeEvent("QRasterWindow", funcName, gil, pyOverride, event);
}

::QPainter * QRasterWindowWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPaintDevice::sharedPainter();
    }
    return QPaintDeviceWrapper::sbk_o_sharedPainter("QRasterWindow", funcName, gil, pyOverride);
}

void QRasterWindowWrapper::showEvent(::QShowEvent * arg__1)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::showEvent(arg__1);
    }
    QWindowWrapper::sbk_o_showEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

::QSize QRasterWindowWrapper::size() const
{
    static const char *funcName = "size";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::size();
    }
    return QSurfaceWrapper::sbk_o_size("QRasterWindow", funcName, gil, pyOverride);
}

::QSurface::SurfaceType QRasterWindowWrapper::surfaceType() const
{
    static const char *funcName = "surfaceType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::surfaceType();
    }
    return QSurfaceWrapper::sbk_o_surfaceType("QRasterWindow", funcName, gil, pyOverride);
}

void QRasterWindowWrapper::tabletEvent(::QTabletEvent * arg__1)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::tabletEvent(arg__1);
    }
    QWindowWrapper::sbk_o_tabletEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

void QRasterWindowWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWindowWrapper::sbk_o_timerEvent("QRasterWindow", funcName, gil, pyOverride, event);
}

void QRasterWindowWrapper::touchEvent(::QTouchEvent * arg__1)
{
    static const char *funcName = "touchEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::touchEvent(arg__1);
    }
    QWindowWrapper::sbk_o_touchEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

void QRasterWindowWrapper::wheelEvent(::QWheelEvent * arg__1)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWindow::wheelEvent(arg__1);
    }
    QWindowWrapper::sbk_o_wheelEvent("QRasterWindow", funcName, gil, pyOverride, arg__1);
}

const QMetaObject *QRasterWindowWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QRasterWindow::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QRasterWindowWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QRasterWindow::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QRasterWindowWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QRasterWindowWrapper *>(this));
    return QRasterWindow::qt_metacast(_clname);
}

QRasterWindowWrapper::~QRasterWindowWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRasterWindow_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRasterWindow >()))
        return -1;

    QRasterWindowWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QRasterWindow", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRasterWindow::QRasterWindow(QWindow*=)
    if (numArgs == 0) {
        overloadId = 0; // QRasterWindow(QWindow*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QRasterWindow(QWindow*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWindow *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QRasterWindow(QWindow*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QRasterWindowWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QRasterWindowWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QRasterWindow >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QRasterWindowFunc_metric(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRasterWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintDevice::metric(QPaintDevice::PaintDeviceMetric)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "metric", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX]);

    // Call function/method
    {
        ::QPaintDevice::PaintDeviceMetric cppArg0 = static_cast< ::QPaintDevice::PaintDeviceMetric>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // metric(QPaintDevice::PaintDeviceMetric)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QRasterWindow *>(cppSelf)->::QRasterWindow::metric(cppArg0)
                : const_cast<const ::QRasterWindow *>(cppSelf)->metric(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRasterWindowFunc_redirected(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRasterWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintDevice::redirected(QPoint*)const->QPaintDevice*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // redirected(QPoint*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "redirected", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // redirected(QPoint*)const
            QPaintDevice * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QRasterWindow *>(cppSelf)->::QRasterWindow::redirected(cppArg0)
                : const_cast<const ::QRasterWindow *>(cppSelf)->redirected(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRasterWindowFunc_resizeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRasterWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWindow::resizeEvent(QResizeEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), (pyArg)))) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resizeEvent", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QResizeEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeEvent(QResizeEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QRasterWindow::resizeEvent(cppArg0)
                : cppSelf->resizeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QRasterWindow_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRasterWindow_methods[] = {
    {"metric", reinterpret_cast<PyCFunction>(Sbk_QRasterWindowFunc_metric), METH_O, nullptr},
    {"redirected", reinterpret_cast<PyCFunction>(Sbk_QRasterWindowFunc_redirected), METH_O, nullptr},
    {"resizeEvent", reinterpret_cast<PyCFunction>(Sbk_QRasterWindowFunc_resizeEvent), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRasterWindow_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRasterWindow *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRasterWindowWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QRasterWindow_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRasterWindow_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QRasterWindowSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QRasterWindow *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]))
        return static_cast< ::QPaintDeviceWindow *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]))
        return static_cast< ::QWindow *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX]))
        return static_cast< ::QSurface *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRasterWindow_Type = nullptr;
static PyTypeObject *Sbk_QRasterWindow_TypeF(void)
{
    return _Sbk_QRasterWindow_Type;
}

static PyType_Slot Sbk_QRasterWindow_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRasterWindow_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRasterWindow_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRasterWindow_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRasterWindow_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRasterWindow_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRasterWindow_spec = {
    "2:PySide6.QtGui.QRasterWindow",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRasterWindow_slots
};

} //extern "C"

static void *Sbk_QRasterWindow_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWindow >())
        return dynamic_cast< ::QRasterWindow *>(reinterpret_cast< ::QWindow *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QRasterWindow *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QSurface >())
        return dynamic_cast< ::QRasterWindow *>(reinterpret_cast< ::QSurface *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QRasterWindow *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRasterWindow_PythonToCpp_QRasterWindow_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRasterWindow_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRasterWindow_PythonToCpp_QRasterWindow_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRasterWindow_TypeF()))
        return QRasterWindow_PythonToCpp_QRasterWindow_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRasterWindow_PTR_CppToPython_QRasterWindow(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QRasterWindow *>(const_cast<void *>(cppIn)), Sbk_QRasterWindow_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRasterWindow_SignatureStrings[] = {
    "PySide6.QtGui.QRasterWindow(self,parent:PySide6.QtGui.QWindow=nullptr)",
    "PySide6.QtGui.QRasterWindow.metric(self,metric:PySide6.QtGui.QPaintDevice.PaintDeviceMetric)->int",
    "PySide6.QtGui.QRasterWindow.redirected(self,arg__1:PySide6.QtCore.QPoint)->PySide6.QtGui.QPaintDevice",
    "PySide6.QtGui.QRasterWindow.resizeEvent(self,event:PySide6.QtGui.QResizeEvent)",
    nullptr}; // Sentinel
#else
static constexpr size_t QRasterWindow_SignatureByteSize = 157;
static constexpr uint8_t QRasterWindow_SignatureBytes[157] = {
    0x78, 0xda, 0x85, 0x90, 0x31, 0x0b, 0xc2, 0x30, 0x10, 0x46, 0xf7, 0xfe, 0x12, 0x0b, 0x1a, 0x70,
    0x71, 0x10, 0x74, 0x51, 0x71, 0x2a, 0xa4, 0x75, 0x70, 0x2c, 0xa1, 0xf9, 0x94, 0x83, 0x9a, 0x94,
    0xeb, 0xb5, 0xa2, 0xbf, 0xde, 0x60, 0x06, 0xab, 0x58, 0xdd, 0x3e, 0x8e, 0xc7, 0x7b, 0x70, 0xfa,
    0x76, 0x20, 0x8b, 0x85, 0xca, 0x65, 0xdf, 0x91, 0xca, 0x0b, 0xd3, 0x0a, 0xf8, 0x48, 0xce, 0xfa,
    0xeb, 0xa4, 0x45, 0x7d, 0x9a, 0x36, 0x86, 0xe1, 0x64, 0xa9, 0xdf, 0xb9, 0x48, 0xac, 0x5c, 0x57,
    0xd7, 0x8d, 0x70, 0x9a, 0xe8, 0x71, 0x8d, 0xba, 0x40, 0x98, 0xaa, 0x68, 0x8b, 0xfb, 0xd3, 0xa6,
    0x0d, 0x39, 0xd9, 0xa2, 0xa7, 0x0a, 0x6a, 0xb0, 0xb3, 0x27, 0x9c, 0xce, 0xd6, 0xe1, 0xf2, 0xb3,
    0xc0, 0xb0, 0xc4, 0xa8, 0x04, 0x36, 0x56, 0x0c, 0x9f, 0xcb, 0x72, 0x3e, 0xa8, 0x6c, 0x3c, 0x23,
    0x64, 0x7c, 0x10, 0x05, 0xdd, 0x78, 0xfd, 0x4f, 0xa5, 0xa5, 0x3b, 0x76, 0x7d, 0x78, 0x47, 0xcc,
    0xa0, 0xff, 0xf2, 0x99, 0xe2, 0x45, 0xa5, 0xc9, 0x03, 0x22, 0x79, 0x7e, 0x99
};
#endif

PyTypeObject *init_QRasterWindow(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX].type;

    Shiboken::AutoDecRef Sbk_QRasterWindow_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]))));

    _Sbk_QRasterWindow_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRasterWindow",
        "QRasterWindow*",
        &Sbk_QRasterWindow_spec,
        &Shiboken::callCppDestructor< QRasterWindow >,
        Sbk_QRasterWindow_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QRasterWindow_TypeF(); // references _Sbk_QRasterWindow_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRasterWindow_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRasterWindow_SignatureBytes, QRasterWindow_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRasterWindow_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRasterWindow_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRasterWindow_PythonToCpp_QRasterWindow_PTR,
        is_QRasterWindow_PythonToCpp_QRasterWindow_PTR_Convertible,
        QRasterWindow_PTR_CppToPython_QRasterWindow);

    Shiboken::Conversions::registerConverterName(converter, "QRasterWindow");
    Shiboken::Conversions::registerConverterName(converter, "QRasterWindow*");
    Shiboken::Conversions::registerConverterName(converter, "QRasterWindow&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRasterWindow).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRasterWindowWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDeviceWindow_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QRasterWindow_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QRasterWindow_TypeF(), &Sbk_QRasterWindowSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRasterWindow_TypeF(), &Sbk_QRasterWindow_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QRasterWindow::staticMetaObject, sizeof(QRasterWindowWrapper));

    return pyType;
}
