// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSINGLEPOINTEVENTWRAPPER_H
#define SBK_QSINGLEPOINTEVENTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QSinglePointEventWrapper : public QSinglePointEvent
{
public:
    QSinglePointEventWrapper(::QEvent::Type type, const ::QPointingDevice * dev, const ::QEventPoint & point, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, ::Qt::MouseEventSource source);
    QSinglePointEventWrapper(::QEvent::Type type, const ::QPointingDevice * dev, const ::QPointF & localPos, const ::QPointF & scenePos, const ::QPointF & globalPos, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, ::Qt::MouseEventSource source = Qt::MouseEventNotSynthesized);
    QSinglePointEventWrapper(const QSinglePointEventWrapper &) = delete;
    QSinglePointEventWrapper(const QSinglePointEvent& self) : QSinglePointEvent(self)
    {
    }
    QSinglePointEventWrapper& operator=(const QSinglePointEventWrapper &) = delete;
    QSinglePointEventWrapper(QSinglePointEventWrapper &&) = delete;
    QSinglePointEventWrapper& operator=(QSinglePointEventWrapper &&) = delete;
    ~QSinglePointEventWrapper() override;

    ::QSinglePointEvent * clone() const override;
    static ::QSinglePointEvent * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted) override;
    void setTimestamp(quint64 timestamp) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QSINGLEPOINTEVENTWRAPPER_H
