// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSTANDARDITEMWRAPPER_H
#define SBK_QSTANDARDITEMWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qstandarditemmodel.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QStandardItemWrapper : public QStandardItem
{
public:
    QStandardItemWrapper();
    QStandardItemWrapper(const ::QIcon & icon, const ::QString & text);
    QStandardItemWrapper(const ::QString & text);
    QStandardItemWrapper(int rows, int columns = 1);
    QStandardItemWrapper(const QStandardItemWrapper &) = delete;
    QStandardItemWrapper(const QStandardItem& self) : QStandardItem(self)
    {
    }
    QStandardItemWrapper& operator=(const QStandardItemWrapper &) = delete;
    QStandardItemWrapper(QStandardItemWrapper &&) = delete;
    QStandardItemWrapper& operator=(QStandardItemWrapper &&) = delete;
    ~QStandardItemWrapper() override;

    ::QStandardItem * clone() const override;
    static ::QStandardItem * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QVariant data(int role = Qt::UserRole + 1) const override;
    static ::QVariant sbk_o_data(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int role = Qt::UserRole + 1);
    void multiData(::QModelRoleDataSpan roleDataSpan) const override;
    static void sbk_o_multiData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QModelRoleDataSpan roleDataSpan);
    bool operator<(const ::QStandardItem & other) const override;
    static bool sbk_o_op_lt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QStandardItem & other);
    void read(::QDataStream & in) override;
    static void sbk_o_read(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QDataStream & in);
    void setData(const ::QVariant & value, int role = Qt::UserRole + 1) override;
    static void sbk_o_setData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QVariant & value, int role = Qt::UserRole + 1);
    int type() const override;
    void write(::QDataStream & out) const override;
    static void sbk_o_write(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QDataStream & out);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[8] = {false, false, false, false, false, false, false, false};
};

#endif // SBK_QSTANDARDITEMWRAPPER_H
