// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSURFACEWRAPPER_H
#define SBK_QSURFACEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qsurface.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QSurfaceWrapper : public QSurface
{
public:
    QSurfaceWrapper(::QSurface::SurfaceClass type);
    QSurfaceWrapper(const QSurfaceWrapper &) = delete;
    QSurfaceWrapper& operator=(const QSurfaceWrapper &) = delete;
    QSurfaceWrapper(QSurfaceWrapper &&) = delete;
    QSurfaceWrapper& operator=(QSurfaceWrapper &&) = delete;
    ~QSurfaceWrapper() override;

    ::QSurfaceFormat format() const override;
    static ::QSurfaceFormat sbk_o_format(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QSize size() const override;
    static ::QSize sbk_o_size(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QPlatformSurface * surfaceHandle() const override;
    static ::QPlatformSurface * sbk_o_surfaceHandle(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QSurface::SurfaceType surfaceType() const override;
    static ::QSurface::SurfaceType sbk_o_surfaceType(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[4] = {false, false, false, false};
};

#endif // SBK_QSURFACEWRAPPER_H
