// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QTABLETEVENTWRAPPER_H
#define SBK_QTABLETEVENTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QTabletEventWrapper : public QTabletEvent
{
public:
    QTabletEventWrapper(::QEvent::Type t, const ::QPointingDevice * device, const ::QPointF & pos, const ::QPointF & globalPos, qreal pressure, float xTilt, float yTilt, float tangentialPressure, qreal rotation, float z, ::QFlags<Qt::KeyboardModifier> keyState, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons);
    QTabletEventWrapper(const QTabletEventWrapper &) = delete;
    QTabletEventWrapper(const QTabletEvent& self) : QTabletEvent(self)
    {
    }
    QTabletEventWrapper& operator=(const QTabletEventWrapper &) = delete;
    QTabletEventWrapper(QTabletEventWrapper &&) = delete;
    QTabletEventWrapper& operator=(QTabletEventWrapper &&) = delete;
    ~QTabletEventWrapper() override;

    ::QTabletEvent * clone() const override;
    static ::QTabletEvent * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted) override;
    void setTimestamp(quint64 timestamp) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QTABLETEVENTWRAPPER_H
