// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QUNDOCOMMANDWRAPPER_H
#define SBK_QUNDOCOMMANDWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qundostack.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QUndoCommandWrapper : public QUndoCommand
{
public:
    QUndoCommandWrapper(::QUndoCommand * parent = nullptr);
    QUndoCommandWrapper(const ::QString & text, ::QUndoCommand * parent = nullptr);
    QUndoCommandWrapper(const QUndoCommandWrapper &) = delete;
    QUndoCommandWrapper& operator=(const QUndoCommandWrapper &) = delete;
    QUndoCommandWrapper(QUndoCommandWrapper &&) = delete;
    QUndoCommandWrapper& operator=(QUndoCommandWrapper &&) = delete;
    ~QUndoCommandWrapper() override;

    int id() const override;
    static int sbk_o_id(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool mergeWith(const ::QUndoCommand * other) override;
    static bool sbk_o_mergeWith(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUndoCommand * other);
    void redo() override;
    static void sbk_o_redo(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void undo() override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[4] = {false, false, false, false};
};

#endif // SBK_QUNDOCOMMANDWRAPPER_H
