// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthelp_python.h"

// main header
#include "qhelpindexwidget_wrapper.h"

// Wrappers providing overrides
#include "qhelpcontentwidget_wrapper.h"

// Argument includes
#include <QList>
#include <QMultiMap>
#include <QString>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qregion.h>
#include <QtHelp/qhelplink.h>
#include <QtWidgets/qabstractitemdelegate.h>
#include <QtWidgets/qabstractitemview.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qitemselectionmodel.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qurl.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QHelpIndexWidgetWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QHelpIndexWidgetWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_actionEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

void QHelpIndexWidgetWrapper::changeEvent(::QEvent * arg__1)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFrame::changeEvent(arg__1);
    }
    QHelpContentWidgetWrapper::sbk_o_changeEvent("QHelpIndexWidget", funcName, gil, pyOverride, arg__1);
}

void QHelpIndexWidgetWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_childEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

void QHelpIndexWidgetWrapper::closeEditor(::QWidget * editor, ::QAbstractItemDelegate::EndEditHint hint)
{
    static const char *funcName = "closeEditor";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::closeEditor(editor, hint);
    }
    QHelpContentWidgetWrapper::sbk_o_closeEditor("QHelpIndexWidget", funcName, gil, pyOverride, editor, hint);
}

void QHelpIndexWidgetWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_closeEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

void QHelpIndexWidgetWrapper::commitData(::QWidget * editor)
{
    static const char *funcName = "commitData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::commitData(editor);
    }
    QHelpContentWidgetWrapper::sbk_o_commitData("QHelpIndexWidget", funcName, gil, pyOverride, editor);
}

void QHelpIndexWidgetWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QHelpContentWidgetWrapper::sbk_o_connectNotify("QHelpIndexWidget", funcName, gil, pyOverride, signal);
}

void QHelpIndexWidgetWrapper::contextMenuEvent(::QContextMenuEvent * arg__1)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::contextMenuEvent(arg__1);
    }
    QHelpContentWidgetWrapper::sbk_o_contextMenuEvent("QHelpIndexWidget", funcName, gil, pyOverride, arg__1);
}

void QHelpIndexWidgetWrapper::currentChanged(const ::QModelIndex & current, const ::QModelIndex & previous)
{
    static const char *funcName = "currentChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::currentChanged(current, previous);
    }
    QHelpContentWidgetWrapper::sbk_o_currentChanged("QHelpIndexWidget", funcName, gil, pyOverride, current, previous);
}

void QHelpIndexWidgetWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_customEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

void QHelpIndexWidgetWrapper::dataChanged(const ::QModelIndex & topLeft, const ::QModelIndex & bottomRight, const ::QList<int> & roles)
{
    static const char *funcName = "dataChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::dataChanged(topLeft, bottomRight, roles);
    }
    QHelpContentWidgetWrapper::sbk_o_dataChanged("QHelpIndexWidget", funcName, gil, pyOverride, topLeft, bottomRight, roles);
}

int QHelpIndexWidgetWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QHelpContentWidgetWrapper::sbk_o_devType("QHelpIndexWidget", funcName, gil, pyOverride);
}

void QHelpIndexWidgetWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QHelpContentWidgetWrapper::sbk_o_connectNotify("QHelpIndexWidget", funcName, gil, pyOverride, signal);
}

void QHelpIndexWidgetWrapper::doItemsLayout()
{
    static const char *funcName = "doItemsLayout";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::doItemsLayout();
    }
    QHelpContentWidgetWrapper::sbk_o_doItemsLayout("QHelpIndexWidget", funcName, gil, pyOverride);
}

void QHelpIndexWidgetWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::dragEnterEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_dragEnterEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

void QHelpIndexWidgetWrapper::dragLeaveEvent(::QDragLeaveEvent * e)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::dragLeaveEvent(e);
    }
    QHelpContentWidgetWrapper::sbk_o_dragLeaveEvent("QHelpIndexWidget", funcName, gil, pyOverride, e);
}

void QHelpIndexWidgetWrapper::dragMoveEvent(::QDragMoveEvent * e)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::dragMoveEvent(e);
    }
    QHelpContentWidgetWrapper::sbk_o_dragMoveEvent("QHelpIndexWidget", funcName, gil, pyOverride, e);
}

void QHelpIndexWidgetWrapper::dropEvent(::QDropEvent * e)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::dropEvent(e);
    }
    QHelpContentWidgetWrapper::sbk_o_dropEvent("QHelpIndexWidget", funcName, gil, pyOverride, e);
}

bool QHelpIndexWidgetWrapper::edit(const ::QModelIndex & index, ::QAbstractItemView::EditTrigger trigger, ::QEvent * event)
{
    static const char *funcName = "edit";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::edit(index, trigger, event);
    }
    return QHelpContentWidgetWrapper::sbk_o_edit("QHelpIndexWidget", funcName, gil, pyOverride, index, trigger, event);
}

void QHelpIndexWidgetWrapper::editorDestroyed(::QObject * editor)
{
    static const char *funcName = "editorDestroyed";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::editorDestroyed(editor);
    }
    QHelpContentWidgetWrapper::sbk_o_editorDestroyed("QHelpIndexWidget", funcName, gil, pyOverride, editor);
}

void QHelpIndexWidgetWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_enterEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

bool QHelpIndexWidgetWrapper::event(::QEvent * e)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::event(e);
    }
    return QHelpContentWidgetWrapper::sbk_o_event("QHelpIndexWidget", funcName, gil, pyOverride, e);
}

bool QHelpIndexWidgetWrapper::eventFilter(::QObject * object, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::eventFilter(object, event);
    }
    return QHelpContentWidgetWrapper::sbk_o_eventFilter("QHelpIndexWidget", funcName, gil, pyOverride, object, event);
}

void QHelpIndexWidgetWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::focusInEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_focusInEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

bool QHelpIndexWidgetWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::focusNextPrevChild(next);
    }
    return QHelpContentWidgetWrapper::sbk_o_focusNextPrevChild("QHelpIndexWidget", funcName, gil, pyOverride, next);
}

void QHelpIndexWidgetWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::focusOutEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_focusOutEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

bool QHelpIndexWidgetWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QHelpContentWidgetWrapper::sbk_o_hasHeightForWidth("QHelpIndexWidget", funcName, gil, pyOverride);
}

int QHelpIndexWidgetWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QHelpContentWidgetWrapper::sbk_o_heightForWidth("QHelpIndexWidget", funcName, gil, pyOverride, arg__1);
}

void QHelpIndexWidgetWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_hideEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

int QHelpIndexWidgetWrapper::horizontalOffset() const
{
    static const char *funcName = "horizontalOffset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::horizontalOffset();
    }
    return QHelpContentWidgetWrapper::sbk_o_devType("QHelpIndexWidget", funcName, gil, pyOverride);
}

void QHelpIndexWidgetWrapper::horizontalScrollbarAction(int action)
{
    static const char *funcName = "horizontalScrollbarAction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::horizontalScrollbarAction(action);
    }
    QHelpContentWidgetWrapper::sbk_o_horizontalScrollbarAction("QHelpIndexWidget", funcName, gil, pyOverride, action);
}

void QHelpIndexWidgetWrapper::horizontalScrollbarValueChanged(int value)
{
    static const char *funcName = "horizontalScrollbarValueChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::horizontalScrollbarValueChanged(value);
    }
    QHelpContentWidgetWrapper::sbk_o_horizontalScrollbarAction("QHelpIndexWidget", funcName, gil, pyOverride, value);
}

::QModelIndex QHelpIndexWidgetWrapper::indexAt(const ::QPoint & p) const
{
    static const char *funcName = "indexAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::indexAt(p);
    }
    return QHelpContentWidgetWrapper::sbk_o_indexAt("QHelpIndexWidget", funcName, gil, pyOverride, p);
}

void QHelpIndexWidgetWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QHelpContentWidgetWrapper::sbk_o_initPainter("QHelpIndexWidget", funcName, gil, pyOverride, painter);
}

void QHelpIndexWidgetWrapper::initStyleOption(::QStyleOptionFrame * option) const
{
    static const char *funcName = "initStyleOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFrame::initStyleOption(option);
    }
    QHelpContentWidgetWrapper::sbk_o_initStyleOption("QHelpIndexWidget", funcName, gil, pyOverride, option);
}

void QHelpIndexWidgetWrapper::initViewItemOption(::QStyleOptionViewItem * option) const
{
    static const char *funcName = "initViewItemOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::initViewItemOption(option);
    }
    QHelpContentWidgetWrapper::sbk_o_initViewItemOption("QHelpIndexWidget", funcName, gil, pyOverride, option);
}

void QHelpIndexWidgetWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::inputMethodEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_inputMethodEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

::QVariant QHelpIndexWidgetWrapper::inputMethodQuery(::Qt::InputMethodQuery query) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::inputMethodQuery(query);
    }
    return QHelpContentWidgetWrapper::sbk_o_inputMethodQuery("QHelpIndexWidget", funcName, gil, pyOverride, query);
}

bool QHelpIndexWidgetWrapper::isIndexHidden(const ::QModelIndex & index) const
{
    static const char *funcName = "isIndexHidden";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::isIndexHidden(index);
    }
    return QHelpContentWidgetWrapper::sbk_o_isIndexHidden("QHelpIndexWidget", funcName, gil, pyOverride, index);
}

::QAbstractItemDelegate * QHelpIndexWidgetWrapper::itemDelegateForIndex(const ::QModelIndex & index) const
{
    static const char *funcName = "itemDelegateForIndex";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::itemDelegateForIndex(index);
    }
    return QHelpContentWidgetWrapper::sbk_o_itemDelegateForIndex("QHelpIndexWidget", funcName, gil, pyOverride, index);
}

void QHelpIndexWidgetWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::keyPressEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_keyPressEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

void QHelpIndexWidgetWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_keyReleaseEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

void QHelpIndexWidgetWrapper::keyboardSearch(const ::QString & search)
{
    static const char *funcName = "keyboardSearch";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::keyboardSearch(search);
    }
    QHelpContentWidgetWrapper::sbk_o_keyboardSearch("QHelpIndexWidget", funcName, gil, pyOverride, search);
}

void QHelpIndexWidgetWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_leaveEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

int QHelpIndexWidgetWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QHelpContentWidgetWrapper::sbk_o_metric("QHelpIndexWidget", funcName, gil, pyOverride, arg__1);
}

::QSize QHelpIndexWidgetWrapper::minimumSizeHint() const
{
    static const char *funcName = "minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::minimumSizeHint();
    }
    return QHelpContentWidgetWrapper::sbk_o_minimumSizeHint("QHelpIndexWidget", funcName, gil, pyOverride);
}

void QHelpIndexWidgetWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::mouseDoubleClickEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_mouseDoubleClickEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

void QHelpIndexWidgetWrapper::mouseMoveEvent(::QMouseEvent * e)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::mouseMoveEvent(e);
    }
    QHelpContentWidgetWrapper::sbk_o_mouseMoveEvent("QHelpIndexWidget", funcName, gil, pyOverride, e);
}

void QHelpIndexWidgetWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::mousePressEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_mousePressEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

void QHelpIndexWidgetWrapper::mouseReleaseEvent(::QMouseEvent * e)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::mouseReleaseEvent(e);
    }
    QHelpContentWidgetWrapper::sbk_o_mouseReleaseEvent("QHelpIndexWidget", funcName, gil, pyOverride, e);
}

::QModelIndex QHelpIndexWidgetWrapper::moveCursor(::QAbstractItemView::CursorAction cursorAction, ::QFlags<Qt::KeyboardModifier> modifiers)
{
    static const char *funcName = "moveCursor";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::moveCursor(cursorAction, modifiers);
    }
    return QHelpContentWidgetWrapper::sbk_o_moveCursor("QHelpIndexWidget", funcName, gil, pyOverride, cursorAction, modifiers);
}

void QHelpIndexWidgetWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_moveEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

bool QHelpIndexWidgetWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[52], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QHelpContentWidgetWrapper::sbk_o_nativeEvent("QHelpIndexWidget", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QHelpIndexWidgetWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[53], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QHelpContentWidgetWrapper::sbk_o_paintEngine("QHelpIndexWidget", funcName, gil, pyOverride);
}

void QHelpIndexWidgetWrapper::paintEvent(::QPaintEvent * e)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[54], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::paintEvent(e);
    }
    QHelpContentWidgetWrapper::sbk_o_paintEvent("QHelpIndexWidget", funcName, gil, pyOverride, e);
}

::QPaintDevice * QHelpIndexWidgetWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[55], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QHelpContentWidgetWrapper::sbk_o_redirected("QHelpIndexWidget", funcName, gil, pyOverride, offset);
}

void QHelpIndexWidgetWrapper::reset()
{
    static const char *funcName = "reset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[56], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::reset();
    }
    QHelpContentWidgetWrapper::sbk_o_doItemsLayout("QHelpIndexWidget", funcName, gil, pyOverride);
}

void QHelpIndexWidgetWrapper::resizeEvent(::QResizeEvent * e)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[57], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::resizeEvent(e);
    }
    QHelpContentWidgetWrapper::sbk_o_resizeEvent("QHelpIndexWidget", funcName, gil, pyOverride, e);
}

void QHelpIndexWidgetWrapper::rowsAboutToBeRemoved(const ::QModelIndex & parent, int start, int end)
{
    static const char *funcName = "rowsAboutToBeRemoved";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[58], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::rowsAboutToBeRemoved(parent, start, end);
    }
    QHelpContentWidgetWrapper::sbk_o_rowsAboutToBeRemoved("QHelpIndexWidget", funcName, gil, pyOverride, parent, start, end);
}

void QHelpIndexWidgetWrapper::rowsInserted(const ::QModelIndex & parent, int start, int end)
{
    static const char *funcName = "rowsInserted";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[59], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::rowsInserted(parent, start, end);
    }
    QHelpContentWidgetWrapper::sbk_o_rowsAboutToBeRemoved("QHelpIndexWidget", funcName, gil, pyOverride, parent, start, end);
}

void QHelpIndexWidgetWrapper::scrollContentsBy(int dx, int dy)
{
    static const char *funcName = "scrollContentsBy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[60], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::scrollContentsBy(dx, dy);
    }
    QHelpContentWidgetWrapper::sbk_o_scrollContentsBy("QHelpIndexWidget", funcName, gil, pyOverride, dx, dy);
}

void QHelpIndexWidgetWrapper::scrollTo(const ::QModelIndex & index, ::QAbstractItemView::ScrollHint hint)
{
    static const char *funcName = "scrollTo";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[61], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::scrollTo(index, hint);
    }
    QHelpContentWidgetWrapper::sbk_o_scrollTo("QHelpIndexWidget", funcName, gil, pyOverride, index, hint);
}

void QHelpIndexWidgetWrapper::selectAll()
{
    static const char *funcName = "selectAll";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[62], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::selectAll();
    }
    QHelpContentWidgetWrapper::sbk_o_doItemsLayout("QHelpIndexWidget", funcName, gil, pyOverride);
}

::QList<QModelIndex> QHelpIndexWidgetWrapper::selectedIndexes() const
{
    static const char *funcName = "selectedIndexes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[63], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::selectedIndexes();
    }
    return QHelpContentWidgetWrapper::sbk_o_selectedIndexes("QHelpIndexWidget", funcName, gil, pyOverride);
}

void QHelpIndexWidgetWrapper::selectionChanged(const ::QItemSelection & selected, const ::QItemSelection & deselected)
{
    static const char *funcName = "selectionChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[64], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::selectionChanged(selected, deselected);
    }
    QHelpContentWidgetWrapper::sbk_o_selectionChanged("QHelpIndexWidget", funcName, gil, pyOverride, selected, deselected);
}

::QFlags<QItemSelectionModel::SelectionFlag> QHelpIndexWidgetWrapper::selectionCommand(const ::QModelIndex & index, const ::QEvent * event) const
{
    static const char *funcName = "selectionCommand";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[65], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::selectionCommand(index, event);
    }
    return QHelpContentWidgetWrapper::sbk_o_selectionCommand("QHelpIndexWidget", funcName, gil, pyOverride, index, event);
}

void QHelpIndexWidgetWrapper::setModel(::QAbstractItemModel * model)
{
    static const char *funcName = "setModel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[66], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::setModel(model);
    }
    QHelpContentWidgetWrapper::sbk_o_setModel("QHelpIndexWidget", funcName, gil, pyOverride, model);
}

void QHelpIndexWidgetWrapper::setRootIndex(const ::QModelIndex & index)
{
    static const char *funcName = "setRootIndex";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[67], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::setRootIndex(index);
    }
    QHelpContentWidgetWrapper::sbk_o_setRootIndex("QHelpIndexWidget", funcName, gil, pyOverride, index);
}

void QHelpIndexWidgetWrapper::setSelection(const ::QRect & rect, ::QFlags<QItemSelectionModel::SelectionFlag> command)
{
    static const char *funcName = "setSelection";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[68], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::setSelection(rect, command);
    }
    QHelpContentWidgetWrapper::sbk_o_setSelection("QHelpIndexWidget", funcName, gil, pyOverride, rect, command);
}

void QHelpIndexWidgetWrapper::setSelectionModel(::QItemSelectionModel * selectionModel)
{
    static const char *funcName = "setSelectionModel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[69], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::setSelectionModel(selectionModel);
    }
    QHelpContentWidgetWrapper::sbk_o_setSelectionModel("QHelpIndexWidget", funcName, gil, pyOverride, selectionModel);
}

void QHelpIndexWidgetWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[70], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QHelpContentWidgetWrapper::sbk_o_setVisible("QHelpIndexWidget", funcName, gil, pyOverride, visible);
}

void QHelpIndexWidgetWrapper::setupViewport(::QWidget * viewport)
{
    static const char *funcName = "setupViewport";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[71], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::setupViewport(viewport);
    }
    QHelpContentWidgetWrapper::sbk_o_setupViewport("QHelpIndexWidget", funcName, gil, pyOverride, viewport);
}

::QPainter * QHelpIndexWidgetWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[72], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QHelpContentWidgetWrapper::sbk_o_sharedPainter("QHelpIndexWidget", funcName, gil, pyOverride);
}

void QHelpIndexWidgetWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[73], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_showEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

::QSize QHelpIndexWidgetWrapper::sizeHint() const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[74], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::sizeHint();
    }
    return QHelpContentWidgetWrapper::sbk_o_minimumSizeHint("QHelpIndexWidget", funcName, gil, pyOverride);
}

int QHelpIndexWidgetWrapper::sizeHintForColumn(int column) const
{
    static const char *funcName = "sizeHintForColumn";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[75], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::sizeHintForColumn(column);
    }
    return QHelpContentWidgetWrapper::sbk_o_heightForWidth("QHelpIndexWidget", funcName, gil, pyOverride, column);
}

int QHelpIndexWidgetWrapper::sizeHintForRow(int row) const
{
    static const char *funcName = "sizeHintForRow";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[76], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::sizeHintForRow(row);
    }
    return QHelpContentWidgetWrapper::sbk_o_heightForWidth("QHelpIndexWidget", funcName, gil, pyOverride, row);
}

void QHelpIndexWidgetWrapper::startDrag(::QFlags<Qt::DropAction> supportedActions)
{
    static const char *funcName = "startDrag";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[77], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::startDrag(supportedActions);
    }
    QHelpContentWidgetWrapper::sbk_o_startDrag("QHelpIndexWidget", funcName, gil, pyOverride, supportedActions);
}

void QHelpIndexWidgetWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[78], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_tabletEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

void QHelpIndexWidgetWrapper::timerEvent(::QTimerEvent * e)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[79], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::timerEvent(e);
    }
    QHelpContentWidgetWrapper::sbk_o_timerEvent("QHelpIndexWidget", funcName, gil, pyOverride, e);
}

void QHelpIndexWidgetWrapper::updateEditorData()
{
    static const char *funcName = "updateEditorData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[80], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::updateEditorData();
    }
    QHelpContentWidgetWrapper::sbk_o_doItemsLayout("QHelpIndexWidget", funcName, gil, pyOverride);
}

void QHelpIndexWidgetWrapper::updateEditorGeometries()
{
    static const char *funcName = "updateEditorGeometries";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[81], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::updateEditorGeometries();
    }
    QHelpContentWidgetWrapper::sbk_o_doItemsLayout("QHelpIndexWidget", funcName, gil, pyOverride);
}

void QHelpIndexWidgetWrapper::updateGeometries()
{
    static const char *funcName = "updateGeometries";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[82], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::updateGeometries();
    }
    QHelpContentWidgetWrapper::sbk_o_doItemsLayout("QHelpIndexWidget", funcName, gil, pyOverride);
}

int QHelpIndexWidgetWrapper::verticalOffset() const
{
    static const char *funcName = "verticalOffset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[83], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::verticalOffset();
    }
    return QHelpContentWidgetWrapper::sbk_o_devType("QHelpIndexWidget", funcName, gil, pyOverride);
}

void QHelpIndexWidgetWrapper::verticalScrollbarAction(int action)
{
    static const char *funcName = "verticalScrollbarAction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[84], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::verticalScrollbarAction(action);
    }
    QHelpContentWidgetWrapper::sbk_o_horizontalScrollbarAction("QHelpIndexWidget", funcName, gil, pyOverride, action);
}

void QHelpIndexWidgetWrapper::verticalScrollbarValueChanged(int value)
{
    static const char *funcName = "verticalScrollbarValueChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[85], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::verticalScrollbarValueChanged(value);
    }
    QHelpContentWidgetWrapper::sbk_o_horizontalScrollbarAction("QHelpIndexWidget", funcName, gil, pyOverride, value);
}

bool QHelpIndexWidgetWrapper::viewportEvent(::QEvent * event)
{
    static const char *funcName = "viewportEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[86], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::viewportEvent(event);
    }
    return QHelpContentWidgetWrapper::sbk_o_viewportEvent("QHelpIndexWidget", funcName, gil, pyOverride, event);
}

::QSize QHelpIndexWidgetWrapper::viewportSizeHint() const
{
    static const char *funcName = "viewportSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[87], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::viewportSizeHint();
    }
    return QHelpContentWidgetWrapper::sbk_o_minimumSizeHint("QHelpIndexWidget", funcName, gil, pyOverride);
}

::QRect QHelpIndexWidgetWrapper::visualRect(const ::QModelIndex & index) const
{
    static const char *funcName = "visualRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[88], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::visualRect(index);
    }
    return QHelpContentWidgetWrapper::sbk_o_visualRect("QHelpIndexWidget", funcName, gil, pyOverride, index);
}

::QRegion QHelpIndexWidgetWrapper::visualRegionForSelection(const ::QItemSelection & selection) const
{
    static const char *funcName = "visualRegionForSelection";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[89], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::visualRegionForSelection(selection);
    }
    return QHelpContentWidgetWrapper::sbk_o_visualRegionForSelection("QHelpIndexWidget", funcName, gil, pyOverride, selection);
}

void QHelpIndexWidgetWrapper::wheelEvent(::QWheelEvent * e)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[90], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::wheelEvent(e);
    }
    QHelpContentWidgetWrapper::sbk_o_wheelEvent("QHelpIndexWidget", funcName, gil, pyOverride, e);
}

const QMetaObject *QHelpIndexWidgetWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QHelpIndexWidget::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QHelpIndexWidgetWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QHelpIndexWidget::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QHelpIndexWidgetWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QHelpIndexWidgetWrapper *>(this));
    return QHelpIndexWidget::qt_metacast(_clname);
}

QHelpIndexWidgetWrapper::~QHelpIndexWidgetWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_QHelpIndexWidget_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QHelpIndexWidget");
    return -1;
}

static PyObject *Sbk_QHelpIndexWidgetFunc_activateCurrentItem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpIndexWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activateCurrentItem()
        cppSelf->activateCurrentItem();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QHelpIndexWidgetFunc_filterIndices(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpIndexWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "filterIndices", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OO:filterIndices", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHelpIndexWidget::filterIndices(QString,const QString&=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // filterIndices(QString,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // filterIndices(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "filterIndices", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexWidget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"wildcard", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "filterIndices", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexWidget_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // filterIndices(QString,QString)
            cppSelf->filterIndices(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QHelpIndexWidget_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHelpIndexWidget_methods[] = {
    {"activateCurrentItem", reinterpret_cast<PyCFunction>(Sbk_QHelpIndexWidgetFunc_activateCurrentItem), METH_NOARGS, nullptr},
    {"filterIndices", reinterpret_cast<PyCFunction>(Sbk_QHelpIndexWidgetFunc_filterIndices), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QHelpIndexWidget_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QHelpIndexWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QHelpIndexWidgetWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QHelpIndexWidget_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHelpIndexWidget_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QHelpIndexWidgetSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QHelpIndexWidget *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]))
        return static_cast< ::QListView *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]))
        return static_cast< ::QAbstractItemView *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX]))
        return static_cast< ::QAbstractScrollArea *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX]))
        return static_cast< ::QFrame *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHelpIndexWidget_Type = nullptr;
static PyTypeObject *Sbk_QHelpIndexWidget_TypeF(void)
{
    return _Sbk_QHelpIndexWidget_Type;
}

static PyType_Slot Sbk_QHelpIndexWidget_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QHelpIndexWidget_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHelpIndexWidget_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHelpIndexWidget_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHelpIndexWidget_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHelpIndexWidget_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHelpIndexWidget_spec = {
    "2:PySide6.QtHelp.QHelpIndexWidget",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHelpIndexWidget_slots
};

} //extern "C"

static void *Sbk_QHelpIndexWidget_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QHelpIndexWidget *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QHelpIndexWidget *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QHelpIndexWidget *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHelpIndexWidget_PythonToCpp_QHelpIndexWidget_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHelpIndexWidget_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHelpIndexWidget_PythonToCpp_QHelpIndexWidget_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHelpIndexWidget_TypeF()))
        return QHelpIndexWidget_PythonToCpp_QHelpIndexWidget_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHelpIndexWidget_PTR_CppToPython_QHelpIndexWidget(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QHelpIndexWidget *>(const_cast<void *>(cppIn)), Sbk_QHelpIndexWidget_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHelpIndexWidget_SignatureStrings[] = {
    "PySide6.QtHelp.QHelpIndexWidget.activateCurrentItem(self)",
    "PySide6.QtHelp.QHelpIndexWidget.filterIndices(self,filter:QString,wildcard:QString={})",
    nullptr}; // Sentinel
#else
static constexpr size_t QHelpIndexWidget_SignatureByteSize = 107;
static constexpr uint8_t QHelpIndexWidget_SignatureBytes[107] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0xf1, 0x48, 0xcd, 0x29,
    0xd0, 0x0b, 0x04, 0x91, 0x9e, 0x79, 0x29, 0xa9, 0x15, 0xe1, 0x99, 0x29, 0xe9, 0xa9, 0x25, 0x7a,
    0x89, 0xc9, 0x25, 0x99, 0x65, 0x89, 0x25, 0xa9, 0xce, 0xa5, 0x45, 0x45, 0xa9, 0x79, 0x25, 0x9e,
    0x25, 0xa9, 0xb9, 0x1a, 0xc5, 0xa9, 0x39, 0x69, 0x9a, 0x5c, 0x01, 0x04, 0x74, 0xa6, 0x65, 0xe6,
    0x94, 0xa4, 0x16, 0x01, 0x45, 0x32, 0x93, 0x53, 0x8b, 0xc1, 0x7a, 0x74, 0x20, 0x42, 0x56, 0x81,
    0xc1, 0x25, 0x45, 0x99, 0x79, 0xe9, 0x3a, 0xe5, 0x99, 0x39, 0x29, 0xc9, 0x89, 0x45, 0x29, 0x30,
    0x01, 0xdb, 0xea, 0x5a, 0x4d, 0x2e, 0x00, 0x42, 0xcc, 0x35, 0x98
};
#endif

PyTypeObject *init_QHelpIndexWidget(PyObject *module)
{
    if (SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexWidget_IDX].type != nullptr)
        return SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexWidget_IDX].type;

    Shiboken::AutoDecRef Sbk_QHelpIndexWidget_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]))));

    _Sbk_QHelpIndexWidget_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHelpIndexWidget",
        "QHelpIndexWidget*",
        &Sbk_QHelpIndexWidget_spec,
        &Shiboken::callCppDestructor< QHelpIndexWidget >,
        Sbk_QHelpIndexWidget_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QHelpIndexWidget_TypeF(); // references _Sbk_QHelpIndexWidget_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHelpIndexWidget_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHelpIndexWidget_SignatureBytes, QHelpIndexWidget_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHelpIndexWidget_PropertyStrings);
    SbkPySide6_QtHelpTypeStructs[SBK_QHelpIndexWidget_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHelpIndexWidget_PythonToCpp_QHelpIndexWidget_PTR,
        is_QHelpIndexWidget_PythonToCpp_QHelpIndexWidget_PTR_Convertible,
        QHelpIndexWidget_PTR_CppToPython_QHelpIndexWidget);

    Shiboken::Conversions::registerConverterName(converter, "QHelpIndexWidget");
    Shiboken::Conversions::registerConverterName(converter, "QHelpIndexWidget*");
    Shiboken::Conversions::registerConverterName(converter, "QHelpIndexWidget&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHelpIndexWidget).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QHelpIndexWidgetWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QHelpIndexWidget_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QHelpIndexWidget_TypeF(), &Sbk_QHelpIndexWidgetSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QHelpIndexWidget_TypeF(), &Sbk_QHelpIndexWidget_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QHelpIndexWidget::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QHelpIndexWidget::staticMetaObject, sizeof(QHelpIndexWidgetWrapper));

    return pyType;
}
