// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthelp_python.h"

// main header
#include "qhelpsearchquerywidget_wrapper.h"

// Wrappers providing overrides
#include "qhelpcontentwidget_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtHelp/qhelpsearchengine.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QHelpSearchQueryWidgetWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QHelpSearchQueryWidgetWrapper::QHelpSearchQueryWidgetWrapper(::QWidget * parent) : QHelpSearchQueryWidget(parent)
{
}

void QHelpSearchQueryWidgetWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_actionEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_childEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_closeEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QHelpContentWidgetWrapper::sbk_o_connectNotify("QHelpSearchQueryWidget", funcName, gil, pyOverride, signal);
}

void QHelpSearchQueryWidgetWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::contextMenuEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_contextMenuEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_customEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

int QHelpSearchQueryWidgetWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QHelpContentWidgetWrapper::sbk_o_devType("QHelpSearchQueryWidget", funcName, gil, pyOverride);
}

void QHelpSearchQueryWidgetWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QHelpContentWidgetWrapper::sbk_o_connectNotify("QHelpSearchQueryWidget", funcName, gil, pyOverride, signal);
}

void QHelpSearchQueryWidgetWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_dragEnterEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_dragLeaveEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_dragMoveEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_dropEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_enterEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

bool QHelpSearchQueryWidgetWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::event(event);
    }
    return QHelpContentWidgetWrapper::sbk_o_event("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

bool QHelpSearchQueryWidgetWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QHelpContentWidgetWrapper::sbk_o_eventFilter("QHelpSearchQueryWidget", funcName, gil, pyOverride, watched, event);
}

bool QHelpSearchQueryWidgetWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QHelpContentWidgetWrapper::sbk_o_focusNextPrevChild("QHelpSearchQueryWidget", funcName, gil, pyOverride, next);
}

void QHelpSearchQueryWidgetWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusOutEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_focusOutEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

bool QHelpSearchQueryWidgetWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QHelpContentWidgetWrapper::sbk_o_hasHeightForWidth("QHelpSearchQueryWidget", funcName, gil, pyOverride);
}

int QHelpSearchQueryWidgetWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QHelpContentWidgetWrapper::sbk_o_heightForWidth("QHelpSearchQueryWidget", funcName, gil, pyOverride, arg__1);
}

void QHelpSearchQueryWidgetWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_hideEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QHelpContentWidgetWrapper::sbk_o_initPainter("QHelpSearchQueryWidget", funcName, gil, pyOverride, painter);
}

void QHelpSearchQueryWidgetWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_inputMethodEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

::QVariant QHelpSearchQueryWidgetWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodQuery(arg__1);
    }
    return QHelpContentWidgetWrapper::sbk_o_inputMethodQuery("QHelpSearchQueryWidget", funcName, gil, pyOverride, arg__1);
}

void QHelpSearchQueryWidgetWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyPressEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_keyPressEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_keyReleaseEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_leaveEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

int QHelpSearchQueryWidgetWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QHelpContentWidgetWrapper::sbk_o_metric("QHelpSearchQueryWidget", funcName, gil, pyOverride, arg__1);
}

::QSize QHelpSearchQueryWidgetWrapper::minimumSizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::minimumSizeHint();
    }
    return QHelpContentWidgetWrapper::sbk_o_minimumSizeHint("QHelpSearchQueryWidget", funcName, gil, pyOverride);
}

void QHelpSearchQueryWidgetWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_mouseDoubleClickEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_mouseMoveEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mousePressEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_mousePressEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_mouseReleaseEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_moveEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

bool QHelpSearchQueryWidgetWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QHelpContentWidgetWrapper::sbk_o_nativeEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QHelpSearchQueryWidgetWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QHelpContentWidgetWrapper::sbk_o_paintEngine("QHelpSearchQueryWidget", funcName, gil, pyOverride);
}

void QHelpSearchQueryWidgetWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_paintEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

::QPaintDevice * QHelpSearchQueryWidgetWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QHelpContentWidgetWrapper::sbk_o_redirected("QHelpSearchQueryWidget", funcName, gil, pyOverride, offset);
}

void QHelpSearchQueryWidgetWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::resizeEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_resizeEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QHelpContentWidgetWrapper::sbk_o_setVisible("QHelpSearchQueryWidget", funcName, gil, pyOverride, visible);
}

::QPainter * QHelpSearchQueryWidgetWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QHelpContentWidgetWrapper::sbk_o_sharedPainter("QHelpSearchQueryWidget", funcName, gil, pyOverride);
}

void QHelpSearchQueryWidgetWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_showEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

::QSize QHelpSearchQueryWidgetWrapper::sizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sizeHint();
    }
    return QHelpContentWidgetWrapper::sbk_o_minimumSizeHint("QHelpSearchQueryWidget", funcName, gil, pyOverride);
}

void QHelpSearchQueryWidgetWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_tabletEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_timerEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

void QHelpSearchQueryWidgetWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::wheelEvent(event);
    }
    QHelpContentWidgetWrapper::sbk_o_wheelEvent("QHelpSearchQueryWidget", funcName, gil, pyOverride, event);
}

const QMetaObject *QHelpSearchQueryWidgetWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QHelpSearchQueryWidget::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QHelpSearchQueryWidgetWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QHelpSearchQueryWidget::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QHelpSearchQueryWidgetWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QHelpSearchQueryWidgetWrapper *>(this));
    return QHelpSearchQueryWidget::qt_metacast(_clname);
}

QHelpSearchQueryWidgetWrapper::~QHelpSearchQueryWidgetWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHelpSearchQueryWidget_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHelpSearchQueryWidget >()))
        return -1;

    QHelpSearchQueryWidgetWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QHelpSearchQueryWidget", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHelpSearchQueryWidget::QHelpSearchQueryWidget(QWidget*=)
    if (numArgs == 0) {
        overloadId = 0; // QHelpSearchQueryWidget(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QHelpSearchQueryWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QHelpSearchQueryWidget(QWidget*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QHelpSearchQueryWidgetWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QHelpSearchQueryWidgetWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QHelpSearchQueryWidget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QHelpSearchQueryWidgetFunc_changeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpSearchQueryWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::changeEvent(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "changeEvent", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("changeEvent(QEvent *event)");
        return {};
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QHelpSearchQueryWidgetFunc_collapseExtendedSearch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpSearchQueryWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // collapseExtendedSearch()
        cppSelf->collapseExtendedSearch();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QHelpSearchQueryWidgetFunc_expandExtendedSearch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpSearchQueryWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // expandExtendedSearch()
        cppSelf->expandExtendedSearch();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QHelpSearchQueryWidgetFunc_focusInEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpSearchQueryWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::focusInEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusInEvent", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("focusInEvent(QFocusEvent *focusEvent)");
        return {};
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QHelpSearchQueryWidgetFunc_isCompactMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpSearchQueryWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isCompactMode()const
        bool cppResult = const_cast<const ::QHelpSearchQueryWidget *>(cppSelf)->isCompactMode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QHelpSearchQueryWidgetFunc_query(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpSearchQueryWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QHelpSearchQueryWidget", "query() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // query()const
        QList<QHelpSearchQuery> cppResult = const_cast<const ::QHelpSearchQueryWidget *>(cppSelf)->query();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtHelpTypeConverters[SBK_QtHelp_QList_QHelpSearchQuery_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QHelpSearchQueryWidgetFunc_searchInput(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpSearchQueryWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // searchInput()const
        QString cppResult = const_cast<const ::QHelpSearchQueryWidget *>(cppSelf)->searchInput();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QHelpSearchQueryWidgetFunc_setCompactMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpSearchQueryWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHelpSearchQueryWidget::setCompactMode(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setCompactMode(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCompactMode", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCompactMode(bool)
            cppSelf->setCompactMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QHelpSearchQueryWidgetFunc_setQuery(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpSearchQueryWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHelpSearchQueryWidget::setQuery(QList<QHelpSearchQuery>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtHelpTypeConverters[SBK_QtHelp_QList_QHelpSearchQuery_IDX], (pyArg)))) {
        overloadId = 0; // setQuery(QList<QHelpSearchQuery>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setQuery", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QHelpSearchQueryWidget", "setQuery(const QList<QHelpSearchQuery> &queryList)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        ::QList<QHelpSearchQuery> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setQuery(QList<QHelpSearchQuery>)
            cppSelf->setQuery(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QHelpSearchQueryWidgetFunc_setSearchInput(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHelpSearchQueryWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHelpSearchQueryWidget::setSearchInput(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setSearchInput(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSearchInput", errInfo, SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSearchInput(QString)
            cppSelf->setSearchInput(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QHelpSearchQueryWidget_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHelpSearchQueryWidget_methods[] = {
    {"changeEvent", reinterpret_cast<PyCFunction>(Sbk_QHelpSearchQueryWidgetFunc_changeEvent), METH_O, nullptr},
    {"collapseExtendedSearch", reinterpret_cast<PyCFunction>(Sbk_QHelpSearchQueryWidgetFunc_collapseExtendedSearch), METH_NOARGS, nullptr},
    {"expandExtendedSearch", reinterpret_cast<PyCFunction>(Sbk_QHelpSearchQueryWidgetFunc_expandExtendedSearch), METH_NOARGS, nullptr},
    {"focusInEvent", reinterpret_cast<PyCFunction>(Sbk_QHelpSearchQueryWidgetFunc_focusInEvent), METH_O, nullptr},
    {"isCompactMode", reinterpret_cast<PyCFunction>(Sbk_QHelpSearchQueryWidgetFunc_isCompactMode), METH_NOARGS, nullptr},
    {"query", reinterpret_cast<PyCFunction>(Sbk_QHelpSearchQueryWidgetFunc_query), METH_NOARGS, nullptr},
    {"searchInput", reinterpret_cast<PyCFunction>(Sbk_QHelpSearchQueryWidgetFunc_searchInput), METH_NOARGS, nullptr},
    {"setCompactMode", reinterpret_cast<PyCFunction>(Sbk_QHelpSearchQueryWidgetFunc_setCompactMode), METH_O, nullptr},
    {"setQuery", reinterpret_cast<PyCFunction>(Sbk_QHelpSearchQueryWidgetFunc_setQuery), METH_O, nullptr},
    {"setSearchInput", reinterpret_cast<PyCFunction>(Sbk_QHelpSearchQueryWidgetFunc_setSearchInput), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QHelpSearchQueryWidget_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QHelpSearchQueryWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QHelpSearchQueryWidgetWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QHelpSearchQueryWidget_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHelpSearchQueryWidget_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QHelpSearchQueryWidgetSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QHelpSearchQueryWidget *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHelpSearchQueryWidget_Type = nullptr;
static PyTypeObject *Sbk_QHelpSearchQueryWidget_TypeF(void)
{
    return _Sbk_QHelpSearchQueryWidget_Type;
}

static PyType_Slot Sbk_QHelpSearchQueryWidget_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QHelpSearchQueryWidget_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHelpSearchQueryWidget_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHelpSearchQueryWidget_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHelpSearchQueryWidget_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHelpSearchQueryWidget_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHelpSearchQueryWidget_spec = {
    "2:PySide6.QtHelp.QHelpSearchQueryWidget",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHelpSearchQueryWidget_slots
};

} //extern "C"

static void *Sbk_QHelpSearchQueryWidget_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QHelpSearchQueryWidget *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QHelpSearchQueryWidget *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QHelpSearchQueryWidget *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHelpSearchQueryWidget_PythonToCpp_QHelpSearchQueryWidget_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHelpSearchQueryWidget_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHelpSearchQueryWidget_PythonToCpp_QHelpSearchQueryWidget_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHelpSearchQueryWidget_TypeF()))
        return QHelpSearchQueryWidget_PythonToCpp_QHelpSearchQueryWidget_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHelpSearchQueryWidget_PTR_CppToPython_QHelpSearchQueryWidget(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QHelpSearchQueryWidget *>(const_cast<void *>(cppIn)), Sbk_QHelpSearchQueryWidget_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QHelpSearchQueryWidget_SignatureStrings[] = {
    "PySide6.QtHelp.QHelpSearchQueryWidget(self,parent:PySide6.QtWidgets.QWidget=nullptr)",
    "PySide6.QtHelp.QHelpSearchQueryWidget.changeEvent(self,event:PySide6.QtCore.QEvent)",
    "PySide6.QtHelp.QHelpSearchQueryWidget.collapseExtendedSearch(self)",
    "PySide6.QtHelp.QHelpSearchQueryWidget.expandExtendedSearch(self)",
    "PySide6.QtHelp.QHelpSearchQueryWidget.focusInEvent(self,focusEvent:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtHelp.QHelpSearchQueryWidget.isCompactMode(self)->bool",
    "PySide6.QtHelp.QHelpSearchQueryWidget.query(self)->QList[PySide6.QtHelp.QHelpSearchQuery]",
    "PySide6.QtHelp.QHelpSearchQueryWidget.searchInput(self)->QString",
    "PySide6.QtHelp.QHelpSearchQueryWidget.setCompactMode(self,on:bool)",
    "PySide6.QtHelp.QHelpSearchQueryWidget.setQuery(self,queryList:QList[PySide6.QtHelp.QHelpSearchQuery])",
    "PySide6.QtHelp.QHelpSearchQueryWidget.setSearchInput(self,searchInput:QString)",
    nullptr}; // Sentinel
#else
static constexpr size_t QHelpSearchQueryWidget_SignatureByteSize = 240;
static constexpr uint8_t QHelpSearchQueryWidget_SignatureBytes[240] = {
    0x78, 0xda, 0xa5, 0x8f, 0xc1, 0x4e, 0xc3, 0x30, 0x0c, 0x86, 0xef, 0x7b, 0x12, 0x2a, 0x95, 0x1c,
    0x39, 0x54, 0x82, 0xcb, 0x54, 0x60, 0x12, 0x93, 0x1a, 0xf5, 0xc0, 0x01, 0x71, 0x08, 0x8d, 0xd7,
    0x45, 0x0a, 0x4e, 0x96, 0x38, 0xd3, 0xf6, 0xf6, 0xd0, 0x04, 0xaa, 0xd1, 0x0b, 0x46, 0x5c, 0x22,
    0xcb, 0xf6, 0xff, 0x39, 0x5f, 0x77, 0xee, 0x8d, 0x86, 0x1b, 0x21, 0xe9, 0x11, 0xac, 0x17, 0x72,
    0x7a, 0x7b, 0x50, 0x61, 0xd8, 0xcb, 0x04, 0xe1, 0xfc, 0x6c, 0xf4, 0x08, 0x74, 0x15, 0xc1, 0xee,
    0x6a, 0xaf, 0x02, 0x20, 0x35, 0xdd, 0x9c, 0x28, 0xc3, 0x28, 0x64, 0x29, 0x6e, 0x31, 0x59, 0xeb,
    0x29, 0x54, 0xab, 0x8e, 0x03, 0x15, 0xc3, 0x5e, 0xe1, 0x08, 0xed, 0xf1, 0x13, 0x5a, 0x0e, 0xc0,
    0xf1, 0x27, 0x7f, 0xed, 0x02, 0x08, 0x99, 0x17, 0xd8, 0x4c, 0x67, 0xad, 0xf2, 0x11, 0xda, 0x13,
    0x01, 0x6a, 0xd0, 0x65, 0x23, 0xe3, 0xb9, 0x08, 0x38, 0x79, 0x85, 0xfa, 0x1f, 0x80, 0x9d, 0x1b,
    0x52, 0xdc, 0xe0, 0x85, 0x58, 0xee, 0xb4, 0x0b, 0xbb, 0x87, 0x64, 0x84, 0xbc, 0x9f, 0x27, 0x5c,
    0xba, 0x89, 0x6b, 0xf7, 0xee, 0xd5, 0x40, 0x5b, 0xa7, 0xa1, 0xfc, 0xeb, 0xfa, 0xee, 0xcd, 0x39,
    0xcb, 0xcc, 0x1f, 0xa6, 0xfa, 0x3b, 0x27, 0x9f, 0x4c, 0xa4, 0x97, 0x5f, 0x82, 0xaf, 0x4c, 0x72,
    0xcc, 0x9d, 0x0d, 0xfa, 0x44, 0x33, 0xbf, 0xa7, 0x60, 0x70, 0x64, 0x03, 0x68, 0xe9, 0x56, 0x3b,
    0x6c, 0x26, 0xb9, 0x8a, 0x8f, 0x90, 0xb3, 0x60, 0x9d, 0x5d, 0x27, 0xc5, 0x86, 0x27, 0xfa, 0x87,
    0x2b, 0xfd, 0x42, 0xb6, 0xbe, 0xb0, 0x6f, 0xbe, 0xb4, 0xab, 0xd5, 0x07, 0xc8, 0x57, 0x3c, 0xec
};
#endif

PyTypeObject *init_QHelpSearchQueryWidget(PyObject *module)
{
    if (SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX].type != nullptr)
        return SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX].type;

    Shiboken::AutoDecRef Sbk_QHelpSearchQueryWidget_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))));

    _Sbk_QHelpSearchQueryWidget_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHelpSearchQueryWidget",
        "QHelpSearchQueryWidget*",
        &Sbk_QHelpSearchQueryWidget_spec,
        &Shiboken::callCppDestructor< QHelpSearchQueryWidget >,
        Sbk_QHelpSearchQueryWidget_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QHelpSearchQueryWidget_TypeF(); // references _Sbk_QHelpSearchQueryWidget_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QHelpSearchQueryWidget_SignatureStrings);
#else
    InitSignatureBytes(pyType, QHelpSearchQueryWidget_SignatureBytes, QHelpSearchQueryWidget_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHelpSearchQueryWidget_PropertyStrings);
    SbkPySide6_QtHelpTypeStructs[SBK_QHelpSearchQueryWidget_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHelpSearchQueryWidget_PythonToCpp_QHelpSearchQueryWidget_PTR,
        is_QHelpSearchQueryWidget_PythonToCpp_QHelpSearchQueryWidget_PTR_Convertible,
        QHelpSearchQueryWidget_PTR_CppToPython_QHelpSearchQueryWidget);

    Shiboken::Conversions::registerConverterName(converter, "QHelpSearchQueryWidget");
    Shiboken::Conversions::registerConverterName(converter, "QHelpSearchQueryWidget*");
    Shiboken::Conversions::registerConverterName(converter, "QHelpSearchQueryWidget&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHelpSearchQueryWidget).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QHelpSearchQueryWidgetWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QHelpSearchQueryWidget_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QHelpSearchQueryWidget_TypeF(), &Sbk_QHelpSearchQueryWidgetSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QHelpSearchQueryWidget_TypeF(), &Sbk_QHelpSearchQueryWidget_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QHelpSearchQueryWidget::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QHelpSearchQueryWidget::staticMetaObject, sizeof(QHelpSearchQueryWidgetWrapper));

    return pyType;
}
