// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qplacedetailsreply_wrapper.h"

// Wrappers providing overrides
#include "qplacereply_wrapper.h"

// Argument includes
#include <QtLocation/qplace.h>
#include <QtLocation/qplacereply.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPlaceDetailsReplyWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPlaceDetailsReplyWrapper::QPlaceDetailsReplyWrapper(::QObject * parent) : QPlaceDetailsReply(parent)
{
}

void QPlaceDetailsReplyWrapper::abort()
{
    static const char *funcName = "abort";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPlaceReply::abort();
    }
    QPlaceReplyWrapper::sbk_o_abort("QPlaceDetailsReply", funcName, gil, pyOverride);
}

void QPlaceDetailsReplyWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QPlaceReplyWrapper::sbk_o_childEvent("QPlaceDetailsReply", funcName, gil, pyOverride, event);
}

void QPlaceDetailsReplyWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QPlaceReplyWrapper::sbk_o_connectNotify("QPlaceDetailsReply", funcName, gil, pyOverride, signal);
}

void QPlaceDetailsReplyWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QPlaceReplyWrapper::sbk_o_customEvent("QPlaceDetailsReply", funcName, gil, pyOverride, event);
}

void QPlaceDetailsReplyWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QPlaceReplyWrapper::sbk_o_connectNotify("QPlaceDetailsReply", funcName, gil, pyOverride, signal);
}

bool QPlaceDetailsReplyWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QPlaceReplyWrapper::sbk_o_event("QPlaceDetailsReply", funcName, gil, pyOverride, event);
}

bool QPlaceDetailsReplyWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QPlaceReplyWrapper::sbk_o_eventFilter("QPlaceDetailsReply", funcName, gil, pyOverride, watched, event);
}

void QPlaceDetailsReplyWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QPlaceReplyWrapper::sbk_o_timerEvent("QPlaceDetailsReply", funcName, gil, pyOverride, event);
}

::QPlaceReply::Type QPlaceDetailsReplyWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPlaceDetailsReply::type();
    }
    return QPlaceReplyWrapper::sbk_o_type("QPlaceDetailsReply", funcName, gil, pyOverride);
}

const QMetaObject *QPlaceDetailsReplyWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QPlaceDetailsReply::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QPlaceDetailsReplyWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QPlaceDetailsReply::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QPlaceDetailsReplyWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QPlaceDetailsReplyWrapper *>(this));
    return QPlaceDetailsReply::qt_metacast(_clname);
}

QPlaceDetailsReplyWrapper::~QPlaceDetailsReplyWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPlaceDetailsReply_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPlaceDetailsReply >()))
        return -1;

    QPlaceDetailsReplyWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QPlaceDetailsReply", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPlaceDetailsReply::QPlaceDetailsReply(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QPlaceDetailsReply(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QPlaceDetailsReply(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceDetailsReply_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceDetailsReply_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceDetailsReply_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPlaceDetailsReply(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QPlaceDetailsReplyWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QPlaceDetailsReplyWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPlaceDetailsReply >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceDetailsReply_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceDetailsReply_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QPlaceDetailsReplyFunc_place(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceDetailsReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceDetailsReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // place()const
        QPlace cppResult = const_cast<const ::QPlaceDetailsReply *>(cppSelf)->place();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPlaceDetailsReplyFunc_setPlace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceDetailsReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceDetailsReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceDetailsReply::setPlace(QPlace)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]), (pyArg)))) {
        overloadId = 0; // setPlace(QPlace)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPlace", errInfo, SbkPySide6_QtLocationTypeStructs[SBK_QPlaceDetailsReply_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlace cppArg0_local;
        ::QPlace *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPlace(QPlace)
            cppSelf->setPlace(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPlaceDetailsReplyFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceDetailsReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceDetailsReply_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QPlaceReply::Type cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QPlaceDetailsReply *>(cppSelf)->::QPlaceDetailsReply::type()
            : const_cast<const ::QPlaceDetailsReply *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceReply_Type_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QPlaceDetailsReply_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPlaceDetailsReply_methods[] = {
    {"place", reinterpret_cast<PyCFunction>(Sbk_QPlaceDetailsReplyFunc_place), METH_NOARGS, nullptr},
    {"setPlace", reinterpret_cast<PyCFunction>(Sbk_QPlaceDetailsReplyFunc_setPlace), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QPlaceDetailsReplyFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPlaceDetailsReply_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPlaceDetailsReply *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceDetailsReply_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPlaceDetailsReplyWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPlaceDetailsReply_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPlaceDetailsReply_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPlaceDetailsReply_Type = nullptr;
static PyTypeObject *Sbk_QPlaceDetailsReply_TypeF(void)
{
    return _Sbk_QPlaceDetailsReply_Type;
}

static PyType_Slot Sbk_QPlaceDetailsReply_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPlaceDetailsReply_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPlaceDetailsReply_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPlaceDetailsReply_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPlaceDetailsReply_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPlaceDetailsReply_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPlaceDetailsReply_spec = {
    "2:PySide6.QtLocation.QPlaceDetailsReply",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPlaceDetailsReply_slots
};

} //extern "C"

static void *Sbk_QPlaceDetailsReply_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QPlaceDetailsReply *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPlaceDetailsReply_PythonToCpp_QPlaceDetailsReply_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPlaceDetailsReply_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPlaceDetailsReply_PythonToCpp_QPlaceDetailsReply_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPlaceDetailsReply_TypeF()))
        return QPlaceDetailsReply_PythonToCpp_QPlaceDetailsReply_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPlaceDetailsReply_PTR_CppToPython_QPlaceDetailsReply(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QPlaceDetailsReply *>(const_cast<void *>(cppIn)), Sbk_QPlaceDetailsReply_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPlaceDetailsReply_SignatureStrings[] = {
    "PySide6.QtLocation.QPlaceDetailsReply(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtLocation.QPlaceDetailsReply.place(self)->PySide6.QtLocation.QPlace",
    "PySide6.QtLocation.QPlaceDetailsReply.setPlace(self,place:PySide6.QtLocation.QPlace)",
    "PySide6.QtLocation.QPlaceDetailsReply.type(self)->PySide6.QtLocation.QPlaceReply.Type",
    nullptr}; // Sentinel
#else
static constexpr size_t QPlaceDetailsReply_SignatureByteSize = 127;
static constexpr uint8_t QPlaceDetailsReply_SignatureBytes[127] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0xf1, 0xc9, 0x4f, 0x4e,
    0x2c, 0xc9, 0xcc, 0xcf, 0xd3, 0x0b, 0x0c, 0xc8, 0x49, 0x4c, 0x4e, 0x75, 0x49, 0x2d, 0x49, 0xcc,
    0xcc, 0x29, 0x0e, 0x4a, 0x2d, 0xc8, 0xa9, 0xd4, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0x29, 0x48, 0x2c,
    0x4a, 0xcd, 0x2b, 0xb1, 0x0a, 0x80, 0xeb, 0x70, 0xce, 0x2f, 0x4a, 0xd5, 0x0b, 0xf4, 0x4f, 0xca,
    0x4a, 0x4d, 0x2e, 0xb1, 0xcd, 0x2b, 0xcd, 0xc9, 0x29, 0x28, 0x29, 0xd2, 0xe4, 0x0a, 0x20, 0xc6,
    0x44, 0xbd, 0x02, 0x90, 0x08, 0xd8, 0x5c, 0x4d, 0x5d, 0x3b, 0x9c, 0x5a, 0x88, 0x34, 0xac, 0x38,
    0xb5, 0x24, 0x00, 0x6e, 0x9e, 0x0e, 0xd8, 0x68, 0x2b, 0x9c, 0x3a, 0x89, 0x75, 0x61, 0x49, 0x65,
    0x01, 0x61, 0x07, 0x42, 0x94, 0x86, 0x00, 0x95, 0x72, 0x01, 0x00, 0xa5, 0x4c, 0x77, 0x9c
};
#endif

PyTypeObject *init_QPlaceDetailsReply(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QPlaceDetailsReply_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QPlaceDetailsReply_IDX].type;

    Shiboken::AutoDecRef Sbk_QPlaceDetailsReply_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceReply_IDX]))));

    _Sbk_QPlaceDetailsReply_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPlaceDetailsReply",
        "QPlaceDetailsReply*",
        &Sbk_QPlaceDetailsReply_spec,
        &Shiboken::callCppDestructor< QPlaceDetailsReply >,
        Sbk_QPlaceDetailsReply_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPlaceDetailsReply_TypeF(); // references _Sbk_QPlaceDetailsReply_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPlaceDetailsReply_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPlaceDetailsReply_SignatureBytes, QPlaceDetailsReply_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPlaceDetailsReply_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QPlaceDetailsReply_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPlaceDetailsReply_PythonToCpp_QPlaceDetailsReply_PTR,
        is_QPlaceDetailsReply_PythonToCpp_QPlaceDetailsReply_PTR_Convertible,
        QPlaceDetailsReply_PTR_CppToPython_QPlaceDetailsReply);

    Shiboken::Conversions::registerConverterName(converter, "QPlaceDetailsReply");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceDetailsReply*");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceDetailsReply&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlaceDetailsReply).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPlaceDetailsReplyWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPlaceDetailsReply_TypeF(), &Sbk_QPlaceDetailsReply_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QPlaceDetailsReply::staticMetaObject, sizeof(QPlaceDetailsReplyWrapper));

    return pyType;
}
