// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QGRAPHICSVIDEOITEMWRAPPER_H
#define SBK_QGRAPHICSVIDEOITEMWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtMultimediaWidgets/qgraphicsvideoitem.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QGraphicsVideoItemWrapper : public QGraphicsVideoItem
{
public:
    QGraphicsVideoItemWrapper(::QGraphicsItem * parent = nullptr);
    QGraphicsVideoItemWrapper(const QGraphicsVideoItemWrapper &) = delete;
    QGraphicsVideoItemWrapper& operator=(const QGraphicsVideoItemWrapper &) = delete;
    QGraphicsVideoItemWrapper(QGraphicsVideoItemWrapper &&) = delete;
    QGraphicsVideoItemWrapper& operator=(QGraphicsVideoItemWrapper &&) = delete;
    ~QGraphicsVideoItemWrapper() override;

    void advance(int phase) override;
    static void sbk_o_advance(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int phase);
    ::QRectF boundingRect() const override;
    static ::QRectF sbk_o_boundingRect(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void childEvent(::QChildEvent * event) override;
    bool collidesWithItem(const ::QGraphicsItem * other, ::Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const override;
    static bool sbk_o_collidesWithItem(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QGraphicsItem * other, ::Qt::ItemSelectionMode mode = Qt::IntersectsItemShape);
    bool collidesWithPath(const ::QPainterPath & path, ::Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const override;
    static bool sbk_o_collidesWithPath(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPainterPath & path, ::Qt::ItemSelectionMode mode = Qt::IntersectsItemShape);
    void connectNotify(const ::QMetaMethod & signal) override;
    bool contains(const ::QPointF & point) const override;
    static bool sbk_o_contains(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPointF & point);
    void contextMenuEvent(::QGraphicsSceneContextMenuEvent * event) override;
    static void sbk_o_contextMenuEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneContextMenuEvent * event);
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    void dragEnterEvent(::QGraphicsSceneDragDropEvent * event) override;
    static void sbk_o_dragEnterEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneDragDropEvent * event);
    void dragLeaveEvent(::QGraphicsSceneDragDropEvent * event) override;
    static void sbk_o_dragLeaveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneDragDropEvent * event);
    void dragMoveEvent(::QGraphicsSceneDragDropEvent * event) override;
    static void sbk_o_dragMoveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneDragDropEvent * event);
    void dropEvent(::QGraphicsSceneDragDropEvent * event) override;
    static void sbk_o_dropEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneDragDropEvent * event);
    bool event(::QEvent * ev) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QVariant extension(const ::QVariant & variant) const override;
    static ::QVariant sbk_o_extension(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QVariant & variant);
    void focusInEvent(::QFocusEvent * event) override;
    static void sbk_o_focusInEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFocusEvent * event);
    void focusOutEvent(::QFocusEvent * event) override;
    static void sbk_o_focusOutEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFocusEvent * event);
    void hoverEnterEvent(::QGraphicsSceneHoverEvent * event) override;
    static void sbk_o_hoverEnterEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneHoverEvent * event);
    void hoverLeaveEvent(::QGraphicsSceneHoverEvent * event) override;
    static void sbk_o_hoverLeaveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneHoverEvent * event);
    void hoverMoveEvent(::QGraphicsSceneHoverEvent * event) override;
    static void sbk_o_hoverMoveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneHoverEvent * event);
    void inputMethodEvent(::QInputMethodEvent * event) override;
    static void sbk_o_inputMethodEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QInputMethodEvent * event);
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery query) const override;
    bool isObscuredBy(const ::QGraphicsItem * item) const override;
    static bool sbk_o_isObscuredBy(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QGraphicsItem * item);
    ::QVariant itemChange(::QGraphicsItem::GraphicsItemChange change, const ::QVariant & value) override;
    static ::QVariant sbk_o_itemChange(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsItem::GraphicsItemChange change, const ::QVariant & value);
    void keyPressEvent(::QKeyEvent * event) override;
    static void sbk_o_keyPressEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QKeyEvent * event);
    void keyReleaseEvent(::QKeyEvent * event) override;
    static void sbk_o_keyReleaseEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QKeyEvent * event);
    void mouseDoubleClickEvent(::QGraphicsSceneMouseEvent * event) override;
    static void sbk_o_mouseDoubleClickEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneMouseEvent * event);
    void mouseMoveEvent(::QGraphicsSceneMouseEvent * event) override;
    static void sbk_o_mouseMoveEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneMouseEvent * event);
    void mousePressEvent(::QGraphicsSceneMouseEvent * event) override;
    static void sbk_o_mousePressEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneMouseEvent * event);
    void mouseReleaseEvent(::QGraphicsSceneMouseEvent * event) override;
    static void sbk_o_mouseReleaseEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneMouseEvent * event);
    ::QPainterPath opaqueArea() const override;
    static ::QPainterPath sbk_o_opaqueArea(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void paint(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget = nullptr) override;
    static void sbk_o_paint(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget = nullptr);
    bool sceneEvent(::QEvent * event) override;
    static bool sbk_o_sceneEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    bool sceneEventFilter(::QGraphicsItem * watched, ::QEvent * event) override;
    static bool sbk_o_sceneEventFilter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsItem * watched, ::QEvent * event);
    ::QPainterPath shape() const override;
    void timerEvent(::QTimerEvent * event) override;
    int type() const override;
    void wheelEvent(::QGraphicsSceneWheelEvent * event) override;
    static void sbk_o_wheelEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGraphicsSceneWheelEvent * event);

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[40] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QGRAPHICSVIDEOITEMWRAPPER_H
