// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QABSTRACTNETWORKCACHEWRAPPER_H
#define SBK_QABSTRACTNETWORKCACHEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtNetwork/qabstractnetworkcache.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QAbstractNetworkCacheWrapper : public QAbstractNetworkCache
{
public:
    QAbstractNetworkCacheWrapper(::QObject * parent = nullptr);
    QAbstractNetworkCacheWrapper(const QAbstractNetworkCacheWrapper &) = delete;
    QAbstractNetworkCacheWrapper& operator=(const QAbstractNetworkCacheWrapper &) = delete;
    QAbstractNetworkCacheWrapper(QAbstractNetworkCacheWrapper &&) = delete;
    QAbstractNetworkCacheWrapper& operator=(QAbstractNetworkCacheWrapper &&) = delete;
    ~QAbstractNetworkCacheWrapper() override;

    qint64 cacheSize() const override;
    static qint64 sbk_o_cacheSize(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void childEvent(::QChildEvent * event) override;
    void clear() override;
    static void sbk_o_clear(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    ::QIODevice * data(const ::QUrl & url) override;
    static ::QIODevice * sbk_o_data(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url);
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    void insert(::QIODevice * device) override;
    static void sbk_o_insert(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QIODevice * device);
    ::QNetworkCacheMetaData metaData(const ::QUrl & url) override;
    static ::QNetworkCacheMetaData sbk_o_metaData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url);
    ::QIODevice * prepare(const ::QNetworkCacheMetaData & metaData) override;
    static ::QIODevice * sbk_o_prepare(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QNetworkCacheMetaData & metaData);
    bool remove(const ::QUrl & url) override;
    static bool sbk_o_remove(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url);
    void timerEvent(::QTimerEvent * event) override;
    void updateMetaData(const ::QNetworkCacheMetaData & metaData) override;
    static void sbk_o_updateMetaData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QNetworkCacheMetaData & metaData);

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[15] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QABSTRACTNETWORKCACHEWRAPPER_H
