// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QABSTRACTSOCKETWRAPPER_H
#define SBK_QABSTRACTSOCKETWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtNetwork/qabstractsocket.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QAbstractSocketWrapper : public QAbstractSocket
{
public:
    QAbstractSocketWrapper(::QAbstractSocket::SocketType socketType, ::QObject * parent);
    QAbstractSocketWrapper(const QAbstractSocketWrapper &) = delete;
    QAbstractSocketWrapper& operator=(const QAbstractSocketWrapper &) = delete;
    QAbstractSocketWrapper(QAbstractSocketWrapper &&) = delete;
    QAbstractSocketWrapper& operator=(QAbstractSocketWrapper &&) = delete;
    ~QAbstractSocketWrapper() override;

    bool atEnd() const override;
    bool bind(const ::QHostAddress & address, quint16 port = 0, ::QFlags<QAbstractSocket::BindFlag> mode = QAbstractSocket::BindFlag::DefaultForPlatform) override;
    static bool sbk_o_bind(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QHostAddress & address, quint16 port = 0, ::QFlags<QAbstractSocket::BindFlag> mode = QAbstractSocket::BindFlag::DefaultForPlatform);
    // Inherited overloads, because the using keyword sux
    bool bind(quint16 port = 0, ::QFlags<QAbstractSocket::BindFlag> mode = QAbstractSocket::BindFlag::DefaultForPlatform) { return QAbstractSocket::bind(port, QFlags<QAbstractSocket::BindFlag>(mode)); }

    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(::QChildEvent * event) override;
    void close() override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void connectToHost(const ::QString & hostName, quint16 port, ::QFlags<QIODeviceBase::OpenModeFlag> mode = QIODeviceBase::OpenModeFlag::ReadWrite, ::QAbstractSocket::NetworkLayerProtocol protocol = QAbstractSocket::NetworkLayerProtocol::AnyIPProtocol) override;
    static void sbk_o_connectToHost(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & hostName, quint16 port, ::QFlags<QIODeviceBase::OpenModeFlag> mode = QIODeviceBase::OpenModeFlag::ReadWrite, ::QAbstractSocket::NetworkLayerProtocol protocol = QAbstractSocket::NetworkLayerProtocol::AnyIPProtocol);
    // Inherited overloads, because the using keyword sux
    void connectToHost(const ::QHostAddress & address, quint16 port, ::QFlags<QIODeviceBase::OpenModeFlag> mode = QIODeviceBase::OpenModeFlag::ReadWrite) { QAbstractSocket::connectToHost(address, port, QFlags<QIODeviceBase::OpenModeFlag>(mode)); }

    void customEvent(::QEvent * event) override;
    void disconnectFromHost() override;
    static void sbk_o_disconnectFromHost(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    bool isSequential() const override;
    bool open(::QFlags<QIODeviceBase::OpenModeFlag> mode) override;
    qint64 pos() const override;
    qint64 readData(char * data, qint64 maxlen) override;
    qint64 readLineData(char * data, qint64 maxlen) override;
    bool reset() override;
    void resume() override;
    bool seek(qint64 pos) override;
    void setReadBufferSize(qint64 size) override;
    bool setSocketDescriptor(::qintptr socketDescriptor, ::QAbstractSocket::SocketState state = QAbstractSocket::SocketState::ConnectedState, ::QFlags<QIODeviceBase::OpenModeFlag> openMode = QIODeviceBase::OpenModeFlag::ReadWrite) override;
    static bool sbk_o_setSocketDescriptor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::qintptr socketDescriptor, ::QAbstractSocket::SocketState state = QAbstractSocket::SocketState::ConnectedState, ::QFlags<QIODeviceBase::OpenModeFlag> openMode = QIODeviceBase::OpenModeFlag::ReadWrite);
    void setSocketOption(::QAbstractSocket::SocketOption option, const ::QVariant & value) override;
    static void sbk_o_setSocketOption(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAbstractSocket::SocketOption option, const ::QVariant & value);
    qint64 size() const override;
    qint64 skipData(qint64 maxSize) override;
    ::qintptr socketDescriptor() const override;
    static ::qintptr sbk_o_socketDescriptor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QVariant socketOption(::QAbstractSocket::SocketOption option) override;
    static ::QVariant sbk_o_socketOption(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAbstractSocket::SocketOption option);
    void timerEvent(::QTimerEvent * event) override;
    bool waitForBytesWritten(int msecs = 30000) override;
    static bool sbk_o_waitForBytesWritten(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int msecs = 30000);
    bool waitForConnected(int msecs = 30000) override;
    static bool sbk_o_waitForConnected(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int msecs = 30000);
    bool waitForDisconnected(int msecs = 30000) override;
    static bool sbk_o_waitForDisconnected(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int msecs = 30000);
    bool waitForReadyRead(int msecs = 30000) override;
    static bool sbk_o_waitForReadyRead(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int msecs = 30000);
    qint64 writeData(const char * data, qint64 len) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[35] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QABSTRACTSOCKETWRAPPER_H
