// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QLOCALSERVERWRAPPER_H
#define SBK_QLOCALSERVERWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtNetwork/qlocalserver.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QLocalServerWrapper : public QLocalServer
{
public:
    QLocalServerWrapper(::QObject * parent = nullptr);
    QLocalServerWrapper(const QLocalServerWrapper &) = delete;
    QLocalServerWrapper& operator=(const QLocalServerWrapper &) = delete;
    QLocalServerWrapper(QLocalServerWrapper &&) = delete;
    QLocalServerWrapper& operator=(QLocalServerWrapper &&) = delete;
    ~QLocalServerWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    bool hasPendingConnections() const override;
    static bool sbk_o_hasPendingConnections(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void incomingConnection(::quintptr socketDescriptor) override;
    static void sbk_o_incomingConnection(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::quintptr socketDescriptor);
    ::QLocalSocket * nextPendingConnection() override;
    static ::QLocalSocket * sbk_o_nextPendingConnection(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[10] = {false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QLOCALSERVERWRAPPER_H
