// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QNETWORKCOOKIEJARWRAPPER_H
#define SBK_QNETWORKCOOKIEJARWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtNetwork/qnetworkcookiejar.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QNetworkCookieJarWrapper : public QNetworkCookieJar
{
public:
    QNetworkCookieJarWrapper(::QObject * parent = nullptr);
    QNetworkCookieJarWrapper(const QNetworkCookieJarWrapper &) = delete;
    QNetworkCookieJarWrapper& operator=(const QNetworkCookieJarWrapper &) = delete;
    QNetworkCookieJarWrapper(QNetworkCookieJarWrapper &&) = delete;
    QNetworkCookieJarWrapper& operator=(QNetworkCookieJarWrapper &&) = delete;
    ~QNetworkCookieJarWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    ::QList<QNetworkCookie> cookiesForUrl(const ::QUrl & url) const override;
    static ::QList<QNetworkCookie> sbk_o_cookiesForUrl(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url);
    void customEvent(::QEvent * event) override;
    bool deleteCookie(const ::QNetworkCookie & cookie) override;
    static bool sbk_o_deleteCookie(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QNetworkCookie & cookie);
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    bool insertCookie(const ::QNetworkCookie & cookie) override;
    bool setCookiesFromUrl(const ::QList<QNetworkCookie> & cookieList, const ::QUrl & url) override;
    static bool sbk_o_setCookiesFromUrl(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QList<QNetworkCookie> & cookieList, const ::QUrl & url);
    void timerEvent(::QTimerEvent * event) override;
    bool updateCookie(const ::QNetworkCookie & cookie) override;
    bool validateCookie(const ::QNetworkCookie & cookie, const ::QUrl & url) const override;
    static bool sbk_o_validateCookie(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QNetworkCookie & cookie, const ::QUrl & url);

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[13] = {false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QNETWORKCOOKIEJARWRAPPER_H
