// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QTCPSERVERWRAPPER_H
#define SBK_QTCPSERVERWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtNetwork/qtcpserver.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QTcpServerWrapper : public QTcpServer
{
public:
    QTcpServerWrapper(::QObject * parent = nullptr);
    QTcpServerWrapper(const QTcpServerWrapper &) = delete;
    QTcpServerWrapper& operator=(const QTcpServerWrapper &) = delete;
    QTcpServerWrapper(QTcpServerWrapper &&) = delete;
    QTcpServerWrapper& operator=(QTcpServerWrapper &&) = delete;
    ~QTcpServerWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    bool hasPendingConnections() const override;
    void incomingConnection(::qintptr handle) override;
    static void sbk_o_incomingConnection(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::qintptr handle);
    ::QTcpSocket * nextPendingConnection() override;
    static ::QTcpSocket * sbk_o_nextPendingConnection(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[10] = {false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QTCPSERVERWRAPPER_H
