// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QABSTRACTOAUTHWRAPPER_H
#define SBK_QABSTRACTOAUTHWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtNetworkAuth/qabstractoauth.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QAbstractOAuthWrapper : public QAbstractOAuth
{
public:
    QAbstractOAuthWrapper(const QAbstractOAuthWrapper &) = delete;
    QAbstractOAuthWrapper& operator=(const QAbstractOAuthWrapper &) = delete;
    QAbstractOAuthWrapper(QAbstractOAuthWrapper &&) = delete;
    QAbstractOAuthWrapper& operator=(QAbstractOAuthWrapper &&) = delete;
    ~QAbstractOAuthWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    ::QNetworkReply * deleteResource(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    static ::QNetworkReply * sbk_o_deleteResource(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap());
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QNetworkReply * get(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    void grant() override;
    static void sbk_o_grant(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QNetworkReply * head(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    ::QNetworkReply * post(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    void prepareRequest(::QNetworkRequest * request, const ::QByteArray & verb, const ::QByteArray & body = QByteArray()) override;
    static void sbk_o_prepareRequest(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QNetworkRequest * request, const ::QByteArray & verb, const ::QByteArray & body = QByteArray());
    ::QNetworkReply * put(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    void resourceOwnerAuthorization(const ::QUrl & url, const ::QMultiMap<QString,QVariant> & parameters) override;
    static void sbk_o_resourceOwnerAuthorization(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMultiMap<QString,QVariant> & parameters);
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[15] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QABSTRACTOAUTHWRAPPER_H
