// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QOAUTH2DEVICEAUTHORIZATIONFLOWWRAPPER_H
#define SBK_QOAUTH2DEVICEAUTHORIZATIONFLOWWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtNetworkAuth/qoauth2deviceauthorizationflow.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QOAuth2DeviceAuthorizationFlowWrapper : public QOAuth2DeviceAuthorizationFlow
{
public:
    QOAuth2DeviceAuthorizationFlowWrapper();
    QOAuth2DeviceAuthorizationFlowWrapper(::QNetworkAccessManager * manager, ::QObject * parent = nullptr);
    QOAuth2DeviceAuthorizationFlowWrapper(::QObject * parent);
    QOAuth2DeviceAuthorizationFlowWrapper(const QOAuth2DeviceAuthorizationFlowWrapper &) = delete;
    QOAuth2DeviceAuthorizationFlowWrapper& operator=(const QOAuth2DeviceAuthorizationFlowWrapper &) = delete;
    QOAuth2DeviceAuthorizationFlowWrapper(QOAuth2DeviceAuthorizationFlowWrapper &&) = delete;
    QOAuth2DeviceAuthorizationFlowWrapper& operator=(QOAuth2DeviceAuthorizationFlowWrapper &&) = delete;
    ~QOAuth2DeviceAuthorizationFlowWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    ::QUrl createAuthenticatedUrl(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    void customEvent(::QEvent * event) override;
    ::QNetworkReply * deleteResource(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    static ::QNetworkReply * sbk_o_deleteResource(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap());
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QNetworkReply * get(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    static ::QNetworkReply * sbk_o_get(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap());
    void grant() override;
    ::QNetworkReply * head(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    static ::QNetworkReply * sbk_o_head(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap());
    ::QNetworkReply * post(const ::QUrl & url, ::QHttpMultiPart * multiPart) override;
    static ::QNetworkReply * sbk_o_post(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, ::QHttpMultiPart * multiPart);
    ::QNetworkReply * post(const ::QUrl & url, const ::QByteArray & data) override;
    static ::QNetworkReply * sbk_o_post(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QByteArray & data);
    ::QNetworkReply * post(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    static ::QNetworkReply * sbk_o_post(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap());
    void prepareRequest(::QNetworkRequest * request, const ::QByteArray & verb, const ::QByteArray & body = QByteArray()) override;
    ::QNetworkReply * put(const ::QUrl & url, ::QHttpMultiPart * multiPart) override;
    static ::QNetworkReply * sbk_o_put(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, ::QHttpMultiPart * multiPart);
    ::QNetworkReply * put(const ::QUrl & url, const ::QByteArray & data) override;
    static ::QNetworkReply * sbk_o_put(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QByteArray & data);
    ::QNetworkReply * put(const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap()) override;
    static ::QNetworkReply * sbk_o_put(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, const ::QMap<QString,QVariant> & parameters = QVariantMap());
    void resourceOwnerAuthorization(const ::QUrl & url, const ::QMultiMap<QString,QVariant> & parameters) override;
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[20] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QOAUTH2DEVICEAUTHORIZATIONFLOWWRAPPER_H
