// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetworkauth_python.h"

// main header
#include "qoauthhttpserverreplyhandler_wrapper.h"

// Wrappers providing overrides
#include "qabstractoauthreplyhandler_wrapper.h"

// Argument includes
#include <QString>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qsslconfiguration.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QOAuthHttpServerReplyHandlerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QOAuthHttpServerReplyHandlerWrapper::QOAuthHttpServerReplyHandlerWrapper(::QObject * parent) : QOAuthHttpServerReplyHandler(parent)
{
}

QOAuthHttpServerReplyHandlerWrapper::QOAuthHttpServerReplyHandlerWrapper(const ::QHostAddress & address, quint16 port, ::QObject * parent) : QOAuthHttpServerReplyHandler(address, port, parent)
{
}

QOAuthHttpServerReplyHandlerWrapper::QOAuthHttpServerReplyHandlerWrapper(quint16 port, ::QObject * parent) : QOAuthHttpServerReplyHandler(port, parent)
{
}

::QString QOAuthHttpServerReplyHandlerWrapper::callback() const
{
    static const char *funcName = "callback";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QOAuthHttpServerReplyHandler::callback();
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_callback("QOAuthHttpServerReplyHandler", funcName, gil, pyOverride);
}

void QOAuthHttpServerReplyHandlerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_childEvent("QOAuthHttpServerReplyHandler", funcName, gil, pyOverride, event);
}

void QOAuthHttpServerReplyHandlerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_connectNotify("QOAuthHttpServerReplyHandler", funcName, gil, pyOverride, signal);
}

void QOAuthHttpServerReplyHandlerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_customEvent("QOAuthHttpServerReplyHandler", funcName, gil, pyOverride, event);
}

void QOAuthHttpServerReplyHandlerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_connectNotify("QOAuthHttpServerReplyHandler", funcName, gil, pyOverride, signal);
}

bool QOAuthHttpServerReplyHandlerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_event("QOAuthHttpServerReplyHandler", funcName, gil, pyOverride, event);
}

bool QOAuthHttpServerReplyHandlerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QAbstractOAuthReplyHandlerWrapper::sbk_o_eventFilter("QOAuthHttpServerReplyHandler", funcName, gil, pyOverride, watched, event);
}

void QOAuthHttpServerReplyHandlerWrapper::networkReplyFinished(::QNetworkReply * reply)
{
    static const char *funcName = "networkReplyFinished";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QOAuthOobReplyHandler::networkReplyFinished(reply);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_networkReplyFinished("QOAuthHttpServerReplyHandler", funcName, gil, pyOverride, reply);
}

void QOAuthHttpServerReplyHandlerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QAbstractOAuthReplyHandlerWrapper::sbk_o_timerEvent("QOAuthHttpServerReplyHandler", funcName, gil, pyOverride, event);
}

const QMetaObject *QOAuthHttpServerReplyHandlerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QOAuthHttpServerReplyHandler::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QOAuthHttpServerReplyHandlerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QOAuthHttpServerReplyHandler::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QOAuthHttpServerReplyHandlerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QOAuthHttpServerReplyHandlerWrapper *>(this));
    return QOAuthHttpServerReplyHandler::qt_metacast(_clname);
}

QOAuthHttpServerReplyHandlerWrapper::~QOAuthHttpServerReplyHandlerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOAuthHttpServerReplyHandler_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOAuthHttpServerReplyHandler >()))
        return -1;

    QOAuthHttpServerReplyHandlerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOO:QOAuthHttpServerReplyHandler", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOAuthHttpServerReplyHandler::QOAuthHttpServerReplyHandler(QObject*=)
    // 1: QOAuthHttpServerReplyHandler::QOAuthHttpServerReplyHandler(QHostAddress,quint16,QObject*=)
    // 2: QOAuthHttpServerReplyHandler::QOAuthHttpServerReplyHandler(quint16,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QOAuthHttpServerReplyHandler(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QOAuthHttpServerReplyHandler(quint16,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QOAuthHttpServerReplyHandler(quint16,QObject*)
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // QOAuthHttpServerReplyHandler(QHostAddress,quint16,QObject*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))) {
            overloadId = 1; // QOAuthHttpServerReplyHandler(QHostAddress,quint16,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QOAuthHttpServerReplyHandler(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOAuthHttpServerReplyHandler(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuthHttpServerReplyHandler(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuthHttpServerReplyHandlerWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuthHttpServerReplyHandlerWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QOAuthHttpServerReplyHandler(const QHostAddress &address, quint16 port, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 2}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QHostAddress cppArg0_local;
            ::QHostAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            quint16 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QObject *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuthHttpServerReplyHandler(QHostAddress,quint16,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuthHttpServerReplyHandlerWrapper(*cppArg0, cppArg1, cppArg2);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuthHttpServerReplyHandlerWrapper(*cppArg0, cppArg1, cppArg2);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[2], self);
            }
            break;
        }
        case 2: // QOAuthHttpServerReplyHandler(quint16 port, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]);
                }
            }
            quint16 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuthHttpServerReplyHandler(quint16,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QOAuthHttpServerReplyHandlerWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QOAuthHttpServerReplyHandlerWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QOAuthHttpServerReplyHandler >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QOAuthHttpServerReplyHandlerFunc_callback(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // callback()const
        QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QOAuthHttpServerReplyHandler *>(cppSelf)->::QOAuthHttpServerReplyHandler::callback()
            : const_cast<const ::QOAuthHttpServerReplyHandler *>(cppSelf)->callback();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuthHttpServerReplyHandlerFunc_callbackHost(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // callbackHost()const
        QString cppResult = const_cast<const ::QOAuthHttpServerReplyHandler *>(cppSelf)->callbackHost();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuthHttpServerReplyHandlerFunc_callbackPath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // callbackPath()const
        QString cppResult = const_cast<const ::QOAuthHttpServerReplyHandler *>(cppSelf)->callbackPath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuthHttpServerReplyHandlerFunc_callbackText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // callbackText()const
        QString cppResult = const_cast<const ::QOAuthHttpServerReplyHandler *>(cppSelf)->callbackText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuthHttpServerReplyHandlerFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        cppSelf->close();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QOAuthHttpServerReplyHandlerFunc_isListening(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isListening()const
        bool cppResult = const_cast<const ::QOAuthHttpServerReplyHandler *>(cppSelf)->isListening();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuthHttpServerReplyHandlerFunc_listen(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "listen", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:listen", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOAuthHttpServerReplyHandler::listen(const QHostAddress&=,quint16=)->bool
    // 1: QOAuthHttpServerReplyHandler::listen(QSslConfiguration,const QHostAddress&=,quint16=)->bool
    if (numArgs == 0) {
        overloadId = 0; // listen(QHostAddress,quint16)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // listen(QSslConfiguration,QHostAddress,quint16)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // listen(QSslConfiguration,QHostAddress,quint16)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[2])))) {
                overloadId = 1; // listen(QSslConfiguration,QHostAddress,quint16)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // listen(QHostAddress,quint16)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
            overloadId = 0; // listen(QHostAddress,quint16)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "listen", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // listen(const QHostAddress &address, quint16 port)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"address", 0}, {"port", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0]))))
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "listen", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QHostAddress cppArg0_local(QHostAddress::Any);
            ::QHostAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0]) {
                if (pythonToCpp[0].isValue())
                    pythonToCpp[0](pyArgs[0], &cppArg0_local);
                else
                    pythonToCpp[0](pyArgs[0], &cppArg0);
                }
            quint16 cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // listen(QHostAddress,quint16)
                bool cppResult = cppSelf->listen(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // listen(const QSslConfiguration &configuration, const QHostAddress &address, quint16 port)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"address", 1}, {"port", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[1]))))
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "listen", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSslConfiguration cppArg0_local;
            ::QSslConfiguration *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QHostAddress cppArg1_local(QHostAddress::Any);
            ::QHostAddress *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }
            quint16 cppArg2 = 0;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // listen(QSslConfiguration,QHostAddress,quint16)
                bool cppResult = cppSelf->listen(*cppArg0, *cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuthHttpServerReplyHandlerFunc_port(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // port()const
        quint16 cppResult = const_cast<const ::QOAuthHttpServerReplyHandler *>(cppSelf)->port();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QOAuthHttpServerReplyHandlerFunc_setCallbackHost(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuthHttpServerReplyHandler::setCallbackHost(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCallbackHost(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCallbackHost", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCallbackHost(QString)
            cppSelf->setCallbackHost(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QOAuthHttpServerReplyHandlerFunc_setCallbackPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuthHttpServerReplyHandler::setCallbackPath(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCallbackPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCallbackPath", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCallbackPath(QString)
            cppSelf->setCallbackPath(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QOAuthHttpServerReplyHandlerFunc_setCallbackText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuthHttpServerReplyHandler::setCallbackText(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCallbackText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCallbackText", errInfo, SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCallbackText(QString)
            cppSelf->setCallbackText(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QOAuthHttpServerReplyHandler_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOAuthHttpServerReplyHandler_methods[] = {
    {"callback", reinterpret_cast<PyCFunction>(Sbk_QOAuthHttpServerReplyHandlerFunc_callback), METH_NOARGS, nullptr},
    {"callbackHost", reinterpret_cast<PyCFunction>(Sbk_QOAuthHttpServerReplyHandlerFunc_callbackHost), METH_NOARGS, nullptr},
    {"callbackPath", reinterpret_cast<PyCFunction>(Sbk_QOAuthHttpServerReplyHandlerFunc_callbackPath), METH_NOARGS, nullptr},
    {"callbackText", reinterpret_cast<PyCFunction>(Sbk_QOAuthHttpServerReplyHandlerFunc_callbackText), METH_NOARGS, nullptr},
    {"close", reinterpret_cast<PyCFunction>(Sbk_QOAuthHttpServerReplyHandlerFunc_close), METH_NOARGS, nullptr},
    {"isListening", reinterpret_cast<PyCFunction>(Sbk_QOAuthHttpServerReplyHandlerFunc_isListening), METH_NOARGS, nullptr},
    {"listen", reinterpret_cast<PyCFunction>(Sbk_QOAuthHttpServerReplyHandlerFunc_listen), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"port", reinterpret_cast<PyCFunction>(Sbk_QOAuthHttpServerReplyHandlerFunc_port), METH_NOARGS, nullptr},
    {"setCallbackHost", reinterpret_cast<PyCFunction>(Sbk_QOAuthHttpServerReplyHandlerFunc_setCallbackHost), METH_O, nullptr},
    {"setCallbackPath", reinterpret_cast<PyCFunction>(Sbk_QOAuthHttpServerReplyHandlerFunc_setCallbackPath), METH_O, nullptr},
    {"setCallbackText", reinterpret_cast<PyCFunction>(Sbk_QOAuthHttpServerReplyHandlerFunc_setCallbackText), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QOAuthHttpServerReplyHandler_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QOAuthHttpServerReplyHandlerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QOAuthHttpServerReplyHandler_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOAuthHttpServerReplyHandler_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOAuthHttpServerReplyHandler_Type = nullptr;
static PyTypeObject *Sbk_QOAuthHttpServerReplyHandler_TypeF(void)
{
    return _Sbk_QOAuthHttpServerReplyHandler_Type;
}

static PyType_Slot Sbk_QOAuthHttpServerReplyHandler_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QOAuthHttpServerReplyHandler_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOAuthHttpServerReplyHandler_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOAuthHttpServerReplyHandler_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOAuthHttpServerReplyHandler_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOAuthHttpServerReplyHandler_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOAuthHttpServerReplyHandler_spec = {
    "2:PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOAuthHttpServerReplyHandler_slots
};

} //extern "C"

static void *Sbk_QOAuthHttpServerReplyHandler_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QOAuthHttpServerReplyHandler *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOAuthHttpServerReplyHandler_PythonToCpp_QOAuthHttpServerReplyHandler_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOAuthHttpServerReplyHandler_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOAuthHttpServerReplyHandler_PythonToCpp_QOAuthHttpServerReplyHandler_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOAuthHttpServerReplyHandler_TypeF()))
        return QOAuthHttpServerReplyHandler_PythonToCpp_QOAuthHttpServerReplyHandler_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOAuthHttpServerReplyHandler_PTR_CppToPython_QOAuthHttpServerReplyHandler(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QOAuthHttpServerReplyHandler *>(const_cast<void *>(cppIn)), Sbk_QOAuthHttpServerReplyHandler_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOAuthHttpServerReplyHandler_SignatureStrings[] = {
    "2:PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler(self,parent:PySide6.QtCore.QObject=nullptr)",
    "1:PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress],port:quint16,parent:PySide6.QtCore.QObject=nullptr)",
    "0:PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler(self,port:quint16,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler.callback(self)->QString",
    "PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler.callbackHost(self)->QString",
    "PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler.callbackPath(self)->QString",
    "PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler.callbackText(self)->QString",
    "PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler.close(self)",
    "PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler.isListening(self)->bool",
    "1:PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler.listen(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress]=QHostAddress.Any,port:quint16=0)->bool",
    "0:PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler.listen(self,configuration:PySide6.QtNetwork.QSslConfiguration,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress]=QHostAddress.Any,port:quint16=0)->bool",
    "PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler.port(self)->quint16",
    "PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler.setCallbackHost(self,path:QString)",
    "PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler.setCallbackPath(self,path:QString)",
    "PySide6.QtNetworkAuth.QOAuthHttpServerReplyHandler.setCallbackText(self,text:QString)",
    nullptr}; // Sentinel
#else
static constexpr size_t QOAuthHttpServerReplyHandler_SignatureByteSize = 305;
static constexpr uint8_t QOAuthHttpServerReplyHandler_SignatureBytes[305] = {
    0x78, 0xda, 0xcd, 0x94, 0x41, 0x4f, 0x84, 0x30, 0x10, 0x85, 0xef, 0xfe, 0x0a, 0x8f, 0x92, 0x60,
    0xc3, 0x7a, 0xd8, 0x03, 0x09, 0x26, 0x84, 0x0b, 0x07, 0xa3, 0x8b, 0xe8, 0xc9, 0x78, 0x28, 0x30,
    0xbb, 0xd4, 0x6d, 0xda, 0xda, 0x0e, 0x2a, 0xff, 0xde, 0xb2, 0x0b, 0xeb, 0xae, 0x6b, 0x8c, 0x16,
    0x62, 0x3c, 0x01, 0x69, 0xe7, 0x7b, 0xf3, 0x26, 0xf3, 0xb8, 0x08, 0x17, 0x6d, 0xce, 0x2a, 0x98,
    0x93, 0x0c, 0xaf, 0x01, 0x5f, 0xa5, 0x5e, 0xc7, 0x0d, 0xd6, 0x24, 0xbb, 0xe9, 0x1e, 0x29, 0xa2,
    0xca, 0x41, 0xbf, 0x80, 0xbe, 0x05, 0xc5, 0xdb, 0x94, 0x8a, 0x8a, 0x83, 0x3e, 0x33, 0xc0, 0x97,
    0xbe, 0xa2, 0x1a, 0x04, 0xee, 0x95, 0x27, 0x52, 0x83, 0xad, 0x2b, 0x9e, 0xa0, 0xc4, 0x48, 0x34,
    0x9c, 0x2b, 0xd4, 0xde, 0xc9, 0xcc, 0x59, 0x80, 0x56, 0x95, 0x06, 0x63, 0x42, 0x6c, 0x15, 0x13,
    0x2b, 0x72, 0x2f, 0x98, 0x14, 0x0f, 0x47, 0x30, 0x92, 0xa5, 0xd2, 0x60, 0xbc, 0xbd, 0xeb, 0x9f,
    0x7e, 0x7f, 0x4e, 0x72, 0x05, 0x25, 0xa3, 0xbc, 0xff, 0x7c, 0xf4, 0x95, 0xd4, 0x18, 0x3e, 0x37,
    0x4c, 0xe0, 0x6c, 0xfe, 0x53, 0x47, 0x81, 0xfb, 0xc8, 0x1c, 0xd4, 0x7e, 0xaf, 0x45, 0x4a, 0xca,
    0x79, 0x41, 0xcb, 0xf5, 0x46, 0xd4, 0x3b, 0xbf, 0xcc, 0x72, 0xd4, 0x76, 0x82, 0x63, 0x50, 0xdd,
    0x0c, 0x27, 0xc4, 0x2d, 0x28, 0xd6, 0x13, 0xe2, 0xee, 0xe0, 0x6d, 0x92, 0xee, 0xb8, 0x34, 0xb0,
    0xe5, 0xb8, 0x94, 0x33, 0x73, 0xc5, 0x0c, 0x82, 0xb0, 0xea, 0x43, 0x33, 0x85, 0x94, 0xdc, 0x29,
    0x01, 0x84, 0x6f, 0x50, 0x7f, 0x16, 0x84, 0xe8, 0xe0, 0x30, 0x16, 0xed, 0xc1, 0xae, 0x46, 0xc1,
    0xe0, 0x25, 0x18, 0xeb, 0xa5, 0x94, 0x62, 0xc9, 0x56, 0x8d, 0xa6, 0x68, 0x4d, 0x84, 0x5f, 0x34,
    0x99, 0x1b, 0x9e, 0xec, 0xdf, 0xf9, 0x4f, 0xee, 0x1d, 0xbc, 0x77, 0xa0, 0x61, 0x1b, 0x7a, 0x9e,
    0x0b, 0xc6, 0x00, 0x26, 0x9f, 0xa3, 0x68, 0xff, 0x20, 0x58, 0x87, 0xfd, 0xbe, 0x7b, 0x23, 0xa9,
    0xbb, 0x44, 0x4e, 0x4a, 0xdd, 0x05, 0xd3, 0x47, 0xfb, 0xf6, 0x41, 0x7d, 0x07, 0xba, 0xfb, 0x66,
    0x69
};
#endif

PyTypeObject *init_QOAuthHttpServerReplyHandler(PyObject *module)
{
    if (SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX].type != nullptr)
        return SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX].type;

    Shiboken::AutoDecRef Sbk_QOAuthHttpServerReplyHandler_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthOobReplyHandler_IDX]))));

    _Sbk_QOAuthHttpServerReplyHandler_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOAuthHttpServerReplyHandler",
        "QOAuthHttpServerReplyHandler*",
        &Sbk_QOAuthHttpServerReplyHandler_spec,
        &Shiboken::callCppDestructor< QOAuthHttpServerReplyHandler >,
        Sbk_QOAuthHttpServerReplyHandler_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOAuthHttpServerReplyHandler_TypeF(); // references _Sbk_QOAuthHttpServerReplyHandler_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOAuthHttpServerReplyHandler_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOAuthHttpServerReplyHandler_SignatureBytes, QOAuthHttpServerReplyHandler_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOAuthHttpServerReplyHandler_PropertyStrings);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuthHttpServerReplyHandler_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOAuthHttpServerReplyHandler_PythonToCpp_QOAuthHttpServerReplyHandler_PTR,
        is_QOAuthHttpServerReplyHandler_PythonToCpp_QOAuthHttpServerReplyHandler_PTR_Convertible,
        QOAuthHttpServerReplyHandler_PTR_CppToPython_QOAuthHttpServerReplyHandler);

    Shiboken::Conversions::registerConverterName(converter, "QOAuthHttpServerReplyHandler");
    Shiboken::Conversions::registerConverterName(converter, "QOAuthHttpServerReplyHandler*");
    Shiboken::Conversions::registerConverterName(converter, "QOAuthHttpServerReplyHandler&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOAuthHttpServerReplyHandler).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QOAuthHttpServerReplyHandlerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QOAuthHttpServerReplyHandler_TypeF(), &Sbk_QOAuthHttpServerReplyHandler_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QOAuthHttpServerReplyHandler::staticMetaObject, sizeof(QOAuthHttpServerReplyHandlerWrapper));

    return pyType;
}
