// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QGEOAREAMONITORSOURCEWRAPPER_H
#define SBK_QGEOAREAMONITORSOURCEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtPositioning/qgeoareamonitorsource.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QGeoAreaMonitorSourceWrapper : public QGeoAreaMonitorSource
{
public:
    QGeoAreaMonitorSourceWrapper(::QObject * parent);
    QGeoAreaMonitorSourceWrapper(const QGeoAreaMonitorSourceWrapper &) = delete;
    QGeoAreaMonitorSourceWrapper& operator=(const QGeoAreaMonitorSourceWrapper &) = delete;
    QGeoAreaMonitorSourceWrapper(QGeoAreaMonitorSourceWrapper &&) = delete;
    QGeoAreaMonitorSourceWrapper& operator=(QGeoAreaMonitorSourceWrapper &&) = delete;
    ~QGeoAreaMonitorSourceWrapper() override;

    ::QList<QGeoAreaMonitorInfo> activeMonitors() const override;
    static ::QList<QGeoAreaMonitorInfo> sbk_o_activeMonitors(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QList<QGeoAreaMonitorInfo> activeMonitors(const ::QGeoShape & lookupArea) const override;
    static ::QList<QGeoAreaMonitorInfo> sbk_o_activeMonitors(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QGeoShape & lookupArea);
    ::QVariant backendProperty(const ::QString & name) const override;
    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    ::QGeoAreaMonitorSource::Error error() const override;
    static ::QGeoAreaMonitorSource::Error sbk_o_error(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QGeoPositionInfoSource * positionInfoSource() const override;
    static ::QGeoPositionInfoSource * sbk_o_positionInfoSource(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool requestUpdate(const ::QGeoAreaMonitorInfo & monitor, const char * signal) override;
    static bool sbk_o_requestUpdate(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QGeoAreaMonitorInfo & monitor, const char * signal);
    bool setBackendProperty(const ::QString & name, const ::QVariant & value) override;
    void setPositionInfoSource(::QGeoPositionInfoSource * source) override;
    static void sbk_o_setPositionInfoSource(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QGeoPositionInfoSource * source);
    bool startMonitoring(const ::QGeoAreaMonitorInfo & monitor) override;
    static bool sbk_o_startMonitoring(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QGeoAreaMonitorInfo & monitor);
    bool stopMonitoring(const ::QGeoAreaMonitorInfo & monitor) override;
    ::QFlags<QGeoAreaMonitorSource::AreaMonitorFeature> supportedAreaMonitorFeatures() const override;
    static ::QFlags<QGeoAreaMonitorSource::AreaMonitorFeature> sbk_o_supportedAreaMonitorFeatures(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[18] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QGEOAREAMONITORSOURCEWRAPPER_H
