// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QGEOPOSITIONINFOSOURCEWRAPPER_H
#define SBK_QGEOPOSITIONINFOSOURCEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtPositioning/qgeopositioninfosource.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QGeoPositionInfoSourceWrapper : public QGeoPositionInfoSource
{
public:
    QGeoPositionInfoSourceWrapper(::QObject * parent);
    QGeoPositionInfoSourceWrapper(const QGeoPositionInfoSourceWrapper &) = delete;
    QGeoPositionInfoSourceWrapper& operator=(const QGeoPositionInfoSourceWrapper &) = delete;
    QGeoPositionInfoSourceWrapper(QGeoPositionInfoSourceWrapper &&) = delete;
    QGeoPositionInfoSourceWrapper& operator=(QGeoPositionInfoSourceWrapper &&) = delete;
    ~QGeoPositionInfoSourceWrapper() override;

    ::QVariant backendProperty(const ::QString & name) const override;
    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    ::QGeoPositionInfoSource::Error error() const override;
    static ::QGeoPositionInfoSource::Error sbk_o_error(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QGeoPositionInfo lastKnownPosition(bool fromSatellitePositioningMethodsOnly = false) const override;
    static ::QGeoPositionInfo sbk_o_lastKnownPosition(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, bool fromSatellitePositioningMethodsOnly = false);
    int minimumUpdateInterval() const override;
    void requestUpdate(int timeout = 0) override;
    bool setBackendProperty(const ::QString & name, const ::QVariant & value) override;
    void setPreferredPositioningMethods(::QFlags<QGeoPositionInfoSource::PositioningMethod> methods) override;
    static void sbk_o_setPreferredPositioningMethods(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<QGeoPositionInfoSource::PositioningMethod> methods);
    void setUpdateInterval(int msec) override;
    void startUpdates() override;
    void stopUpdates() override;
    ::QFlags<QGeoPositionInfoSource::PositioningMethod> supportedPositioningMethods() const override;
    static ::QFlags<QGeoPositionInfoSource::PositioningMethod> sbk_o_supportedPositioningMethods(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[18] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QGEOPOSITIONINFOSOURCEWRAPPER_H
