// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QNMEAPOSITIONINFOSOURCEWRAPPER_H
#define SBK_QNMEAPOSITIONINFOSOURCEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtPositioning/qnmeapositioninfosource.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QNmeaPositionInfoSourceWrapper : public QNmeaPositionInfoSource
{
public:
    QNmeaPositionInfoSourceWrapper(::QNmeaPositionInfoSource::UpdateMode updateMode, ::QObject * parent = nullptr);
    QNmeaPositionInfoSourceWrapper(const QNmeaPositionInfoSourceWrapper &) = delete;
    QNmeaPositionInfoSourceWrapper& operator=(const QNmeaPositionInfoSourceWrapper &) = delete;
    QNmeaPositionInfoSourceWrapper(QNmeaPositionInfoSourceWrapper &&) = delete;
    QNmeaPositionInfoSourceWrapper& operator=(QNmeaPositionInfoSourceWrapper &&) = delete;
    ~QNmeaPositionInfoSourceWrapper() override;

    ::QVariant backendProperty(const ::QString & name) const override;
    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    ::QGeoPositionInfoSource::Error error() const override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QGeoPositionInfo lastKnownPosition(bool fromSatellitePositioningMethodsOnly = false) const override;
    int minimumUpdateInterval() const override;
    bool parsePosInfoFromNmeaData(const char * data, int size, ::QGeoPositionInfo * posInfo, bool * hasFix) override;
    static bool sbk_o_parsePosInfoFromNmeaData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const char * data, int size, ::QGeoPositionInfo * posInfo, bool * hasFix);
    // Inherited overloads, because the using keyword sux
    bool parsePosInfoFromNmeaData(::QByteArrayView data, ::QGeoPositionInfo * posInfo, bool * hasFix) { return QNmeaPositionInfoSource::parsePosInfoFromNmeaData(data, posInfo, hasFix); }

    void requestUpdate(int timeout = 0) override;
    bool setBackendProperty(const ::QString & name, const ::QVariant & value) override;
    void setPreferredPositioningMethods(::QFlags<QGeoPositionInfoSource::PositioningMethod> methods) override;
    void setUpdateInterval(int msec) override;
    void startUpdates() override;
    void stopUpdates() override;
    ::QFlags<QGeoPositionInfoSource::PositioningMethod> supportedPositioningMethods() const override;
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[19] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QNMEAPOSITIONINFOSOURCEWRAPPER_H
