// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QPRINTERWRAPPER_H
#define SBK_QPRINTERWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtPrintSupport/qprinter.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QPrinterWrapper : public QPrinter
{
public:
    QPrinterWrapper(::QPrinter::PrinterMode mode = QPrinter::PrinterMode::ScreenResolution);
    QPrinterWrapper(const ::QPrinterInfo & printer, ::QPrinter::PrinterMode mode = QPrinter::PrinterMode::ScreenResolution);
    QPrinterWrapper(const QPrinterWrapper &) = delete;
    QPrinterWrapper& operator=(const QPrinterWrapper &) = delete;
    QPrinterWrapper(QPrinterWrapper &&) = delete;
    QPrinterWrapper& operator=(QPrinterWrapper &&) = delete;
    ~QPrinterWrapper() override;

    int devType() const override;
    static int sbk_o_devType(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void initPainter(::QPainter * painter) const override;
    static void sbk_o_initPainter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter);
    int metric(::QPaintDevice::PaintDeviceMetric arg__1) const override;
    bool newPage() override;
    ::QPaintEngine * paintEngine() const override;
    static ::QPaintEngine * sbk_o_paintEngine(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QPaintDevice * redirected(::QPoint * offset) const override;
    static ::QPaintDevice * sbk_o_redirected(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPoint * offset);
    bool setPageLayout(const ::QPageLayout & pageLayout) override;
    static bool sbk_o_setPageLayout(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPageLayout & pageLayout);
    bool setPageMargins(const ::QMarginsF & margins, ::QPageLayout::Unit units = QPageLayout::Millimeter) override;
    static bool sbk_o_setPageMargins(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QMarginsF & margins, ::QPageLayout::Unit units = QPageLayout::Millimeter);
    bool setPageOrientation(::QPageLayout::Orientation orientation) override;
    static bool sbk_o_setPageOrientation(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPageLayout::Orientation orientation);
    void setPageRanges(const ::QPageRanges & ranges) override;
    static void sbk_o_setPageRanges(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPageRanges & ranges);
    ::QPainter * sharedPainter() const override;
    static ::QPainter * sbk_o_sharedPainter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[11] = {false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QPRINTERWRAPPER_H
