// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qjsprimitivevalue_wrapper.h"

// Argument includes
#include <QString>
#include <QtQml/qjsprimitivevalue.h>
#include <qmetatype.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QJSPrimitiveValue_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QJSPrimitiveValue >()))
        return -1;

    ::QJSPrimitiveValue *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QJSPrimitiveValue", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QJSPrimitiveValue::QJSPrimitiveValue()
    // 1: QJSPrimitiveValue::QJSPrimitiveValue(QMetaType)
    // 2: QJSPrimitiveValue::QJSPrimitiveValue(QString)
    // 3: QJSPrimitiveValue::QJSPrimitiveValue(bool)
    // 4: QJSPrimitiveValue::QJSPrimitiveValue(QJSPrimitiveValue)
    // 5: QJSPrimitiveValue::QJSPrimitiveValue(QMetaType,const void*)
    // 6: QJSPrimitiveValue::QJSPrimitiveValue(QVariant)
    // 7: QJSPrimitiveValue::QJSPrimitiveValue(double)
    // 8: QJSPrimitiveValue::QJSPrimitiveValue(int)
    if (numArgs == 0) {
        overloadId = 0; // QJSPrimitiveValue()
    } else if (numArgs == 1
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))) {
        overloadId = 7; // QJSPrimitiveValue(double)
    } else if (numArgs == 1
        && PyBool_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 3; // QJSPrimitiveValue(bool)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 8; // QJSPrimitiveValue(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 2; // QJSPrimitiveValue(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArgs[0])))) {
        overloadId = 4; // QJSPrimitiveValue(QJSPrimitiveValue)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QJSPrimitiveValue(QMetaType)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
            overloadId = 5; // QJSPrimitiveValue(QMetaType,const void*)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[0])))) {
        overloadId = 6; // QJSPrimitiveValue(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QJSPrimitiveValue()
        {

            // QJSPrimitiveValue()
            cptr = new ::QJSPrimitiveValue();
            break;
        }
        case 1: // QJSPrimitiveValue(QMetaType type)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QMetaType cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSPrimitiveValue(QMetaType)
                cptr = new ::QJSPrimitiveValue(cppArg0);
            }
            break;
        }
        case 2: // QJSPrimitiveValue(QString string)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSPrimitiveValue(QString)
                cptr = new ::QJSPrimitiveValue(cppArg0);
            }
            break;
        }
        case 3: // QJSPrimitiveValue(bool value)
        {
            bool cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSPrimitiveValue(bool)
                cptr = new ::QJSPrimitiveValue(cppArg0);
            }
            break;
        }
        case 4: // QJSPrimitiveValue(const QJSPrimitiveValue &QJSPrimitiveValue)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QJSPrimitiveValue cppArg0_local;
            ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSPrimitiveValue(QJSPrimitiveValue)
                cptr = new ::QJSPrimitiveValue(*cppArg0);
            }
            break;
        }
        case 5: // QJSPrimitiveValue(const QMetaType type, const void *value)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QMetaType cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSPrimitiveValue(QMetaType,const void*)
                cptr = new ::QJSPrimitiveValue(cppArg0, cppArg1);
            }
            break;
        }
        case 6: // QJSPrimitiveValue(const QVariant &variant)
        {
            ::QVariant cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSPrimitiveValue(QVariant)
                cptr = new ::QJSPrimitiveValue(cppArg0);
            }
            break;
        }
        case 7: // QJSPrimitiveValue(double value)
        {
            double cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSPrimitiveValue(double)
                cptr = new ::QJSPrimitiveValue(cppArg0);
            }
            break;
        }
        case 8: // QJSPrimitiveValue(int value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSPrimitiveValue(int)
                cptr = new ::QJSPrimitiveValue(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QJSPrimitiveValue >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QJSPrimitiveValueFunc_constData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // constData()const
        const void * cppResult = const_cast<const ::QJSPrimitiveValue *>(cppSelf)->constData();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()
        void * cppResult = cppSelf->data();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc_equals(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSPrimitiveValue::equals(QJSPrimitiveValue)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArg)))) {
        overloadId = 0; // equals(QJSPrimitiveValue)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "equals", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJSPrimitiveValue cppArg0_local;
        ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // equals(QJSPrimitiveValue)const
            bool cppResult = const_cast<const ::QJSPrimitiveValue *>(cppSelf)->equals(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc_metaType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // metaType()const
        QMetaType cppResult = const_cast<const ::QJSPrimitiveValue *>(cppSelf)->metaType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc_strictlyEquals(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSPrimitiveValue::strictlyEquals(QJSPrimitiveValue)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArg)))) {
        overloadId = 0; // strictlyEquals(QJSPrimitiveValue)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "strictlyEquals", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJSPrimitiveValue cppArg0_local;
        ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // strictlyEquals(QJSPrimitiveValue)const
            bool cppResult = const_cast<const ::QJSPrimitiveValue *>(cppSelf)->strictlyEquals(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc_toBoolean(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toBoolean()const
        bool cppResult = const_cast<const ::QJSPrimitiveValue *>(cppSelf)->toBoolean();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc_toDouble(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toDouble()const
        double cppResult = const_cast<const ::QJSPrimitiveValue *>(cppSelf)->toDouble();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc_toInteger(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toInteger()const
        int cppResult = const_cast<const ::QJSPrimitiveValue *>(cppSelf)->toInteger();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toString()const
        QString cppResult = const_cast<const ::QJSPrimitiveValue *>(cppSelf)->toString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc_toVariant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toVariant()const
        QVariant cppResult = const_cast<const ::QJSPrimitiveValue *>(cppSelf)->toVariant();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        QJSPrimitiveValue::Type cppResult = const_cast<const ::QJSPrimitiveValue *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_Type_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValue__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QJSPrimitiveValue_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QJSPrimitiveValue_EnumFlagInfo[] = {
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QJSPrimitiveValue_methods[] = {
    {"constData", reinterpret_cast<PyCFunction>(Sbk_QJSPrimitiveValueFunc_constData), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QJSPrimitiveValueFunc_data), METH_NOARGS, nullptr},
    {"equals", reinterpret_cast<PyCFunction>(Sbk_QJSPrimitiveValueFunc_equals), METH_O, nullptr},
    {"metaType", reinterpret_cast<PyCFunction>(Sbk_QJSPrimitiveValueFunc_metaType), METH_NOARGS, nullptr},
    {"strictlyEquals", reinterpret_cast<PyCFunction>(Sbk_QJSPrimitiveValueFunc_strictlyEquals), METH_O, nullptr},
    {"toBoolean", reinterpret_cast<PyCFunction>(Sbk_QJSPrimitiveValueFunc_toBoolean), METH_NOARGS, nullptr},
    {"toDouble", reinterpret_cast<PyCFunction>(Sbk_QJSPrimitiveValueFunc_toDouble), METH_NOARGS, nullptr},
    {"toInteger", reinterpret_cast<PyCFunction>(Sbk_QJSPrimitiveValueFunc_toInteger), METH_NOARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QJSPrimitiveValueFunc_toString), METH_NOARGS, nullptr},
    {"toVariant", reinterpret_cast<PyCFunction>(Sbk_QJSPrimitiveValueFunc_toVariant), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QJSPrimitiveValueFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QJSPrimitiveValue__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QJSPrimitiveValueFunc___mod__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSPrimitiveValue::operator%(QJSPrimitiveValue)->QJSPrimitiveValue
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArg)))) {
        overloadId = 0; // operator%(QJSPrimitiveValue,QJSPrimitiveValue)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator%", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJSPrimitiveValue cppArg0_local;
        ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator%(QJSPrimitiveValue,QJSPrimitiveValue)
            QJSPrimitiveValue cppResult = (*cppSelf) % (*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc___mul__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSPrimitiveValue::operator*(QJSPrimitiveValue)->QJSPrimitiveValue
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArg)))) {
        overloadId = 0; // operator*(QJSPrimitiveValue,QJSPrimitiveValue)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator*", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJSPrimitiveValue cppArg0_local;
        ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator*(QJSPrimitiveValue,QJSPrimitiveValue)
            QJSPrimitiveValue cppResult = (*cppSelf) * (*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc___pos__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // operator+()
        QJSPrimitiveValue cppResult = + (*cppSelf);
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc___add__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSPrimitiveValue::operator+(QJSPrimitiveValue)->QJSPrimitiveValue
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArg)))) {
        overloadId = 0; // operator+(QJSPrimitiveValue,QJSPrimitiveValue)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator+", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJSPrimitiveValue cppArg0_local;
        ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+(QJSPrimitiveValue,QJSPrimitiveValue)
            QJSPrimitiveValue cppResult = (*cppSelf) + (*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSPrimitiveValue::operator++(int)->QJSPrimitiveValue
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // operator++(int)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator++", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator++(int)

            for (int i = 0; i < cppArg0; ++i, ++(*cppSelf));
            QJSPrimitiveValue cppResult = (*cppSelf);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc___neg__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // operator-()
        QJSPrimitiveValue cppResult = - (*cppSelf);
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc___sub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSPrimitiveValue::operator-(QJSPrimitiveValue)->QJSPrimitiveValue
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArg)))) {
        overloadId = 0; // operator-(QJSPrimitiveValue,QJSPrimitiveValue)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator-", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJSPrimitiveValue cppArg0_local;
        ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator-(QJSPrimitiveValue,QJSPrimitiveValue)
            QJSPrimitiveValue cppResult = (*cppSelf) - (*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc___isub__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSPrimitiveValue::operator--(int)->QJSPrimitiveValue
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // operator--(int)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator--", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator--(int)

            for (int i = 0; i < cppArg0; ++i, --(*cppSelf));
            QJSPrimitiveValue cppResult = (*cppSelf);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QJSPrimitiveValueFunc___div__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSPrimitiveValue::operator/(QJSPrimitiveValue)->QJSPrimitiveValue
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArg)))) {
        overloadId = 0; // operator/(QJSPrimitiveValue,QJSPrimitiveValue)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "operator/", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJSPrimitiveValue cppArg0_local;
        ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // operator/(QJSPrimitiveValue,QJSPrimitiveValue)
            QJSPrimitiveValue cppResult = (*cppSelf) / (*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

// Rich comparison
static PyObject * Sbk_QJSPrimitiveValue_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArg)))) {
                // operator!=(const QJSPrimitiveValue &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJSPrimitiveValue cppArg0_local;
                ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArg)))) {
                // operator<(const QJSPrimitiveValue &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJSPrimitiveValue cppArg0_local;
                ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArg)))) {
                // operator<=(const QJSPrimitiveValue &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJSPrimitiveValue cppArg0_local;
                ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArg)))) {
                // operator==(const QJSPrimitiveValue &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJSPrimitiveValue cppArg0_local;
                ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArg)))) {
                // operator>(const QJSPrimitiveValue &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJSPrimitiveValue cppArg0_local;
                ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), (pyArg)))) {
                // operator>=(const QJSPrimitiveValue &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJSPrimitiveValue cppArg0_local;
                ::QJSPrimitiveValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QJSPrimitiveValue_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QJSPrimitiveValue_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QJSPrimitiveValue_Type = nullptr;
static PyTypeObject *Sbk_QJSPrimitiveValue_TypeF(void)
{
    return _Sbk_QJSPrimitiveValue_Type;
}

static PyType_Slot Sbk_QJSPrimitiveValue_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QJSPrimitiveValue_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QJSPrimitiveValue_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QJSPrimitiveValue_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QJSPrimitiveValue_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QJSPrimitiveValue_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_inplace_subtract,reinterpret_cast<void *>(Sbk_QJSPrimitiveValueFunc___isub__)},
    {Py_nb_remainder,   reinterpret_cast<void *>(Sbk_QJSPrimitiveValueFunc___mod__)},
    {Py_nb_negative,    reinterpret_cast<void *>(Sbk_QJSPrimitiveValueFunc___neg__)},
    {Py_nb_true_divide, reinterpret_cast<void *>(Sbk_QJSPrimitiveValueFunc___div__)},
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QJSPrimitiveValueFunc___iadd__)},
    {Py_nb_subtract,    reinterpret_cast<void *>(Sbk_QJSPrimitiveValueFunc___sub__)},
    {Py_nb_add,         reinterpret_cast<void *>(Sbk_QJSPrimitiveValueFunc___add__)},
    {Py_nb_multiply,    reinterpret_cast<void *>(Sbk_QJSPrimitiveValueFunc___mul__)},
    {Py_nb_positive,    reinterpret_cast<void *>(Sbk_QJSPrimitiveValueFunc___pos__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QJSPrimitiveValue_spec = {
    "2:PySide6.QtQml.QJSPrimitiveValue",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QJSPrimitiveValue_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QJSPrimitiveValue_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QJSPrimitiveValue::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QJSPrimitiveValue::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QJSPrimitiveValue_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_Type_IDX])))
        return Enum_PythonToCpp_QJSPrimitiveValue_Type;
    return {};
}

static PyObject *QJSPrimitiveValue_Type_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QJSPrimitiveValue::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QJSPrimitiveValue::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_Type_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QJSPrimitiveValue_PythonToCpp_QJSPrimitiveValue_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QJSPrimitiveValue_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QJSPrimitiveValue_PythonToCpp_QJSPrimitiveValue_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QJSPrimitiveValue_TypeF()))
        return QJSPrimitiveValue_PythonToCpp_QJSPrimitiveValue_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QJSPrimitiveValue_PTR_CppToPython_QJSPrimitiveValue(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QJSPrimitiveValue_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QJSPrimitiveValue_COPY_CppToPython_QJSPrimitiveValue(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QJSPrimitiveValue *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QJSPrimitiveValue_TypeF(), new ::QJSPrimitiveValue(*source), true, true);
}

// Python to C++ copy conversion.
static void QJSPrimitiveValue_PythonToCpp_QJSPrimitiveValue_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QJSPrimitiveValue *>(cppOut) = *reinterpret_cast< ::QJSPrimitiveValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QJSPrimitiveValue_PythonToCpp_QJSPrimitiveValue_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QJSPrimitiveValue_TypeF()))
        return QJSPrimitiveValue_PythonToCpp_QJSPrimitiveValue_COPY;
    return {};
}

// Implicit conversions.
static void PySide6_QtCore_QString_PythonToCpp_QJSPrimitiveValue(PyObject *pyIn, void *cppOut)
{
    ::QString cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QJSPrimitiveValue *>(cppOut) = ::QJSPrimitiveValue(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_QString_PythonToCpp_QJSPrimitiveValue_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return PySide6_QtCore_QString_PythonToCpp_QJSPrimitiveValue;
    return {};
}

static void bool_PythonToCpp_QJSPrimitiveValue(PyObject *pyIn, void *cppOut)
{
    bool cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyIn, &cppIn);
    *reinterpret_cast<::QJSPrimitiveValue *>(cppOut) = ::QJSPrimitiveValue(cppIn);
}
static PythonToCppFunc is_bool_PythonToCpp_QJSPrimitiveValue_Convertible(PyObject *pyIn)
{
    if (PyBool_Check(pyIn))
        return bool_PythonToCpp_QJSPrimitiveValue;
    return {};
}

static void double_PythonToCpp_QJSPrimitiveValue(PyObject *pyIn, void *cppOut)
{
    double cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<double>(), pyIn, &cppIn);
    *reinterpret_cast<::QJSPrimitiveValue *>(cppOut) = ::QJSPrimitiveValue(cppIn);
}
static PythonToCppFunc is_double_PythonToCpp_QJSPrimitiveValue_Convertible(PyObject *pyIn)
{
    if (PyFloat_Check(pyIn))
        return double_PythonToCpp_QJSPrimitiveValue;
    return {};
}

static void int_PythonToCpp_QJSPrimitiveValue(PyObject *pyIn, void *cppOut)
{
    int cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn, &cppIn);
    *reinterpret_cast<::QJSPrimitiveValue *>(cppOut) = ::QJSPrimitiveValue(cppIn);
}
static PythonToCppFunc is_int_PythonToCpp_QJSPrimitiveValue_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return int_PythonToCpp_QJSPrimitiveValue;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QJSPrimitiveValue_SignatureStrings[] = {
    "8:PySide6.QtQml.QJSPrimitiveValue(self)",
    "7:PySide6.QtQml.QJSPrimitiveValue(self,type:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])",
    "6:PySide6.QtQml.QJSPrimitiveValue(self,string:QString)",
    "5:PySide6.QtQml.QJSPrimitiveValue(self,value:bool)",
    "4:PySide6.QtQml.QJSPrimitiveValue(self,QJSPrimitiveValue:PySide6.QtQml.QJSPrimitiveValue)",
    "3:PySide6.QtQml.QJSPrimitiveValue(self,type:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type],value:void)",
    "2:PySide6.QtQml.QJSPrimitiveValue(self,variant:QVariant)",
    "1:PySide6.QtQml.QJSPrimitiveValue(self,value:double)",
    "0:PySide6.QtQml.QJSPrimitiveValue(self,value:int)",
    "PySide6.QtQml.QJSPrimitiveValue.constData(self)->void",
    "PySide6.QtQml.QJSPrimitiveValue.data(self)->void",
    "PySide6.QtQml.QJSPrimitiveValue.equals(self,other:typing.Union[PySide6.QtQml.QJSPrimitiveValue, QString, bool, double, int])->bool",
    "PySide6.QtQml.QJSPrimitiveValue.metaType(self)->PySide6.QtCore.QMetaType",
    "PySide6.QtQml.QJSPrimitiveValue.strictlyEquals(self,other:typing.Union[PySide6.QtQml.QJSPrimitiveValue, QString, bool, double, int])->bool",
    "PySide6.QtQml.QJSPrimitiveValue.toBoolean(self)->bool",
    "PySide6.QtQml.QJSPrimitiveValue.toDouble(self)->double",
    "PySide6.QtQml.QJSPrimitiveValue.toInteger(self)->int",
    "PySide6.QtQml.QJSPrimitiveValue.toString(self)->QString",
    "PySide6.QtQml.QJSPrimitiveValue.toVariant(self)->QVariant",
    "PySide6.QtQml.QJSPrimitiveValue.type(self)->PySide6.QtQml.QJSPrimitiveValue.Type",
    "PySide6.QtQml.QJSPrimitiveValue.__copy__(self)->typing.Self",
    "PySide6.QtQml.QJSPrimitiveValue.__mod__(self,rhs:typing.Union[PySide6.QtQml.QJSPrimitiveValue, QString, bool, double, int])->PySide6.QtQml.QJSPrimitiveValue",
    "PySide6.QtQml.QJSPrimitiveValue.__mul__(self,rhs:typing.Union[PySide6.QtQml.QJSPrimitiveValue, QString, bool, double, int])->PySide6.QtQml.QJSPrimitiveValue",
    "PySide6.QtQml.QJSPrimitiveValue.__pos__(self)->PySide6.QtQml.QJSPrimitiveValue",
    "PySide6.QtQml.QJSPrimitiveValue.__add__(self,rhs:typing.Union[PySide6.QtQml.QJSPrimitiveValue, QString, bool, double, int])->PySide6.QtQml.QJSPrimitiveValue",
    "PySide6.QtQml.QJSPrimitiveValue.__iadd__(self,arg__1:int)->PySide6.QtQml.QJSPrimitiveValue",
    "PySide6.QtQml.QJSPrimitiveValue.__neg__(self)->PySide6.QtQml.QJSPrimitiveValue",
    "PySide6.QtQml.QJSPrimitiveValue.__sub__(self,rhs:typing.Union[PySide6.QtQml.QJSPrimitiveValue, QString, bool, double, int])->PySide6.QtQml.QJSPrimitiveValue",
    "PySide6.QtQml.QJSPrimitiveValue.__isub__(self,arg__1:int)->PySide6.QtQml.QJSPrimitiveValue",
    "PySide6.QtQml.QJSPrimitiveValue.__div__(self,rhs:typing.Union[PySide6.QtQml.QJSPrimitiveValue, QString, bool, double, int])->PySide6.QtQml.QJSPrimitiveValue",
    "PySide6.QtQml.QJSPrimitiveValue.__ne__(self,rhs:typing.Union[PySide6.QtQml.QJSPrimitiveValue, QString, bool, double, int])->bool",
    "PySide6.QtQml.QJSPrimitiveValue.__lt__(self,rhs:typing.Union[PySide6.QtQml.QJSPrimitiveValue, QString, bool, double, int])->bool",
    "PySide6.QtQml.QJSPrimitiveValue.__le__(self,rhs:typing.Union[PySide6.QtQml.QJSPrimitiveValue, QString, bool, double, int])->bool",
    "PySide6.QtQml.QJSPrimitiveValue.__eq__(self,rhs:typing.Union[PySide6.QtQml.QJSPrimitiveValue, QString, bool, double, int])->bool",
    "PySide6.QtQml.QJSPrimitiveValue.__gt__(self,rhs:typing.Union[PySide6.QtQml.QJSPrimitiveValue, QString, bool, double, int])->bool",
    "PySide6.QtQml.QJSPrimitiveValue.__ge__(self,rhs:typing.Union[PySide6.QtQml.QJSPrimitiveValue, QString, bool, double, int])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QJSPrimitiveValue_SignatureByteSize = 414;
static constexpr uint8_t QJSPrimitiveValue_SignatureBytes[414] = {
    0x78, 0xda, 0xcd, 0x95, 0x5d, 0x4f, 0x83, 0x30, 0x14, 0x86, 0xef, 0xf9, 0x15, 0x5c, 0x4a, 0x82,
    0xc4, 0xf9, 0x31, 0x0d, 0x17, 0x5e, 0xe8, 0xbc, 0xd0, 0xc4, 0x64, 0x04, 0xf5, 0xc6, 0x2c, 0x4d,
    0x37, 0x8e, 0xac, 0x49, 0x69, 0xb7, 0x52, 0x48, 0xf8, 0xf7, 0x96, 0x51, 0xdc, 0x12, 0xb7, 0xb4,
    0x8b, 0x4c, 0xb8, 0xe1, 0xf3, 0x3c, 0x3d, 0xef, 0xfb, 0x9e, 0xb2, 0xdd, 0x85, 0xd3, 0x2a, 0x26,
    0x09, 0x8c, 0x83, 0x48, 0x46, 0x19, 0x0d, 0xa2, 0x97, 0x78, 0x2a, 0x48, 0x46, 0x24, 0x29, 0xe1,
    0x03, 0xd3, 0x02, 0xce, 0x72, 0xa0, 0x5f, 0x9e, 0x73, 0x6b, 0x55, 0xe7, 0xcb, 0x6a, 0x05, 0xa1,
    0x3a, 0x10, 0x96, 0x06, 0xef, 0x8c, 0x70, 0xf6, 0xb9, 0xc5, 0x1e, 0xb9, 0x80, 0x20, 0x7a, 0x05,
    0x89, 0xdf, 0x54, 0x95, 0xef, 0x1e, 0x7a, 0x13, 0xd4, 0x87, 0x99, 0xe7, 0x8c, 0xed, 0x5a, 0xe6,
    0x52, 0xa8, 0x6e, 0x61, 0x14, 0x6f, 0xce, 0x9e, 0x73, 0x63, 0x87, 0x95, 0xf5, 0x65, 0x38, 0xe7,
    0x9c, 0x7a, 0xce, 0xb5, 0x1d, 0xf2, 0xeb, 0xb1, 0x09, 0xf3, 0x9c, 0xab, 0xff, 0x8e, 0x4d, 0xfb,
    0x2a, 0x39, 0x49, 0x3c, 0xe7, 0xd2, 0x36, 0x0a, 0x41, 0x30, 0x93, 0x61, 0xf4, 0xd1, 0x5c, 0x78,
    0xce, 0xe8, 0x98, 0x0c, 0x13, 0x5e, 0xcc, 0xa9, 0xf2, 0x7a, 0x71, 0x0c, 0x44, 0xea, 0x36, 0x86,
    0xfa, 0x60, 0xc1, 0x59, 0x2e, 0x27, 0x58, 0xe2, 0x66, 0x13, 0x9e, 0xdf, 0xd7, 0xb6, 0x8c, 0x54,
    0x72, 0x2c, 0x00, 0xeb, 0x02, 0xd3, 0xbc, 0x51, 0xc7, 0xe5, 0x12, 0xc4, 0xa1, 0x51, 0xec, 0xc5,
    0x7d, 0x57, 0x6f, 0x3d, 0xdf, 0xad, 0x77, 0x93, 0xef, 0x36, 0x79, 0xf8, 0xae, 0xb2, 0x38, 0x53,
    0x12, 0xea, 0x87, 0x46, 0x09, 0x99, 0x1e, 0x62, 0xab, 0xfb, 0xd0, 0x90, 0x8d, 0x0b, 0xd5, 0x5f,
    0xc3, 0x42, 0xd2, 0xea, 0xa9, 0x7f, 0x4f, 0x92, 0x3f, 0xa8, 0x32, 0xc0, 0xac, 0x35, 0x65, 0x49,
    0x4d, 0x36, 0xbd, 0x5a, 0xa8, 0xe9, 0x6c, 0x81, 0x3d, 0x33, 0x09, 0x29, 0x88, 0x96, 0x53, 0x4a,
    0x2d, 0xa0, 0xc6, 0x65, 0xcb, 0x68, 0xd3, 0x16, 0x9c, 0xfe, 0x52, 0x7e, 0x40, 0x7d, 0x6f, 0x26,
    0xf7, 0xce, 0x78, 0x7f, 0xad, 0xd5, 0xbc, 0x11, 0x5a, 0xf0, 0x55, 0x85, 0x50, 0xbb, 0xa8, 0x9e,
    0x72, 0xac, 0xee, 0x2c, 0xd8, 0x8c, 0x27, 0x1a, 0xf5, 0xc5, 0x32, 0xef, 0x74, 0x8b, 0x18, 0x70,
    0x1b, 0x71, 0x05, 0x1d, 0xae, 0xb8, 0x15, 0xcf, 0xb7, 0xa1, 0xff, 0x7d, 0x39, 0x9c, 0x0c, 0x78,
    0x10, 0x64, 0x47, 0x1d, 0x16, 0x29, 0x42, 0xa3, 0xcd, 0xcf, 0x77, 0x17, 0x4b, 0x33, 0x48, 0xbb,
    0x8c, 0x31, 0x2f, 0xe6, 0x03, 0x8e, 0x71, 0x47, 0x5d, 0xc7, 0x31, 0x26, 0xa4, 0x1c, 0xae, 0x6f,
    0x06, 0xa7, 0xd2, 0x66, 0xf5, 0x87, 0x82, 0x10, 0x95, 0x7d, 0x0b, 0xe8, 0x3b, 0x01, 0x58, 0xf7,
    0x2c, 0x20, 0xed, 0x7b, 0x04, 0xe9, 0x69, 0x47, 0xf0, 0x0d, 0x6a, 0x12, 0xc2, 0x59
};
#endif

PyTypeObject *init_QJSPrimitiveValue(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX].type;

    Shiboken::AutoDecRef Sbk_QJSPrimitiveValue_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QJSPrimitiveValue_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QJSPrimitiveValue",
        "QJSPrimitiveValue",
        &Sbk_QJSPrimitiveValue_spec,
        &Shiboken::callCppDestructor< ::QJSPrimitiveValue >,
        Sbk_QJSPrimitiveValue_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QJSPrimitiveValue_TypeF(); // references _Sbk_QJSPrimitiveValue_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QJSPrimitiveValue_SignatureStrings);
#else
    InitSignatureBytes(pyType, QJSPrimitiveValue_SignatureBytes, QJSPrimitiveValue_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QJSPrimitiveValue_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QJSPrimitiveValue_PythonToCpp_QJSPrimitiveValue_PTR,
        is_QJSPrimitiveValue_PythonToCpp_QJSPrimitiveValue_PTR_Convertible,
        QJSPrimitiveValue_PTR_CppToPython_QJSPrimitiveValue,
        QJSPrimitiveValue_COPY_CppToPython_QJSPrimitiveValue);

    Shiboken::Conversions::registerConverterName(converter, "QJSPrimitiveValue");
    Shiboken::Conversions::registerConverterName(converter, "QJSPrimitiveValue*");
    Shiboken::Conversions::registerConverterName(converter, "QJSPrimitiveValue&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QJSPrimitiveValue).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QJSPrimitiveValue_PythonToCpp_QJSPrimitiveValue_COPY,
        is_QJSPrimitiveValue_PythonToCpp_QJSPrimitiveValue_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_QString_PythonToCpp_QJSPrimitiveValue,
        is_PySide6_QtCore_QString_PythonToCpp_QJSPrimitiveValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        bool_PythonToCpp_QJSPrimitiveValue,
        is_bool_PythonToCpp_QJSPrimitiveValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        double_PythonToCpp_QJSPrimitiveValue,
        is_double_PythonToCpp_QJSPrimitiveValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        int_PythonToCpp_QJSPrimitiveValue,
        is_int_PythonToCpp_QJSPrimitiveValue_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QJSPrimitiveValue_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "Undefined",
        "Null",
        "Boolean",
        "Integer",
        "Double",
        "String",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QJSPrimitiveValue::Type::Undefined), //  0x00  0
        uint8_t(QJSPrimitiveValue::Type::Null),      //  0x01  1
        uint8_t(QJSPrimitiveValue::Type::Boolean),   //  0x02  2
        uint8_t(QJSPrimitiveValue::Type::Integer),   //  0x03  3
        uint8_t(QJSPrimitiveValue::Type::Double),    //  0x04  4
        uint8_t(QJSPrimitiveValue::Type::String)     //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QJSPrimitiveValue_TypeF(),
        "2:PySide6.QtQml.QJSPrimitiveValue.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_Type_IDX].type = EType;
    // Register converter for enum 'QJSPrimitiveValue::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QJSPrimitiveValue_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QJSPrimitiveValue_Type,
            is_Enum_PythonToCpp_QJSPrimitiveValue_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QJSPrimitiveValue::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    qRegisterMetaType< ::QJSPrimitiveValue >("QJSPrimitiveValue");
    qRegisterMetaType< ::QJSPrimitiveValue::Type >("QJSPrimitiveValue::Type");

    return pyType;
}
