// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qqmlcontext_wrapper.h"

// Wrappers providing overrides
#include "qqmlpropertymap_wrapper.h"

// inner classes
#include "qqmlcontext_propertypair_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQmlContextWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQmlContextWrapper::QQmlContextWrapper(::QQmlContext * parent, ::QObject * objParent) : QQmlContext(parent, objParent)
{
}

QQmlContextWrapper::QQmlContextWrapper(::QQmlEngine * parent, ::QObject * objParent) : QQmlContext(parent, objParent)
{
}

void QQmlContextWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QQmlPropertyMapWrapper::sbk_o_childEvent("QQmlContext", funcName, gil, pyOverride, event);
}

void QQmlContextWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QQmlPropertyMapWrapper::sbk_o_connectNotify("QQmlContext", funcName, gil, pyOverride, signal);
}

void QQmlContextWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QQmlPropertyMapWrapper::sbk_o_customEvent("QQmlContext", funcName, gil, pyOverride, event);
}

void QQmlContextWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QQmlPropertyMapWrapper::sbk_o_connectNotify("QQmlContext", funcName, gil, pyOverride, signal);
}

bool QQmlContextWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QQmlPropertyMapWrapper::sbk_o_event("QQmlContext", funcName, gil, pyOverride, event);
}

bool QQmlContextWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QQmlPropertyMapWrapper::sbk_o_eventFilter("QQmlContext", funcName, gil, pyOverride, watched, event);
}

void QQmlContextWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QQmlPropertyMapWrapper::sbk_o_timerEvent("QQmlContext", funcName, gil, pyOverride, event);
}

const QMetaObject *QQmlContextWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QQmlContext::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QQmlContextWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QQmlContext::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QQmlContextWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QQmlContextWrapper *>(this));
    return QQmlContext::qt_metacast(_clname);
}

QQmlContextWrapper::~QQmlContextWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQmlContext_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQmlContext >()))
        return -1;

    QQmlContextWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QQmlContext", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQmlContext::QQmlContext(QQmlContext*,QObject*=)
    // 1: QQmlContext::QQmlContext(QQmlEngine*,QObject*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QQmlContext(QQmlEngine*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QQmlContext(QQmlEngine*,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QQmlContext(QQmlContext*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QQmlContext(QQmlContext*,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QQmlContext(QQmlContext *parent, QObject *objParent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"objParent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QQmlContext *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QQmlContext(QQmlContext*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QQmlContextWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QQmlContextWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QQmlContext(QQmlEngine *parent, QObject *objParent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"objParent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QQmlEngine *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QQmlContext(QQmlEngine*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QQmlContextWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QQmlContextWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQmlContext >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QQmlContextFunc_baseUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // baseUrl()const
        QUrl cppResult = const_cast<const ::QQmlContext *>(cppSelf)->baseUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQmlContextFunc_contextObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contextObject()const
        QObject * cppResult = const_cast<const ::QQmlContext *>(cppSelf)->contextObject();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQmlContextFunc_contextProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlContext::contextProperty(QString)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // contextProperty(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contextProperty", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contextProperty(QString)const
            QVariant cppResult = const_cast<const ::QQmlContext *>(cppSelf)->contextProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQmlContextFunc_engine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // engine()const
        QQmlEngine * cppResult = const_cast<const ::QQmlContext *>(cppSelf)->engine();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlEngine_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQmlContextFunc_importedScript(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlContext::importedScript(QString)const->QJSValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // importedScript(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "importedScript", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // importedScript(QString)const
            QJSValue cppResult = const_cast<const ::QQmlContext *>(cppSelf)->importedScript(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQmlContextFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QQmlContext *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQmlContextFunc_nameForObject(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlContext::nameForObject(const QObject*)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // nameForObject(const QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "nameForObject", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // nameForObject(const QObject*)const
            QString cppResult = const_cast<const ::QQmlContext *>(cppSelf)->nameForObject(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQmlContextFunc_objectForName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlContext::objectForName(QString)const->QObject*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // objectForName(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "objectForName", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // objectForName(QString)const
            QObject * cppResult = const_cast<const ::QQmlContext *>(cppSelf)->objectForName(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQmlContextFunc_parentContext(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parentContext()const
        QQmlContext * cppResult = const_cast<const ::QQmlContext *>(cppSelf)->parentContext();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQmlContextFunc_resolvedUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlContext::resolvedUrl(QUrl)const->QUrl
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // resolvedUrl(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resolvedUrl", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // resolvedUrl(QUrl)const
            QUrl cppResult = const_cast<const ::QQmlContext *>(cppSelf)->resolvedUrl(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQmlContextFunc_setBaseUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlContext::setBaseUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setBaseUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBaseUrl", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBaseUrl(QUrl)
            cppSelf->setBaseUrl(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQmlContextFunc_setContextObject(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlContext::setContextObject(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // setContextObject(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setContextObject", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setContextObject(QObject*)
            cppSelf->setContextObject(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQmlContextFunc_setContextProperties(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlContext::setContextProperties(QList<QQmlContext::PropertyPair>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QQmlContext_PropertyPair_IDX], (pyArg)))) {
        overloadId = 0; // setContextProperties(QList<QQmlContext::PropertyPair>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setContextProperties", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);

    // Call function/method
    {
        ::QList<QQmlContext::PropertyPair> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setContextProperties(QList<QQmlContext::PropertyPair>)
            cppSelf->setContextProperties(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQmlContextFunc_setContextProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setContextProperty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQmlContext::setContextProperty(QString,QObject*)
    // 1: QQmlContext::setContextProperty(QString,QVariant)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // setContextProperty(QString,QObject*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 1; // setContextProperty(QString,QVariant)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setContextProperty", errInfo, SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setContextProperty(const QString &arg__1, QObject *arg__2)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContextProperty(QString,QObject*)
                cppSelf->setContextProperty(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setContextProperty(const QString &arg__1, const QVariant &arg__2)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setContextProperty(QString,QVariant)
                cppSelf->setContextProperty(cppArg0, cppArg1);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QQmlContext_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQmlContext_methods[] = {
    {"baseUrl", reinterpret_cast<PyCFunction>(Sbk_QQmlContextFunc_baseUrl), METH_NOARGS, nullptr},
    {"contextObject", reinterpret_cast<PyCFunction>(Sbk_QQmlContextFunc_contextObject), METH_NOARGS, nullptr},
    {"contextProperty", reinterpret_cast<PyCFunction>(Sbk_QQmlContextFunc_contextProperty), METH_O, nullptr},
    {"engine", reinterpret_cast<PyCFunction>(Sbk_QQmlContextFunc_engine), METH_NOARGS, nullptr},
    {"importedScript", reinterpret_cast<PyCFunction>(Sbk_QQmlContextFunc_importedScript), METH_O, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QQmlContextFunc_isValid), METH_NOARGS, nullptr},
    {"nameForObject", reinterpret_cast<PyCFunction>(Sbk_QQmlContextFunc_nameForObject), METH_O, nullptr},
    {"objectForName", reinterpret_cast<PyCFunction>(Sbk_QQmlContextFunc_objectForName), METH_O, nullptr},
    {"parentContext", reinterpret_cast<PyCFunction>(Sbk_QQmlContextFunc_parentContext), METH_NOARGS, nullptr},
    {"resolvedUrl", reinterpret_cast<PyCFunction>(Sbk_QQmlContextFunc_resolvedUrl), METH_O, nullptr},
    {"setBaseUrl", reinterpret_cast<PyCFunction>(Sbk_QQmlContextFunc_setBaseUrl), METH_O, nullptr},
    {"setContextObject", reinterpret_cast<PyCFunction>(Sbk_QQmlContextFunc_setContextObject), METH_O, nullptr},
    {"setContextProperties", reinterpret_cast<PyCFunction>(Sbk_QQmlContextFunc_setContextProperties), METH_O, nullptr},
    {"setContextProperty", reinterpret_cast<PyCFunction>(Sbk_QQmlContextFunc_setContextProperty), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQmlContext_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQmlContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQmlContextWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQmlContext_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQmlContext_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQmlContext_Type = nullptr;
static PyTypeObject *Sbk_QQmlContext_TypeF(void)
{
    return _Sbk_QQmlContext_Type;
}

static PyType_Slot Sbk_QQmlContext_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQmlContext_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQmlContext_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQmlContext_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQmlContext_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQmlContext_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQmlContext_spec = {
    "2:PySide6.QtQml.QQmlContext",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQmlContext_slots
};

} //extern "C"

static void *Sbk_QQmlContext_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QQmlContext *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQmlContext_PythonToCpp_QQmlContext_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQmlContext_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQmlContext_PythonToCpp_QQmlContext_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlContext_TypeF()))
        return QQmlContext_PythonToCpp_QQmlContext_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQmlContext_PTR_CppToPython_QQmlContext(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QQmlContext *>(const_cast<void *>(cppIn)), Sbk_QQmlContext_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQmlContext_SignatureStrings[] = {
    "1:PySide6.QtQml.QQmlContext(self,parent:PySide6.QtQml.QQmlContext,objParent:PySide6.QtCore.QObject=nullptr)",
    "0:PySide6.QtQml.QQmlContext(self,parent:PySide6.QtQml.QQmlEngine,objParent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtQml.QQmlContext.baseUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtQml.QQmlContext.contextObject(self)->PySide6.QtCore.QObject",
    "PySide6.QtQml.QQmlContext.contextProperty(self,arg__1:QString)->QVariant",
    "PySide6.QtQml.QQmlContext.engine(self)->PySide6.QtQml.QQmlEngine",
    "PySide6.QtQml.QQmlContext.importedScript(self,name:QString)->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QQmlContext.isValid(self)->bool",
    "PySide6.QtQml.QQmlContext.nameForObject(self,arg__1:PySide6.QtCore.QObject)->QString",
    "PySide6.QtQml.QQmlContext.objectForName(self,arg__1:QString)->PySide6.QtCore.QObject",
    "PySide6.QtQml.QQmlContext.parentContext(self)->PySide6.QtQml.QQmlContext",
    "PySide6.QtQml.QQmlContext.resolvedUrl(self,arg__1:typing.Union[PySide6.QtCore.QUrl, QString])->PySide6.QtCore.QUrl",
    "PySide6.QtQml.QQmlContext.setBaseUrl(self,arg__1:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtQml.QQmlContext.setContextObject(self,arg__1:PySide6.QtCore.QObject)",
    "PySide6.QtQml.QQmlContext.setContextProperties(self,properties:QList[PySide6.QtQml.QQmlContext.PropertyPair])",
    "1:PySide6.QtQml.QQmlContext.setContextProperty(self,arg__1:QString,arg__2:PySide6.QtCore.QObject)",
    "0:PySide6.QtQml.QQmlContext.setContextProperty(self,arg__1:QString,arg__2:QVariant)",
    nullptr}; // Sentinel
#else
static constexpr size_t QQmlContext_SignatureByteSize = 339;
static constexpr uint8_t QQmlContext_SignatureBytes[339] = {
    0x78, 0xda, 0xad, 0x94, 0xc1, 0x4f, 0x83, 0x30, 0x14, 0xc6, 0xef, 0xfb, 0x2b, 0x3c, 0xba, 0x04,
    0xc9, 0xe6, 0xc1, 0x03, 0x89, 0x1e, 0x24, 0x7a, 0x30, 0x46, 0x69, 0xc8, 0x76, 0x59, 0xcc, 0x52,
    0xe0, 0xb9, 0x74, 0xe9, 0x5a, 0xf2, 0xda, 0x19, 0xf9, 0xef, 0xed, 0x28, 0x18, 0x64, 0xb4, 0x1b,
    0x8b, 0x17, 0x08, 0xe9, 0xeb, 0xef, 0xfb, 0xfa, 0xf5, 0x3d, 0xe6, 0x51, 0x52, 0xa5, 0xac, 0x80,
    0xbb, 0x90, 0x68, 0xb2, 0xe3, 0x21, 0x31, 0x8f, 0x58, 0x0a, 0x0d, 0xdf, 0xfa, 0x5a, 0x01, 0xff,
    0x0c, 0x4a, 0x8a, 0x20, 0xb4, 0xbb, 0x2a, 0x90, 0xd9, 0x36, 0xe9, 0xd7, 0xc4, 0x12, 0x21, 0x24,
    0xef, 0xd9, 0x16, 0x72, 0x7d, 0x2f, 0xf6, 0x9c, 0x97, 0x1a, 0xa7, 0x93, 0xd9, 0xc5, 0x5a, 0x4f,
    0x62, 0xc3, 0x04, 0x8c, 0x90, 0x72, 0x0a, 0x85, 0x19, 0x55, 0xb0, 0x40, 0x5e, 0x0b, 0x4e, 0x6f,
    0x1e, 0xfa, 0x20, 0xb3, 0xe4, 0xd9, 0x9c, 0xdb, 0xb7, 0x55, 0x73, 0x21, 0xec, 0xea, 0x69, 0x4a,
    0x82, 0xb2, 0x04, 0xd4, 0x95, 0x3d, 0x3b, 0xc5, 0xcd, 0x7a, 0x3d, 0x8f, 0x48, 0xaa, 0x91, 0x89,
    0x8d, 0xc1, 0x92, 0x25, 0x45, 0x46, 0x85, 0x0f, 0x04, 0x75, 0x2c, 0xc7, 0x3e, 0xfe, 0xc6, 0xe6,
    0x01, 0xb0, 0x5d, 0x29, 0x51, 0x43, 0x91, 0xe6, 0xc8, 0xca, 0xe6, 0x12, 0x04, 0xdd, 0x41, 0xc7,
    0x46, 0x6f, 0xf3, 0x4b, 0xba, 0xa4, 0x7c, 0xef, 0x65, 0x2a, 0x53, 0xc1, 0x8a, 0xd6, 0x55, 0x26,
    0xa5, 0x2f, 0xd1, 0x83, 0xda, 0xb3, 0xc4, 0x4e, 0xa2, 0x6d, 0x12, 0xc3, 0xb1, 0x1e, 0x82, 0xb1,
    0xde, 0x3c, 0x50, 0x59, 0x97, 0x1a, 0xec, 0x9b, 0xa1, 0x3b, 0xe2, 0x1d, 0x7d, 0x6b, 0xb6, 0x39,
    0xbb, 0xfd, 0x3a, 0x98, 0x79, 0x53, 0xe0, 0x01, 0x21, 0x28, 0xc9, 0xbf, 0xa0, 0x68, 0xbb, 0xb0,
    0xf5, 0xa6, 0xab, 0xd2, 0x58, 0x0b, 0x17, 0x82, 0x49, 0xb1, 0x1a, 0xe8, 0xcb, 0xe0, 0xaa, 0x71,
    0xff, 0x31, 0xba, 0x6f, 0x15, 0xe8, 0xc7, 0x4e, 0xdf, 0x5f, 0xa0, 0xe8, 0x87, 0xc7, 0x47, 0x73,
    0x71, 0xe2, 0x16, 0xcf, 0xc2, 0x35, 0x03, 0xc2, 0x40, 0x35, 0xbf, 0x87, 0xdf, 0xef, 0x88, 0xbc,
    0x32, 0xa5, 0x57, 0x6e, 0x48, 0x3b, 0x5b, 0x09, 0x65, 0x68, 0xcc, 0xcf, 0xa3, 0x11, 0x7a, 0x83,
    0x03, 0x69, 0x3f, 0x6f, 0x9d, 0xe7, 0x99, 0xfd, 0x9b, 0x42, 0x3b, 0xf7, 0xd3, 0xc9, 0x0f, 0x14,
    0x81, 0x03, 0xd1
};
#endif

PyTypeObject *init_QQmlContext(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX].type;

    Shiboken::AutoDecRef Sbk_QQmlContext_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QQmlContext_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQmlContext",
        "QQmlContext*",
        &Sbk_QQmlContext_spec,
        &Shiboken::callCppDestructor< QQmlContext >,
        Sbk_QQmlContext_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQmlContext_TypeF(); // references _Sbk_QQmlContext_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQmlContext_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQmlContext_SignatureBytes, QQmlContext_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQmlContext_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QQmlContext_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQmlContext_PythonToCpp_QQmlContext_PTR,
        is_QQmlContext_PythonToCpp_QQmlContext_PTR_Convertible,
        QQmlContext_PTR_CppToPython_QQmlContext);

    Shiboken::Conversions::registerConverterName(converter, "QQmlContext");
    Shiboken::Conversions::registerConverterName(converter, "QQmlContext*");
    Shiboken::Conversions::registerConverterName(converter, "QQmlContext&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQmlContext).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQmlContextWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QQmlContext_TypeF(), &Sbk_QQmlContext_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QQmlContext::staticMetaObject, sizeof(QQmlContextWrapper));

    return pyType;
}
