// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qquickasyncimageprovider_wrapper.h"

// Wrappers providing overrides
#include "qsgtextureprovider_wrapper.h"
#include "qquickimageprovider_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qimage.h>
#include <QtGui/qpixmap.h>
#include <QtQml/qqmlengine.h>
#include <QtQuick/qquickimageprovider.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQuickAsyncImageProviderWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQuickAsyncImageProviderWrapper::QQuickAsyncImageProviderWrapper()
{
}

void QQuickAsyncImageProviderWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QSGTextureProviderWrapper::sbk_o_childEvent("QQuickAsyncImageProvider", funcName, gil, pyOverride, event);
}

void QQuickAsyncImageProviderWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QSGTextureProviderWrapper::sbk_o_connectNotify("QQuickAsyncImageProvider", funcName, gil, pyOverride, signal);
}

void QQuickAsyncImageProviderWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QSGTextureProviderWrapper::sbk_o_customEvent("QQuickAsyncImageProvider", funcName, gil, pyOverride, event);
}

void QQuickAsyncImageProviderWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QSGTextureProviderWrapper::sbk_o_connectNotify("QQuickAsyncImageProvider", funcName, gil, pyOverride, signal);
}

bool QQuickAsyncImageProviderWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QSGTextureProviderWrapper::sbk_o_event("QQuickAsyncImageProvider", funcName, gil, pyOverride, event);
}

bool QQuickAsyncImageProviderWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QSGTextureProviderWrapper::sbk_o_eventFilter("QQuickAsyncImageProvider", funcName, gil, pyOverride, watched, event);
}

::QFlags<QQmlImageProviderBase::Flag> QQuickAsyncImageProviderWrapper::flags() const
{
    static const char *funcName = "flags";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickImageProvider::flags();
    }
    return QQuickImageProviderWrapper::sbk_o_flags("QQuickAsyncImageProvider", funcName, gil, pyOverride);
}

::QQmlImageProviderBase::ImageType QQuickAsyncImageProviderWrapper::imageType() const
{
    static const char *funcName = "imageType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickImageProvider::imageType();
    }
    return QQuickImageProviderWrapper::sbk_o_imageType("QQuickAsyncImageProvider", funcName, gil, pyOverride);
}

::QImage QQuickAsyncImageProviderWrapper::requestImage(const ::QString & id, ::QSize * size, const ::QSize & requestedSize)
{
    static const char *funcName = "requestImage";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickImageProvider::requestImage(id, size, requestedSize);
    }
    return QQuickImageProviderWrapper::sbk_o_requestImage("QQuickAsyncImageProvider", funcName, gil, pyOverride, id, size, requestedSize);
}

::QQuickImageResponse * QQuickAsyncImageProviderWrapper::requestImageResponse(const ::QString & id, const ::QSize & requestedSize)
{
    static const char *funcName = "requestImageResponse";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QQuickAsyncImageProvider.requestImageResponse");
        return nullptr;
    }
    return sbk_o_requestImageResponse("QQuickAsyncImageProvider", funcName, gil, pyOverride, id, requestedSize);
}

::QQuickImageResponse * QQuickAsyncImageProviderWrapper::sbk_o_requestImageResponse(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & id, const ::QSize & requestedSize)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &id),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &requestedSize)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &id),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &requestedSize)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickImageResponse_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QQuickImageResponse >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QQuickImageResponse *cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (Shiboken::Object::checkType(pyResult))
        Shiboken::Object::releaseOwnership(pyResult);
    return cppResult;
}

::QPixmap QQuickAsyncImageProviderWrapper::requestPixmap(const ::QString & id, ::QSize * size, const ::QSize & requestedSize)
{
    static const char *funcName = "requestPixmap";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickImageProvider::requestPixmap(id, size, requestedSize);
    }
    return QQuickImageProviderWrapper::sbk_o_requestPixmap("QQuickAsyncImageProvider", funcName, gil, pyOverride, id, size, requestedSize);
}

::QQuickTextureFactory * QQuickAsyncImageProviderWrapper::requestTexture(const ::QString & id, ::QSize * size, const ::QSize & requestedSize)
{
    static const char *funcName = "requestTexture";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickImageProvider::requestTexture(id, size, requestedSize);
    }
    return QQuickImageProviderWrapper::sbk_o_requestTexture("QQuickAsyncImageProvider", funcName, gil, pyOverride, id, size, requestedSize);
}

void QQuickAsyncImageProviderWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QSGTextureProviderWrapper::sbk_o_timerEvent("QQuickAsyncImageProvider", funcName, gil, pyOverride, event);
}

const QMetaObject *QQuickAsyncImageProviderWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QQuickAsyncImageProvider::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QQuickAsyncImageProviderWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QQuickAsyncImageProvider::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QQuickAsyncImageProviderWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QQuickAsyncImageProviderWrapper *>(this));
    return QQuickAsyncImageProvider::qt_metacast(_clname);
}

QQuickAsyncImageProviderWrapper::~QQuickAsyncImageProviderWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuickAsyncImageProvider_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickAsyncImageProvider_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QQuickAsyncImageProvider");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuickAsyncImageProvider >()))
        return -1;

    QQuickAsyncImageProviderWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QQuickAsyncImageProvider_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QQuickAsyncImageProvider()
        void *addr = PySide::nextQObjectMemoryAddr();
        if (addr != nullptr) {
            cptr = new (addr) QQuickAsyncImageProviderWrapper();
            PySide::setNextQObjectMemoryAddr(nullptr);
        } else {
            cptr = new QQuickAsyncImageProviderWrapper();
        }

    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQuickAsyncImageProvider >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickAsyncImageProvider_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QQuickAsyncImageProviderFunc_requestImageResponse(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickAsyncImageProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickAsyncImageProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "requestImageResponse", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickAsyncImageProvider::requestImageResponse(QString,QSize)->QQuickImageResponse*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[1])))) {
        overloadId = 0; // requestImageResponse(QString,QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "requestImageResponse", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickAsyncImageProvider_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSize cppArg1_local;
        ::QSize *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // requestImageResponse(QString,QSize)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QQuickAsyncImageProvider.requestImageResponse");
                return {};
            }
            QQuickImageResponse * cppResult = cppSelf->requestImageResponse(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickImageResponse_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QQuickAsyncImageProvider_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuickAsyncImageProvider_methods[] = {
    {"requestImageResponse", reinterpret_cast<PyCFunction>(Sbk_QQuickAsyncImageProviderFunc_requestImageResponse), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQuickAsyncImageProvider_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQuickAsyncImageProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickAsyncImageProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQuickAsyncImageProviderWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQuickAsyncImageProvider_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuickAsyncImageProvider_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuickAsyncImageProvider_Type = nullptr;
static PyTypeObject *Sbk_QQuickAsyncImageProvider_TypeF(void)
{
    return _Sbk_QQuickAsyncImageProvider_Type;
}

static PyType_Slot Sbk_QQuickAsyncImageProvider_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQuickAsyncImageProvider_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuickAsyncImageProvider_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuickAsyncImageProvider_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuickAsyncImageProvider_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuickAsyncImageProvider_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuickAsyncImageProvider_spec = {
    "2:PySide6.QtQuick.QQuickAsyncImageProvider",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuickAsyncImageProvider_slots
};

} //extern "C"

static void *Sbk_QQuickAsyncImageProvider_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QQuickAsyncImageProvider *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuickAsyncImageProvider_PythonToCpp_QQuickAsyncImageProvider_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuickAsyncImageProvider_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuickAsyncImageProvider_PythonToCpp_QQuickAsyncImageProvider_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickAsyncImageProvider_TypeF()))
        return QQuickAsyncImageProvider_PythonToCpp_QQuickAsyncImageProvider_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuickAsyncImageProvider_PTR_CppToPython_QQuickAsyncImageProvider(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QQuickAsyncImageProvider *>(const_cast<void *>(cppIn)), Sbk_QQuickAsyncImageProvider_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuickAsyncImageProvider_SignatureStrings[] = {
    "PySide6.QtQuick.QQuickAsyncImageProvider(self)",
    "PySide6.QtQuick.QQuickAsyncImageProvider.requestImageResponse(self,id:QString,requestedSize:PySide6.QtCore.QSize)->PySide6.QtQuick.QQuickImageResponse",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuickAsyncImageProvider_SignatureByteSize = 113;
static constexpr uint8_t QQuickAsyncImageProvider_SignatureBytes[113] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x2c, 0xcd, 0x4c,
    0xce, 0xd6, 0x0b, 0x04, 0x53, 0x8e, 0xc5, 0x95, 0x79, 0xc9, 0x9e, 0xb9, 0x89, 0xe9, 0xa9, 0x01,
    0x45, 0xf9, 0x65, 0x40, 0x05, 0x45, 0x1a, 0xc5, 0xa9, 0x39, 0x69, 0x9a, 0x5c, 0x01, 0x44, 0x2a,
    0xd7, 0x2b, 0x4a, 0x2d, 0x2c, 0x4d, 0x2d, 0x2e, 0x01, 0x0b, 0x06, 0xa5, 0x16, 0x17, 0xe4, 0xe7,
    0x15, 0xa7, 0x82, 0xcd, 0xd0, 0xc9, 0x4c, 0xb1, 0x0a, 0x0c, 0x2e, 0x29, 0xca, 0xcc, 0x4b, 0xd7,
    0x81, 0x2a, 0x4a, 0x4d, 0x09, 0xce, 0xac, 0x4a, 0xb5, 0x42, 0x98, 0xed, 0x9c, 0x5f, 0x94, 0xaa,
    0x17, 0x08, 0x12, 0xd4, 0xd4, 0xb5, 0xc3, 0x6e, 0x25, 0x8a, 0xc1, 0x5c, 0x00, 0x8b, 0xbe, 0x49,
    0x21
};
#endif

PyTypeObject *init_QQuickAsyncImageProvider(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QQuickAsyncImageProvider_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QQuickAsyncImageProvider_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuickAsyncImageProvider_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickImageProvider_IDX]))));

    _Sbk_QQuickAsyncImageProvider_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuickAsyncImageProvider",
        "QQuickAsyncImageProvider*",
        &Sbk_QQuickAsyncImageProvider_spec,
        &Shiboken::callCppDestructor< QQuickAsyncImageProvider >,
        Sbk_QQuickAsyncImageProvider_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQuickAsyncImageProvider_TypeF(); // references _Sbk_QQuickAsyncImageProvider_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuickAsyncImageProvider_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuickAsyncImageProvider_SignatureBytes, QQuickAsyncImageProvider_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuickAsyncImageProvider_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickAsyncImageProvider_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuickAsyncImageProvider_PythonToCpp_QQuickAsyncImageProvider_PTR,
        is_QQuickAsyncImageProvider_PythonToCpp_QQuickAsyncImageProvider_PTR_Convertible,
        QQuickAsyncImageProvider_PTR_CppToPython_QQuickAsyncImageProvider);

    Shiboken::Conversions::registerConverterName(converter, "QQuickAsyncImageProvider");
    Shiboken::Conversions::registerConverterName(converter, "QQuickAsyncImageProvider*");
    Shiboken::Conversions::registerConverterName(converter, "QQuickAsyncImageProvider&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuickAsyncImageProvider).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQuickAsyncImageProviderWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QQuickAsyncImageProvider_TypeF(), &Sbk_QQuickAsyncImageProvider_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QQuickAsyncImageProvider::staticMetaObject, sizeof(QQuickAsyncImageProviderWrapper));

    return pyType;
}
