// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qquickimageresponse_wrapper.h"

// Wrappers providing overrides
#include "qsgnode_wrapper.h"
#include "qsgtextureprovider_wrapper.h"

// Argument includes
#include <QString>
#include <QtQuick/qquickimageprovider.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQuickImageResponseWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQuickImageResponseWrapper::QQuickImageResponseWrapper()
{
}

void QQuickImageResponseWrapper::cancel()
{
    static const char *funcName = "cancel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickImageResponse::cancel();
    }
    QSGNodeWrapper::sbk_o_preprocess("QQuickImageResponse", funcName, gil, pyOverride);
}

void QQuickImageResponseWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QSGTextureProviderWrapper::sbk_o_childEvent("QQuickImageResponse", funcName, gil, pyOverride, event);
}

void QQuickImageResponseWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QSGTextureProviderWrapper::sbk_o_connectNotify("QQuickImageResponse", funcName, gil, pyOverride, signal);
}

void QQuickImageResponseWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QSGTextureProviderWrapper::sbk_o_customEvent("QQuickImageResponse", funcName, gil, pyOverride, event);
}

void QQuickImageResponseWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QSGTextureProviderWrapper::sbk_o_connectNotify("QQuickImageResponse", funcName, gil, pyOverride, signal);
}

::QString QQuickImageResponseWrapper::errorString() const
{
    static const char *funcName = "errorString";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QQuickImageResponse::errorString();
    }
    return sbk_o_errorString("QQuickImageResponse", funcName, gil, pyOverride);
}

::QString QQuickImageResponseWrapper::sbk_o_errorString(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QString();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QString", Py_TYPE(pyResult)->tp_name);
        return ::QString();
    }
    ::QString cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QQuickImageResponseWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QSGTextureProviderWrapper::sbk_o_event("QQuickImageResponse", funcName, gil, pyOverride, event);
}

bool QQuickImageResponseWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QSGTextureProviderWrapper::sbk_o_eventFilter("QQuickImageResponse", funcName, gil, pyOverride, watched, event);
}

::QQuickTextureFactory * QQuickImageResponseWrapper::textureFactory() const
{
    static const char *funcName = "textureFactory";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QQuickImageResponse.textureFactory");
        return nullptr;
    }
    return sbk_o_textureFactory("QQuickImageResponse", funcName, gil, pyOverride);
}

::QQuickTextureFactory * QQuickImageResponseWrapper::sbk_o_textureFactory(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickTextureFactory_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QQuickTextureFactory >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QQuickTextureFactory *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QQuickImageResponseWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QSGTextureProviderWrapper::sbk_o_timerEvent("QQuickImageResponse", funcName, gil, pyOverride, event);
}

const QMetaObject *QQuickImageResponseWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QQuickImageResponse::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QQuickImageResponseWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QQuickImageResponse::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QQuickImageResponseWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QQuickImageResponseWrapper *>(this));
    return QQuickImageResponse::qt_metacast(_clname);
}

QQuickImageResponseWrapper::~QQuickImageResponseWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuickImageResponse_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickImageResponse_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QQuickImageResponse");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuickImageResponse >()))
        return -1;

    QQuickImageResponseWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QQuickImageResponse_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QQuickImageResponse()
        void *addr = PySide::nextQObjectMemoryAddr();
        if (addr != nullptr) {
            cptr = new (addr) QQuickImageResponseWrapper();
            PySide::setNextQObjectMemoryAddr(nullptr);
        } else {
            cptr = new QQuickImageResponseWrapper();
        }

    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQuickImageResponse >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickImageResponse_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QQuickImageResponseFunc_cancel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickImageResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickImageResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cancel()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QQuickImageResponse::cancel()
            : cppSelf->cancel();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QQuickImageResponseFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickImageResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickImageResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QQuickImageResponse *>(cppSelf)->::QQuickImageResponse::errorString()
            : const_cast<const ::QQuickImageResponse *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QQuickImageResponseFunc_textureFactory(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickImageResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickImageResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureFactory()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QQuickImageResponse.textureFactory");
            return {};
        }
        QQuickTextureFactory * cppResult = const_cast<const ::QQuickImageResponse *>(cppSelf)->textureFactory();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickTextureFactory_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QQuickImageResponse_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuickImageResponse_methods[] = {
    {"cancel", reinterpret_cast<PyCFunction>(Sbk_QQuickImageResponseFunc_cancel), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QQuickImageResponseFunc_errorString), METH_NOARGS, nullptr},
    {"textureFactory", reinterpret_cast<PyCFunction>(Sbk_QQuickImageResponseFunc_textureFactory), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQuickImageResponse_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQuickImageResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickImageResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQuickImageResponseWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQuickImageResponse_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuickImageResponse_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuickImageResponse_Type = nullptr;
static PyTypeObject *Sbk_QQuickImageResponse_TypeF(void)
{
    return _Sbk_QQuickImageResponse_Type;
}

static PyType_Slot Sbk_QQuickImageResponse_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQuickImageResponse_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuickImageResponse_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuickImageResponse_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuickImageResponse_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuickImageResponse_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuickImageResponse_spec = {
    "2:PySide6.QtQuick.QQuickImageResponse",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuickImageResponse_slots
};

} //extern "C"

static void *Sbk_QQuickImageResponse_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QQuickImageResponse *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuickImageResponse_PythonToCpp_QQuickImageResponse_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuickImageResponse_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuickImageResponse_PythonToCpp_QQuickImageResponse_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickImageResponse_TypeF()))
        return QQuickImageResponse_PythonToCpp_QQuickImageResponse_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuickImageResponse_PTR_CppToPython_QQuickImageResponse(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QQuickImageResponse *>(const_cast<void *>(cppIn)), Sbk_QQuickImageResponse_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuickImageResponse_SignatureStrings[] = {
    "PySide6.QtQuick.QQuickImageResponse(self)",
    "PySide6.QtQuick.QQuickImageResponse.cancel(self)",
    "PySide6.QtQuick.QQuickImageResponse.errorString(self)->QString",
    "PySide6.QtQuick.QQuickImageResponse.textureFactory(self)->PySide6.QtQuick.QQuickTextureFactory",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuickImageResponse_SignatureByteSize = 102;
static constexpr uint8_t QQuickImageResponse_SignatureBytes[102] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x2c, 0xcd, 0x4c,
    0xce, 0xd6, 0x0b, 0x04, 0x53, 0x9e, 0xb9, 0x89, 0xe9, 0xa9, 0x41, 0xa9, 0xc5, 0x05, 0xf9, 0x79,
    0xc5, 0xa9, 0x1a, 0xc5, 0xa9, 0x39, 0x69, 0x9a, 0x5c, 0x01, 0x84, 0x55, 0xea, 0x25, 0x27, 0xe6,
    0x25, 0xa7, 0xe6, 0x90, 0xa0, 0x21, 0xb5, 0xa8, 0x28, 0xbf, 0x28, 0xb8, 0xa4, 0x28, 0x33, 0x2f,
    0x1d, 0xa2, 0x4b, 0xd7, 0x2e, 0x10, 0xc2, 0x25, 0x4a, 0x7b, 0x49, 0x6a, 0x45, 0x49, 0x69, 0x51,
    0xaa, 0x5b, 0x62, 0x72, 0x49, 0x7e, 0x51, 0x25, 0xcc, 0x04, 0xec, 0x3a, 0x43, 0x50, 0xd4, 0x72,
    0x01, 0x00, 0x61, 0xcf, 0x5b, 0x6e
};
#endif

PyTypeObject *init_QQuickImageResponse(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QQuickImageResponse_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QQuickImageResponse_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuickImageResponse_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QQuickImageResponse_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuickImageResponse",
        "QQuickImageResponse*",
        &Sbk_QQuickImageResponse_spec,
        &Shiboken::callCppDestructor< QQuickImageResponse >,
        Sbk_QQuickImageResponse_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQuickImageResponse_TypeF(); // references _Sbk_QQuickImageResponse_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuickImageResponse_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuickImageResponse_SignatureBytes, QQuickImageResponse_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuickImageResponse_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickImageResponse_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuickImageResponse_PythonToCpp_QQuickImageResponse_PTR,
        is_QQuickImageResponse_PythonToCpp_QQuickImageResponse_PTR_Convertible,
        QQuickImageResponse_PTR_CppToPython_QQuickImageResponse);

    Shiboken::Conversions::registerConverterName(converter, "QQuickImageResponse");
    Shiboken::Conversions::registerConverterName(converter, "QQuickImageResponse*");
    Shiboken::Conversions::registerConverterName(converter, "QQuickImageResponse&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuickImageResponse).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQuickImageResponseWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QQuickImageResponse_TypeF(), &Sbk_QQuickImageResponse_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QQuickImageResponse::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QQuickImageResponse::staticMetaObject, sizeof(QQuickImageResponseWrapper));

    return pyType;
}
