// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgimagenode_wrapper.h"

// Wrappers providing overrides
#include "qsgnode_wrapper.h"
#include "qsgninepatchnode_wrapper.h"
#include "qsgtextnode_wrapper.h"

// Argument includes
#include <QtQuick/qsggeometry.h>
#include <QtQuick/qsgtexture.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGImageNodeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGImageNodeWrapper::QSGImageNodeWrapper()
{
}

::QSGTexture::AnisotropyLevel QSGImageNodeWrapper::anisotropyLevel() const
{
    static const char *funcName = "anisotropyLevel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.anisotropyLevel");
        return QSGTexture::AnisotropyNone;
    }
    return sbk_o_anisotropyLevel("QSGImageNode", funcName, gil, pyOverride);
}

::QSGTexture::AnisotropyLevel QSGImageNodeWrapper::sbk_o_anisotropyLevel(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return QSGTexture::AnisotropyNone;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_AnisotropyLevel_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QSGTexture::AnisotropyLevel >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QSGTexture::AnisotropyNone;
    }
    ::QSGTexture::AnisotropyLevel cppResult{QSGTexture::AnisotropyNone};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSGTexture::Filtering QSGImageNodeWrapper::filtering() const
{
    static const char *funcName = "filtering";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.filtering");
        return QSGTexture::None;
    }
    return QSGTextNodeWrapper::sbk_o_filtering("QSGImageNode", funcName, gil, pyOverride);
}

bool QSGImageNodeWrapper::isSubtreeBlocked() const
{
    static const char *funcName = "isSubtreeBlocked";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSGNode::isSubtreeBlocked();
    }
    return QSGNodeWrapper::sbk_o_isSubtreeBlocked("QSGImageNode", funcName, gil, pyOverride);
}

::QSGTexture::Filtering QSGImageNodeWrapper::mipmapFiltering() const
{
    static const char *funcName = "mipmapFiltering";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.mipmapFiltering");
        return QSGTexture::None;
    }
    return QSGTextNodeWrapper::sbk_o_filtering("QSGImageNode", funcName, gil, pyOverride);
}

bool QSGImageNodeWrapper::ownsTexture() const
{
    static const char *funcName = "ownsTexture";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.ownsTexture");
        return false;
    }
    return QSGNodeWrapper::sbk_o_isSubtreeBlocked("QSGImageNode", funcName, gil, pyOverride);
}

void QSGImageNodeWrapper::preprocess()
{
    static const char *funcName = "preprocess";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSGNode::preprocess();
    }
    QSGNodeWrapper::sbk_o_preprocess("QSGImageNode", funcName, gil, pyOverride);
}

::QRectF QSGImageNodeWrapper::rect() const
{
    static const char *funcName = "rect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.rect");
        return {};
    }
    return QSGTextNodeWrapper::sbk_o_viewport("QSGImageNode", funcName, gil, pyOverride);
}

void QSGImageNodeWrapper::setAnisotropyLevel(::QSGTexture::AnisotropyLevel level)
{
    static const char *funcName = "setAnisotropyLevel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setAnisotropyLevel");
        return;
    }
    sbk_o_setAnisotropyLevel("QSGImageNode", funcName, gil, pyOverride, level);
}

void QSGImageNodeWrapper::sbk_o_setAnisotropyLevel(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSGTexture::AnisotropyLevel level)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_AnisotropyLevel_IDX])))->converter, &level)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_AnisotropyLevel_IDX])))->converter, &level)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QSGImageNodeWrapper::setFiltering(::QSGTexture::Filtering filtering)
{
    static const char *funcName = "setFiltering";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setFiltering");
        return;
    }
    QSGTextNodeWrapper::sbk_o_setFiltering("QSGImageNode", funcName, gil, pyOverride, filtering);
}

void QSGImageNodeWrapper::setMipmapFiltering(::QSGTexture::Filtering filtering)
{
    static const char *funcName = "setMipmapFiltering";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setMipmapFiltering");
        return;
    }
    QSGTextNodeWrapper::sbk_o_setFiltering("QSGImageNode", funcName, gil, pyOverride, filtering);
}

void QSGImageNodeWrapper::setOwnsTexture(bool owns)
{
    static const char *funcName = "setOwnsTexture";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setOwnsTexture");
        return;
    }
    sbk_o_setOwnsTexture("QSGImageNode", funcName, gil, pyOverride, owns);
}

void QSGImageNodeWrapper::sbk_o_setOwnsTexture(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, bool owns)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &owns)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &owns)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QSGImageNodeWrapper::setRect(const ::QRectF & rect)
{
    static const char *funcName = "setRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setRect");
        return;
    }
    QSGTextNodeWrapper::sbk_o_setViewport("QSGImageNode", funcName, gil, pyOverride, rect);
}

void QSGImageNodeWrapper::setSourceRect(const ::QRectF & r)
{
    static const char *funcName = "setSourceRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setSourceRect");
        return;
    }
    QSGTextNodeWrapper::sbk_o_setViewport("QSGImageNode", funcName, gil, pyOverride, r);
}

void QSGImageNodeWrapper::setTexture(::QSGTexture * texture)
{
    static const char *funcName = "setTexture";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setTexture");
        return;
    }
    QSGNinePatchNodeWrapper::sbk_o_setTexture("QSGImageNode", funcName, gil, pyOverride, texture);
}

void QSGImageNodeWrapper::setTextureCoordinatesTransform(::QFlags<QSGImageNode::TextureCoordinatesTransformFlag> mode)
{
    static const char *funcName = "setTextureCoordinatesTransform";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setTextureCoordinatesTransform");
        return;
    }
    sbk_o_setTextureCoordinatesTransform("QSGImageNode", funcName, gil, pyOverride, mode);
}

void QSGImageNodeWrapper::sbk_o_setTextureCoordinatesTransform(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<QSGImageNode::TextureCoordinatesTransformFlag> mode)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGImageNode_TextureCoordinatesTransformFlag_IDX])))->flagsConverter, &mode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGImageNode_TextureCoordinatesTransformFlag_IDX])))->flagsConverter, &mode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

::QRectF QSGImageNodeWrapper::sourceRect() const
{
    static const char *funcName = "sourceRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.sourceRect");
        return {};
    }
    return QSGTextNodeWrapper::sbk_o_viewport("QSGImageNode", funcName, gil, pyOverride);
}

::QSGTexture * QSGImageNodeWrapper::texture() const
{
    static const char *funcName = "texture";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.texture");
        return nullptr;
    }
    return sbk_o_texture("QSGImageNode", funcName, gil, pyOverride);
}

::QSGTexture * QSGImageNodeWrapper::sbk_o_texture(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QSGTexture >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSGTexture *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QFlags<QSGImageNode::TextureCoordinatesTransformFlag> QSGImageNodeWrapper::textureCoordinatesTransform() const
{
    static const char *funcName = "textureCoordinatesTransform";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.textureCoordinatesTransform");
        return QFlags<QSGImageNode::TextureCoordinatesTransformFlag>(0);
    }
    return sbk_o_textureCoordinatesTransform("QSGImageNode", funcName, gil, pyOverride);
}

::QFlags<QSGImageNode::TextureCoordinatesTransformFlag> QSGImageNodeWrapper::sbk_o_textureCoordinatesTransform(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return QFlags<QSGImageNode::TextureCoordinatesTransformFlag>(0);
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGImageNode_TextureCoordinatesTransformFlag_IDX])))->flagsConverter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QFlags<QSGImageNode::TextureCoordinatesTransformFlag> >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QFlags<QSGImageNode::TextureCoordinatesTransformFlag>(0);
    }
    ::QFlags<QSGImageNode::TextureCoordinatesTransformFlag> cppResult = QFlags<QSGImageNode::TextureCoordinatesTransformFlag>(0);
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QSGImageNodeWrapper::~QSGImageNodeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGImageNode_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QSGImageNode");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGImageNode >()))
        return -1;

    QSGImageNodeWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QSGImageNode()
        cptr = new QSGImageNodeWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGImageNode >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGImageNodeFunc_anisotropyLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // anisotropyLevel()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.anisotropyLevel");
            return {};
        }
        QSGTexture::AnisotropyLevel cppResult = const_cast<const ::QSGImageNode *>(cppSelf)->anisotropyLevel();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_AnisotropyLevel_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSGImageNodeFunc_filtering(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filtering()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.filtering");
            return {};
        }
        QSGTexture::Filtering cppResult = const_cast<const ::QSGImageNode *>(cppSelf)->filtering();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_Filtering_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSGImageNodeFunc_mipmapFiltering(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mipmapFiltering()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.mipmapFiltering");
            return {};
        }
        QSGTexture::Filtering cppResult = const_cast<const ::QSGImageNode *>(cppSelf)->mipmapFiltering();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_Filtering_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSGImageNodeFunc_ownsTexture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ownsTexture()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.ownsTexture");
            return {};
        }
        bool cppResult = const_cast<const ::QSGImageNode *>(cppSelf)->ownsTexture();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSGImageNodeFunc_rebuildGeometry(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "rebuildGeometry", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QSGImageNode::rebuildGeometry(QSGGeometry*,QSGTexture*,QRectF,QRectF,QFlags<QSGImageNode::TextureCoordinatesTransformFlag>)
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometry_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGImageNode_TextureCoordinatesTransformFlag_IDX])))->flagsConverter, (pyArgs[4])))) {
        overloadId = 0; // rebuildGeometry(QSGGeometry*,QSGTexture*,QRectF,QRectF,QFlags<QSGImageNode::TextureCoordinatesTransformFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rebuildGeometry", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSGGeometry *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSGTexture *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRectF cppArg2_local;
        ::QRectF *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QRectF cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QFlags<QSGImageNode::TextureCoordinatesTransformFlag> cppArg4 = QFlags<QSGImageNode::TextureCoordinatesTransformFlag>(0);
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rebuildGeometry(QSGGeometry*,QSGTexture*,QRectF,QRectF,QFlags<QSGImageNode::TextureCoordinatesTransformFlag>)
            ::QSGImageNode::rebuildGeometry(cppArg0, cppArg1, *cppArg2, cppArg3, cppArg4);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSGImageNodeFunc_rect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rect()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.rect");
            return {};
        }
        QRectF cppResult = const_cast<const ::QSGImageNode *>(cppSelf)->rect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSGImageNodeFunc_setAnisotropyLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGImageNode::setAnisotropyLevel(QSGTexture::AnisotropyLevel)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_AnisotropyLevel_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAnisotropyLevel(QSGTexture::AnisotropyLevel)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAnisotropyLevel", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]);

    // Call function/method
    {
        ::QSGTexture::AnisotropyLevel cppArg0{QSGTexture::AnisotropyNone};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAnisotropyLevel(QSGTexture::AnisotropyLevel)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setAnisotropyLevel");
                return {};
            }
            cppSelf->setAnisotropyLevel(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSGImageNodeFunc_setFiltering(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGImageNode::setFiltering(QSGTexture::Filtering)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_Filtering_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFiltering(QSGTexture::Filtering)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFiltering", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]);

    // Call function/method
    {
        ::QSGTexture::Filtering cppArg0{QSGTexture::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFiltering(QSGTexture::Filtering)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setFiltering");
                return {};
            }
            cppSelf->setFiltering(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSGImageNodeFunc_setMipmapFiltering(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGImageNode::setMipmapFiltering(QSGTexture::Filtering)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_Filtering_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMipmapFiltering(QSGTexture::Filtering)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMipmapFiltering", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]);

    // Call function/method
    {
        ::QSGTexture::Filtering cppArg0{QSGTexture::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMipmapFiltering(QSGTexture::Filtering)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setMipmapFiltering");
                return {};
            }
            cppSelf->setMipmapFiltering(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSGImageNodeFunc_setOwnsTexture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGImageNode::setOwnsTexture(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setOwnsTexture(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOwnsTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOwnsTexture(bool)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setOwnsTexture");
                return {};
            }
            cppSelf->setOwnsTexture(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSGImageNodeFunc_setRect(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, "setRect", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]);

    if (PyArg_UnpackTuple(args, "setRect", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGImageNode::setRect(QRectF)
    // 1: QSGImageNode::setRect(qreal,qreal,qreal,qreal)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 1; // setRect(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRect", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setRect(const QRectF &rect)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setRect(QRectF)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                    Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setRect");
                    return {};
                }
                cppSelf->setRect(*cppArg0);
            }
            break;
        }
        case 1: // setRect(qreal x, qreal y, qreal w, qreal h)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setRect(qreal,qreal,qreal,qreal)
                cppSelf->setRect(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSGImageNodeFunc_setSourceRect(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, "setSourceRect", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]);

    if (PyArg_UnpackTuple(args, "setSourceRect", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGImageNode::setSourceRect(QRectF)
    // 1: QSGImageNode::setSourceRect(qreal,qreal,qreal,qreal)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 1; // setSourceRect(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setSourceRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSourceRect", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setSourceRect(const QRectF &r)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setSourceRect(QRectF)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                    Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setSourceRect");
                    return {};
                }
                cppSelf->setSourceRect(*cppArg0);
            }
            break;
        }
        case 1: // setSourceRect(qreal x, qreal y, qreal w, qreal h)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setSourceRect(qreal,qreal,qreal,qreal)
                cppSelf->setSourceRect(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSGImageNodeFunc_setTexture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGImageNode::setTexture(QSGTexture*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_IDX]), (pyArg)))) {
        overloadId = 0; // setTexture(QSGTexture*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTexture", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGTexture *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTexture(QSGTexture*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setTexture");
                return {};
            }
            cppSelf->setTexture(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSGImageNodeFunc_setTextureCoordinatesTransform(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGImageNode::setTextureCoordinatesTransform(QFlags<QSGImageNode::TextureCoordinatesTransformFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGImageNode_TextureCoordinatesTransformFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setTextureCoordinatesTransform(QFlags<QSGImageNode::TextureCoordinatesTransformFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextureCoordinatesTransform", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]);

    // Call function/method
    {
        ::QFlags<QSGImageNode::TextureCoordinatesTransformFlag> cppArg0 = QFlags<QSGImageNode::TextureCoordinatesTransformFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextureCoordinatesTransform(QFlags<QSGImageNode::TextureCoordinatesTransformFlag>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.setTextureCoordinatesTransform");
                return {};
            }
            cppSelf->setTextureCoordinatesTransform(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSGImageNodeFunc_sourceRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sourceRect()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.sourceRect");
            return {};
        }
        QRectF cppResult = const_cast<const ::QSGImageNode *>(cppSelf)->sourceRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSGImageNodeFunc_texture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // texture()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.texture");
            return {};
        }
        QSGTexture * cppResult = const_cast<const ::QSGImageNode *>(cppSelf)->texture();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSGImageNodeFunc_textureCoordinatesTransform(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureCoordinatesTransform()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QSGImageNode.textureCoordinatesTransform");
            return {};
        }
        QFlags<QSGImageNode::TextureCoordinatesTransformFlag> cppResult = const_cast<const ::QSGImageNode *>(cppSelf)->textureCoordinatesTransform();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGImageNode_TextureCoordinatesTransformFlag_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QSGImageNode_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSGImageNode_EnumFlagInfo[] = {
    "TextureCoordinatesTransformFlag:Flag:TextureCoordinatesTransformMode",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGImageNode_methods[] = {
    {"anisotropyLevel", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_anisotropyLevel), METH_NOARGS, nullptr},
    {"filtering", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_filtering), METH_NOARGS, nullptr},
    {"mipmapFiltering", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_mipmapFiltering), METH_NOARGS, nullptr},
    {"ownsTexture", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_ownsTexture), METH_NOARGS, nullptr},
    {"rebuildGeometry", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_rebuildGeometry), METH_VARARGS|METH_STATIC, nullptr},
    {"rect", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_rect), METH_NOARGS, nullptr},
    {"setAnisotropyLevel", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_setAnisotropyLevel), METH_O, nullptr},
    {"setFiltering", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_setFiltering), METH_O, nullptr},
    {"setMipmapFiltering", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_setMipmapFiltering), METH_O, nullptr},
    {"setOwnsTexture", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_setOwnsTexture), METH_O, nullptr},
    {"setRect", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_setRect), METH_VARARGS, nullptr},
    {"setSourceRect", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_setSourceRect), METH_VARARGS, nullptr},
    {"setTexture", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_setTexture), METH_O, nullptr},
    {"setTextureCoordinatesTransform", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_setTextureCoordinatesTransform), METH_O, nullptr},
    {"sourceRect", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_sourceRect), METH_NOARGS, nullptr},
    {"texture", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_texture), METH_NOARGS, nullptr},
    {"textureCoordinatesTransform", reinterpret_cast<PyCFunction>(Sbk_QSGImageNodeFunc_textureCoordinatesTransform), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGImageNode_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGImageNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGImageNodeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGImageNode_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGImageNode_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGImageNode_Type = nullptr;
static PyTypeObject *Sbk_QSGImageNode_TypeF(void)
{
    return _Sbk_QSGImageNode_Type;
}

static PyType_Slot Sbk_QSGImageNode_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGImageNode_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGImageNode_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGImageNode_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGImageNode_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGImageNode_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGImageNode_spec = {
    "2:PySide6.QtQuick.QSGImageNode",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGImageNode_slots
};

} //extern "C"

static void *Sbk_QSGImageNode_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QSGNode >())
        return dynamic_cast< ::QSGImageNode *>(reinterpret_cast< ::QSGNode *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSGImageNode_TextureCoordinatesTransformFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGImageNode::TextureCoordinatesTransformFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGImageNode::TextureCoordinatesTransformFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSGImageNode_TextureCoordinatesTransformFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_TextureCoordinatesTransformFlag_IDX])))
        return Enum_PythonToCpp_QSGImageNode_TextureCoordinatesTransformFlag;
    return {};
}

static PyObject *QSGImageNode_TextureCoordinatesTransformFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSGImageNode::TextureCoordinatesTransformFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSGImageNode::TextureCoordinatesTransformFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_TextureCoordinatesTransformFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QSGImageNode_TextureCoordinatesTransformFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QSGImageNode::TextureCoordinatesTransformFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QSGImageNode::TextureCoordinatesTransformFlag> *>(cppOut) = value;

}

static PyObject *QSGImageNode_TextureCoordinatesTransformFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QSGImageNode::TextureCoordinatesTransformFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_TextureCoordinatesTransformFlag_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGImageNode_PythonToCpp_QSGImageNode_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGImageNode_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGImageNode_PythonToCpp_QSGImageNode_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGImageNode_TypeF()))
        return QSGImageNode_PythonToCpp_QSGImageNode_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGImageNode_PTR_CppToPython_QSGImageNode(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSGImageNode *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSGImageNode_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSGImageNode_SignatureStrings[] = {
    "PySide6.QtQuick.QSGImageNode(self)",
    "PySide6.QtQuick.QSGImageNode.anisotropyLevel(self)->PySide6.QtQuick.QSGTexture.AnisotropyLevel",
    "PySide6.QtQuick.QSGImageNode.filtering(self)->PySide6.QtQuick.QSGTexture.Filtering",
    "PySide6.QtQuick.QSGImageNode.mipmapFiltering(self)->PySide6.QtQuick.QSGTexture.Filtering",
    "PySide6.QtQuick.QSGImageNode.ownsTexture(self)->bool",
    "PySide6.QtQuick.QSGImageNode.rebuildGeometry(g:PySide6.QtQuick.QSGGeometry,texture:PySide6.QtQuick.QSGTexture,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],sourceRect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],texCoordMode:PySide6.QtQuick.QSGImageNode.TextureCoordinatesTransformFlag)",
    "PySide6.QtQuick.QSGImageNode.rect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtQuick.QSGImageNode.setAnisotropyLevel(self,level:PySide6.QtQuick.QSGTexture.AnisotropyLevel)",
    "PySide6.QtQuick.QSGImageNode.setFiltering(self,filtering:PySide6.QtQuick.QSGTexture.Filtering)",
    "PySide6.QtQuick.QSGImageNode.setMipmapFiltering(self,filtering:PySide6.QtQuick.QSGTexture.Filtering)",
    "PySide6.QtQuick.QSGImageNode.setOwnsTexture(self,owns:bool)",
    "1:PySide6.QtQuick.QSGImageNode.setRect(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "0:PySide6.QtQuick.QSGImageNode.setRect(self,x:qreal,y:qreal,w:qreal,h:qreal)",
    "1:PySide6.QtQuick.QSGImageNode.setSourceRect(self,r:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "0:PySide6.QtQuick.QSGImageNode.setSourceRect(self,x:qreal,y:qreal,w:qreal,h:qreal)",
    "PySide6.QtQuick.QSGImageNode.setTexture(self,texture:PySide6.QtQuick.QSGTexture)",
    "PySide6.QtQuick.QSGImageNode.setTextureCoordinatesTransform(self,mode:PySide6.QtQuick.QSGImageNode.TextureCoordinatesTransformFlag)",
    "PySide6.QtQuick.QSGImageNode.sourceRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtQuick.QSGImageNode.texture(self)->PySide6.QtQuick.QSGTexture",
    "PySide6.QtQuick.QSGImageNode.textureCoordinatesTransform(self)->PySide6.QtQuick.QSGImageNode.TextureCoordinatesTransformFlag",
    nullptr}; // Sentinel
#else
static constexpr size_t QSGImageNode_SignatureByteSize = 361;
static constexpr uint8_t QSGImageNode_SignatureBytes[361] = {
    0x78, 0xda, 0xb5, 0x54, 0xb1, 0x4e, 0xc3, 0x30, 0x10, 0xdd, 0xf3, 0x15, 0x8c, 0x8d, 0x64, 0x22,
    0x58, 0x18, 0x3c, 0x20, 0x55, 0x95, 0x52, 0x21, 0x51, 0x68, 0xda, 0x32, 0x21, 0x06, 0x37, 0xb9,
    0x06, 0x0b, 0xc7, 0x0e, 0xb6, 0x43, 0x9b, 0xbf, 0x27, 0x25, 0x49, 0x21, 0xc5, 0x8d, 0x0d, 0x6d,
    0x27, 0x47, 0xf1, 0xbb, 0x77, 0xef, 0xee, 0xde, 0x79, 0x5a, 0xce, 0x69, 0x02, 0x37, 0x41, 0xa4,
    0xa3, 0x82, 0xc6, 0x6f, 0x41, 0x34, 0x1f, 0xdf, 0x65, 0x24, 0x85, 0x07, 0x91, 0xc0, 0x40, 0x01,
    0x5b, 0xf9, 0xde, 0xb4, 0x07, 0x12, 0x10, 0x4e, 0x95, 0xd0, 0x52, 0xe4, 0xe5, 0x3d, 0x7c, 0x00,
    0xab, 0x43, 0x2e, 0x6f, 0x0d, 0x31, 0x0b, 0xd8, 0xe8, 0x42, 0x42, 0x30, 0xec, 0x46, 0xf4, 0xd3,
    0xaf, 0x28, 0xd3, 0x20, 0x29, 0x4f, 0x1d, 0x88, 0xc3, 0x16, 0xdb, 0x4f, 0x99, 0xd1, 0x3c, 0x23,
    0x79, 0x78, 0x7a, 0x62, 0xb1, 0xe6, 0xaa, 0x09, 0x69, 0x49, 0x97, 0x42, 0x58, 0x0a, 0x94, 0xb0,
    0x2c, 0x28, 0x4b, 0xc6, 0x20, 0x32, 0xd0, 0xb2, 0x1c, 0xa4, 0xd8, 0x00, 0x6f, 0x6f, 0x91, 0xae,
    0xe9, 0xf1, 0x61, 0xb1, 0x48, 0x42, 0xac, 0xb1, 0x2e, 0xf3, 0x4a, 0x6e, 0xf0, 0xc4, 0xa9, 0xe0,
    0xcf, 0xdf, 0xe0, 0x91, 0xa8, 0xaa, 0x89, 0x66, 0x15, 0x22, 0x44, 0x17, 0xa6, 0xdf, 0x2f, 0x48,
    0x89, 0x42, 0xc6, 0x30, 0x3b, 0x8e, 0xa4, 0x92, 0x39, 0x12, 0x42, 0x26, 0x93, 0xaa, 0x42, 0xdc,
    0x5b, 0x7e, 0xa3, 0xfa, 0x0b, 0x4d, 0x39, 0xd1, 0xa0, 0x16, 0x92, 0x70, 0xb5, 0x12, 0x32, 0x0b,
    0x19, 0x49, 0x7d, 0x5b, 0xf3, 0x62, 0xfd, 0x7b, 0x7e, 0x3f, 0x04, 0xf6, 0x87, 0x2b, 0xd0, 0x43,
    0x83, 0x7d, 0x11, 0xdb, 0x7e, 0x62, 0x77, 0x0b, 0xfb, 0xd6, 0x34, 0x5d, 0xb7, 0xa1, 0x9d, 0xab,
    0xb1, 0x8b, 0xeb, 0xec, 0xf4, 0x13, 0x83, 0xa5, 0x4f, 0x9e, 0xe4, 0x71, 0xcf, 0xde, 0x68, 0xeb,
    0x77, 0xbc, 0x75, 0xb8, 0xef, 0x5d, 0x63, 0x5b, 0xf4, 0xac, 0x1d, 0xd5, 0x91, 0x06, 0xf5, 0xbd,
    0xab, 0x3f, 0xe4, 0xda, 0xe0, 0x77, 0x09, 0x84, 0xa1, 0xb2, 0x39, 0xd7, 0xcd, 0xf9, 0x5a, 0x9f,
    0x2e, 0xc2, 0xe7, 0xbb, 0x85, 0x68, 0xe4, 0x9f, 0x57, 0xfb, 0x7e, 0x3a, 0x6b, 0x05, 0x36, 0xc2,
    0xce, 0xc8, 0xec, 0xef, 0x87, 0x33, 0xa1, 0x69, 0x65, 0xeb, 0x24, 0xd9, 0x99, 0xb7, 0x5e, 0x75,
    0x5b, 0xf4, 0xbf, 0xdd, 0xd7, 0xdd, 0x87, 0xfa, 0x70, 0x43, 0x9c, 0x68, 0x0e, 0x36, 0xc3, 0x4c,
    0xed, 0xdc, 0x09, 0xef, 0x13, 0xf2, 0x19, 0xbf, 0xa5
};
#endif

PyTypeObject *init_QSGImageNode(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGImageNode_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGGeometryNode_IDX]))));

    _Sbk_QSGImageNode_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGImageNode",
        "QSGImageNode*",
        &Sbk_QSGImageNode_spec,
        &Shiboken::callCppDestructor< QSGImageNode >,
        Sbk_QSGImageNode_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGImageNode_TypeF(); // references _Sbk_QSGImageNode_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSGImageNode_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSGImageNode_SignatureBytes, QSGImageNode_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGImageNode_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGImageNode_PythonToCpp_QSGImageNode_PTR,
        is_QSGImageNode_PythonToCpp_QSGImageNode_PTR_Convertible,
        QSGImageNode_PTR_CppToPython_QSGImageNode);

    Shiboken::Conversions::registerConverterName(converter, "QSGImageNode");
    Shiboken::Conversions::registerConverterName(converter, "QSGImageNode*");
    Shiboken::Conversions::registerConverterName(converter, "QSGImageNode&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGImageNode).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGImageNodeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSGImageNode_TypeF(), &Sbk_QSGImageNode_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSGImageNode_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'TextureCoordinatesTransformFlag'.
    const char *TextureCoordinatesTransformFlag_Initializer[] = {
        "NoTransform",
        "MirrorHorizontally",
        "MirrorVertically",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TextureCoordinatesTransformFlag_InitializerValues[] = {
        uint8_t(QSGImageNode::TextureCoordinatesTransformFlag::NoTransform),        //  0x00  0
        uint8_t(QSGImageNode::TextureCoordinatesTransformFlag::MirrorHorizontally), //  0x01  1
        uint8_t(QSGImageNode::TextureCoordinatesTransformFlag::MirrorVertically)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGImageNode_TypeF(),
        "2:PySide6.QtQuick.QSGImageNode.TextureCoordinatesTransformFlag",
        TextureCoordinatesTransformFlag_Initializer, TextureCoordinatesTransformFlag_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGImageNode_TextureCoordinatesTransformFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGImageNode_TextureCoordinatesTransformFlag_IDX].type =
        EType;
    // Register converter for enum 'QSGImageNode::TextureCoordinatesTransformFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGImageNode_TextureCoordinatesTransformFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSGImageNode_TextureCoordinatesTransformFlag,
            is_Enum_PythonToCpp_QSGImageNode_TextureCoordinatesTransformFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSGImageNode::TextureCoordinatesTransformFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "TextureCoordinatesTransformFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QSGImageNode_TextureCoordinatesTransformFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QSGImageNode_TextureCoordinatesTransformFlag,
            is_Enum_PythonToCpp_QSGImageNode_TextureCoordinatesTransformFlag_Convertible);
        // Register converter for flag 'QFlags<QSGImageNode::TextureCoordinatesTransformFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QSGImageNode::TextureCoordinatesTransformFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QSGImageNode::TextureCoordinatesTransformMode");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'TextureCoordinatesTransformFlag' enum/flags.

    qRegisterMetaType< ::QSGImageNode *>();
    qRegisterMetaType< ::QSGImageNode::TextureCoordinatesTransformFlag >("QSGImageNode::TextureCoordinatesTransformFlag");

    return pyType;
}
