// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_RENDERSTATEWRAPPER_H
#define SBK_RENDERSTATEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtQuick/qsgrendernode.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class RenderStateWrapper : public QSGRenderNode::RenderState
{
public:
    RenderStateWrapper();
    RenderStateWrapper(const RenderStateWrapper &) = delete;
    RenderStateWrapper& operator=(const RenderStateWrapper &) = delete;
    RenderStateWrapper(RenderStateWrapper &&) = delete;
    RenderStateWrapper& operator=(RenderStateWrapper &&) = delete;
    ~RenderStateWrapper() override;

    const ::QRegion * clipRegion() const override;
    static const ::QRegion * sbk_o_clipRegion(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void * get(const char * state) const override;
    static void * sbk_o_get(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const char * state);
    const ::QMatrix4x4 * projectionMatrix() const override;
    static const ::QMatrix4x4 * sbk_o_projectionMatrix(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool scissorEnabled() const override;
    ::QRect scissorRect() const override;
    static ::QRect sbk_o_scissorRect(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool stencilEnabled() const override;
    int stencilValue() const override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[7] = {false, false, false, false, false, false, false};
};

#endif // SBK_RENDERSTATEWRAPPER_H
