// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSGRENDERNODEWRAPPER_H
#define SBK_QSGRENDERNODEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtQuick/qsgrendernode.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QSGRenderNodeWrapper : public QSGRenderNode
{
public:
    QSGRenderNodeWrapper();
    QSGRenderNodeWrapper(const QSGRenderNodeWrapper &) = delete;
    QSGRenderNodeWrapper& operator=(const QSGRenderNodeWrapper &) = delete;
    QSGRenderNodeWrapper(QSGRenderNodeWrapper &&) = delete;
    QSGRenderNodeWrapper& operator=(QSGRenderNodeWrapper &&) = delete;
    ~QSGRenderNodeWrapper() override;

    ::QFlags<QSGRenderNode::StateFlag> changedStates() const override;
    static ::QFlags<QSGRenderNode::StateFlag> sbk_o_changedStates(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QFlags<QSGRenderNode::RenderingFlag> flags() const override;
    static ::QFlags<QSGRenderNode::RenderingFlag> sbk_o_flags(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isSubtreeBlocked() const override;
    void prepare() override;
    void preprocess() override;
    ::QRectF rect() const override;
    void releaseResources() override;
    void render(const ::QSGRenderNode::RenderState * state) override;
    static void sbk_o_render(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QSGRenderNode::RenderState * state);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[8] = {false, false, false, false, false, false, false, false};
};

#endif // SBK_QSGRENDERNODEWRAPPER_H
