// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSGTEXTNODEWRAPPER_H
#define SBK_QSGTEXTNODEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtQuick/qsgtextnode.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QSGTextNodeWrapper : public QSGTextNode
{
public:
    QSGTextNodeWrapper();
    QSGTextNodeWrapper(const QSGTextNodeWrapper &) = delete;
    QSGTextNodeWrapper& operator=(const QSGTextNodeWrapper &) = delete;
    QSGTextNodeWrapper(QSGTextNodeWrapper &&) = delete;
    QSGTextNodeWrapper& operator=(QSGTextNodeWrapper &&) = delete;
    ~QSGTextNodeWrapper() override;

    void clear() override;
    ::QColor color() const override;
    static ::QColor sbk_o_color(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void doAddTextDocument(::QPointF position, ::QTextDocument * document, int selectionStart, int selectionCount) override;
    static void sbk_o_doAddTextDocument(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPointF position, ::QTextDocument * document, int selectionStart, int selectionCount);
    void doAddTextLayout(::QPointF position, ::QTextLayout * layout, int selectionStart, int selectionCount, int lineStart, int lineCount) override;
    static void sbk_o_doAddTextLayout(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPointF position, ::QTextLayout * layout, int selectionStart, int selectionCount, int lineStart, int lineCount);
    ::QSGTexture::Filtering filtering() const override;
    static ::QSGTexture::Filtering sbk_o_filtering(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isSubtreeBlocked() const override;
    ::QColor linkColor() const override;
    void preprocess() override;
    ::QSGTextNode::RenderType renderType() const override;
    static ::QSGTextNode::RenderType sbk_o_renderType(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    int renderTypeQuality() const override;
    static int sbk_o_renderTypeQuality(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QColor selectionColor() const override;
    ::QColor selectionTextColor() const override;
    void setColor(::QColor color) override;
    static void sbk_o_setColor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QColor color);
    void setFiltering(::QSGTexture::Filtering arg__1) override;
    static void sbk_o_setFiltering(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSGTexture::Filtering arg__1);
    void setLinkColor(::QColor linkColor) override;
    void setRenderType(::QSGTextNode::RenderType renderType) override;
    static void sbk_o_setRenderType(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSGTextNode::RenderType renderType);
    void setRenderTypeQuality(int renderTypeQuality) override;
    static void sbk_o_setRenderTypeQuality(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int renderTypeQuality);
    void setSelectionColor(::QColor selectionColor) override;
    void setSelectionTextColor(::QColor selectionTextColor) override;
    void setStyleColor(::QColor styleColor) override;
    void setTextStyle(::QSGTextNode::TextStyle textStyle) override;
    static void sbk_o_setTextStyle(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSGTextNode::TextStyle textStyle);
    void setViewport(const ::QRectF & viewport) override;
    static void sbk_o_setViewport(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRectF & viewport);
    ::QColor styleColor() const override;
    ::QSGTextNode::TextStyle textStyle() override;
    static ::QSGTextNode::TextStyle sbk_o_textStyle(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QRectF viewport() const override;
    static ::QRectF sbk_o_viewport(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[25] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSGTEXTNODEWRAPPER_H
