// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSGTEXTUREWRAPPER_H
#define SBK_QSGTEXTUREWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtQuick/qsgtexture.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QSGTextureWrapper : public QSGTexture
{
public:
    QSGTextureWrapper();
    QSGTextureWrapper(const QSGTextureWrapper &) = delete;
    QSGTextureWrapper& operator=(const QSGTextureWrapper &) = delete;
    QSGTextureWrapper(QSGTextureWrapper &&) = delete;
    QSGTextureWrapper& operator=(QSGTextureWrapper &&) = delete;
    ~QSGTextureWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void commitTextureOperations(::QRhi * rhi, ::QRhiResourceUpdateBatch * resourceUpdates) override;
    static void sbk_o_commitTextureOperations(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QRhi * rhi, ::QRhiResourceUpdateBatch * resourceUpdates);
    qint64 comparisonKey() const override;
    static qint64 sbk_o_comparisonKey(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    bool hasAlphaChannel() const override;
    bool hasMipmaps() const override;
    bool isAtlasTexture() const override;
    ::QRectF normalizedTextureSubRect() const override;
    ::QSGTexture * removedFromAtlas(::QRhiResourceUpdateBatch * resourceUpdates = nullptr) const override;
    static ::QSGTexture * sbk_o_removedFromAtlas(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QRhiResourceUpdateBatch * resourceUpdates = nullptr);
    ::QRhiTexture * rhiTexture() const override;
    static ::QRhiTexture * sbk_o_rhiTexture(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QSize textureSize() const override;
    static ::QSize sbk_o_textureSize(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[16] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSGTEXTUREWRAPPER_H
