// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtremoteobjects_python.h"

// main header
#include "qremoteobjecthostbase_wrapper.h"

// Wrappers providing overrides
#include "qconnectionabstractserver_wrapper.h"
#include "qremoteobjectnode_wrapper.h"
#include "qtroiodevicebase_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <qabstractitemmodel.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qitemselectionmodel.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRemoteObjectHostBaseWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QRemoteObjectHostBaseWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_childEvent("QRemoteObjectHostBase", funcName, gil, pyOverride, event);
}

void QRemoteObjectHostBaseWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QtROIoDeviceBaseWrapper::sbk_o_connectNotify("QRemoteObjectHostBase", funcName, gil, pyOverride, signal);
}

void QRemoteObjectHostBaseWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_customEvent("QRemoteObjectHostBase", funcName, gil, pyOverride, event);
}

void QRemoteObjectHostBaseWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QtROIoDeviceBaseWrapper::sbk_o_connectNotify("QRemoteObjectHostBase", funcName, gil, pyOverride, signal);
}

bool QRemoteObjectHostBaseWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QtROIoDeviceBaseWrapper::sbk_o_event("QRemoteObjectHostBase", funcName, gil, pyOverride, event);
}

bool QRemoteObjectHostBaseWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QtROIoDeviceBaseWrapper::sbk_o_eventFilter("QRemoteObjectHostBase", funcName, gil, pyOverride, watched, event);
}

::QUrl QRemoteObjectHostBaseWrapper::hostUrl() const
{
    static const char *funcName = "hostUrl";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRemoteObjectHostBase::hostUrl();
    }
    return QConnectionAbstractServerWrapper::sbk_o_address("QRemoteObjectHostBase", funcName, gil, pyOverride);
}

bool QRemoteObjectHostBaseWrapper::setHostUrl(const ::QUrl & hostAddress, ::QRemoteObjectHostBase::AllowedSchemas allowedSchemas)
{
    static const char *funcName = "setHostUrl";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRemoteObjectHostBase::setHostUrl(hostAddress, allowedSchemas);
    }
    return sbk_o_setHostUrl("QRemoteObjectHostBase", funcName, gil, pyOverride, hostAddress, allowedSchemas);
}

bool QRemoteObjectHostBaseWrapper::sbk_o_setHostUrl(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & hostAddress, ::QRemoteObjectHostBase::AllowedSchemas allowedSchemas)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &hostAddress),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_AllowedSchemas_IDX])))->converter, &allowedSchemas)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &hostAddress),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_AllowedSchemas_IDX])))->converter, &allowedSchemas)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRemoteObjectHostBaseWrapper::setName(const ::QString & name)
{
    static const char *funcName = "setName";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRemoteObjectHostBase::setName(name);
    }
    QRemoteObjectNodeWrapper::sbk_o_setName("QRemoteObjectHostBase", funcName, gil, pyOverride, name);
}

bool QRemoteObjectHostBaseWrapper::setRegistryUrl(const ::QUrl & registryAddress)
{
    static const char *funcName = "setRegistryUrl";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRemoteObjectNode::setRegistryUrl(registryAddress);
    }
    return QRemoteObjectNodeWrapper::sbk_o_setRegistryUrl("QRemoteObjectHostBase", funcName, gil, pyOverride, registryAddress);
}

void QRemoteObjectHostBaseWrapper::timerEvent(::QTimerEvent * arg__1)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QRemoteObjectNode::timerEvent(arg__1);
    }
    QtROIoDeviceBaseWrapper::sbk_o_timerEvent("QRemoteObjectHostBase", funcName, gil, pyOverride, arg__1);
}

const QMetaObject *QRemoteObjectHostBaseWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QRemoteObjectHostBase::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QRemoteObjectHostBaseWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QRemoteObjectHostBase::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QRemoteObjectHostBaseWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QRemoteObjectHostBaseWrapper *>(this));
    return QRemoteObjectHostBase::qt_metacast(_clname);
}

QRemoteObjectHostBaseWrapper::~QRemoteObjectHostBaseWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_QRemoteObjectHostBase_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QRemoteObjectHostBase");
    return -1;
}

static PyObject *Sbk_QRemoteObjectHostBaseFunc_addHostSideConnection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectHostBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectHostBase::addHostSideConnection(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // addHostSideConnection(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addHostSideConnection", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addHostSideConnection(QIODevice*)
            cppSelf->addHostSideConnection(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QRemoteObjectHostBaseFunc_disableRemoting(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectHostBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectHostBase::disableRemoting(QObject*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // disableRemoting(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "disableRemoting", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // disableRemoting(QObject*)
            bool cppResult = cppSelf->disableRemoting(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRemoteObjectHostBaseFunc_enableRemoting(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectHostBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "enableRemoting", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:enableRemoting", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRemoteObjectHostBase::enableRemoting(QAbstractItemModel*,QString,QList<int>,QItemSelectionModel*=)->bool
    // 1: QRemoteObjectHostBase::enableRemoting(QObject*,const QString&=)->bool
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtRemoteObjectsTypeConverters[SBK_QtRemoteObjects_QList_int_IDX], (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // enableRemoting(QAbstractItemModel*,QString,QList<int>,QItemSelectionModel*)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionModel_IDX]), (pyArgs[3])))) {
            overloadId = 0; // enableRemoting(QAbstractItemModel*,QString,QList<int>,QItemSelectionModel*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // enableRemoting(QObject*,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 1; // enableRemoting(QObject*,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "enableRemoting", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // enableRemoting(QAbstractItemModel *model, const QString &name, const QList<int> roles, QItemSelectionModel *selectionModel)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"selectionModel", 3}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionModel_IDX]), (pyArgs[3]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "enableRemoting", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QList<int> cppArg2_local;
            ::QList<int> *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QItemSelectionModel *cppArg3 = nullptr;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // enableRemoting(QAbstractItemModel*,QString,QList<int>,QItemSelectionModel*)
                bool cppResult = cppSelf->enableRemoting(cppArg0, cppArg1, *cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // enableRemoting(QObject *object, const QString &name)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"name", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "enableRemoting", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // enableRemoting(QObject*,QString)
                bool cppResult = cppSelf->enableRemoting(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRemoteObjectHostBaseFunc_hostUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectHostBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hostUrl()const
        QUrl cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QRemoteObjectHostBase *>(cppSelf)->::QRemoteObjectHostBase::hostUrl()
            : const_cast<const ::QRemoteObjectHostBase *>(cppSelf)->hostUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRemoteObjectHostBaseFunc_proxy(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectHostBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "proxy", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]);

    if (PyArg_ParseTuple(args, "|OO:proxy", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRemoteObjectHostBase::proxy(QUrl,const QUrl&=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // proxy(QUrl,QUrl)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[1])))) {
            overloadId = 0; // proxy(QUrl,QUrl)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "proxy", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"hostUrl", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "proxy", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QUrl cppArg1_local{};
        ::QUrl *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // proxy(QUrl,QUrl)
            bool cppResult = cppSelf->proxy(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRemoteObjectHostBaseFunc_reverseProxy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectHostBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reverseProxy()
        bool cppResult = cppSelf->reverseProxy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRemoteObjectHostBaseFunc_setHostUrl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectHostBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setHostUrl", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setHostUrl", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRemoteObjectHostBase::setHostUrl(QUrl,QRemoteObjectHostBase::AllowedSchemas=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setHostUrl(QUrl,QRemoteObjectHostBase::AllowedSchemas)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_AllowedSchemas_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setHostUrl(QUrl,QRemoteObjectHostBase::AllowedSchemas)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setHostUrl", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"allowedSchemas", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_AllowedSchemas_IDX])))->converter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setHostUrl", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QRemoteObjectHostBase::AllowedSchemas cppArg1(QRemoteObjectHostBase::AllowedSchemas::BuiltInSchemasOnly);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHostUrl(QUrl,QRemoteObjectHostBase::AllowedSchemas)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QRemoteObjectHostBase::setHostUrl(*cppArg0, cppArg1)
                : cppSelf->setHostUrl(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QRemoteObjectHostBaseFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRemoteObjectHostBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRemoteObjectNode::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QRemoteObjectHostBase::setName(cppArg0)
                : cppSelf->setName(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QRemoteObjectHostBase_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRemoteObjectHostBase_EnumFlagInfo[] = {
    "AllowedSchemas:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRemoteObjectHostBase_methods[] = {
    {"addHostSideConnection", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectHostBaseFunc_addHostSideConnection), METH_O, nullptr},
    {"disableRemoting", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectHostBaseFunc_disableRemoting), METH_O, nullptr},
    {"enableRemoting", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectHostBaseFunc_enableRemoting), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"hostUrl", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectHostBaseFunc_hostUrl), METH_NOARGS, nullptr},
    {"proxy", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectHostBaseFunc_proxy), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"reverseProxy", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectHostBaseFunc_reverseProxy), METH_NOARGS, nullptr},
    {"setHostUrl", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectHostBaseFunc_setHostUrl), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QRemoteObjectHostBaseFunc_setName), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRemoteObjectHostBase_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRemoteObjectHostBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRemoteObjectHostBaseWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QRemoteObjectHostBase_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRemoteObjectHostBase_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRemoteObjectHostBase_Type = nullptr;
static PyTypeObject *Sbk_QRemoteObjectHostBase_TypeF(void)
{
    return _Sbk_QRemoteObjectHostBase_Type;
}

static PyType_Slot Sbk_QRemoteObjectHostBase_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRemoteObjectHostBase_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRemoteObjectHostBase_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRemoteObjectHostBase_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRemoteObjectHostBase_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRemoteObjectHostBase_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRemoteObjectHostBase_spec = {
    "2:PySide6.QtRemoteObjects.QRemoteObjectHostBase",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRemoteObjectHostBase_slots
};

} //extern "C"

static void *Sbk_QRemoteObjectHostBase_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QRemoteObjectHostBase *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRemoteObjectHostBase_AllowedSchemas(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRemoteObjectHostBase::AllowedSchemas>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRemoteObjectHostBase::AllowedSchemas *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRemoteObjectHostBase_AllowedSchemas_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_AllowedSchemas_IDX])))
        return Enum_PythonToCpp_QRemoteObjectHostBase_AllowedSchemas;
    return {};
}

static PyObject *QRemoteObjectHostBase_AllowedSchemas_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRemoteObjectHostBase::AllowedSchemas>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRemoteObjectHostBase::AllowedSchemas *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_AllowedSchemas_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRemoteObjectHostBase_PythonToCpp_QRemoteObjectHostBase_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRemoteObjectHostBase_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRemoteObjectHostBase_PythonToCpp_QRemoteObjectHostBase_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRemoteObjectHostBase_TypeF()))
        return QRemoteObjectHostBase_PythonToCpp_QRemoteObjectHostBase_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRemoteObjectHostBase_PTR_CppToPython_QRemoteObjectHostBase(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QRemoteObjectHostBase *>(const_cast<void *>(cppIn)), Sbk_QRemoteObjectHostBase_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRemoteObjectHostBase_SignatureStrings[] = {
    "PySide6.QtRemoteObjects.QRemoteObjectHostBase.addHostSideConnection(self,ioDevice:PySide6.QtCore.QIODevice)",
    "PySide6.QtRemoteObjects.QRemoteObjectHostBase.disableRemoting(self,remoteObject:PySide6.QtCore.QObject)->bool",
    "1:PySide6.QtRemoteObjects.QRemoteObjectHostBase.enableRemoting(self,model:PySide6.QtCore.QAbstractItemModel,name:QString,roles:QList[int],selectionModel:PySide6.QtCore.QItemSelectionModel=nullptr)->bool",
    "0:PySide6.QtRemoteObjects.QRemoteObjectHostBase.enableRemoting(self,object:PySide6.QtCore.QObject,name:QString=QString())->bool",
    "PySide6.QtRemoteObjects.QRemoteObjectHostBase.hostUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtRemoteObjects.QRemoteObjectHostBase.proxy(self,registryUrl:typing.Union[PySide6.QtCore.QUrl, QString],hostUrl:typing.Union[PySide6.QtCore.QUrl, QString]={})->bool",
    "PySide6.QtRemoteObjects.QRemoteObjectHostBase.reverseProxy(self)->bool",
    "PySide6.QtRemoteObjects.QRemoteObjectHostBase.setHostUrl(self,hostAddress:typing.Union[PySide6.QtCore.QUrl, QString],allowedSchemas:PySide6.QtRemoteObjects.QRemoteObjectHostBase.AllowedSchemas=QRemoteObjectHostBase.AllowedSchemas.BuiltInSchemasOnly)->bool",
    "PySide6.QtRemoteObjects.QRemoteObjectHostBase.setName(self,name:QString)",
    nullptr}; // Sentinel
#else
static constexpr size_t QRemoteObjectHostBase_SignatureByteSize = 337;
static constexpr uint8_t QRemoteObjectHostBase_SignatureBytes[337] = {
    0x78, 0xda, 0xad, 0x92, 0x4d, 0x4f, 0xc3, 0x30, 0x0c, 0x86, 0xef, 0xfb, 0x15, 0x1c, 0x57, 0xa9,
    0x54, 0x70, 0xe1, 0x50, 0xa9, 0x48, 0xdb, 0x38, 0x30, 0x89, 0xb1, 0x96, 0x6a, 0xa7, 0x69, 0x87,
    0xb4, 0x31, 0x5b, 0x50, 0x1a, 0x4f, 0x89, 0x37, 0xa8, 0x10, 0xff, 0x9d, 0xf4, 0x6b, 0x5a, 0xd9,
    0x84, 0xc8, 0xc4, 0xa9, 0x4e, 0x6c, 0xbf, 0x8f, 0x5f, 0x37, 0x71, 0x99, 0x0a, 0x0e, 0x77, 0x41,
    0x42, 0x2f, 0x50, 0x20, 0xc1, 0x3c, 0x7b, 0x83, 0x9c, 0x4c, 0x90, 0x1c, 0x1f, 0x1f, 0xd1, 0xd0,
    0x98, 0x19, 0x08, 0x18, 0xe7, 0x55, 0x5c, 0xb5, 0x4c, 0x50, 0x29, 0x9b, 0x12, 0xa8, 0x86, 0x06,
    0xe4, 0xab, 0x2f, 0xf0, 0x01, 0xf6, 0x22, 0x87, 0x30, 0x3e, 0x28, 0x4e, 0x50, 0x43, 0x90, 0x4c,
    0xe7, 0x4d, 0xc2, 0x1b, 0xc4, 0x4e, 0x2c, 0x2e, 0x0c, 0xcb, 0x24, 0xd4, 0x39, 0xa1, 0xd6, 0x0d,
    0x45, 0x1f, 0x55, 0x9e, 0x90, 0x9a, 0x6b, 0xef, 0xfa, 0x3e, 0x43, 0x94, 0x83, 0xdb, 0xd0, 0x8d,
    0x07, 0xea, 0x14, 0x57, 0x20, 0x07, 0x79, 0xc2, 0x19, 0x65, 0x86, 0x34, 0xcb, 0x69, 0x4a, 0x50,
    0xcc, 0xaa, 0x0a, 0x5f, 0xb1, 0x02, 0xc2, 0x24, 0x25, 0x6d, 0x3b, 0x7d, 0x8d, 0x12, 0x4c, 0x98,
    0x3c, 0x09, 0x43, 0x4b, 0xa1, 0x68, 0xe5, 0x5b, 0xa9, 0x66, 0x53, 0xb3, 0xb3, 0x72, 0x95, 0x4c,
    0xda, 0x2b, 0x89, 0xd4, 0x4e, 0xca, 0x2d, 0xe9, 0xce, 0xca, 0xcd, 0x3f, 0x58, 0xc1, 0xdf, 0x76,
    0xd6, 0x33, 0x10, 0xb5, 0xdf, 0xa1, 0xd7, 0xf1, 0xdd, 0xe8, 0x1b, 0x1b, 0x2c, 0xb4, 0xac, 0xb1,
    0x56, 0xe1, 0x27, 0xd1, 0xa6, 0x1c, 0x05, 0xb7, 0x1a, 0x3f, 0xca, 0xee, 0xff, 0xaf, 0xed, 0x5a,
    0x75, 0x69, 0x45, 0x42, 0x2a, 0xb7, 0x76, 0xca, 0x60, 0xa1, 0xec, 0xda, 0x96, 0x67, 0x28, 0xfe,
    0x55, 0x6b, 0x64, 0xe5, 0xb7, 0x23, 0x39, 0xb4, 0x44, 0x9f, 0x5f, 0x97, 0xb9, 0xd7, 0xb0, 0x07,
    0x6d, 0x20, 0x3e, 0xcc, 0x7c, 0x99, 0x8c, 0x81, 0x3a, 0xee, 0xf6, 0x58, 0x3b, 0x18, 0x71, 0xae,
    0xc1, 0x18, 0x17, 0xe3, 0x4c, 0x4a, 0x7c, 0x07, 0x9e, 0xe6, 0x1b, 0x28, 0x98, 0x71, 0x7c, 0x46,
    0xa3, 0x5e, 0x73, 0xf4, 0x97, 0xa2, 0x60, 0xbc, 0x13, 0x92, 0xa6, 0xaa, 0x3d, 0xce, 0x95, 0x2c,
    0x2f, 0xf6, 0xff, 0x6c, 0xdf, 0x64, 0x63, 0xfe, 0xf8, 0x75, 0x7a, 0x83, 0x6f, 0xde, 0x3c, 0xbc,
    0x21
};
#endif

PyTypeObject *init_QRemoteObjectHostBase(PyObject *module)
{
    if (SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX].type != nullptr)
        return SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX].type;

    Shiboken::AutoDecRef Sbk_QRemoteObjectHostBase_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectNode_IDX]))));

    _Sbk_QRemoteObjectHostBase_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRemoteObjectHostBase",
        "QRemoteObjectHostBase*",
        &Sbk_QRemoteObjectHostBase_spec,
        &Shiboken::callCppDestructor< QRemoteObjectHostBase >,
        Sbk_QRemoteObjectHostBase_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRemoteObjectHostBase_TypeF(); // references _Sbk_QRemoteObjectHostBase_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRemoteObjectHostBase_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRemoteObjectHostBase_SignatureBytes, QRemoteObjectHostBase_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRemoteObjectHostBase_PropertyStrings);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRemoteObjectHostBase_PythonToCpp_QRemoteObjectHostBase_PTR,
        is_QRemoteObjectHostBase_PythonToCpp_QRemoteObjectHostBase_PTR_Convertible,
        QRemoteObjectHostBase_PTR_CppToPython_QRemoteObjectHostBase);

    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectHostBase");
    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectHostBase*");
    Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectHostBase&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRemoteObjectHostBase).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRemoteObjectHostBaseWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRemoteObjectHostBase_TypeF(), &Sbk_QRemoteObjectHostBase_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRemoteObjectHostBase_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'AllowedSchemas'.
    const char *AllowedSchemas_Initializer[] = {
        "BuiltInSchemasOnly",
        "AllowExternalRegistration",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AllowedSchemas_InitializerValues[] = {
        uint8_t(QRemoteObjectHostBase::AllowedSchemas::BuiltInSchemasOnly),       //  0x00  0
        uint8_t(QRemoteObjectHostBase::AllowedSchemas::AllowExternalRegistration) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRemoteObjectHostBase_TypeF(),
        "2:PySide6.QtRemoteObjects.QRemoteObjectHostBase.AllowedSchemas",
        AllowedSchemas_Initializer, AllowedSchemas_InitializerValues);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QRemoteObjectHostBase_AllowedSchemas_IDX].type = EType;
    // Register converter for enum 'QRemoteObjectHostBase::AllowedSchemas'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRemoteObjectHostBase_AllowedSchemas_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRemoteObjectHostBase_AllowedSchemas,
            is_Enum_PythonToCpp_QRemoteObjectHostBase_AllowedSchemas_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRemoteObjectHostBase::AllowedSchemas");
        Shiboken::Conversions::registerConverterAlias(converter, "AllowedSchemas");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AllowedSchemas' enum.

    qRegisterMetaType< ::QRemoteObjectHostBase::AllowedSchemas >("QRemoteObjectHostBase::AllowedSchemas");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QRemoteObjectHostBase::staticMetaObject, sizeof(QRemoteObjectHostBaseWrapper));

    return pyType;
}
