// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtremoteobjects_python.h"

// main header
#include "qtroserveriodevice_wrapper.h"

// Wrappers providing overrides
#include "qtroiodevicebase_wrapper.h"

// Argument includes
#include <QString>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QtROServerIoDeviceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QtROServerIoDeviceWrapper::QtROServerIoDeviceWrapper(::QObject * parent) : QtROServerIoDevice(parent)
{
}

qint64 QtROServerIoDeviceWrapper::bytesAvailable() const
{
    static const char *funcName = "bytesAvailable";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QtROIoDeviceBase::bytesAvailable();
    }
    return QtROIoDeviceBaseWrapper::sbk_o_bytesAvailable("QtROServerIoDevice", funcName, gil, pyOverride);
}

void QtROServerIoDeviceWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_childEvent("QtROServerIoDevice", funcName, gil, pyOverride, event);
}

void QtROServerIoDeviceWrapper::close()
{
    static const char *funcName = "close";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QtROIoDeviceBase::close();
    }
    QtROIoDeviceBaseWrapper::sbk_o_close("QtROServerIoDevice", funcName, gil, pyOverride);
}

void QtROServerIoDeviceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QtROIoDeviceBaseWrapper::sbk_o_connectNotify("QtROServerIoDevice", funcName, gil, pyOverride, signal);
}

::QIODevice * QtROServerIoDeviceWrapper::connection() const
{
    static const char *funcName = "connection";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QtROServerIoDevice.connection");
        return nullptr;
    }
    return QtROIoDeviceBaseWrapper::sbk_o_connection("QtROServerIoDevice", funcName, gil, pyOverride);
}

void QtROServerIoDeviceWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_customEvent("QtROServerIoDevice", funcName, gil, pyOverride, event);
}

::QString QtROServerIoDeviceWrapper::deviceType() const
{
    static const char *funcName = "deviceType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QtROServerIoDevice::deviceType();
    }
    return QtROIoDeviceBaseWrapper::sbk_o_deviceType("QtROServerIoDevice", funcName, gil, pyOverride);
}

void QtROServerIoDeviceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QtROIoDeviceBaseWrapper::sbk_o_connectNotify("QtROServerIoDevice", funcName, gil, pyOverride, signal);
}

void QtROServerIoDeviceWrapper::doClose()
{
    static const char *funcName = "doClose";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QtROServerIoDevice.doClose");
        return;
    }
    QtROIoDeviceBaseWrapper::sbk_o_close("QtROServerIoDevice", funcName, gil, pyOverride);
}

bool QtROServerIoDeviceWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QtROIoDeviceBaseWrapper::sbk_o_event("QtROServerIoDevice", funcName, gil, pyOverride, event);
}

bool QtROServerIoDeviceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QtROIoDeviceBaseWrapper::sbk_o_eventFilter("QtROServerIoDevice", funcName, gil, pyOverride, watched, event);
}

bool QtROServerIoDeviceWrapper::isOpen() const
{
    static const char *funcName = "isOpen";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QtROIoDeviceBase::isOpen();
    }
    return QtROIoDeviceBaseWrapper::sbk_o_isOpen("QtROServerIoDevice", funcName, gil, pyOverride);
}

void QtROServerIoDeviceWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QtROIoDeviceBaseWrapper::sbk_o_timerEvent("QtROServerIoDevice", funcName, gil, pyOverride, event);
}

void QtROServerIoDeviceWrapper::write(const ::QByteArray & data)
{
    static const char *funcName = "write";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QtROIoDeviceBase::write(data);
    }
    QtROIoDeviceBaseWrapper::sbk_o_write("QtROServerIoDevice", funcName, gil, pyOverride, data);
}

void QtROServerIoDeviceWrapper::write(const ::QByteArray & data, qint64 arg__2)
{
    static const char *funcName = "write";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QtROIoDeviceBase::write(data, arg__2);
    }
    QtROIoDeviceBaseWrapper::sbk_o_write("QtROServerIoDevice", funcName, gil, pyOverride, data, arg__2);
}

const QMetaObject *QtROServerIoDeviceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QtROServerIoDevice::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QtROServerIoDeviceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QtROServerIoDevice::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QtROServerIoDeviceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QtROServerIoDeviceWrapper *>(this));
    return QtROServerIoDevice::qt_metacast(_clname);
}

QtROServerIoDeviceWrapper::~QtROServerIoDeviceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QtROServerIoDevice_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerIoDevice_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QtROServerIoDevice");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QtROServerIoDevice >()))
        return -1;

    QtROServerIoDeviceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QtROServerIoDevice", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QtROServerIoDevice::QtROServerIoDevice(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QtROServerIoDevice(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QtROServerIoDevice(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerIoDevice_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerIoDevice_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerIoDevice_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QtROServerIoDevice(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QtROServerIoDeviceWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QtROServerIoDeviceWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QtROServerIoDevice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerIoDevice_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerIoDevice_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QtROServerIoDeviceFunc_deviceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtROServerIoDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerIoDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // deviceType()const
        QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QtROServerIoDevice *>(cppSelf)->::QtROServerIoDevice::deviceType()
            : const_cast<const ::QtROServerIoDevice *>(cppSelf)->deviceType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QtROServerIoDevice_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QtROServerIoDevice_methods[] = {
    {"deviceType", reinterpret_cast<PyCFunction>(Sbk_QtROServerIoDeviceFunc_deviceType), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QtROServerIoDevice_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QtROServerIoDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerIoDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QtROServerIoDeviceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QtROServerIoDevice_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QtROServerIoDevice_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QtROServerIoDevice_Type = nullptr;
static PyTypeObject *Sbk_QtROServerIoDevice_TypeF(void)
{
    return _Sbk_QtROServerIoDevice_Type;
}

static PyType_Slot Sbk_QtROServerIoDevice_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QtROServerIoDevice_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QtROServerIoDevice_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QtROServerIoDevice_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QtROServerIoDevice_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QtROServerIoDevice_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QtROServerIoDevice_spec = {
    "2:PySide6.QtRemoteObjects.QtROServerIoDevice",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QtROServerIoDevice_slots
};

} //extern "C"

static void *Sbk_QtROServerIoDevice_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QtROServerIoDevice *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QtROServerIoDevice_PythonToCpp_QtROServerIoDevice_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QtROServerIoDevice_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QtROServerIoDevice_PythonToCpp_QtROServerIoDevice_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QtROServerIoDevice_TypeF()))
        return QtROServerIoDevice_PythonToCpp_QtROServerIoDevice_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QtROServerIoDevice_PTR_CppToPython_QtROServerIoDevice(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QtROServerIoDevice *>(const_cast<void *>(cppIn)), Sbk_QtROServerIoDevice_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QtROServerIoDevice_SignatureStrings[] = {
    "PySide6.QtRemoteObjects.QtROServerIoDevice(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtRemoteObjects.QtROServerIoDevice.deviceType(self)->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t QtROServerIoDevice_SignatureByteSize = 105;
static constexpr uint8_t QtROServerIoDevice_SignatureBytes[105] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x4a, 0xcd, 0xcd,
    0x2f, 0x49, 0xf5, 0x4f, 0xca, 0x4a, 0x4d, 0x2e, 0x29, 0x06, 0xf1, 0xfd, 0x83, 0x53, 0x8b, 0xca,
    0x52, 0x8b, 0x3c, 0xf3, 0x5d, 0x52, 0xcb, 0x32, 0x93, 0x53, 0x35, 0x8a, 0x53, 0x73, 0xd2, 0x74,
    0x0a, 0x12, 0x8b, 0x52, 0xf3, 0x4a, 0xac, 0x02, 0xe0, 0xda, 0x9c, 0xf3, 0x8b, 0x52, 0xf5, 0x02,
    0x21, 0xda, 0x6c, 0xf3, 0x4a, 0x73, 0x72, 0x0a, 0x4a, 0x8a, 0x34, 0xb9, 0x02, 0x88, 0x36, 0x56,
    0x2f, 0x05, 0x4c, 0x85, 0x54, 0x16, 0x40, 0x6c, 0xd0, 0xd4, 0xb5, 0x0b, 0x0c, 0x2e, 0x29, 0xca,
    0xcc, 0x4b, 0xe7, 0x02, 0x00, 0x9c, 0x74, 0x39, 0x12
};
#endif

PyTypeObject *init_QtROServerIoDevice(PyObject *module)
{
    if (SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerIoDevice_IDX].type != nullptr)
        return SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerIoDevice_IDX].type;

    Shiboken::AutoDecRef Sbk_QtROServerIoDevice_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROIoDeviceBase_IDX]))));

    _Sbk_QtROServerIoDevice_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QtROServerIoDevice",
        "QtROServerIoDevice*",
        &Sbk_QtROServerIoDevice_spec,
        &Shiboken::callCppDestructor< QtROServerIoDevice >,
        Sbk_QtROServerIoDevice_Type_bases.object(),
        0);
    auto *pyType = Sbk_QtROServerIoDevice_TypeF(); // references _Sbk_QtROServerIoDevice_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QtROServerIoDevice_SignatureStrings);
#else
    InitSignatureBytes(pyType, QtROServerIoDevice_SignatureBytes, QtROServerIoDevice_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QtROServerIoDevice_PropertyStrings);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROServerIoDevice_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QtROServerIoDevice_PythonToCpp_QtROServerIoDevice_PTR,
        is_QtROServerIoDevice_PythonToCpp_QtROServerIoDevice_PTR_Convertible,
        QtROServerIoDevice_PTR_CppToPython_QtROServerIoDevice);

    Shiboken::Conversions::registerConverterName(converter, "QtROServerIoDevice");
    Shiboken::Conversions::registerConverterName(converter, "QtROServerIoDevice*");
    Shiboken::Conversions::registerConverterName(converter, "QtROServerIoDevice&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QtROServerIoDevice).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QtROServerIoDeviceWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QtROServerIoDevice_TypeF(), &Sbk_QtROServerIoDevice_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QtROServerIoDevice::staticMetaObject, sizeof(QtROServerIoDeviceWrapper));

    return pyType;
}
