// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSCXMLDATAMODELWRAPPER_H
#define SBK_QSCXMLDATAMODELWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtScxml/qscxmldatamodel.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QScxmlDataModelWrapper : public QScxmlDataModel
{
public:
    QScxmlDataModelWrapper(::QObject * parent = nullptr);
    QScxmlDataModelWrapper(const QScxmlDataModelWrapper &) = delete;
    QScxmlDataModelWrapper& operator=(const QScxmlDataModelWrapper &) = delete;
    QScxmlDataModelWrapper(QScxmlDataModelWrapper &&) = delete;
    QScxmlDataModelWrapper& operator=(QScxmlDataModelWrapper &&) = delete;
    ~QScxmlDataModelWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    void evaluateAssignment(int id, bool * ok) override;
    static void sbk_o_evaluateAssignment(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int id, bool * ok);
    void evaluateForeach(int id, bool * ok, ::QScxmlDataModel::ForeachLoopBody * body) override;
    static void sbk_o_evaluateForeach(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int id, bool * ok, ::QScxmlDataModel::ForeachLoopBody * body);
    void evaluateInitialization(int id, bool * ok) override;
    bool evaluateToBool(int id, bool * ok) override;
    static bool sbk_o_evaluateToBool(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int id, bool * ok);
    ::QString evaluateToString(int id, bool * ok) override;
    static ::QString sbk_o_evaluateToString(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int id, bool * ok);
    ::QVariant evaluateToVariant(int id, bool * ok) override;
    static ::QVariant sbk_o_evaluateToVariant(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int id, bool * ok);
    void evaluateToVoid(int id, bool * ok) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    bool hasScxmlProperty(const ::QString & name) const override;
    static bool sbk_o_hasScxmlProperty(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & name);
    ::QVariant scxmlProperty(const ::QString & name) const override;
    static ::QVariant sbk_o_scxmlProperty(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & name);
    void setScxmlEvent(const ::QScxmlEvent & event) override;
    static void sbk_o_setScxmlEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QScxmlEvent & event);
    bool setScxmlProperty(const ::QString & name, const ::QVariant & value, const ::QString & context) override;
    static bool sbk_o_setScxmlProperty(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & name, const ::QVariant & value, const ::QString & context);
    bool setup(const ::QMap<QString,QVariant> & initialDataValues) override;
    static bool sbk_o_setup(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QMap<QString,QVariant> & initialDataValues);
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[19] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSCXMLDATAMODELWRAPPER_H
