// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsensors_python.h"

// main header
#include "qmagnetometer_wrapper.h"

// Wrappers providing overrides
#include "qsensorreading_wrapper.h"

// Argument includes
#include <QtSensors/qmagnetometer.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QMagnetometerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QMagnetometerWrapper::QMagnetometerWrapper(::QObject * parent) : QMagnetometer(parent)
{
}

void QMagnetometerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QSensorReadingWrapper::sbk_o_childEvent("QMagnetometer", funcName, gil, pyOverride, event);
}

void QMagnetometerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QSensorReadingWrapper::sbk_o_connectNotify("QMagnetometer", funcName, gil, pyOverride, signal);
}

void QMagnetometerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QSensorReadingWrapper::sbk_o_customEvent("QMagnetometer", funcName, gil, pyOverride, event);
}

void QMagnetometerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QSensorReadingWrapper::sbk_o_connectNotify("QMagnetometer", funcName, gil, pyOverride, signal);
}

bool QMagnetometerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QSensorReadingWrapper::sbk_o_event("QMagnetometer", funcName, gil, pyOverride, event);
}

bool QMagnetometerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QSensorReadingWrapper::sbk_o_eventFilter("QMagnetometer", funcName, gil, pyOverride, watched, event);
}

void QMagnetometerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QSensorReadingWrapper::sbk_o_timerEvent("QMagnetometer", funcName, gil, pyOverride, event);
}

const QMetaObject *QMagnetometerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QMagnetometer::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QMagnetometerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QMagnetometer::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QMagnetometerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QMagnetometerWrapper *>(this));
    return QMagnetometer::qt_metacast(_clname);
}

QMagnetometerWrapper::~QMagnetometerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMagnetometer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMagnetometer >()))
        return -1;

    QMagnetometerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QMagnetometer", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMagnetometer::QMagnetometer(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QMagnetometer(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QMagnetometer(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometer_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometer_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometer_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QMagnetometer(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QMagnetometerWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QMagnetometerWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QMagnetometer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometer_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometer_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QMagnetometerFunc_reading(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMagnetometer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reading()const
        QMagnetometerReading * cppResult = const_cast<const ::QMagnetometer *>(cppSelf)->reading();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometerReading_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMagnetometerFunc_returnGeoValues(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMagnetometer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // returnGeoValues()const
        bool cppResult = const_cast<const ::QMagnetometer *>(cppSelf)->returnGeoValues();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMagnetometerFunc_setReturnGeoValues(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMagnetometer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMagnetometer::setReturnGeoValues(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setReturnGeoValues(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReturnGeoValues", errInfo, SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometer_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReturnGeoValues(bool)
            cppSelf->setReturnGeoValues(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QMagnetometer_PropertyStrings[] = {
    "returnGeoValues::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMagnetometer_methods[] = {
    {"reading", reinterpret_cast<PyCFunction>(Sbk_QMagnetometerFunc_reading), METH_NOARGS, nullptr},
    {"returnGeoValues", reinterpret_cast<PyCFunction>(Sbk_QMagnetometerFunc_returnGeoValues), METH_NOARGS, nullptr},
    {"setReturnGeoValues", reinterpret_cast<PyCFunction>(Sbk_QMagnetometerFunc_setReturnGeoValues), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QMagnetometer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QMagnetometer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometer_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QMagnetometerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QMagnetometer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMagnetometer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMagnetometer_Type = nullptr;
static PyTypeObject *Sbk_QMagnetometer_TypeF(void)
{
    return _Sbk_QMagnetometer_Type;
}

static PyType_Slot Sbk_QMagnetometer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QMagnetometer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMagnetometer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMagnetometer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMagnetometer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMagnetometer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMagnetometer_spec = {
    "2:PySide6.QtSensors.QMagnetometer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMagnetometer_slots
};

} //extern "C"

static void *Sbk_QMagnetometer_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QMagnetometer *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMagnetometer_PythonToCpp_QMagnetometer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMagnetometer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMagnetometer_PythonToCpp_QMagnetometer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMagnetometer_TypeF()))
        return QMagnetometer_PythonToCpp_QMagnetometer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMagnetometer_PTR_CppToPython_QMagnetometer(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QMagnetometer *>(const_cast<void *>(cppIn)), Sbk_QMagnetometer_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMagnetometer_SignatureStrings[] = {
    "PySide6.QtSensors.QMagnetometer(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,returnGeoValues:bool=None)",
    "PySide6.QtSensors.QMagnetometer.reading(self)->PySide6.QtSensors.QMagnetometerReading",
    "PySide6.QtSensors.QMagnetometer.returnGeoValues(self)->bool",
    "PySide6.QtSensors.QMagnetometer.setReturnGeoValues(self,returnGeoValues:bool)",
    nullptr}; // Sentinel
#else
static constexpr size_t QMagnetometer_SignatureByteSize = 155;
static constexpr uint8_t QMagnetometer_SignatureBytes[155] = {
    0x78, 0xda, 0x8d, 0x8f, 0x3d, 0x0b, 0xc2, 0x40, 0x10, 0x44, 0xfb, 0xfc, 0x12, 0x23, 0xf1, 0x4a,
    0x8b, 0x40, 0x6c, 0x2c, 0x2c, 0x44, 0xf3, 0x05, 0xf6, 0x17, 0x33, 0x86, 0xc8, 0xb9, 0x1b, 0xf6,
    0x36, 0x48, 0xfe, 0xbd, 0x18, 0x51, 0x10, 0x82, 0xb1, 0xde, 0x37, 0x33, 0x6f, 0xb3, 0xa1, 0x6c,
    0x6b, 0xac, 0x4d, 0xae, 0x25, 0xc8, 0xb3, 0x78, 0x93, 0x1f, 0x6c, 0x43, 0x50, 0xbe, 0x41, 0x21,
    0x0b, 0x0f, 0x77, 0x89, 0x3a, 0x2b, 0x20, 0x8d, 0xb3, 0x0f, 0xbb, 0x65, 0x81, 0xc9, 0xd3, 0xea,
    0x8a, 0xb3, 0x26, 0xd4, 0x3b, 0xd7, 0xa9, 0x44, 0xcb, 0x78, 0x8f, 0xe1, 0xce, 0x52, 0xa7, 0xe4,
    0x86, 0xe4, 0xc8, 0x84, 0x48, 0xa0, 0xbd, 0xd0, 0x0e, 0x7c, 0xb2, 0xae, 0x87, 0x8f, 0x2b, 0x66,
    0x37, 0x5e, 0xc2, 0x20, 0xfb, 0x3d, 0x6c, 0x04, 0xb6, 0x6e, 0xa9, 0x19, 0x05, 0xc2, 0xd5, 0x66,
    0x06, 0x2f, 0x5e, 0xf4, 0x1f, 0xad, 0x5f, 0x42, 0xef, 0xf6, 0xa7, 0xd7, 0x6c, 0xd6, 0x43, 0x8b,
    0x89, 0xf8, 0xe4, 0x93, 0x61, 0xf0, 0x00, 0x8a, 0xae, 0x80, 0x6d
};
#endif

PyTypeObject *init_QMagnetometer(PyObject *module)
{
    if (SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometer_IDX].type != nullptr)
        return SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometer_IDX].type;

    Shiboken::AutoDecRef Sbk_QMagnetometer_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]))));

    _Sbk_QMagnetometer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMagnetometer",
        "QMagnetometer*",
        &Sbk_QMagnetometer_spec,
        &Shiboken::callCppDestructor< QMagnetometer >,
        Sbk_QMagnetometer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QMagnetometer_TypeF(); // references _Sbk_QMagnetometer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMagnetometer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMagnetometer_SignatureBytes, QMagnetometer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMagnetometer_PropertyStrings);
    SbkPySide6_QtSensorsTypeStructs[SBK_QMagnetometer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMagnetometer_PythonToCpp_QMagnetometer_PTR,
        is_QMagnetometer_PythonToCpp_QMagnetometer_PTR_Convertible,
        QMagnetometer_PTR_CppToPython_QMagnetometer);

    Shiboken::Conversions::registerConverterName(converter, "QMagnetometer");
    Shiboken::Conversions::registerConverterName(converter, "QMagnetometer*");
    Shiboken::Conversions::registerConverterName(converter, "QMagnetometer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMagnetometer).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QMagnetometerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QMagnetometer_TypeF(), &Sbk_QMagnetometer_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QMagnetometer::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QMagnetometer::staticMetaObject, sizeof(QMagnetometerWrapper));

    return pyType;
}

PyTypeObject *init_QMagnetometerStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QMagnetometer");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "sensorType",
                         Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), QMagnetometer::sensorType));
    return type;
}
