// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSENSORBACKENDWRAPPER_H
#define SBK_QSENSORBACKENDWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtSensors/qsensorbackend.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QSensorBackendWrapper : public QSensorBackend
{
public:
    QSensorBackendWrapper(::QSensor * sensor, ::QObject * parent = nullptr);
    QSensorBackendWrapper(const QSensorBackendWrapper &) = delete;
    QSensorBackendWrapper& operator=(const QSensorBackendWrapper &) = delete;
    QSensorBackendWrapper(QSensorBackendWrapper &&) = delete;
    QSensorBackendWrapper& operator=(QSensorBackendWrapper &&) = delete;
    ~QSensorBackendWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    bool isFeatureSupported(::QSensor::Feature feature) const override;
    static bool sbk_o_isFeatureSupported(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSensor::Feature feature);
    void start() override;
    void stop() override;
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[10] = {false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSENSORBACKENDWRAPPER_H
