// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qcanbus_wrapper.h"

// Wrappers providing overrides
#include "qmodbusreply_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtSerialBus/qcanbus.h>
#include <QtSerialBus/qcanbusdevice.h>
#include <QtSerialBus/qcanbusdeviceinfo.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QCanBusWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QCanBusWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QModbusReplyWrapper::sbk_o_childEvent("QCanBus", funcName, gil, pyOverride, event);
}

void QCanBusWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QModbusReplyWrapper::sbk_o_connectNotify("QCanBus", funcName, gil, pyOverride, signal);
}

void QCanBusWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QModbusReplyWrapper::sbk_o_customEvent("QCanBus", funcName, gil, pyOverride, event);
}

void QCanBusWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QModbusReplyWrapper::sbk_o_connectNotify("QCanBus", funcName, gil, pyOverride, signal);
}

bool QCanBusWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QModbusReplyWrapper::sbk_o_event("QCanBus", funcName, gil, pyOverride, event);
}

bool QCanBusWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QModbusReplyWrapper::sbk_o_eventFilter("QCanBus", funcName, gil, pyOverride, watched, event);
}

void QCanBusWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QModbusReplyWrapper::sbk_o_timerEvent("QCanBus", funcName, gil, pyOverride, event);
}

const QMetaObject *QCanBusWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QCanBus::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QCanBusWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QCanBus::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QCanBusWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QCanBusWrapper *>(this));
    return QCanBus::qt_metacast(_clname);
}

QCanBusWrapper::~QCanBusWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_QCanBus_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("QCanBus");
    return -1;
}

static PyObject *Sbk_QCanBusFunc_availableDevices(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBus *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBus_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "availableDevices", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCanBus::availableDevices(QString*)const->tuple
    // 1: QCanBus::availableDevices(QString,QString*)const->tuple
    if (numArgs == 0) {
        overloadId = 0; // availableDevices(QString*)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // availableDevices(QString,QString*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "availableDevices", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBus_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // availableDevices(QString *errorMessage) const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // availableDevices(QString*)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtserialbus.cpp (qcanbus-available-devices)]
                QString errorMessage;
                const QList<QCanBusDeviceInfo> result = cppSelf->availableDevices(&errorMessage);
                pyResult = PyTuple_New(2);
                PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanBusDeviceInfo_IDX], &result));
                PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &errorMessage));
                // END of custom code block [file: ../glue/qtserialbus.cpp (qcanbus-available-devices)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // availableDevices(const QString &plugin, QString *errorMessage) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // availableDevices(QString,QString*)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtserialbus.cpp (qcanbus-available-devices-plugin)]
                QString errorMessage;
                const QList<QCanBusDeviceInfo> result = cppSelf->availableDevices(cppArg0, &errorMessage);
                pyResult = PyTuple_New(2);
                PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanBusDeviceInfo_IDX], &result));
                PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &errorMessage));
                // END of custom code block [file: ../glue/qtserialbus.cpp (qcanbus-available-devices-plugin)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCanBusFunc_createDevice(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBus *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBus_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createDevice", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCanBus::createDevice(QString,QString,QString*)const->tuple
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // createDevice(QString,QString,QString*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createDevice", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBus_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createDevice(QString,QString,QString*)const
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtserialbus.cpp (qcanbus-createdevice)]
            PyObject *pyDevice{};
            QString errorMessage;
            if (auto *device = cppSelf->createDevice(cppArg0, cppArg1, &errorMessage)) {
                pyDevice = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]), device);
                // Ownership transferences (target)
                Shiboken::Object::getOwnership(pyDevice);
            } else {
                pyDevice = Py_None;
                Py_INCREF(pyDevice);
            }
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, pyDevice);
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &errorMessage));
            // END of custom code block [file: ../glue/qtserialbus.cpp (qcanbus-createdevice)]
            // ========================================================================
            // End of code injection


            // Ownership transferences.
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCanBusFunc_instance(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // instance()
        QCanBus * cppResult = ::QCanBus::instance();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBus_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QCanBusFunc_plugins(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBus *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBus_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // plugins()const
        QStringList cppResult = const_cast<const ::QCanBus *>(cppSelf)->plugins();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QCanBus_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCanBus_methods[] = {
    {"availableDevices", reinterpret_cast<PyCFunction>(Sbk_QCanBusFunc_availableDevices), METH_VARARGS, nullptr},
    {"createDevice", reinterpret_cast<PyCFunction>(Sbk_QCanBusFunc_createDevice), METH_VARARGS, nullptr},
    {"instance", reinterpret_cast<PyCFunction>(Sbk_QCanBusFunc_instance), METH_NOARGS|METH_STATIC, nullptr},
    {"plugins", reinterpret_cast<PyCFunction>(Sbk_QCanBusFunc_plugins), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QCanBus_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QCanBus *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBus_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QCanBusWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QCanBus_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCanBus_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCanBus_Type = nullptr;
static PyTypeObject *Sbk_QCanBus_TypeF(void)
{
    return _Sbk_QCanBus_Type;
}

static PyType_Slot Sbk_QCanBus_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QCanBus_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCanBus_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCanBus_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCanBus_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCanBus_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCanBus_spec = {
    "2:PySide6.QtSerialBus.QCanBus",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCanBus_slots
};

} //extern "C"

static void *Sbk_QCanBus_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QCanBus *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCanBus_PythonToCpp_QCanBus_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCanBus_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCanBus_PythonToCpp_QCanBus_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCanBus_TypeF()))
        return QCanBus_PythonToCpp_QCanBus_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCanBus_PTR_CppToPython_QCanBus(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QCanBus *>(const_cast<void *>(cppIn)), Sbk_QCanBus_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QCanBus_SignatureStrings[] = {
    "1:PySide6.QtSerialBus.QCanBus.availableDevices(self)->tuple",
    "0:PySide6.QtSerialBus.QCanBus.availableDevices(self,plugin:QString)->tuple",
    "PySide6.QtSerialBus.QCanBus.createDevice(self,plugin:QString,interfaceName:QString)->tuple",
    "PySide6.QtSerialBus.QCanBus.instance()->PySide6.QtSerialBus.QCanBus",
    "PySide6.QtSerialBus.QCanBus.plugins(self)->QStringList",
    nullptr}; // Sentinel
#else
static constexpr size_t QCanBus_SignatureByteSize = 139;
static constexpr uint8_t QCanBus_SignatureBytes[139] = {
    0x78, 0xda, 0x95, 0xd0, 0xb1, 0x0a, 0xc2, 0x40, 0x0c, 0x06, 0xe0, 0xbd, 0x4f, 0xa2, 0x50, 0x8b,
    0x2e, 0x0e, 0x1d, 0x1c, 0xd4, 0x51, 0x8a, 0xc7, 0x3d, 0x41, 0x3c, 0xff, 0x96, 0x40, 0x0c, 0xe5,
    0x2e, 0x57, 0xf0, 0xed, 0xad, 0x58, 0x3a, 0x49, 0xa1, 0x53, 0x96, 0x3f, 0xdf, 0x1f, 0x72, 0xa8,
    0xef, 0x6f, 0xcf, 0x4f, 0x1c, 0x2b, 0x67, 0x1e, 0x91, 0x49, 0xce, 0x39, 0x55, 0xee, 0x42, 0xfa,
    0x9d, 0x34, 0x10, 0x0b, 0x3d, 0x04, 0x57, 0x0c, 0x1c, 0x90, 0x36, 0x09, 0xd2, 0x6e, 0x77, 0x27,
    0xcb, 0xbd, 0xa0, 0xd8, 0xaf, 0xdf, 0x2d, 0x7b, 0xc9, 0x1d, 0x6b, 0xed, 0xbc, 0x45, 0xd6, 0x6e,
    0xa6, 0x96, 0xa0, 0x10, 0x41, 0x36, 0x29, 0xff, 0x90, 0x92, 0xd5, 0x10, 0x5b, 0x0a, 0x68, 0xe8,
    0x85, 0x55, 0x34, 0x6b, 0x32, 0xd2, 0x91, 0x1d, 0xd3, 0x0b, 0xb9, 0x45, 0xe3, 0x77, 0xcc, 0xfc,
    0x9a, 0xa9, 0xfe, 0xc6, 0xc9, 0x8a, 0x0f, 0xcc, 0x22, 0x7d, 0x49
};
#endif

PyTypeObject *init_QCanBus(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBus_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBus_IDX].type;

    Shiboken::AutoDecRef Sbk_QCanBus_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QCanBus_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCanBus",
        "QCanBus*",
        &Sbk_QCanBus_spec,
        &Shiboken::callCppDestructor< QCanBus >,
        Sbk_QCanBus_Type_bases.object(),
        0);
    auto *pyType = Sbk_QCanBus_TypeF(); // references _Sbk_QCanBus_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QCanBus_SignatureStrings);
#else
    InitSignatureBytes(pyType, QCanBus_SignatureBytes, QCanBus_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCanBus_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBus_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCanBus_PythonToCpp_QCanBus_PTR,
        is_QCanBus_PythonToCpp_QCanBus_PTR_Convertible,
        QCanBus_PTR_CppToPython_QCanBus);

    Shiboken::Conversions::registerConverterName(converter, "QCanBus");
    Shiboken::Conversions::registerConverterName(converter, "QCanBus*");
    Shiboken::Conversions::registerConverterName(converter, "QCanBus&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCanBus).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QCanBusWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QCanBus_TypeF(), &Sbk_QCanBus_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QCanBus::staticMetaObject, sizeof(QCanBusWrapper));

    return pyType;
}
