// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qmodbusclient_wrapper.h"

// Wrappers providing overrides
#include "qmodbusdevice_wrapper.h"
#include "qmodbusreply_wrapper.h"
#include "qmodbusclient_wrapper.h"

// Argument includes
#include <QtSerialBus/qmodbusdataunit.h>
#include <QtSerialBus/qmodbuspdu.h>
#include <QtSerialBus/qmodbusreply.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QModbusClientWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QModbusClientWrapper::QModbusClientWrapper(::QObject * parent) : QModbusClient(parent)
{
}

void QModbusClientWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QModbusReplyWrapper::sbk_o_childEvent("QModbusClient", funcName, gil, pyOverride, event);
}

void QModbusClientWrapper::close()
{
    static const char *funcName = "close";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QModbusClient.close");
        return;
    }
    QModbusDeviceWrapper::sbk_o_close("QModbusClient", funcName, gil, pyOverride);
}

void QModbusClientWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QModbusReplyWrapper::sbk_o_connectNotify("QModbusClient", funcName, gil, pyOverride, signal);
}

void QModbusClientWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QModbusReplyWrapper::sbk_o_customEvent("QModbusClient", funcName, gil, pyOverride, event);
}

void QModbusClientWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QModbusReplyWrapper::sbk_o_connectNotify("QModbusClient", funcName, gil, pyOverride, signal);
}

bool QModbusClientWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QModbusReplyWrapper::sbk_o_event("QModbusClient", funcName, gil, pyOverride, event);
}

bool QModbusClientWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QModbusReplyWrapper::sbk_o_eventFilter("QModbusClient", funcName, gil, pyOverride, watched, event);
}

bool QModbusClientWrapper::open()
{
    static const char *funcName = "open";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QModbusClient.open");
        return false;
    }
    return QModbusDeviceWrapper::sbk_o_open("QModbusClient", funcName, gil, pyOverride);
}

bool QModbusClientWrapper::processPrivateResponse(const ::QModbusResponse & response, ::QModbusDataUnit * data)
{
    static const char *funcName = "processPrivateResponse";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusClient::processPrivateResponse(response, data);
    }
    return sbk_o_processPrivateResponse("QModbusClient", funcName, gil, pyOverride, response, data);
}

bool QModbusClientWrapper::sbk_o_processPrivateResponse(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModbusResponse & response, ::QModbusDataUnit * data)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), &response),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), data)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), &response),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), data)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QModbusClientWrapper::processResponse(const ::QModbusResponse & response, ::QModbusDataUnit * data)
{
    static const char *funcName = "processResponse";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QModbusClient::processResponse(response, data);
    }
    return QModbusClientWrapper::sbk_o_processPrivateResponse("QModbusClient", funcName, gil, pyOverride, response, data);
}

void QModbusClientWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QModbusReplyWrapper::sbk_o_timerEvent("QModbusClient", funcName, gil, pyOverride, event);
}

const QMetaObject *QModbusClientWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QModbusClient::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QModbusClientWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QModbusClient::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QModbusClientWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QModbusClientWrapper *>(this));
    return QModbusClient::qt_metacast(_clname);
}

QModbusClientWrapper::~QModbusClientWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QModbusClient_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QModbusClient");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QModbusClient >()))
        return -1;

    QModbusClientWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QModbusClient", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QModbusClient::QModbusClient(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QModbusClient(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QModbusClient(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QModbusClient(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QModbusClientWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QModbusClientWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QModbusClient >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QModbusClientFunc_numberOfRetries(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusClient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // numberOfRetries()const
        int cppResult = const_cast<const ::QModbusClient *>(cppSelf)->numberOfRetries();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QModbusClientFunc_processPrivateResponse(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusClient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "processPrivateResponse", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QModbusClient::processPrivateResponse(QModbusResponse,QModbusDataUnit*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), (pyArgs[1])))) {
        overloadId = 0; // processPrivateResponse(QModbusResponse,QModbusDataUnit*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "processPrivateResponse", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModbusResponse *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QModbusDataUnit *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // processPrivateResponse(QModbusResponse,QModbusDataUnit*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QModbusClient::processPrivateResponse(*cppArg0, cppArg1)
                : cppSelf->processPrivateResponse(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QModbusClientFunc_processResponse(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusClient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "processResponse", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QModbusClient::processResponse(QModbusResponse,QModbusDataUnit*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), (pyArgs[1])))) {
        overloadId = 0; // processResponse(QModbusResponse,QModbusDataUnit*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "processResponse", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModbusResponse *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QModbusDataUnit *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // processResponse(QModbusResponse,QModbusDataUnit*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QModbusClient::processResponse(*cppArg0, cppArg1)
                : cppSelf->processResponse(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QModbusClientFunc_sendRawRequest(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusClient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sendRawRequest", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QModbusClient::sendRawRequest(QModbusRequest,int)->QModbusReply*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRequest_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // sendRawRequest(QModbusRequest,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sendRawRequest", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModbusRequest *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sendRawRequest(QModbusRequest,int)
            QModbusReply * cppResult = cppSelf->sendRawRequest(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusReply_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QModbusClientFunc_sendReadRequest(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusClient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sendReadRequest", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QModbusClient::sendReadRequest(QModbusDataUnit,int)->QModbusReply*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // sendReadRequest(QModbusDataUnit,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sendReadRequest", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModbusDataUnit cppArg0_local;
        ::QModbusDataUnit *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sendReadRequest(QModbusDataUnit,int)
            QModbusReply * cppResult = cppSelf->sendReadRequest(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusReply_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QModbusClientFunc_sendReadWriteRequest(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusClient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sendReadWriteRequest", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QModbusClient::sendReadWriteRequest(QModbusDataUnit,QModbusDataUnit,int)->QModbusReply*
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // sendReadWriteRequest(QModbusDataUnit,QModbusDataUnit,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sendReadWriteRequest", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModbusDataUnit cppArg0_local;
        ::QModbusDataUnit *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QModbusDataUnit cppArg1_local;
        ::QModbusDataUnit *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sendReadWriteRequest(QModbusDataUnit,QModbusDataUnit,int)
            QModbusReply * cppResult = cppSelf->sendReadWriteRequest(*cppArg0, *cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusReply_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QModbusClientFunc_sendWriteRequest(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusClient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sendWriteRequest", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QModbusClient::sendWriteRequest(QModbusDataUnit,int)->QModbusReply*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // sendWriteRequest(QModbusDataUnit,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sendWriteRequest", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModbusDataUnit cppArg0_local;
        ::QModbusDataUnit *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sendWriteRequest(QModbusDataUnit,int)
            QModbusReply * cppResult = cppSelf->sendWriteRequest(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusReply_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QModbusClientFunc_setNumberOfRetries(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusClient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusClient::setNumberOfRetries(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setNumberOfRetries(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNumberOfRetries", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNumberOfRetries(int)
            cppSelf->setNumberOfRetries(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QModbusClientFunc_setTimeout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusClient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusClient::setTimeout(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setTimeout(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTimeout", errInfo, SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTimeout(int)
            cppSelf->setTimeout(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QModbusClientFunc_timeout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusClient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // timeout()const
        int cppResult = const_cast<const ::QModbusClient *>(cppSelf)->timeout();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QModbusClient_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QModbusClient_methods[] = {
    {"numberOfRetries", reinterpret_cast<PyCFunction>(Sbk_QModbusClientFunc_numberOfRetries), METH_NOARGS, nullptr},
    {"processPrivateResponse", reinterpret_cast<PyCFunction>(Sbk_QModbusClientFunc_processPrivateResponse), METH_VARARGS, nullptr},
    {"processResponse", reinterpret_cast<PyCFunction>(Sbk_QModbusClientFunc_processResponse), METH_VARARGS, nullptr},
    {"sendRawRequest", reinterpret_cast<PyCFunction>(Sbk_QModbusClientFunc_sendRawRequest), METH_VARARGS, nullptr},
    {"sendReadRequest", reinterpret_cast<PyCFunction>(Sbk_QModbusClientFunc_sendReadRequest), METH_VARARGS, nullptr},
    {"sendReadWriteRequest", reinterpret_cast<PyCFunction>(Sbk_QModbusClientFunc_sendReadWriteRequest), METH_VARARGS, nullptr},
    {"sendWriteRequest", reinterpret_cast<PyCFunction>(Sbk_QModbusClientFunc_sendWriteRequest), METH_VARARGS, nullptr},
    {"setNumberOfRetries", reinterpret_cast<PyCFunction>(Sbk_QModbusClientFunc_setNumberOfRetries), METH_O, nullptr},
    {"setTimeout", reinterpret_cast<PyCFunction>(Sbk_QModbusClientFunc_setTimeout), METH_O, nullptr},
    {"timeout", reinterpret_cast<PyCFunction>(Sbk_QModbusClientFunc_timeout), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QModbusClient_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QModbusClient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QModbusClientWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QModbusClient_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QModbusClient_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QModbusClient_Type = nullptr;
static PyTypeObject *Sbk_QModbusClient_TypeF(void)
{
    return _Sbk_QModbusClient_Type;
}

static PyType_Slot Sbk_QModbusClient_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QModbusClient_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QModbusClient_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QModbusClient_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QModbusClient_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QModbusClient_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QModbusClient_spec = {
    "2:PySide6.QtSerialBus.QModbusClient",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QModbusClient_slots
};

} //extern "C"

static void *Sbk_QModbusClient_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QModbusClient *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QModbusClient_PythonToCpp_QModbusClient_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QModbusClient_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QModbusClient_PythonToCpp_QModbusClient_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QModbusClient_TypeF()))
        return QModbusClient_PythonToCpp_QModbusClient_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QModbusClient_PTR_CppToPython_QModbusClient(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QModbusClient *>(const_cast<void *>(cppIn)), Sbk_QModbusClient_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QModbusClient_SignatureStrings[] = {
    "PySide6.QtSerialBus.QModbusClient(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtSerialBus.QModbusClient.numberOfRetries(self)->int",
    "PySide6.QtSerialBus.QModbusClient.processPrivateResponse(self,response:PySide6.QtSerialBus.QModbusResponse,data:PySide6.QtSerialBus.QModbusDataUnit)->bool",
    "PySide6.QtSerialBus.QModbusClient.processResponse(self,response:PySide6.QtSerialBus.QModbusResponse,data:PySide6.QtSerialBus.QModbusDataUnit)->bool",
    "PySide6.QtSerialBus.QModbusClient.sendRawRequest(self,request:PySide6.QtSerialBus.QModbusRequest,serverAddress:int)->PySide6.QtSerialBus.QModbusReply",
    "PySide6.QtSerialBus.QModbusClient.sendReadRequest(self,read:PySide6.QtSerialBus.QModbusDataUnit,serverAddress:int)->PySide6.QtSerialBus.QModbusReply",
    "PySide6.QtSerialBus.QModbusClient.sendReadWriteRequest(self,read:PySide6.QtSerialBus.QModbusDataUnit,write:PySide6.QtSerialBus.QModbusDataUnit,serverAddress:int)->PySide6.QtSerialBus.QModbusReply",
    "PySide6.QtSerialBus.QModbusClient.sendWriteRequest(self,write:PySide6.QtSerialBus.QModbusDataUnit,serverAddress:int)->PySide6.QtSerialBus.QModbusReply",
    "PySide6.QtSerialBus.QModbusClient.setNumberOfRetries(self,number:int)",
    "PySide6.QtSerialBus.QModbusClient.setTimeout(self,newTimeout:int)",
    "PySide6.QtSerialBus.QModbusClient.timeout(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QModbusClient_SignatureByteSize = 257;
static constexpr uint8_t QModbusClient_SignatureBytes[257] = {
    0x78, 0xda, 0xcd, 0x94, 0x41, 0x4b, 0x03, 0x31, 0x10, 0x85, 0xef, 0xfe, 0x12, 0x0b, 0xeb, 0x1e,
    0x3d, 0x2c, 0x28, 0x68, 0xbd, 0x6a, 0x77, 0xb7, 0x8a, 0xe7, 0x6c, 0xf3, 0x0a, 0x91, 0x34, 0x89,
    0x33, 0x93, 0x2e, 0xfd, 0xf7, 0xa6, 0xdb, 0xad, 0x88, 0xca, 0x1a, 0x04, 0xb1, 0xb7, 0x0c, 0x99,
    0xf7, 0xf2, 0x3d, 0x92, 0x4c, 0xbd, 0x5b, 0x1a, 0x8d, 0xcb, 0xb2, 0x91, 0x25, 0xc8, 0x28, 0x7b,
    0x1b, 0xb9, 0x6c, 0xee, 0xbd, 0xee, 0x22, 0xcf, 0xad, 0x81, 0x93, 0x73, 0x86, 0x5d, 0x17, 0x41,
    0x51, 0x5a, 0x57, 0xf5, 0x7b, 0xf7, 0xdc, 0x13, 0xca, 0x66, 0xd1, 0xbd, 0x60, 0x25, 0x57, 0x2e,
    0x5a, 0x1b, 0x84, 0x66, 0x67, 0xf5, 0x4f, 0x6e, 0xa5, 0x8b, 0x9b, 0x0e, 0xb4, 0x58, 0xb7, 0x10,
    0x32, 0xe0, 0xc1, 0x7d, 0x76, 0x71, 0x6d, 0x9c, 0x64, 0x88, 0x03, 0xf9, 0x15, 0x98, 0x6b, 0x32,
    0x5b, 0x25, 0x68, 0xc1, 0xc1, 0x3b, 0xc6, 0x81, 0x90, 0xc6, 0xaa, 0x9a, 0xb0, 0x39, 0x2a, 0x0a,
    0xad, 0x44, 0x4d, 0x35, 0xde, 0xa5, 0xfd, 0x27, 0x67, 0x24, 0x91, 0x75, 0xde, 0xdb, 0x7c, 0xb4,
    0x93, 0x62, 0x62, 0x38, 0xdd, 0xaa, 0xbe, 0xc5, 0x6b, 0x04, 0xcb, 0x11, 0x69, 0x28, 0xa6, 0x89,
    0x86, 0x96, 0x82, 0x41, 0x5b, 0xd0, 0x8d, 0xd6, 0x29, 0x06, 0x57, 0xe9, 0x86, 0xd2, 0xc9, 0x93,
    0xb2, 0x60, 0x77, 0xb9, 0x54, 0x50, 0xfa, 0x13, 0x96, 0xd2, 0x39, 0xe1, 0xff, 0x1a, 0xea, 0x99,
    0xcc, 0xfe, 0x61, 0xfd, 0x86, 0xac, 0xdf, 0x4b, 0xff, 0x3b, 0xc3, 0x57, 0xfe, 0x13, 0xc0, 0x92,
    0x87, 0x6f, 0x3e, 0x7d, 0x71, 0x98, 0x04, 0xc3, 0x39, 0x79, 0x2e, 0x8f, 0x66, 0x03, 0x1f, 0xc7,
    0x58, 0x0e, 0xfd, 0x58, 0xe7, 0x3a, 0xc8, 0x07, 0xf9, 0x38, 0x71, 0xde, 0x00, 0x04, 0x6a, 0xd8,
    0xf1
};
#endif

PyTypeObject *init_QModbusClient(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX].type;

    Shiboken::AutoDecRef Sbk_QModbusClient_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]))));

    _Sbk_QModbusClient_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QModbusClient",
        "QModbusClient*",
        &Sbk_QModbusClient_spec,
        &Shiboken::callCppDestructor< QModbusClient >,
        Sbk_QModbusClient_Type_bases.object(),
        0);
    auto *pyType = Sbk_QModbusClient_TypeF(); // references _Sbk_QModbusClient_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QModbusClient_SignatureStrings);
#else
    InitSignatureBytes(pyType, QModbusClient_SignatureBytes, QModbusClient_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QModbusClient_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QModbusClient_PythonToCpp_QModbusClient_PTR,
        is_QModbusClient_PythonToCpp_QModbusClient_PTR_Convertible,
        QModbusClient_PTR_CppToPython_QModbusClient);

    Shiboken::Conversions::registerConverterName(converter, "QModbusClient");
    Shiboken::Conversions::registerConverterName(converter, "QModbusClient*");
    Shiboken::Conversions::registerConverterName(converter, "QModbusClient&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QModbusClient).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QModbusClientWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QModbusClient_TypeF(), &Sbk_QModbusClient_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QModbusClient::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QModbusClient::staticMetaObject, sizeof(QModbusClientWrapper));

    return pyType;
}
