// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialport_python.h"

// main header
#include "qserialport_wrapper.h"

// Wrappers providing overrides
#include "qserialport_wrapper.h"

// Argument includes
#include <QString>
#include <QtSerialPort/qserialport.h>
#include <QtSerialPort/qserialportinfo.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSerialPortWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSerialPortWrapper::QSerialPortWrapper(::QObject * parent) : QSerialPort(parent)
{
}

QSerialPortWrapper::QSerialPortWrapper(const ::QSerialPortInfo & info, ::QObject * parent) : QSerialPort(info, parent)
{
}

QSerialPortWrapper::QSerialPortWrapper(const ::QString & name, ::QObject * parent) : QSerialPort(name, parent)
{
}

bool QSerialPortWrapper::atEnd() const
{
    static const char *funcName = "atEnd";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::atEnd();
    }
    return sbk_o_atEnd("QSerialPort", funcName, gil, pyOverride);
}

bool QSerialPortWrapper::sbk_o_atEnd(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QSerialPortWrapper::bytesAvailable() const
{
    static const char *funcName = "bytesAvailable";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSerialPort::bytesAvailable();
    }
    return sbk_o_bytesAvailable("QSerialPort", funcName, gil, pyOverride);
}

qint64 QSerialPortWrapper::sbk_o_bytesAvailable(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "qint64", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    qint64 cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QSerialPortWrapper::bytesToWrite() const
{
    static const char *funcName = "bytesToWrite";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSerialPort::bytesToWrite();
    }
    return QSerialPortWrapper::sbk_o_bytesAvailable("QSerialPort", funcName, gil, pyOverride);
}

bool QSerialPortWrapper::canReadLine() const
{
    static const char *funcName = "canReadLine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSerialPort::canReadLine();
    }
    return QSerialPortWrapper::sbk_o_atEnd("QSerialPort", funcName, gil, pyOverride);
}

void QSerialPortWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    sbk_o_childEvent("QSerialPort", funcName, gil, pyOverride, event);
}

void QSerialPortWrapper::sbk_o_childEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QChildEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QSerialPortWrapper::close()
{
    static const char *funcName = "close";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSerialPort::close();
    }
    sbk_o_close("QSerialPort", funcName, gil, pyOverride);
}

void QSerialPortWrapper::sbk_o_close(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QSerialPortWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    sbk_o_connectNotify("QSerialPort", funcName, gil, pyOverride, signal);
}

void QSerialPortWrapper::sbk_o_connectNotify(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QMetaMethod & signal)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QSerialPortWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    sbk_o_customEvent("QSerialPort", funcName, gil, pyOverride, event);
}

void QSerialPortWrapper::sbk_o_customEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QSerialPortWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QSerialPortWrapper::sbk_o_connectNotify("QSerialPort", funcName, gil, pyOverride, signal);
}

bool QSerialPortWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return sbk_o_event("QSerialPort", funcName, gil, pyOverride, event);
}

bool QSerialPortWrapper::sbk_o_event(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSerialPortWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return sbk_o_eventFilter("QSerialPort", funcName, gil, pyOverride, watched, event);
}

bool QSerialPortWrapper::sbk_o_eventFilter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * watched, ::QEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSerialPortWrapper::isSequential() const
{
    static const char *funcName = "isSequential";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSerialPort::isSequential();
    }
    return QSerialPortWrapper::sbk_o_atEnd("QSerialPort", funcName, gil, pyOverride);
}

bool QSerialPortWrapper::open(::QFlags<QIODeviceBase::OpenModeFlag> mode)
{
    static const char *funcName = "open";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSerialPort::open(mode);
    }
    return sbk_o_open("QSerialPort", funcName, gil, pyOverride, mode);
}

bool QSerialPortWrapper::sbk_o_open(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<QIODeviceBase::OpenModeFlag> mode)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, &mode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, &mode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QSerialPortWrapper::pos() const
{
    static const char *funcName = "pos";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::pos();
    }
    return QSerialPortWrapper::sbk_o_bytesAvailable("QSerialPort", funcName, gil, pyOverride);
}

qint64 QSerialPortWrapper::readData(char * data, qint64 maxSize)
{
    static const char *funcName = "readData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSerialPort::readData(data, maxSize);
    }
    return sbk_o_readData("QSerialPort", funcName, gil, pyOverride, data, maxSize);
}

qint64 QSerialPortWrapper::sbk_o_readData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, char * data, qint64 maxSize)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        maxSize
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }

    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    qint64 cppResult = 0;
    if (PyBytes_Check(pyResult.object())) {
        cppResult = PyBytes_Size(pyResult.object());
        memcpy(data, PyBytes_AsString(pyResult.object()), cppResult);
    } else if (Shiboken::String::check(pyResult.object())) {
        cppResult = Shiboken::String::len(pyResult.object());
        memcpy(data, Shiboken::String::toCString(pyResult.object()), cppResult);
    }
    // END of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    // ========================================================================
    // End of code injection

    return cppResult;
}

qint64 QSerialPortWrapper::readLineData(char * data, qint64 maxSize)
{
    static const char *funcName = "readLineData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSerialPort::readLineData(data, maxSize);
    }
    return sbk_o_readLineData("QSerialPort", funcName, gil, pyOverride, data, maxSize);
}

qint64 QSerialPortWrapper::sbk_o_readLineData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, char * data, qint64 maxSize)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        maxSize
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }

    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    qint64 cppResult = 0;
    if (PyBytes_Check(pyResult.object())) {
        cppResult = PyBytes_Size(pyResult.object());
        memcpy(data, PyBytes_AsString(pyResult.object()), cppResult);
    } else if (Shiboken::String::check(pyResult.object())) {
        cppResult = Shiboken::String::len(pyResult.object());
        memcpy(data, Shiboken::String::toCString(pyResult.object()), cppResult);
    }
    // END of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    // ========================================================================
    // End of code injection

    return cppResult;
}

bool QSerialPortWrapper::reset()
{
    static const char *funcName = "reset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::reset();
    }
    return QSerialPortWrapper::sbk_o_atEnd("QSerialPort", funcName, gil, pyOverride);
}

bool QSerialPortWrapper::seek(qint64 pos)
{
    static const char *funcName = "seek";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::seek(pos);
    }
    return sbk_o_seek("QSerialPort", funcName, gil, pyOverride, pos);
}

bool QSerialPortWrapper::sbk_o_seek(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, qint64 pos)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &pos)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        pos
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QSerialPortWrapper::size() const
{
    static const char *funcName = "size";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::size();
    }
    return QSerialPortWrapper::sbk_o_bytesAvailable("QSerialPort", funcName, gil, pyOverride);
}

qint64 QSerialPortWrapper::skipData(qint64 maxSize)
{
    static const char *funcName = "skipData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QIODevice::skipData(maxSize);
    }
    return sbk_o_skipData("QSerialPort", funcName, gil, pyOverride, maxSize);
}

qint64 QSerialPortWrapper::sbk_o_skipData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, qint64 maxSize)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &maxSize)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        maxSize
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "qint64", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    qint64 cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSerialPortWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    sbk_o_timerEvent("QSerialPort", funcName, gil, pyOverride, event);
}

void QSerialPortWrapper::sbk_o_timerEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QTimerEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

bool QSerialPortWrapper::waitForBytesWritten(int msecs)
{
    static const char *funcName = "waitForBytesWritten";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSerialPort::waitForBytesWritten(msecs);
    }
    return sbk_o_waitForBytesWritten("QSerialPort", funcName, gil, pyOverride, msecs);
}

bool QSerialPortWrapper::sbk_o_waitForBytesWritten(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int msecs)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &msecs)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        msecs
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSerialPortWrapper::waitForReadyRead(int msecs)
{
    static const char *funcName = "waitForReadyRead";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSerialPort::waitForReadyRead(msecs);
    }
    return sbk_o_waitForReadyRead("QSerialPort", funcName, gil, pyOverride, msecs);
}

bool QSerialPortWrapper::sbk_o_waitForReadyRead(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int msecs)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &msecs)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        msecs
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QSerialPortWrapper::writeData(const char * data, qint64 maxSize)
{
    static const char *funcName = "writeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSerialPort::writeData(data, maxSize);
    }
    return sbk_o_writeData("QSerialPort", funcName, gil, pyOverride, data, maxSize);
}

qint64 QSerialPortWrapper::sbk_o_writeData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const char * data, qint64 maxSize)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), data),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &maxSize)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NL)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), data),
        maxSize
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "qint64", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    qint64 cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

const QMetaObject *QSerialPortWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSerialPort::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSerialPortWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSerialPort::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSerialPortWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QSerialPortWrapper *>(this));
    return QSerialPort::qt_metacast(_clname);
}

QSerialPortWrapper::~QSerialPortWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSerialPort_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSerialPort >()))
        return -1;

    QSerialPortWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QSerialPort", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSerialPort::QSerialPort(QObject*=)
    // 1: QSerialPort::QSerialPort(QSerialPortInfo,QObject*=)
    // 2: QSerialPort::QSerialPort(QString,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QSerialPort(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QSerialPort(QSerialPortInfo,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QSerialPort(QSerialPortInfo,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSerialPort(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QSerialPort(QString,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QSerialPort(QString,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSerialPort(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSerialPort(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSerialPortWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSerialPortWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QSerialPort(const QSerialPortInfo &info, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSerialPortInfo cppArg0_local;
            ::QSerialPortInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSerialPort(QSerialPortInfo,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSerialPortWrapper(*cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSerialPortWrapper(*cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 2: // QSerialPort(const QString &name, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSerialPort(QString,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QSerialPortWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QSerialPortWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSerialPort >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QSerialPortFunc_baudRate(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "baudRate", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    if (PyArg_ParseTuple(args, "|O:baudRate", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSerialPort::baudRate(QFlags<QSerialPort::Direction>=)const->qint32
    if (numArgs == 0) {
        overloadId = 0; // baudRate(QFlags<QSerialPort::Direction>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QFlags_QSerialPort_Direction_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // baudRate(QFlags<QSerialPort::Direction>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "baudRate", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"directions", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QFlags_QSerialPort_Direction_IDX])))->flagsConverter, (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "baudRate", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);
            }
        }
        ::QFlags<QSerialPort::Direction> cppArg0(QSerialPort::Direction::AllDirections);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // baudRate(QFlags<QSerialPort::Direction>)const
            qint32 cppResult = const_cast<const ::QSerialPort *>(cppSelf)->baudRate(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_bytesAvailable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bytesAvailable()const
        qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSerialPort *>(cppSelf)->::QSerialPort::bytesAvailable()
            : const_cast<const ::QSerialPort *>(cppSelf)->bytesAvailable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_bytesToWrite(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bytesToWrite()const
        qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSerialPort *>(cppSelf)->::QSerialPort::bytesToWrite()
            : const_cast<const ::QSerialPort *>(cppSelf)->bytesToWrite();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_canReadLine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // canReadLine()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSerialPort *>(cppSelf)->::QSerialPort::canReadLine()
            : const_cast<const ::QSerialPort *>(cppSelf)->canReadLine();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_clear(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "clear", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    if (PyArg_ParseTuple(args, "|O:clear", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSerialPort::clear(QFlags<QSerialPort::Direction>=)->bool
    if (numArgs == 0) {
        overloadId = 0; // clear(QFlags<QSerialPort::Direction>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QFlags_QSerialPort_Direction_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // clear(QFlags<QSerialPort::Direction>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "clear", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"directions", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QFlags_QSerialPort_Direction_IDX])))->flagsConverter, (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "clear", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);
            }
        }
        ::QFlags<QSerialPort::Direction> cppArg0(QSerialPort::Direction::AllDirections);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // clear(QFlags<QSerialPort::Direction>)
            bool cppResult = cppSelf->clear(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_clearError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearError()
        cppSelf->clearError();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSerialPortFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSerialPort::close()
            : cppSelf->close();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSerialPortFunc_dataBits(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dataBits()const
        QSerialPort::DataBits cppResult = const_cast<const ::QSerialPort *>(cppSelf)->dataBits();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_DataBits_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QSerialPort::SerialPortError cppResult = const_cast<const ::QSerialPort *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_SerialPortError_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_flowControl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flowControl()const
        QSerialPort::FlowControl cppResult = const_cast<const ::QSerialPort *>(cppSelf)->flowControl();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_FlowControl_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_flush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flush()
        bool cppResult = cppSelf->flush();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_handle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // handle()const
        int cppResult = const_cast<const ::QSerialPort *>(cppSelf)->handle();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_isBreakEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBreakEnabled()const
        bool cppResult = const_cast<const ::QSerialPort *>(cppSelf)->isBreakEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_isDataTerminalReady(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDataTerminalReady()
        bool cppResult = cppSelf->isDataTerminalReady();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_isRequestToSend(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRequestToSend()
        bool cppResult = cppSelf->isRequestToSend();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_isSequential(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSequential()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSerialPort *>(cppSelf)->::QSerialPort::isSequential()
            : const_cast<const ::QSerialPort *>(cppSelf)->isSequential();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_open(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QIODevice::open(QFlags<QIODeviceBase::OpenModeFlag>)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // open(QFlags<QIODeviceBase::OpenModeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "open", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        ::QFlags<QIODeviceBase::OpenModeFlag> cppArg0 = QFlags<QIODeviceBase::OpenModeFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // open(QFlags<QIODeviceBase::OpenModeFlag>)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSerialPort::open(cppArg0)
                : cppSelf->open(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_parity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parity()const
        QSerialPort::Parity cppResult = const_cast<const ::QSerialPort *>(cppSelf)->parity();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_Parity_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_pinoutSignals(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pinoutSignals()
        QFlags<QSerialPort::PinoutSignal> cppResult = cppSelf->pinoutSignals();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QFlags_QSerialPort_PinoutSignal_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_portName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // portName()const
        QString cppResult = const_cast<const ::QSerialPort *>(cppSelf)->portName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_readBufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readBufferSize()const
        qint64 cppResult = const_cast<const ::QSerialPort *>(cppSelf)->readBufferSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_readData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QIODevice::readData(char*,qint64)->PyObject
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // readData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "readData", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readData(char*,qint64)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            QByteArray ba(1 + qsizetype(cppArg0), char(0));
            Py_BEGIN_ALLOW_THREADS
            (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QSerialPort::readData(ba.data(), qint64(cppArg0)) : cppSelf->readData(ba.data(), qint64(cppArg0)));
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::String::fromCString(ba.constData());
            // END of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_readLineData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QIODevice::readLineData(char*,qint64)->PyObject
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // readLineData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "readLineData", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readLineData(char*,qint64)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            QByteArray ba(1 + qsizetype(cppArg0), char(0));
            Py_BEGIN_ALLOW_THREADS
            (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QSerialPort::readLineData(ba.data(), qint64(cppArg0)) : cppSelf->readLineData(ba.data(), qint64(cppArg0)));
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::String::fromCString(ba.constData());
            // END of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_setBaudRate(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setBaudRate", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setBaudRate", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSerialPort::setBaudRate(qint32,QFlags<QSerialPort::Direction>=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setBaudRate(qint32,QFlags<QSerialPort::Direction>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QFlags_QSerialPort_Direction_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // setBaudRate(qint32,QFlags<QSerialPort::Direction>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setBaudRate", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"directions", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QFlags_QSerialPort_Direction_IDX])))->flagsConverter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setBaudRate", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);
            }
        }
        qint32 cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QSerialPort::Direction> cppArg1(QSerialPort::Direction::AllDirections);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBaudRate(qint32,QFlags<QSerialPort::Direction>)
            bool cppResult = cppSelf->setBaudRate(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_setBreakEnabled(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setBreakEnabled", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    if (PyArg_ParseTuple(args, "|O:setBreakEnabled", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSerialPort::setBreakEnabled(bool=)->bool
    if (numArgs == 0) {
        overloadId = 0; // setBreakEnabled(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // setBreakEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setBreakEnabled", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"set", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setBreakEnabled", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBreakEnabled(bool)
            bool cppResult = cppSelf->setBreakEnabled(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_setDataBits(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSerialPort::setDataBits(QSerialPort::DataBits)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_DataBits_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDataBits(QSerialPort::DataBits)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDataBits", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        ::QSerialPort::DataBits cppArg0 = static_cast< ::QSerialPort::DataBits>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDataBits(QSerialPort::DataBits)
            bool cppResult = cppSelf->setDataBits(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_setDataTerminalReady(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSerialPort::setDataTerminalReady(bool)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDataTerminalReady(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDataTerminalReady", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDataTerminalReady(bool)
            bool cppResult = cppSelf->setDataTerminalReady(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_setFlowControl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSerialPort::setFlowControl(QSerialPort::FlowControl)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_FlowControl_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFlowControl(QSerialPort::FlowControl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlowControl", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        ::QSerialPort::FlowControl cppArg0{QSerialPort::NoFlowControl};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlowControl(QSerialPort::FlowControl)
            bool cppResult = cppSelf->setFlowControl(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_setParity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSerialPort::setParity(QSerialPort::Parity)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_Parity_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setParity(QSerialPort::Parity)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setParity", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        ::QSerialPort::Parity cppArg0{QSerialPort::NoParity};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setParity(QSerialPort::Parity)
            bool cppResult = cppSelf->setParity(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_setPort(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSerialPort::setPort(QSerialPortInfo)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), (pyArg)))) {
        overloadId = 0; // setPort(QSerialPortInfo)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPort", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSerialPortInfo cppArg0_local;
        ::QSerialPortInfo *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPort(QSerialPortInfo)
            cppSelf->setPort(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSerialPortFunc_setPortName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSerialPort::setPortName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPortName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPortName", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPortName(QString)
            cppSelf->setPortName(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSerialPortFunc_setReadBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSerialPort::setReadBufferSize(qint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // setReadBufferSize(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReadBufferSize", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReadBufferSize(qint64)
            cppSelf->setReadBufferSize(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSerialPortFunc_setRequestToSend(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSerialPort::setRequestToSend(bool)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setRequestToSend(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRequestToSend", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRequestToSend(bool)
            bool cppResult = cppSelf->setRequestToSend(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_setSettingsRestoredOnClose(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSerialPort::setSettingsRestoredOnClose(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSettingsRestoredOnClose(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSettingsRestoredOnClose", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSettingsRestoredOnClose(bool)
            cppSelf->setSettingsRestoredOnClose(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSerialPortFunc_setStopBits(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSerialPort::setStopBits(QSerialPort::StopBits)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_StopBits_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setStopBits(QSerialPort::StopBits)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStopBits", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        ::QSerialPort::StopBits cppArg0 = static_cast< ::QSerialPort::StopBits>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStopBits(QSerialPort::StopBits)
            bool cppResult = cppSelf->setStopBits(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_settingsRestoredOnClose(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // settingsRestoredOnClose()const
        bool cppResult = const_cast<const ::QSerialPort *>(cppSelf)->settingsRestoredOnClose();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_stopBits(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stopBits()const
        QSerialPort::StopBits cppResult = const_cast<const ::QSerialPort *>(cppSelf)->stopBits();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_StopBits_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_waitForBytesWritten(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "waitForBytesWritten", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    if (PyArg_ParseTuple(args, "|O:waitForBytesWritten", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QIODevice::waitForBytesWritten(int=)->bool
    if (numArgs == 0) {
        overloadId = 0; // waitForBytesWritten(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // waitForBytesWritten(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "waitForBytesWritten", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"msecs", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "waitForBytesWritten", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);
            }
        }
        int cppArg0 = 30000;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForBytesWritten(int)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSerialPort::waitForBytesWritten(cppArg0)
                : cppSelf->waitForBytesWritten(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_waitForReadyRead(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "waitForReadyRead", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    if (PyArg_ParseTuple(args, "|O:waitForReadyRead", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QIODevice::waitForReadyRead(int=)->bool
    if (numArgs == 0) {
        overloadId = 0; // waitForReadyRead(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // waitForReadyRead(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "waitForReadyRead", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"msecs", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "waitForReadyRead", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);
            }
        }
        int cppArg0 = 30000;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForReadyRead(int)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSerialPort::waitForReadyRead(cppArg0)
                : cppSelf->waitForReadyRead(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSerialPortFunc_writeData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QIODevice::writeData(const char*,qint64)->qint64
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
        overloadId = 0; // writeData(const char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeData", errInfo, SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qint64 cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeData(const char*,qint64)
            qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSerialPort::writeData(cppArg0, cppArg1)
                : cppSelf->writeData(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QSerialPort_PropertyStrings[] = {
    "baudRate::",
    "breakEnabled:isBreakEnabled:",
    "dataBits::",
    "dataTerminalReady:isDataTerminalReady:",
    "error:",
    "flowControl::",
    "parity::",
    "requestToSend:isRequestToSend:",
    "settingsRestoredOnClose::",
    "stopBits::",
    nullptr // Sentinel
};

static const char *Sbk_QSerialPort_EnumFlagInfo[] = {
    "BaudRate:IntEnum",
    "DataBits:Enum",
    "Direction:Flag:Directions",
    "FlowControl:Enum",
    "Parity:Enum",
    "PinoutSignal:Flag:PinoutSignals",
    "SerialPortError:Enum",
    "StopBits:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSerialPort_methods[] = {
    {"baudRate", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_baudRate), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"bytesAvailable", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_bytesAvailable), METH_NOARGS, nullptr},
    {"bytesToWrite", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_bytesToWrite), METH_NOARGS, nullptr},
    {"canReadLine", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_canReadLine), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_clear), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"clearError", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_clearError), METH_NOARGS, nullptr},
    {"close", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_close), METH_NOARGS, nullptr},
    {"dataBits", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_dataBits), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_error), METH_NOARGS, nullptr},
    {"flowControl", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_flowControl), METH_NOARGS, nullptr},
    {"flush", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_flush), METH_NOARGS, nullptr},
    {"handle", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_handle), METH_NOARGS, nullptr},
    {"isBreakEnabled", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_isBreakEnabled), METH_NOARGS, nullptr},
    {"isDataTerminalReady", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_isDataTerminalReady), METH_NOARGS, nullptr},
    {"isRequestToSend", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_isRequestToSend), METH_NOARGS, nullptr},
    {"isSequential", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_isSequential), METH_NOARGS, nullptr},
    {"open", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_open), METH_O, nullptr},
    {"parity", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_parity), METH_NOARGS, nullptr},
    {"pinoutSignals", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_pinoutSignals), METH_NOARGS, nullptr},
    {"portName", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_portName), METH_NOARGS, nullptr},
    {"readBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_readBufferSize), METH_NOARGS, nullptr},
    {"readData", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_readData), METH_O, nullptr},
    {"readLineData", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_readLineData), METH_O, nullptr},
    {"setBaudRate", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_setBaudRate), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setBreakEnabled", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_setBreakEnabled), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setDataBits", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_setDataBits), METH_O, nullptr},
    {"setDataTerminalReady", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_setDataTerminalReady), METH_O, nullptr},
    {"setFlowControl", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_setFlowControl), METH_O, nullptr},
    {"setParity", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_setParity), METH_O, nullptr},
    {"setPort", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_setPort), METH_O, nullptr},
    {"setPortName", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_setPortName), METH_O, nullptr},
    {"setReadBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_setReadBufferSize), METH_O, nullptr},
    {"setRequestToSend", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_setRequestToSend), METH_O, nullptr},
    {"setSettingsRestoredOnClose", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_setSettingsRestoredOnClose), METH_O, nullptr},
    {"setStopBits", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_setStopBits), METH_O, nullptr},
    {"settingsRestoredOnClose", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_settingsRestoredOnClose), METH_NOARGS, nullptr},
    {"stopBits", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_stopBits), METH_NOARGS, nullptr},
    {"waitForBytesWritten", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_waitForBytesWritten), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"waitForReadyRead", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_waitForReadyRead), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"writeData", reinterpret_cast<PyCFunction>(Sbk_QSerialPortFunc_writeData), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSerialPort_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSerialPort *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSerialPortWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSerialPort_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSerialPort_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QSerialPortSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QSerialPort *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]))
        return static_cast< ::QIODevice *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_IDX]))
        return static_cast< ::QIODeviceBase *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSerialPort_Type = nullptr;
static PyTypeObject *Sbk_QSerialPort_TypeF(void)
{
    return _Sbk_QSerialPort_Type;
}

static PyType_Slot Sbk_QSerialPort_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSerialPort_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSerialPort_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSerialPort_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSerialPort_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSerialPort_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSerialPort_spec = {
    "2:PySide6.QtSerialPort.QSerialPort",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSerialPort_slots
};

} //extern "C"

static void *Sbk_QSerialPort_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSerialPort *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSerialPort_Direction(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSerialPort::Direction>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSerialPort::Direction *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSerialPort_Direction_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_Direction_IDX])))
        return Enum_PythonToCpp_QSerialPort_Direction;
    return {};
}

static PyObject *QSerialPort_Direction_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSerialPort::Direction>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSerialPort::Direction *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_Direction_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QSerialPort_Direction(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QSerialPort::Direction>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QSerialPort::Direction> *>(cppOut) = value;

}

static PyObject *QSerialPort_Direction_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QSerialPort::Direction> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_Direction_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QSerialPort_BaudRate(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSerialPort::BaudRate>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSerialPort::BaudRate *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSerialPort_BaudRate_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_BaudRate_IDX])))
        return Enum_PythonToCpp_QSerialPort_BaudRate;
    return {};
}

static PyObject *QSerialPort_BaudRate_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSerialPort::BaudRate>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSerialPort::BaudRate *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_BaudRate_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSerialPort_DataBits(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSerialPort::DataBits>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSerialPort::DataBits *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSerialPort_DataBits_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_DataBits_IDX])))
        return Enum_PythonToCpp_QSerialPort_DataBits;
    return {};
}

static PyObject *QSerialPort_DataBits_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSerialPort::DataBits>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSerialPort::DataBits *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_DataBits_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSerialPort_Parity(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSerialPort::Parity>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSerialPort::Parity *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSerialPort_Parity_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_Parity_IDX])))
        return Enum_PythonToCpp_QSerialPort_Parity;
    return {};
}

static PyObject *QSerialPort_Parity_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSerialPort::Parity>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSerialPort::Parity *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_Parity_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSerialPort_StopBits(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSerialPort::StopBits>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSerialPort::StopBits *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSerialPort_StopBits_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_StopBits_IDX])))
        return Enum_PythonToCpp_QSerialPort_StopBits;
    return {};
}

static PyObject *QSerialPort_StopBits_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSerialPort::StopBits>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSerialPort::StopBits *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_StopBits_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSerialPort_FlowControl(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSerialPort::FlowControl>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSerialPort::FlowControl *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSerialPort_FlowControl_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_FlowControl_IDX])))
        return Enum_PythonToCpp_QSerialPort_FlowControl;
    return {};
}

static PyObject *QSerialPort_FlowControl_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSerialPort::FlowControl>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSerialPort::FlowControl *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_FlowControl_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QSerialPort_PinoutSignal(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSerialPort::PinoutSignal>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSerialPort::PinoutSignal *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSerialPort_PinoutSignal_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_PinoutSignal_IDX])))
        return Enum_PythonToCpp_QSerialPort_PinoutSignal;
    return {};
}

static PyObject *QSerialPort_PinoutSignal_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSerialPort::PinoutSignal>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSerialPort::PinoutSignal *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_PinoutSignal_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QSerialPort_PinoutSignal(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QSerialPort::PinoutSignal>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QSerialPort::PinoutSignal> *>(cppOut) = value;

}

static PyObject *QSerialPort_PinoutSignal_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QSerialPort::PinoutSignal> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_PinoutSignal_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QSerialPort_SerialPortError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSerialPort::SerialPortError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSerialPort::SerialPortError *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSerialPort_SerialPortError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_SerialPortError_IDX])))
        return Enum_PythonToCpp_QSerialPort_SerialPortError;
    return {};
}

static PyObject *QSerialPort_SerialPortError_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSerialPort::SerialPortError>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSerialPort::SerialPortError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_SerialPortError_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSerialPort_PythonToCpp_QSerialPort_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSerialPort_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSerialPort_PythonToCpp_QSerialPort_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSerialPort_TypeF()))
        return QSerialPort_PythonToCpp_QSerialPort_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSerialPort_PTR_CppToPython_QSerialPort(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSerialPort *>(const_cast<void *>(cppIn)), Sbk_QSerialPort_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSerialPort_SignatureStrings[] = {
    "2:PySide6.QtSerialPort.QSerialPort(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,baudRate:qint32=None,dataBits:QSerialPort.DataBits=None,parity:QSerialPort.Parity=None,stopBits:QSerialPort.StopBits=None,flowControl:QSerialPort.FlowControl=None,dataTerminalReady:bool=None,requestToSend:bool=None,error:QSerialPort.SerialPortError=None,breakEnabled:bool=None,settingsRestoredOnClose:bool=None)",
    "1:PySide6.QtSerialPort.QSerialPort(self,info:PySide6.QtSerialPort.QSerialPortInfo,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,baudRate:qint32=None,dataBits:QSerialPort.DataBits=None,parity:QSerialPort.Parity=None,stopBits:QSerialPort.StopBits=None,flowControl:QSerialPort.FlowControl=None,dataTerminalReady:bool=None,requestToSend:bool=None,error:QSerialPort.SerialPortError=None,breakEnabled:bool=None,settingsRestoredOnClose:bool=None)",
    "0:PySide6.QtSerialPort.QSerialPort(self,name:QString,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,baudRate:qint32=None,dataBits:QSerialPort.DataBits=None,parity:QSerialPort.Parity=None,stopBits:QSerialPort.StopBits=None,flowControl:QSerialPort.FlowControl=None,dataTerminalReady:bool=None,requestToSend:bool=None,error:QSerialPort.SerialPortError=None,breakEnabled:bool=None,settingsRestoredOnClose:bool=None)",
    "PySide6.QtSerialPort.QSerialPort.baudRate(self,directions:PySide6.QtSerialPort.QSerialPort.Direction=QSerialPort.Direction.AllDirections)->qint32",
    "PySide6.QtSerialPort.QSerialPort.bytesAvailable(self)->qint64",
    "PySide6.QtSerialPort.QSerialPort.bytesToWrite(self)->qint64",
    "PySide6.QtSerialPort.QSerialPort.canReadLine(self)->bool",
    "PySide6.QtSerialPort.QSerialPort.clear(self,directions:PySide6.QtSerialPort.QSerialPort.Direction=QSerialPort.Direction.AllDirections)->bool",
    "PySide6.QtSerialPort.QSerialPort.clearError(self)",
    "PySide6.QtSerialPort.QSerialPort.close(self)",
    "PySide6.QtSerialPort.QSerialPort.dataBits(self)->PySide6.QtSerialPort.QSerialPort.DataBits",
    "PySide6.QtSerialPort.QSerialPort.error(self)->PySide6.QtSerialPort.QSerialPort.SerialPortError",
    "PySide6.QtSerialPort.QSerialPort.flowControl(self)->PySide6.QtSerialPort.QSerialPort.FlowControl",
    "PySide6.QtSerialPort.QSerialPort.flush(self)->bool",
    "PySide6.QtSerialPort.QSerialPort.handle(self)->int",
    "PySide6.QtSerialPort.QSerialPort.isBreakEnabled(self)->bool",
    "PySide6.QtSerialPort.QSerialPort.isDataTerminalReady(self)->bool",
    "PySide6.QtSerialPort.QSerialPort.isRequestToSend(self)->bool",
    "PySide6.QtSerialPort.QSerialPort.isSequential(self)->bool",
    "PySide6.QtSerialPort.QSerialPort.open(self,mode:PySide6.QtCore.QIODeviceBase.OpenModeFlag)->bool",
    "PySide6.QtSerialPort.QSerialPort.parity(self)->PySide6.QtSerialPort.QSerialPort.Parity",
    "PySide6.QtSerialPort.QSerialPort.pinoutSignals(self)->PySide6.QtSerialPort.QSerialPort.PinoutSignal",
    "PySide6.QtSerialPort.QSerialPort.portName(self)->QString",
    "PySide6.QtSerialPort.QSerialPort.readBufferSize(self)->qint64",
    "PySide6.QtSerialPort.QSerialPort.readData(self,maxSize:qint64)->PyObject",
    "PySide6.QtSerialPort.QSerialPort.readLineData(self,maxSize:qint64)->PyObject",
    "PySide6.QtSerialPort.QSerialPort.setBaudRate(self,baudRate:qint32,directions:PySide6.QtSerialPort.QSerialPort.Direction=QSerialPort.Direction.AllDirections)->bool",
    "PySide6.QtSerialPort.QSerialPort.setBreakEnabled(self,set:bool=true)->bool",
    "PySide6.QtSerialPort.QSerialPort.setDataBits(self,dataBits:PySide6.QtSerialPort.QSerialPort.DataBits)->bool",
    "PySide6.QtSerialPort.QSerialPort.setDataTerminalReady(self,set:bool)->bool",
    "PySide6.QtSerialPort.QSerialPort.setFlowControl(self,flowControl:PySide6.QtSerialPort.QSerialPort.FlowControl)->bool",
    "PySide6.QtSerialPort.QSerialPort.setParity(self,parity:PySide6.QtSerialPort.QSerialPort.Parity)->bool",
    "PySide6.QtSerialPort.QSerialPort.setPort(self,info:PySide6.QtSerialPort.QSerialPortInfo)",
    "PySide6.QtSerialPort.QSerialPort.setPortName(self,name:QString)",
    "PySide6.QtSerialPort.QSerialPort.setReadBufferSize(self,size:qint64)",
    "PySide6.QtSerialPort.QSerialPort.setRequestToSend(self,set:bool)->bool",
    "PySide6.QtSerialPort.QSerialPort.setSettingsRestoredOnClose(self,restore:bool)",
    "PySide6.QtSerialPort.QSerialPort.setStopBits(self,stopBits:PySide6.QtSerialPort.QSerialPort.StopBits)->bool",
    "PySide6.QtSerialPort.QSerialPort.settingsRestoredOnClose(self)->bool",
    "PySide6.QtSerialPort.QSerialPort.stopBits(self)->PySide6.QtSerialPort.QSerialPort.StopBits",
    "PySide6.QtSerialPort.QSerialPort.waitForBytesWritten(self,msecs:int=30000)->bool",
    "PySide6.QtSerialPort.QSerialPort.waitForReadyRead(self,msecs:int=30000)->bool",
    "PySide6.QtSerialPort.QSerialPort.writeData(self,data:char*,maxSize:qint64)->qint64",
    nullptr}; // Sentinel
#else
static constexpr size_t QSerialPort_SignatureByteSize = 709;
static constexpr uint8_t QSerialPort_SignatureBytes[709] = {
    0x78, 0xda, 0xed, 0x57, 0x4b, 0x6f, 0x1a, 0x31, 0x10, 0xbe, 0xf7, 0x97, 0x34, 0x11, 0x5d, 0xa5,
    0x49, 0x95, 0xc3, 0x4a, 0x44, 0xca, 0x42, 0x90, 0xa2, 0xb6, 0xe1, 0xb1, 0x48, 0x3d, 0x1b, 0x76,
    0x00, 0xb7, 0xc6, 0x26, 0xb6, 0x37, 0x94, 0xfe, 0xfa, 0xda, 0xd8, 0xfb, 0x24, 0xd5, 0x8e, 0xfb,
    0x88, 0x7a, 0x08, 0x87, 0x15, 0xcc, 0xce, 0xf7, 0xcd, 0xd8, 0xf3, 0xe4, 0x32, 0x9e, 0x1c, 0x52,
    0x9a, 0xc1, 0x75, 0x34, 0xd5, 0x29, 0x48, 0x4a, 0xd8, 0x44, 0x48, 0x1d, 0x4d, 0xab, 0xef, 0x6f,
    0x15, 0xb0, 0x55, 0x6f, 0x47, 0x24, 0x70, 0x5d, 0x53, 0x1e, 0x08, 0x09, 0xd1, 0x74, 0xbc, 0xf8,
    0x0a, 0x4b, 0xdd, 0xe7, 0x39, 0x63, 0x3b, 0x2d, 0x7b, 0xe7, 0xf1, 0x47, 0x38, 0xec, 0x85, 0xcc,
    0xc6, 0x9c, 0x1d, 0xfa, 0x0f, 0x82, 0x43, 0x6f, 0x41, 0xf2, 0x6c, 0x46, 0x34, 0xc4, 0x8f, 0x94,
    0xeb, 0xab, 0x4b, 0x27, 0xcc, 0x88, 0x26, 0x09, 0xd5, 0x2a, 0xae, 0xd9, 0x89, 0x86, 0x5e, 0xe8,
    0x54, 0x8c, 0x41, 0xaa, 0x0f, 0x0d, 0x85, 0xc9, 0x51, 0xe4, 0x5e, 0x2b, 0x2d, 0x76, 0x27, 0x0c,
    0xa9, 0x17, 0x3a, 0x95, 0x15, 0x13, 0xfb, 0x81, 0xe0, 0x5a, 0x0a, 0xd6, 0xd0, 0x1a, 0x55, 0xf2,
    0xca, 0x9b, 0x39, 0xc8, 0x2d, 0xe5, 0x84, 0xcd, 0x80, 0x64, 0x87, 0x78, 0x21, 0x8a, 0x77, 0x12,
    0x1e, 0x73, 0x50, 0x7a, 0x2e, 0x52, 0xe0, 0x59, 0x4d, 0x0e, 0x52, 0x0a, 0xd9, 0x34, 0x5e, 0x7e,
    0xbd, 0xb3, 0xef, 0xfc, 0xe9, 0x25, 0x90, 0x6f, 0x77, 0x9c, 0x2c, 0x18, 0xd4, 0xd1, 0x0a, 0xb4,
    0xa6, 0x7c, 0xad, 0x66, 0x86, 0xda, 0xdc, 0xa3, 0xb9, 0xae, 0x01, 0x13, 0x0a, 0x2a, 0x8d, 0xb3,
    0x37, 0xef, 0x91, 0x81, 0xa1, 0x7c, 0x25, 0x3a, 0x55, 0xef, 0x8d, 0xd2, 0x6b, 0x08, 0x5f, 0x3a,
    0x84, 0x17, 0xc8, 0x10, 0x72, 0xb2, 0x05, 0xe3, 0x87, 0x96, 0x86, 0xef, 0x35, 0x4a, 0x2f, 0x1d,
    0xa5, 0xae, 0x18, 0x45, 0xc5, 0xc5, 0xba, 0x60, 0x65, 0x54, 0x9a, 0x40, 0x50, 0xc1, 0x55, 0x67,
    0x74, 0xa3, 0x61, 0xa1, 0xdb, 0x7f, 0x56, 0x1a, 0xdd, 0x32, 0x56, 0xfe, 0x50, 0x67, 0xef, 0x6e,
    0x5c, 0xe4, 0x10, 0x1e, 0x1d, 0x34, 0xa8, 0xdb, 0x27, 0x42, 0x99, 0x3d, 0xef, 0xd1, 0x2f, 0x8f,
    0xbe, 0xfe, 0x80, 0x44, 0xcf, 0xc5, 0x17, 0x13, 0xe3, 0x60, 0xec, 0x92, 0x70, 0x1b, 0xb8, 0x4f,
    0x94, 0x97, 0x50, 0x7b, 0x95, 0x08, 0x20, 0x03, 0x22, 0xff, 0xfd, 0x0d, 0x06, 0x38, 0x73, 0x4c,
    0x1e, 0x77, 0x08, 0x0c, 0xc2, 0x64, 0x0d, 0x56, 0xb9, 0x28, 0xba, 0xe2, 0x86, 0xba, 0x4f, 0xe9,
    0x01, 0xdd, 0xd4, 0x50, 0x39, 0x8d, 0xe0, 0x6d, 0x55, 0x4a, 0x37, 0x7d, 0xad, 0x92, 0xd1, 0x46,
    0x6a, 0x55, 0x8e, 0x31, 0x90, 0xab, 0x4d, 0x58, 0xe6, 0x6c, 0x08, 0xcf, 0xaa, 0x24, 0x37, 0x79,
    0xda, 0x0d, 0xa1, 0x2a, 0xa9, 0xb5, 0x83, 0x30, 0x73, 0x54, 0x0d, 0xdb, 0x5d, 0x2a, 0x94, 0x60,
    0x56, 0x6f, 0x65, 0xa1, 0xe0, 0xd4, 0x82, 0xb9, 0x36, 0x82, 0x30, 0xa4, 0xd8, 0x01, 0x77, 0xf5,
    0xb5, 0x15, 0x19, 0x9c, 0xcc, 0x8f, 0xfb, 0xf1, 0x10, 0x9e, 0xe8, 0x12, 0x12, 0xa2, 0x20, 0x1a,
    0x1b, 0xdd, 0xcf, 0x46, 0x6b, 0xc4, 0xc8, 0x1a, 0x6d, 0xc0, 0xcd, 0x09, 0x74, 0x5a, 0xb8, 0x19,
    0x82, 0xa0, 0xa5, 0x5c, 0xe4, 0x3a, 0xa5, 0x6b, 0x73, 0xdb, 0xf8, 0x8a, 0x99, 0xd4, 0x50, 0x08,
    0x1b, 0xe6, 0xf1, 0x60, 0x86, 0x6c, 0x41, 0xef, 0x67, 0x6d, 0x37, 0xd0, 0x64, 0x51, 0x96, 0xe4,
    0xab, 0x15, 0xc8, 0x94, 0xfe, 0x08, 0x6e, 0x96, 0x16, 0x6d, 0x93, 0xc9, 0x87, 0x85, 0x7c, 0xb7,
    0x24, 0xb1, 0x43, 0x1f, 0x0f, 0xe9, 0x86, 0x3a, 0x8e, 0xc8, 0xb6, 0xdc, 0xbf, 0x42, 0x66, 0x46,
    0x62, 0xd2, 0x98, 0x68, 0xad, 0xc5, 0xe1, 0x3f, 0xe8, 0xcf, 0xd6, 0xc5, 0x76, 0x01, 0xdb, 0x51,
    0xee, 0xc6, 0xb6, 0x96, 0x39, 0x84, 0x50, 0x0d, 0xeb, 0xed, 0xb8, 0xda, 0x88, 0xd0, 0x5d, 0x39,
    0xd4, 0xd6, 0x69, 0xef, 0x28, 0x7d, 0x0f, 0xa1, 0x1a, 0xb5, 0x7a, 0x71, 0x63, 0xcd, 0x0a, 0xe9,
    0xca, 0x21, 0x46, 0x27, 0x55, 0x91, 0x17, 0x8b, 0x21, 0xb2, 0xd2, 0x83, 0xac, 0x84, 0xff, 0x7b,
    0x39, 0x43, 0x13, 0x97, 0x85, 0xde, 0xd8, 0xab, 0x71, 0xf8, 0xd9, 0x69, 0xbd, 0xf7, 0x54, 0xad,
    0xce, 0x90, 0x24, 0xed, 0xf6, 0xff, 0x5b, 0xf1, 0x4f, 0x9f, 0x5f, 0x5d, 0x1d, 0xa1, 0x74, 0x42,
    0x47, 0x8a, 0xa3, 0xf3, 0x2b, 0xbb, 0x77, 0xa8, 0xd8, 0xea, 0xbb, 0x77, 0x08, 0xaf, 0x19, 0xe2,
    0xfa, 0x2f, 0xfd, 0xc6, 0x93, 0xd4, 0xbd, 0x45, 0xad, 0x3a, 0x1e, 0xd0, 0x4d, 0xbd, 0x27, 0x54,
    0x8f, 0x84, 0x4c, 0xec, 0x16, 0x6c, 0x77, 0x60, 0x5d, 0xce, 0x4d, 0x05, 0x4b, 0x15, 0x9b, 0x40,
    0xf7, 0xaf, 0x2e, 0xcc, 0x07, 0xed, 0xab, 0x27, 0x3c, 0x96, 0xbb, 0x7d, 0xfc, 0x21, 0x9b, 0x5d,
    0xcb, 0xab, 0x46, 0x6f, 0xdb, 0x55, 0xbc, 0xdc, 0x10, 0x79, 0x7e, 0xda, 0xf3, 0xfd, 0x1c, 0xfa,
    0x09, 0xc1, 0xf2, 0x8c, 0x21
};
#endif

PyTypeObject *init_QSerialPort(PyObject *module)
{
    if (SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX].type != nullptr)
        return SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX].type;

    Shiboken::AutoDecRef Sbk_QSerialPort_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]))));

    _Sbk_QSerialPort_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSerialPort",
        "QSerialPort*",
        &Sbk_QSerialPort_spec,
        &Shiboken::callCppDestructor< QSerialPort >,
        Sbk_QSerialPort_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSerialPort_TypeF(); // references _Sbk_QSerialPort_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSerialPort_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSerialPort_SignatureBytes, QSerialPort_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSerialPort_PropertyStrings);
    SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSerialPort_PythonToCpp_QSerialPort_PTR,
        is_QSerialPort_PythonToCpp_QSerialPort_PTR_Convertible,
        QSerialPort_PTR_CppToPython_QSerialPort);

    Shiboken::Conversions::registerConverterName(converter, "QSerialPort");
    Shiboken::Conversions::registerConverterName(converter, "QSerialPort*");
    Shiboken::Conversions::registerConverterName(converter, "QSerialPort&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSerialPort).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSerialPortWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QSerialPort_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QSerialPort_TypeF(), &Sbk_QSerialPortSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSerialPort_TypeF(), &Sbk_QSerialPort_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSerialPort_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Direction'.
    const char *Direction_Initializer[] = {
        "Input",
        "Output",
        "AllDirections",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Direction_InitializerValues[] = {
        uint8_t(QSerialPort::Direction::Input),        //  0x01  1
        uint8_t(QSerialPort::Direction::Output),       //  0x02  2
        uint8_t(QSerialPort::Direction::AllDirections) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSerialPort_TypeF(),
        "2:PySide6.QtSerialPort.QSerialPort.Direction",
        Direction_Initializer, Direction_InitializerValues);
    SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_Direction_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtSerialPortTypeStructs[SBK_QFlags_QSerialPort_Direction_IDX].type =
        EType;
    // Register converter for enum 'QSerialPort::Direction'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSerialPort_Direction_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSerialPort_Direction,
            is_Enum_PythonToCpp_QSerialPort_Direction_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSerialPort::Direction");
        Shiboken::Conversions::registerConverterAlias(converter, "Direction");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QSerialPort_Direction_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QSerialPort_Direction,
            is_Enum_PythonToCpp_QSerialPort_Direction_Convertible);
        // Register converter for flag 'QFlags<QSerialPort::Direction>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QSerialPort::Direction>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QSerialPort::Directions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Direction' enum/flags.

    // Initialization of enum 'BaudRate'.
    const char *BaudRate_Initializer[] = {
        "Baud1200",
        "Baud2400",
        "Baud4800",
        "Baud9600",
        "Baud19200",
        "Baud38400",
        "Baud57600",
        "Baud115200",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t BaudRate_InitializerValues[] = {
        uint32_t(QSerialPort::BaudRate::Baud1200),  //  0x000004b0  1200
        uint32_t(QSerialPort::BaudRate::Baud2400),  //  0x00000960  2400
        uint32_t(QSerialPort::BaudRate::Baud4800),  //  0x000012c0  4800
        uint32_t(QSerialPort::BaudRate::Baud9600),  //  0x00002580  9600
        uint32_t(QSerialPort::BaudRate::Baud19200), //  0x00004b00  19200
        uint32_t(QSerialPort::BaudRate::Baud38400), //  0x00009600  38400
        uint32_t(QSerialPort::BaudRate::Baud57600), //  0x0000e100  57600
        uint32_t(QSerialPort::BaudRate::Baud115200) //  0x0001c200  115200
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSerialPort_TypeF(),
        "2:PySide6.QtSerialPort.QSerialPort.BaudRate",
        BaudRate_Initializer, BaudRate_InitializerValues);
    SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_BaudRate_IDX].type = EType;
    // Register converter for enum 'QSerialPort::BaudRate'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSerialPort_BaudRate_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSerialPort_BaudRate,
            is_Enum_PythonToCpp_QSerialPort_BaudRate_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSerialPort::BaudRate");
        Shiboken::Conversions::registerConverterAlias(converter, "BaudRate");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'BaudRate' enum.

    // Initialization of enum 'DataBits'.
    const char *DataBits_Initializer[] = {
        "Data5",
        "Data6",
        "Data7",
        "Data8",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DataBits_InitializerValues[] = {
        uint8_t(QSerialPort::DataBits::Data5), //  0x05  5
        uint8_t(QSerialPort::DataBits::Data6), //  0x06  6
        uint8_t(QSerialPort::DataBits::Data7), //  0x07  7
        uint8_t(QSerialPort::DataBits::Data8)  //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSerialPort_TypeF(),
        "2:PySide6.QtSerialPort.QSerialPort.DataBits",
        DataBits_Initializer, DataBits_InitializerValues);
    SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_DataBits_IDX].type = EType;
    // Register converter for enum 'QSerialPort::DataBits'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSerialPort_DataBits_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSerialPort_DataBits,
            is_Enum_PythonToCpp_QSerialPort_DataBits_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSerialPort::DataBits");
        Shiboken::Conversions::registerConverterAlias(converter, "DataBits");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DataBits' enum.

    // Initialization of enum 'Parity'.
    const char *Parity_Initializer[] = {
        "NoParity",
        "EvenParity",
        "OddParity",
        "SpaceParity",
        "MarkParity",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Parity_InitializerValues[] = {
        uint8_t(QSerialPort::Parity::NoParity),    //  0x00  0
        uint8_t(QSerialPort::Parity::EvenParity),  //  0x02  2
        uint8_t(QSerialPort::Parity::OddParity),   //  0x03  3
        uint8_t(QSerialPort::Parity::SpaceParity), //  0x04  4
        uint8_t(QSerialPort::Parity::MarkParity)   //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSerialPort_TypeF(),
        "2:PySide6.QtSerialPort.QSerialPort.Parity",
        Parity_Initializer, Parity_InitializerValues);
    SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_Parity_IDX].type = EType;
    // Register converter for enum 'QSerialPort::Parity'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSerialPort_Parity_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSerialPort_Parity,
            is_Enum_PythonToCpp_QSerialPort_Parity_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSerialPort::Parity");
        Shiboken::Conversions::registerConverterAlias(converter, "Parity");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Parity' enum.

    // Initialization of enum 'StopBits'.
    const char *StopBits_Initializer[] = {
        "OneStop",
        "OneAndHalfStop",
        "TwoStop",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StopBits_InitializerValues[] = {
        uint8_t(QSerialPort::StopBits::OneStop),        //  0x01  1
        uint8_t(QSerialPort::StopBits::OneAndHalfStop), //  0x03  3
        uint8_t(QSerialPort::StopBits::TwoStop)         //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSerialPort_TypeF(),
        "2:PySide6.QtSerialPort.QSerialPort.StopBits",
        StopBits_Initializer, StopBits_InitializerValues);
    SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_StopBits_IDX].type = EType;
    // Register converter for enum 'QSerialPort::StopBits'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSerialPort_StopBits_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSerialPort_StopBits,
            is_Enum_PythonToCpp_QSerialPort_StopBits_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSerialPort::StopBits");
        Shiboken::Conversions::registerConverterAlias(converter, "StopBits");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StopBits' enum.

    // Initialization of enum 'FlowControl'.
    const char *FlowControl_Initializer[] = {
        "NoFlowControl",
        "HardwareControl",
        "SoftwareControl",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FlowControl_InitializerValues[] = {
        uint8_t(QSerialPort::FlowControl::NoFlowControl),   //  0x00  0
        uint8_t(QSerialPort::FlowControl::HardwareControl), //  0x01  1
        uint8_t(QSerialPort::FlowControl::SoftwareControl)  //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSerialPort_TypeF(),
        "2:PySide6.QtSerialPort.QSerialPort.FlowControl",
        FlowControl_Initializer, FlowControl_InitializerValues);
    SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_FlowControl_IDX].type = EType;
    // Register converter for enum 'QSerialPort::FlowControl'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSerialPort_FlowControl_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSerialPort_FlowControl,
            is_Enum_PythonToCpp_QSerialPort_FlowControl_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSerialPort::FlowControl");
        Shiboken::Conversions::registerConverterAlias(converter, "FlowControl");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FlowControl' enum.

    // Initialization of enum 'PinoutSignal'.
    const char *PinoutSignal_Initializer[] = {
        "NoSignal",
        "DataTerminalReadySignal",
        "DataCarrierDetectSignal",
        "DataSetReadySignal",
        "RingIndicatorSignal",
        "RequestToSendSignal",
        "ClearToSendSignal",
        "SecondaryTransmittedDataSignal",
        "SecondaryReceivedDataSignal",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t PinoutSignal_InitializerValues[] = {
        uint16_t(QSerialPort::PinoutSignal::NoSignal),                       //  0x0000  0
        uint16_t(QSerialPort::PinoutSignal::DataTerminalReadySignal),        //  0x0004  4
        uint16_t(QSerialPort::PinoutSignal::DataCarrierDetectSignal),        //  0x0008  8
        uint16_t(QSerialPort::PinoutSignal::DataSetReadySignal),             //  0x0010  16
        uint16_t(QSerialPort::PinoutSignal::RingIndicatorSignal),            //  0x0020  32
        uint16_t(QSerialPort::PinoutSignal::RequestToSendSignal),            //  0x0040  64
        uint16_t(QSerialPort::PinoutSignal::ClearToSendSignal),              //  0x0080  128
        uint16_t(QSerialPort::PinoutSignal::SecondaryTransmittedDataSignal), //  0x0100  256
        uint16_t(QSerialPort::PinoutSignal::SecondaryReceivedDataSignal)     //  0x0200  512
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSerialPort_TypeF(),
        "2:PySide6.QtSerialPort.QSerialPort.PinoutSignal",
        PinoutSignal_Initializer, PinoutSignal_InitializerValues);
    SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_PinoutSignal_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtSerialPortTypeStructs[SBK_QFlags_QSerialPort_PinoutSignal_IDX].type =
        EType;
    // Register converter for enum 'QSerialPort::PinoutSignal'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSerialPort_PinoutSignal_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSerialPort_PinoutSignal,
            is_Enum_PythonToCpp_QSerialPort_PinoutSignal_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSerialPort::PinoutSignal");
        Shiboken::Conversions::registerConverterAlias(converter, "PinoutSignal");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QSerialPort_PinoutSignal_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QSerialPort_PinoutSignal,
            is_Enum_PythonToCpp_QSerialPort_PinoutSignal_Convertible);
        // Register converter for flag 'QFlags<QSerialPort::PinoutSignal>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QSerialPort::PinoutSignal>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QSerialPort::PinoutSignals");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'PinoutSignal' enum/flags.

    // Initialization of enum 'SerialPortError'.
    const char *SerialPortError_Initializer[] = {
        "NoError",
        "DeviceNotFoundError",
        "PermissionError",
        "OpenError",
        "WriteError",
        "ReadError",
        "ResourceError",
        "UnsupportedOperationError",
        "UnknownError",
        "TimeoutError",
        "NotOpenError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SerialPortError_InitializerValues[] = {
        uint8_t(QSerialPort::SerialPortError::NoError),                   //  0x00  0
        uint8_t(QSerialPort::SerialPortError::DeviceNotFoundError),       //  0x01  1
        uint8_t(QSerialPort::SerialPortError::PermissionError),           //  0x02  2
        uint8_t(QSerialPort::SerialPortError::OpenError),                 //  0x03  3
        uint8_t(QSerialPort::SerialPortError::WriteError),                //  0x04  4
        uint8_t(QSerialPort::SerialPortError::ReadError),                 //  0x05  5
        uint8_t(QSerialPort::SerialPortError::ResourceError),             //  0x06  6
        uint8_t(QSerialPort::SerialPortError::UnsupportedOperationError), //  0x07  7
        uint8_t(QSerialPort::SerialPortError::UnknownError),              //  0x08  8
        uint8_t(QSerialPort::SerialPortError::TimeoutError),              //  0x09  9
        uint8_t(QSerialPort::SerialPortError::NotOpenError)               //  0x0a  10
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSerialPort_TypeF(),
        "2:PySide6.QtSerialPort.QSerialPort.SerialPortError",
        SerialPortError_Initializer, SerialPortError_InitializerValues);
    SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_SerialPortError_IDX].type = EType;
    // Register converter for enum 'QSerialPort::SerialPortError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSerialPort_SerialPortError_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSerialPort_SerialPortError,
            is_Enum_PythonToCpp_QSerialPort_SerialPortError_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSerialPort::SerialPortError");
        Shiboken::Conversions::registerConverterAlias(converter, "SerialPortError");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SerialPortError' enum.

    PySide::Signal::registerSignals(pyType, &::QSerialPort::staticMetaObject);
    qRegisterMetaType< ::QSerialPort::Direction >("QSerialPort::Direction");
    qRegisterMetaType< ::QSerialPort::BaudRate >("QSerialPort::BaudRate");
    qRegisterMetaType< ::QSerialPort::DataBits >("QSerialPort::DataBits");
    qRegisterMetaType< ::QSerialPort::Parity >("QSerialPort::Parity");
    qRegisterMetaType< ::QSerialPort::StopBits >("QSerialPort::StopBits");
    qRegisterMetaType< ::QSerialPort::FlowControl >("QSerialPort::FlowControl");
    qRegisterMetaType< ::QSerialPort::PinoutSignal >("QSerialPort::PinoutSignal");
    qRegisterMetaType< ::QSerialPort::SerialPortError >("QSerialPort::SerialPortError");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSerialPort::staticMetaObject, sizeof(QSerialPortWrapper));

    return pyType;
}
