// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSQLRELATIONALDELEGATEWRAPPER_H
#define SBK_QSQLRELATIONALDELEGATEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtSql/qsqlrelationaldelegate.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QSqlRelationalDelegateWrapper : public QSqlRelationalDelegate
{
public:
    QSqlRelationalDelegateWrapper(::QObject * aParent = nullptr);
    QSqlRelationalDelegateWrapper(const QSqlRelationalDelegateWrapper &) = delete;
    QSqlRelationalDelegateWrapper& operator=(const QSqlRelationalDelegateWrapper &) = delete;
    QSqlRelationalDelegateWrapper(QSqlRelationalDelegateWrapper &&) = delete;
    QSqlRelationalDelegateWrapper& operator=(QSqlRelationalDelegateWrapper &&) = delete;
    ~QSqlRelationalDelegateWrapper() override;

    void childEvent(::QChildEvent * event) override;
    static void sbk_o_childEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QChildEvent * event);
    void connectNotify(const ::QMetaMethod & signal) override;
    static void sbk_o_connectNotify(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QMetaMethod & signal);
    ::QWidget * createEditor(::QWidget * aParent, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) const override;
    static ::QWidget * sbk_o_createEditor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * aParent, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);
    void customEvent(::QEvent * event) override;
    static void sbk_o_customEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    void destroyEditor(::QWidget * editor, const ::QModelIndex & index) const override;
    static void sbk_o_destroyEditor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * editor, const ::QModelIndex & index);
    void disconnectNotify(const ::QMetaMethod & signal) override;
    ::QString displayText(const ::QVariant & value, const ::QLocale & locale) const override;
    static ::QString sbk_o_displayText(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QVariant & value, const ::QLocale & locale);
    bool editorEvent(::QEvent * event, ::QAbstractItemModel * model, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) override;
    static bool sbk_o_editorEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event, ::QAbstractItemModel * model, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);
    bool event(::QEvent * event) override;
    static bool sbk_o_event(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    bool eventFilter(::QObject * object, ::QEvent * event) override;
    static bool sbk_o_eventFilter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * object, ::QEvent * event);
    bool helpEvent(::QHelpEvent * event, ::QAbstractItemView * view, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) override;
    static bool sbk_o_helpEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QHelpEvent * event, ::QAbstractItemView * view, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);
    void initStyleOption(::QStyleOptionViewItem * option, const ::QModelIndex & index) const override;
    static void sbk_o_initStyleOption(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyleOptionViewItem * option, const ::QModelIndex & index);
    void paint(::QPainter * painter, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) const override;
    static void sbk_o_paint(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);
    ::QList<int> paintingRoles() const override;
    static ::QList<int> sbk_o_paintingRoles(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void setEditorData(::QWidget * editor, const ::QModelIndex & index) const override;
    static void sbk_o_setEditorData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * editor, const ::QModelIndex & index);
    void setModelData(::QWidget * editor, ::QAbstractItemModel * model, const ::QModelIndex & index) const override;
    static void sbk_o_setModelData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * editor, ::QAbstractItemModel * model, const ::QModelIndex & index);
    ::QSize sizeHint(const ::QStyleOptionViewItem & option, const ::QModelIndex & index) const override;
    static ::QSize sbk_o_sizeHint(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);
    void timerEvent(::QTimerEvent * event) override;
    static void sbk_o_timerEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QTimerEvent * event);
    void updateEditorGeometry(::QWidget * editor, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) const override;
    static void sbk_o_updateEditorGeometry(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * editor, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[19] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSQLRELATIONALDELEGATEWRAPPER_H
