// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsql_python.h"

// main header
#include "qsqlrelationaltablemodel_wrapper.h"

// Wrappers providing overrides
#include "qsqltablemodel_wrapper.h"
#include "qsqlrelationaldelegate_wrapper.h"
#include "qsqlresult_wrapper.h"
#include "qsqldriver_wrapper.h"
#include "qsqlquerymodel_wrapper.h"

// Extra includes
#include <QSize>
#include <QStringList>

// Argument includes
#include <QHash>
#include <QList>
#include <QMap>
#include <QString>
#include <QStringList>
#include <QtSql/qsqldatabase.h>
#include <QtSql/qsqlrecord.h>
#include <QtSql/qsqlrelationaltablemodel.h>
#include <QtSql/qsqltablemodel.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qmimedata.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSqlRelationalTableModelWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSqlRelationalTableModelWrapper::QSqlRelationalTableModelWrapper(::QObject * parent, const ::QSqlDatabase & db) : QSqlRelationalTableModel(parent, db)
{
}

::QModelIndex QSqlRelationalTableModelWrapper::buddy(const ::QModelIndex & index) const
{
    static const char *funcName = "buddy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::buddy(index);
    }
    return QSqlQueryModelWrapper::sbk_o_buddy("QSqlRelationalTableModel", funcName, gil, pyOverride, index);
}

bool QSqlRelationalTableModelWrapper::canDropMimeData(const ::QMimeData * data, ::Qt::DropAction action, int row, int column, const ::QModelIndex & parent) const
{
    static const char *funcName = "canDropMimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::canDropMimeData(data, action, row, column, parent);
    }
    return QSqlQueryModelWrapper::sbk_o_canDropMimeData("QSqlRelationalTableModel", funcName, gil, pyOverride, data, action, row, column, parent);
}

bool QSqlRelationalTableModelWrapper::canFetchMore(const ::QModelIndex & parent) const
{
    static const char *funcName = "canFetchMore";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlQueryModel::canFetchMore(parent);
    }
    return QSqlQueryModelWrapper::sbk_o_canFetchMore("QSqlRelationalTableModel", funcName, gil, pyOverride, parent);
}

void QSqlRelationalTableModelWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QSqlRelationalDelegateWrapper::sbk_o_childEvent("QSqlRelationalTableModel", funcName, gil, pyOverride, event);
}

void QSqlRelationalTableModelWrapper::clear()
{
    static const char *funcName = "clear";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlRelationalTableModel::clear();
    }
    QSqlResultWrapper::sbk_o_detachFromResultSet("QSqlRelationalTableModel", funcName, gil, pyOverride);
}

bool QSqlRelationalTableModelWrapper::clearItemData(const ::QModelIndex & index)
{
    static const char *funcName = "clearItemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::clearItemData(index);
    }
    return QSqlQueryModelWrapper::sbk_o_canFetchMore("QSqlRelationalTableModel", funcName, gil, pyOverride, index);
}

int QSqlRelationalTableModelWrapper::columnCount(const ::QModelIndex & parent) const
{
    static const char *funcName = "columnCount";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlQueryModel::columnCount(parent);
    }
    return QSqlQueryModelWrapper::sbk_o_columnCount("QSqlRelationalTableModel", funcName, gil, pyOverride, parent);
}

void QSqlRelationalTableModelWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QSqlRelationalDelegateWrapper::sbk_o_connectNotify("QSqlRelationalTableModel", funcName, gil, pyOverride, signal);
}

void QSqlRelationalTableModelWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QSqlRelationalDelegateWrapper::sbk_o_customEvent("QSqlRelationalTableModel", funcName, gil, pyOverride, event);
}

::QVariant QSqlRelationalTableModelWrapper::data(const ::QModelIndex & item, int role) const
{
    static const char *funcName = "data";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlRelationalTableModel::data(item, role);
    }
    return QSqlQueryModelWrapper::sbk_o_data("QSqlRelationalTableModel", funcName, gil, pyOverride, item, role);
}

bool QSqlRelationalTableModelWrapper::deleteRowFromTable(int row)
{
    static const char *funcName = "deleteRowFromTable";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::deleteRowFromTable(row);
    }
    return QSqlResultWrapper::sbk_o_isNull("QSqlRelationalTableModel", funcName, gil, pyOverride, row);
}

void QSqlRelationalTableModelWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QSqlRelationalDelegateWrapper::sbk_o_connectNotify("QSqlRelationalTableModel", funcName, gil, pyOverride, signal);
}

bool QSqlRelationalTableModelWrapper::dropMimeData(const ::QMimeData * data, ::Qt::DropAction action, int row, int column, const ::QModelIndex & parent)
{
    static const char *funcName = "dropMimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractTableModel::dropMimeData(data, action, row, column, parent);
    }
    return QSqlQueryModelWrapper::sbk_o_canDropMimeData("QSqlRelationalTableModel", funcName, gil, pyOverride, data, action, row, column, parent);
}

bool QSqlRelationalTableModelWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QSqlRelationalDelegateWrapper::sbk_o_event("QSqlRelationalTableModel", funcName, gil, pyOverride, event);
}

bool QSqlRelationalTableModelWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QSqlRelationalDelegateWrapper::sbk_o_eventFilter("QSqlRelationalTableModel", funcName, gil, pyOverride, watched, event);
}

void QSqlRelationalTableModelWrapper::fetchMore(const ::QModelIndex & parent)
{
    static const char *funcName = "fetchMore";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlQueryModel::fetchMore(parent);
    }
    QSqlQueryModelWrapper::sbk_o_fetchMore("QSqlRelationalTableModel", funcName, gil, pyOverride, parent);
}

::QFlags<Qt::ItemFlag> QSqlRelationalTableModelWrapper::flags(const ::QModelIndex & index) const
{
    static const char *funcName = "flags";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::flags(index);
    }
    return QSqlQueryModelWrapper::sbk_o_flags("QSqlRelationalTableModel", funcName, gil, pyOverride, index);
}

::QVariant QSqlRelationalTableModelWrapper::headerData(int section, ::Qt::Orientation orientation, int role) const
{
    static const char *funcName = "headerData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::headerData(section, orientation, role);
    }
    return QSqlQueryModelWrapper::sbk_o_headerData("QSqlRelationalTableModel", funcName, gil, pyOverride, section, orientation, role);
}

::QModelIndex QSqlRelationalTableModelWrapper::index(int row, int column, const ::QModelIndex & parent) const
{
    static const char *funcName = "index";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractTableModel::index(row, column, parent);
    }
    return QSqlQueryModelWrapper::sbk_o_index("QSqlRelationalTableModel", funcName, gil, pyOverride, row, column, parent);
}

::QModelIndex QSqlRelationalTableModelWrapper::indexInQuery(const ::QModelIndex & item) const
{
    static const char *funcName = "indexInQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::indexInQuery(item);
    }
    return QSqlQueryModelWrapper::sbk_o_buddy("QSqlRelationalTableModel", funcName, gil, pyOverride, item);
}

bool QSqlRelationalTableModelWrapper::insertColumns(int column, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "insertColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlQueryModel::insertColumns(column, count, parent);
    }
    return QSqlQueryModelWrapper::sbk_o_insertColumns("QSqlRelationalTableModel", funcName, gil, pyOverride, column, count, parent);
}

bool QSqlRelationalTableModelWrapper::insertRowIntoTable(const ::QSqlRecord & values)
{
    static const char *funcName = "insertRowIntoTable";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlRelationalTableModel::insertRowIntoTable(values);
    }
    return QSqlTableModelWrapper::sbk_o_insertRowIntoTable("QSqlRelationalTableModel", funcName, gil, pyOverride, values);
}

bool QSqlRelationalTableModelWrapper::insertRows(int row, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "insertRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::insertRows(row, count, parent);
    }
    return QSqlQueryModelWrapper::sbk_o_insertColumns("QSqlRelationalTableModel", funcName, gil, pyOverride, row, count, parent);
}

::QMap<int,QVariant> QSqlRelationalTableModelWrapper::itemData(const ::QModelIndex & index) const
{
    static const char *funcName = "itemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::itemData(index);
    }
    return QSqlQueryModelWrapper::sbk_o_itemData("QSqlRelationalTableModel", funcName, gil, pyOverride, index);
}

::QList<QModelIndex> QSqlRelationalTableModelWrapper::match(const ::QModelIndex & start, int role, const ::QVariant & value, int hits, ::QFlags<Qt::MatchFlag> flags) const
{
    static const char *funcName = "match";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::match(start, role, value, hits, flags);
    }
    return QSqlQueryModelWrapper::sbk_o_match("QSqlRelationalTableModel", funcName, gil, pyOverride, start, role, value, hits, flags);
}

::QMimeData * QSqlRelationalTableModelWrapper::mimeData(const ::QList<QModelIndex> & indexes) const
{
    static const char *funcName = "mimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::mimeData(indexes);
    }
    return QSqlQueryModelWrapper::sbk_o_mimeData("QSqlRelationalTableModel", funcName, gil, pyOverride, indexes);
}

::QStringList QSqlRelationalTableModelWrapper::mimeTypes() const
{
    static const char *funcName = "mimeTypes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::mimeTypes();
    }
    return QSqlDriverWrapper::sbk_o_subscribedToNotifications("QSqlRelationalTableModel", funcName, gil, pyOverride);
}

bool QSqlRelationalTableModelWrapper::moveColumns(const ::QModelIndex & sourceParent, int sourceColumn, int count, const ::QModelIndex & destinationParent, int destinationChild)
{
    static const char *funcName = "moveColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::moveColumns(sourceParent, sourceColumn, count, destinationParent, destinationChild);
    }
    return QSqlQueryModelWrapper::sbk_o_moveColumns("QSqlRelationalTableModel", funcName, gil, pyOverride, sourceParent, sourceColumn, count, destinationParent, destinationChild);
}

bool QSqlRelationalTableModelWrapper::moveRows(const ::QModelIndex & sourceParent, int sourceRow, int count, const ::QModelIndex & destinationParent, int destinationChild)
{
    static const char *funcName = "moveRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::moveRows(sourceParent, sourceRow, count, destinationParent, destinationChild);
    }
    return QSqlQueryModelWrapper::sbk_o_moveColumns("QSqlRelationalTableModel", funcName, gil, pyOverride, sourceParent, sourceRow, count, destinationParent, destinationChild);
}

void QSqlRelationalTableModelWrapper::multiData(const ::QModelIndex & index, ::QModelRoleDataSpan roleDataSpan) const
{
    static const char *funcName = "multiData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::multiData(index, roleDataSpan);
    }
    QSqlQueryModelWrapper::sbk_o_multiData("QSqlRelationalTableModel", funcName, gil, pyOverride, index, roleDataSpan);
}

::QString QSqlRelationalTableModelWrapper::orderByClause() const
{
    static const char *funcName = "orderByClause";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlRelationalTableModel::orderByClause();
    }
    return QSqlTableModelWrapper::sbk_o_orderByClause("QSqlRelationalTableModel", funcName, gil, pyOverride);
}

void QSqlRelationalTableModelWrapper::queryChange()
{
    static const char *funcName = "queryChange";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlQueryModel::queryChange();
    }
    QSqlResultWrapper::sbk_o_detachFromResultSet("QSqlRelationalTableModel", funcName, gil, pyOverride);
}

::QSqlTableModel * QSqlRelationalTableModelWrapper::relationModel(int column) const
{
    static const char *funcName = "relationModel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlRelationalTableModel::relationModel(column);
    }
    return sbk_o_relationModel("QSqlRelationalTableModel", funcName, gil, pyOverride, column);
}

::QSqlTableModel * QSqlRelationalTableModelWrapper::sbk_o_relationModel(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int column)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &column)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        column
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlTableModel_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QSqlTableModel >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSqlTableModel *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSqlRelationalTableModelWrapper::removeColumns(int column, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "removeColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlRelationalTableModel::removeColumns(column, count, parent);
    }
    return QSqlQueryModelWrapper::sbk_o_insertColumns("QSqlRelationalTableModel", funcName, gil, pyOverride, column, count, parent);
}

bool QSqlRelationalTableModelWrapper::removeRows(int row, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "removeRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::removeRows(row, count, parent);
    }
    return QSqlQueryModelWrapper::sbk_o_insertColumns("QSqlRelationalTableModel", funcName, gil, pyOverride, row, count, parent);
}

void QSqlRelationalTableModelWrapper::resetInternalData()
{
    static const char *funcName = "resetInternalData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::resetInternalData();
    }
    QSqlResultWrapper::sbk_o_detachFromResultSet("QSqlRelationalTableModel", funcName, gil, pyOverride);
}

void QSqlRelationalTableModelWrapper::revert()
{
    static const char *funcName = "revert";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::revert();
    }
    QSqlResultWrapper::sbk_o_detachFromResultSet("QSqlRelationalTableModel", funcName, gil, pyOverride);
}

void QSqlRelationalTableModelWrapper::revertRow(int row)
{
    static const char *funcName = "revertRow";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlRelationalTableModel::revertRow(row);
    }
    QSqlResultWrapper::sbk_o_setAt("QSqlRelationalTableModel", funcName, gil, pyOverride, row);
}

::QHash<int,QByteArray> QSqlRelationalTableModelWrapper::roleNames() const
{
    static const char *funcName = "roleNames";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlQueryModel::roleNames();
    }
    return QSqlQueryModelWrapper::sbk_o_roleNames("QSqlRelationalTableModel", funcName, gil, pyOverride);
}

int QSqlRelationalTableModelWrapper::rowCount(const ::QModelIndex & parent) const
{
    static const char *funcName = "rowCount";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::rowCount(parent);
    }
    return QSqlQueryModelWrapper::sbk_o_columnCount("QSqlRelationalTableModel", funcName, gil, pyOverride, parent);
}

bool QSqlRelationalTableModelWrapper::select()
{
    static const char *funcName = "select";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlRelationalTableModel::select();
    }
    return QSqlTableModelWrapper::sbk_o_select("QSqlRelationalTableModel", funcName, gil, pyOverride);
}

bool QSqlRelationalTableModelWrapper::selectRow(int row)
{
    static const char *funcName = "selectRow";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::selectRow(row);
    }
    return QSqlResultWrapper::sbk_o_isNull("QSqlRelationalTableModel", funcName, gil, pyOverride, row);
}

::QString QSqlRelationalTableModelWrapper::selectStatement() const
{
    static const char *funcName = "selectStatement";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlRelationalTableModel::selectStatement();
    }
    return QSqlTableModelWrapper::sbk_o_orderByClause("QSqlRelationalTableModel", funcName, gil, pyOverride);
}

bool QSqlRelationalTableModelWrapper::setData(const ::QModelIndex & item, const ::QVariant & value, int role)
{
    static const char *funcName = "setData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlRelationalTableModel::setData(item, value, role);
    }
    return QSqlQueryModelWrapper::sbk_o_setData("QSqlRelationalTableModel", funcName, gil, pyOverride, item, value, role);
}

void QSqlRelationalTableModelWrapper::setEditStrategy(::QSqlTableModel::EditStrategy strategy)
{
    static const char *funcName = "setEditStrategy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::setEditStrategy(strategy);
    }
    QSqlTableModelWrapper::sbk_o_setEditStrategy("QSqlRelationalTableModel", funcName, gil, pyOverride, strategy);
}

void QSqlRelationalTableModelWrapper::setFilter(const ::QString & filter)
{
    static const char *funcName = "setFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::setFilter(filter);
    }
    QSqlResultWrapper::sbk_o_setQuery("QSqlRelationalTableModel", funcName, gil, pyOverride, filter);
}

bool QSqlRelationalTableModelWrapper::setHeaderData(int section, ::Qt::Orientation orientation, const ::QVariant & value, int role)
{
    static const char *funcName = "setHeaderData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlQueryModel::setHeaderData(section, orientation, value, role);
    }
    return QSqlQueryModelWrapper::sbk_o_setHeaderData("QSqlRelationalTableModel", funcName, gil, pyOverride, section, orientation, value, role);
}

bool QSqlRelationalTableModelWrapper::setItemData(const ::QModelIndex & index, const ::QMap<int,QVariant> & roles)
{
    static const char *funcName = "setItemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::setItemData(index, roles);
    }
    return QSqlQueryModelWrapper::sbk_o_setItemData("QSqlRelationalTableModel", funcName, gil, pyOverride, index, roles);
}

void QSqlRelationalTableModelWrapper::setRelation(int column, const ::QSqlRelation & relation)
{
    static const char *funcName = "setRelation";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlRelationalTableModel::setRelation(column, relation);
    }
    sbk_o_setRelation("QSqlRelationalTableModel", funcName, gil, pyOverride, column, relation);
}

void QSqlRelationalTableModelWrapper::sbk_o_setRelation(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int column, const ::QSqlRelation & relation)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &column),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelation_IDX]), &relation)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(iN)",
        column,
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelation_IDX]), &relation)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QSqlRelationalTableModelWrapper::setSort(int column, ::Qt::SortOrder order)
{
    static const char *funcName = "setSort";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::setSort(column, order);
    }
    QSqlQueryModelWrapper::sbk_o_sort("QSqlRelationalTableModel", funcName, gil, pyOverride, column, order);
}

void QSqlRelationalTableModelWrapper::setTable(const ::QString & tableName)
{
    static const char *funcName = "setTable";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlRelationalTableModel::setTable(tableName);
    }
    QSqlResultWrapper::sbk_o_setQuery("QSqlRelationalTableModel", funcName, gil, pyOverride, tableName);
}

::QModelIndex QSqlRelationalTableModelWrapper::sibling(int row, int column, const ::QModelIndex & idx) const
{
    static const char *funcName = "sibling";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractTableModel::sibling(row, column, idx);
    }
    return QSqlQueryModelWrapper::sbk_o_index("QSqlRelationalTableModel", funcName, gil, pyOverride, row, column, idx);
}

void QSqlRelationalTableModelWrapper::sort(int column, ::Qt::SortOrder order)
{
    static const char *funcName = "sort";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[52], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::sort(column, order);
    }
    QSqlQueryModelWrapper::sbk_o_sort("QSqlRelationalTableModel", funcName, gil, pyOverride, column, order);
}

::QSize QSqlRelationalTableModelWrapper::span(const ::QModelIndex & index) const
{
    static const char *funcName = "span";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[53], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::span(index);
    }
    return QSqlQueryModelWrapper::sbk_o_span("QSqlRelationalTableModel", funcName, gil, pyOverride, index);
}

bool QSqlRelationalTableModelWrapper::submit()
{
    static const char *funcName = "submit";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[54], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlTableModel::submit();
    }
    return QSqlResultWrapper::sbk_o_nextResult("QSqlRelationalTableModel", funcName, gil, pyOverride);
}

::QFlags<Qt::DropAction> QSqlRelationalTableModelWrapper::supportedDragActions() const
{
    static const char *funcName = "supportedDragActions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[55], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::supportedDragActions();
    }
    return QSqlQueryModelWrapper::sbk_o_supportedDragActions("QSqlRelationalTableModel", funcName, gil, pyOverride);
}

::QFlags<Qt::DropAction> QSqlRelationalTableModelWrapper::supportedDropActions() const
{
    static const char *funcName = "supportedDropActions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[56], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::supportedDropActions();
    }
    return QSqlQueryModelWrapper::sbk_o_supportedDragActions("QSqlRelationalTableModel", funcName, gil, pyOverride);
}

void QSqlRelationalTableModelWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[57], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QSqlRelationalDelegateWrapper::sbk_o_timerEvent("QSqlRelationalTableModel", funcName, gil, pyOverride, event);
}

bool QSqlRelationalTableModelWrapper::updateRowInTable(int row, const ::QSqlRecord & values)
{
    static const char *funcName = "updateRowInTable";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[58], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSqlRelationalTableModel::updateRowInTable(row, values);
    }
    return QSqlTableModelWrapper::sbk_o_updateRowInTable("QSqlRelationalTableModel", funcName, gil, pyOverride, row, values);
}

const QMetaObject *QSqlRelationalTableModelWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSqlRelationalTableModel::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSqlRelationalTableModelWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSqlRelationalTableModel::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSqlRelationalTableModelWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QSqlRelationalTableModelWrapper *>(this));
    return QSqlRelationalTableModel::qt_metacast(_clname);
}

QSqlRelationalTableModelWrapper::~QSqlRelationalTableModelWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSqlRelationalTableModel_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSqlRelationalTableModel >()))
        return -1;

    QSqlRelationalTableModelWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QSqlRelationalTableModel", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSqlRelationalTableModel::QSqlRelationalTableModel(QObject*=,const QSqlDatabase&=)
    if (numArgs == 0) {
        overloadId = 0; // QSqlRelationalTableModel(QObject*,QSqlDatabase)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QSqlRelationalTableModel(QObject*,QSqlDatabase)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QSqlRelationalTableModel(QObject*,QSqlDatabase)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"parent", 0}, {"db", 1}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlDatabase_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QSqlDatabase cppArg1_local = QSqlDatabase();
        ::QSqlDatabase *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSqlRelationalTableModel(QObject*,QSqlDatabase)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QSqlRelationalTableModelWrapper(cppArg0, *cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QSqlRelationalTableModelWrapper(cppArg0, *cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSqlRelationalTableModel >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSqlRelationalTableModel::clear()
            : cppSelf->clear();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_data(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    if (PyArg_ParseTuple(args, "|OO:data", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::data(QModelIndex,int=)const->QVariant
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // data(QModelIndex,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // data(QModelIndex,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1 = Qt::DisplayRole;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // data(QModelIndex,int)const
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSqlRelationalTableModel *>(cppSelf)->::QSqlRelationalTableModel::data(*cppArg0, cppArg1)
                : const_cast<const ::QSqlRelationalTableModel *>(cppSelf)->data(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_insertRowIntoTable(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlTableModel::insertRowIntoTable(QSqlRecord)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRecord_IDX]), (pyArg)))) {
        overloadId = 0; // insertRowIntoTable(QSqlRecord)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "insertRowIntoTable", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSqlRecord cppArg0_local;
        ::QSqlRecord *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // insertRowIntoTable(QSqlRecord)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlRelationalTableModel::insertRowIntoTable(*cppArg0)
                : cppSelf->insertRowIntoTable(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_orderByClause(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // orderByClause()const
        QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSqlRelationalTableModel *>(cppSelf)->::QSqlRelationalTableModel::orderByClause()
            : const_cast<const ::QSqlRelationalTableModel *>(cppSelf)->orderByClause();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_relation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlRelationalTableModel::relation(int)const->QSqlRelation
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // relation(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "relation", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // relation(int)const
            QSqlRelation cppResult = const_cast<const ::QSqlRelationalTableModel *>(cppSelf)->relation(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelation_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_relationModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlRelationalTableModel::relationModel(int)const->QSqlTableModel*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // relationModel(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "relationModel", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // relationModel(int)const
            QSqlTableModel * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSqlRelationalTableModel *>(cppSelf)->::QSqlRelationalTableModel::relationModel(cppArg0)
                : const_cast<const ::QSqlRelationalTableModel *>(cppSelf)->relationModel(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlTableModel_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_removeColumns(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "removeColumns", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:removeColumns", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::removeColumns(int,int,const QModelIndex&=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // removeColumns(int,int,QModelIndex)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2])))) {
            overloadId = 0; // removeColumns(int,int,QModelIndex)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "removeColumns", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "removeColumns", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QModelIndex cppArg2_local = QModelIndex();
        ::QModelIndex *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeColumns(int,int,QModelIndex)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlRelationalTableModel::removeColumns(cppArg0, cppArg1, *cppArg2)
                : cppSelf->removeColumns(cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_revertRow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlTableModel::revertRow(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // revertRow(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "revertRow", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // revertRow(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlRelationalTableModel::revertRow(cppArg0)
                : cppSelf->revertRow(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_select(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // select()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSqlRelationalTableModel::select()
            : cppSelf->select();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_selectStatement(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectStatement()const
        QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSqlRelationalTableModel *>(cppSelf)->::QSqlRelationalTableModel::selectStatement()
            : const_cast<const ::QSqlRelationalTableModel *>(cppSelf)->selectStatement();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_setData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setData", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::setData(QModelIndex,QVariant,int=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setData(QModelIndex,QVariant,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 0; // setData(QModelIndex,QVariant,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setData", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setData", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = Qt::EditRole;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setData(QModelIndex,QVariant,int)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlRelationalTableModel::setData(*cppArg0, cppArg1, cppArg2)
                : cppSelf->setData(*cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_setJoinMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlRelationalTableModel::setJoinMode(QSqlRelationalTableModel::JoinMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_JoinMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setJoinMode(QSqlRelationalTableModel::JoinMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setJoinMode", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    // Call function/method
    {
        ::QSqlRelationalTableModel::JoinMode cppArg0{QSqlRelationalTableModel::InnerJoin};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setJoinMode(QSqlRelationalTableModel::JoinMode)
            cppSelf->setJoinMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_setRelation(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setRelation", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlRelationalTableModel::setRelation(int,QSqlRelation)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelation_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setRelation(int,QSqlRelation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRelation", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSqlRelation cppArg1_local;
        ::QSqlRelation *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRelation(int,QSqlRelation)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlRelationalTableModel::setRelation(cppArg0, *cppArg1)
                : cppSelf->setRelation(cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_setTable(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSqlTableModel::setTable(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setTable(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTable", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTable(QString)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlRelationalTableModel::setTable(cppArg0)
                : cppSelf->setTable(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSqlRelationalTableModelFunc_updateRowInTable(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "updateRowInTable", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSqlTableModel::updateRowInTable(int,QSqlRecord)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRecord_IDX]), (pyArgs[1])))) {
        overloadId = 0; // updateRowInTable(int,QSqlRecord)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "updateRowInTable", errInfo, SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSqlRecord cppArg1_local;
        ::QSqlRecord *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // updateRowInTable(int,QSqlRecord)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSqlRelationalTableModel::updateRowInTable(cppArg0, *cppArg1)
                : cppSelf->updateRowInTable(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QSqlRelationalTableModel_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSqlRelationalTableModel_EnumFlagInfo[] = {
    "JoinMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSqlRelationalTableModel_methods[] = {
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_clear), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_data), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"insertRowIntoTable", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_insertRowIntoTable), METH_O, nullptr},
    {"orderByClause", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_orderByClause), METH_NOARGS, nullptr},
    {"relation", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_relation), METH_O, nullptr},
    {"relationModel", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_relationModel), METH_O, nullptr},
    {"removeColumns", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_removeColumns), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"revertRow", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_revertRow), METH_O, nullptr},
    {"select", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_select), METH_NOARGS, nullptr},
    {"selectStatement", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_selectStatement), METH_NOARGS, nullptr},
    {"setData", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_setData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setJoinMode", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_setJoinMode), METH_O, nullptr},
    {"setRelation", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_setRelation), METH_VARARGS, nullptr},
    {"setTable", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_setTable), METH_O, nullptr},
    {"updateRowInTable", reinterpret_cast<PyCFunction>(Sbk_QSqlRelationalTableModelFunc_updateRowInTable), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSqlRelationalTableModel_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSqlRelationalTableModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSqlRelationalTableModelWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSqlRelationalTableModel_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSqlRelationalTableModel_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSqlRelationalTableModel_Type = nullptr;
static PyTypeObject *Sbk_QSqlRelationalTableModel_TypeF(void)
{
    return _Sbk_QSqlRelationalTableModel_Type;
}

static PyType_Slot Sbk_QSqlRelationalTableModel_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSqlRelationalTableModel_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSqlRelationalTableModel_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSqlRelationalTableModel_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSqlRelationalTableModel_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSqlRelationalTableModel_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSqlRelationalTableModel_spec = {
    "2:PySide6.QtSql.QSqlRelationalTableModel",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSqlRelationalTableModel_slots
};

} //extern "C"

static void *Sbk_QSqlRelationalTableModel_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSqlRelationalTableModel *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QSqlRelationalTableModel_JoinMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSqlRelationalTableModel::JoinMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSqlRelationalTableModel::JoinMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QSqlRelationalTableModel_JoinMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_JoinMode_IDX])))
        return Enum_PythonToCpp_QSqlRelationalTableModel_JoinMode;
    return {};
}

static PyObject *QSqlRelationalTableModel_JoinMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QSqlRelationalTableModel::JoinMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QSqlRelationalTableModel::JoinMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_JoinMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSqlRelationalTableModel_PythonToCpp_QSqlRelationalTableModel_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSqlRelationalTableModel_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSqlRelationalTableModel_PythonToCpp_QSqlRelationalTableModel_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSqlRelationalTableModel_TypeF()))
        return QSqlRelationalTableModel_PythonToCpp_QSqlRelationalTableModel_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSqlRelationalTableModel_PTR_CppToPython_QSqlRelationalTableModel(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSqlRelationalTableModel *>(const_cast<void *>(cppIn)), Sbk_QSqlRelationalTableModel_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSqlRelationalTableModel_SignatureStrings[] = {
    "PySide6.QtSql.QSqlRelationalTableModel(self,parent:PySide6.QtCore.QObject=nullptr,db:PySide6.QtSql.QSqlDatabase=QSqlDatabase())",
    "PySide6.QtSql.QSqlRelationalTableModel.clear(self)",
    "PySide6.QtSql.QSqlRelationalTableModel.data(self,item:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],role:int=Qt.DisplayRole)->QVariant",
    "PySide6.QtSql.QSqlRelationalTableModel.insertRowIntoTable(self,values:PySide6.QtSql.QSqlRecord)->bool",
    "PySide6.QtSql.QSqlRelationalTableModel.orderByClause(self)->QString",
    "PySide6.QtSql.QSqlRelationalTableModel.relation(self,column:int)->PySide6.QtSql.QSqlRelation",
    "PySide6.QtSql.QSqlRelationalTableModel.relationModel(self,column:int)->PySide6.QtSql.QSqlTableModel",
    "PySide6.QtSql.QSqlRelationalTableModel.removeColumns(self,column:int,count:int,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->bool",
    "PySide6.QtSql.QSqlRelationalTableModel.revertRow(self,row:int)",
    "PySide6.QtSql.QSqlRelationalTableModel.select(self)->bool",
    "PySide6.QtSql.QSqlRelationalTableModel.selectStatement(self)->QString",
    "PySide6.QtSql.QSqlRelationalTableModel.setData(self,item:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],value:QVariant,role:int=Qt.EditRole)->bool",
    "PySide6.QtSql.QSqlRelationalTableModel.setJoinMode(self,joinMode:PySide6.QtSql.QSqlRelationalTableModel.JoinMode)",
    "PySide6.QtSql.QSqlRelationalTableModel.setRelation(self,column:int,relation:PySide6.QtSql.QSqlRelation)",
    "PySide6.QtSql.QSqlRelationalTableModel.setTable(self,tableName:QString)",
    "PySide6.QtSql.QSqlRelationalTableModel.updateRowInTable(self,row:int,values:PySide6.QtSql.QSqlRecord)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QSqlRelationalTableModel_SignatureByteSize = 401;
static constexpr uint8_t QSqlRelationalTableModel_SignatureBytes[401] = {
    0x78, 0xda, 0xb5, 0x54, 0x3d, 0x4f, 0xc3, 0x30, 0x14, 0xdc, 0xf9, 0x15, 0x8c, 0x54, 0x0a, 0x19,
    0x19, 0x22, 0x85, 0x81, 0x96, 0xa1, 0x48, 0x40, 0x3e, 0x80, 0x05, 0x31, 0x38, 0xc9, 0x03, 0xb9,
    0x72, 0xec, 0x60, 0xbf, 0xb4, 0xe4, 0xdf, 0xf3, 0x6a, 0x27, 0x34, 0x54, 0x14, 0x1c, 0x04, 0x4b,
    0x64, 0x3b, 0xbe, 0xbb, 0x67, 0xfb, 0xee, 0x25, 0x5d, 0xce, 0x2b, 0x38, 0x0b, 0x53, 0xcc, 0x5f,
    0x45, 0x98, 0xd2, 0x27, 0x03, 0xc1, 0x90, 0x2b, 0xc9, 0xc4, 0x1d, 0x2b, 0x04, 0x5c, 0xab, 0x0a,
    0xc4, 0x89, 0x01, 0xf1, 0x1c, 0x34, 0x4c, 0x83, 0xc4, 0x28, 0xf9, 0x80, 0xcc, 0x95, 0x86, 0x30,
    0xbd, 0x2d, 0x56, 0x50, 0x62, 0x2c, 0x5b, 0x21, 0x1a, 0xd4, 0x41, 0x55, 0x8c, 0x76, 0x0c, 0xa4,
    0x0b, 0x86, 0xac, 0x60, 0x06, 0xe2, 0xf1, 0xe4, 0x64, 0x36, 0x3b, 0x4a, 0xbc, 0xf4, 0xc3, 0x52,
    0x00, 0xd3, 0xb6, 0x0a, 0x6f, 0x48, 0x45, 0x2a, 0xae, 0x6e, 0x8e, 0x50, 0x47, 0xd8, 0x35, 0x5c,
    0xbe, 0x84, 0xf7, 0x92, 0xf6, 0x3d, 0xee, 0x1f, 0xc1, 0x22, 0x96, 0xb2, 0x82, 0xb7, 0xe0, 0x78,
    0xff, 0x5f, 0x02, 0xda, 0x70, 0x83, 0x74, 0xf2, 0xdd, 0xae, 0xa7, 0x40, 0x2b, 0x01, 0x11, 0x97,
    0x18, 0xa7, 0x18, 0x2e, 0xb8, 0x69, 0x04, 0xeb, 0x32, 0x5a, 0x9a, 0x9d, 0x9e, 0xa7, 0x0f, 0x4c,
    0x73, 0x26, 0xd1, 0xb7, 0x4e, 0x2e, 0x0d, 0x68, 0xcc, 0xd4, 0x66, 0x29, 0x51, 0xd9, 0x75, 0x57,
    0xf5, 0x9a, 0x89, 0x16, 0x4c, 0xf4, 0x15, 0x4b, 0xa9, 0x74, 0x45, 0x4a, 0x85, 0x52, 0xc2, 0x57,
    0x85, 0x10, 0xa0, 0x2f, 0xba, 0xb9, 0x60, 0xad, 0x71, 0x02, 0xdb, 0x52, 0x73, 0xd4, 0x74, 0x29,
    0xbe, 0x1c, 0xba, 0x5f, 0x74, 0xf5, 0x95, 0x4a, 0xb4, 0xb5, 0xdc, 0xde, 0x01, 0x31, 0x1d, 0x66,
    0x98, 0x4a, 0x3e, 0xf2, 0xdb, 0x0f, 0x0a, 0x3b, 0xb0, 0xbf, 0x46, 0xad, 0xd6, 0x30, 0xb7, 0xb4,
    0x66, 0x5f, 0x83, 0x86, 0x2d, 0xb9, 0x7b, 0x3b, 0xea, 0x8d, 0xfe, 0xb7, 0x96, 0x89, 0x47, 0x10,
    0x72, 0xfe, 0xb4, 0xe7, 0xd3, 0xb0, 0x76, 0x26, 0x71, 0x55, 0x6b, 0xb5, 0xb1, 0xd7, 0xe2, 0x0b,
    0x27, 0x10, 0x45, 0x74, 0x78, 0xf6, 0x29, 0xc2, 0x0e, 0x99, 0x23, 0xa3, 0x0c, 0xd1, 0x79, 0x7e,
    0xe9, 0x1c, 0x03, 0xb8, 0xf8, 0xd7, 0x38, 0xda, 0xb0, 0x44, 0x43, 0xf4, 0x3e, 0xa5, 0xf3, 0xb2,
    0xe2, 0xd8, 0x47, 0x73, 0xda, 0xc1, 0xf1, 0x4a, 0x71, 0x6b, 0x47, 0x57, 0xf6, 0xaa, 0x9f, 0x45,
    0x9e, 0x04, 0x03, 0x7a, 0xc2, 0x23, 0x61, 0x76, 0x20, 0x61, 0xc1, 0x90, 0x8e, 0x6f, 0xc4, 0xa7,
    0xe8, 0x8c, 0xda, 0x0c, 0x6e, 0x87, 0x37, 0xac, 0xa6, 0xdb, 0x73, 0x6f, 0xea, 0xcd, 0xd3, 0x36,
    0xd4, 0x62, 0xc1, 0x36, 0xae, 0x11, 0x5f, 0x6f, 0x4d, 0xdf, 0xf6, 0xf5, 0x0e, 0x01, 0x23, 0x61,
    0xb2
};
#endif

PyTypeObject *init_QSqlRelationalTableModel(PyObject *module)
{
    if (SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX].type != nullptr)
        return SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX].type;

    Shiboken::AutoDecRef Sbk_QSqlRelationalTableModel_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtSqlTypeStructs[SBK_QSqlTableModel_IDX]))));

    _Sbk_QSqlRelationalTableModel_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSqlRelationalTableModel",
        "QSqlRelationalTableModel*",
        &Sbk_QSqlRelationalTableModel_spec,
        &Shiboken::callCppDestructor< QSqlRelationalTableModel >,
        Sbk_QSqlRelationalTableModel_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSqlRelationalTableModel_TypeF(); // references _Sbk_QSqlRelationalTableModel_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSqlRelationalTableModel_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSqlRelationalTableModel_SignatureBytes, QSqlRelationalTableModel_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSqlRelationalTableModel_PropertyStrings);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSqlRelationalTableModel_PythonToCpp_QSqlRelationalTableModel_PTR,
        is_QSqlRelationalTableModel_PythonToCpp_QSqlRelationalTableModel_PTR_Convertible,
        QSqlRelationalTableModel_PTR_CppToPython_QSqlRelationalTableModel);

    Shiboken::Conversions::registerConverterName(converter, "QSqlRelationalTableModel");
    Shiboken::Conversions::registerConverterName(converter, "QSqlRelationalTableModel*");
    Shiboken::Conversions::registerConverterName(converter, "QSqlRelationalTableModel&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSqlRelationalTableModel).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSqlRelationalTableModelWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSqlRelationalTableModel_TypeF(), &Sbk_QSqlRelationalTableModel_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSqlRelationalTableModel_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'JoinMode'.
    const char *JoinMode_Initializer[] = {
        "InnerJoin",
        "LeftJoin",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t JoinMode_InitializerValues[] = {
        uint8_t(QSqlRelationalTableModel::JoinMode::InnerJoin), //  0x00  0
        uint8_t(QSqlRelationalTableModel::JoinMode::LeftJoin)   //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSqlRelationalTableModel_TypeF(),
        "2:PySide6.QtSql.QSqlRelationalTableModel.JoinMode",
        JoinMode_Initializer, JoinMode_InitializerValues);
    SbkPySide6_QtSqlTypeStructs[SBK_QSqlRelationalTableModel_JoinMode_IDX].type = EType;
    // Register converter for enum 'QSqlRelationalTableModel::JoinMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSqlRelationalTableModel_JoinMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QSqlRelationalTableModel_JoinMode,
            is_Enum_PythonToCpp_QSqlRelationalTableModel_JoinMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QSqlRelationalTableModel::JoinMode");
        Shiboken::Conversions::registerConverterAlias(converter, "JoinMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'JoinMode' enum.

    qRegisterMetaType< ::QSqlRelationalTableModel::JoinMode >("QSqlRelationalTableModel::JoinMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSqlRelationalTableModel::staticMetaObject, sizeof(QSqlRelationalTableModelWrapper));

    return pyType;
}
