// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSQLRESULTWRAPPER_H
#define SBK_QSQLRESULTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtSql/qsqlresult.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QSqlResultWrapper : public QSqlResult
{
public:
    QSqlResultWrapper(const ::QSqlDriver * db);
    QSqlResultWrapper(const QSqlResultWrapper &) = delete;
    QSqlResultWrapper& operator=(const QSqlResultWrapper &) = delete;
    QSqlResultWrapper(QSqlResultWrapper &&) = delete;
    QSqlResultWrapper& operator=(QSqlResultWrapper &&) = delete;
    ~QSqlResultWrapper() override;

    void bindValue(const ::QString & placeholder, const ::QVariant & val, ::QFlags<QSql::ParamTypeFlag> type) override;
    static void sbk_o_bindValue(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & placeholder, const ::QVariant & val, ::QFlags<QSql::ParamTypeFlag> type);
    void bindValue(int pos, const ::QVariant & val, ::QFlags<QSql::ParamTypeFlag> type) override;
    static void sbk_o_bindValue(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int pos, const ::QVariant & val, ::QFlags<QSql::ParamTypeFlag> type);
    ::QVariant data(int i) override;
    static ::QVariant sbk_o_data(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int i);
    void detachFromResultSet() override;
    static void sbk_o_detachFromResultSet(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool exec() override;
    static bool sbk_o_exec(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool execBatch(bool arrayBind = false) override;
    static bool sbk_o_execBatch(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, bool arrayBind = false);
    bool fetch(int i) override;
    static bool sbk_o_fetch(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int i);
    bool fetchFirst() override;
    static bool sbk_o_fetchFirst(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool fetchLast() override;
    static bool sbk_o_fetchLast(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool fetchNext() override;
    static bool sbk_o_fetchNext(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool fetchPrevious() override;
    static bool sbk_o_fetchPrevious(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QVariant handle() const override;
    static ::QVariant sbk_o_handle(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isNull(int i) override;
    static bool sbk_o_isNull(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int i);
    ::QVariant lastInsertId() const override;
    bool nextResult() override;
    static bool sbk_o_nextResult(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    int numRowsAffected() override;
    static int sbk_o_numRowsAffected(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool prepare(const ::QString & query) override;
    static bool sbk_o_prepare(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & query);
    ::QSqlRecord record() const override;
    static ::QSqlRecord sbk_o_record(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool reset(const ::QString & sqlquery) override;
    static bool sbk_o_reset(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & sqlquery);
    bool savePrepare(const ::QString & sqlquery) override;
    void setActive(bool a) override;
    static void sbk_o_setActive(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, bool a);
    void setAt(int at) override;
    static void sbk_o_setAt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int at);
    void setForwardOnly(bool forward) override;
    void setLastError(const ::QSqlError & e) override;
    static void sbk_o_setLastError(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QSqlError & e);
    void setNumericalPrecisionPolicy(::QSql::NumericalPrecisionPolicy policy) override;
    static void sbk_o_setNumericalPrecisionPolicy(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSql::NumericalPrecisionPolicy policy);
    void setQuery(const ::QString & query) override;
    static void sbk_o_setQuery(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & query);
    void setSelect(bool s) override;
    int size() override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[28] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSQLRESULTWRAPPER_H
