// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSTATEWRAPPER_H
#define SBK_QSTATEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtStateMachine/qstate.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QStateWrapper : public QState
{
public:
    QStateWrapper(::QState * parent = nullptr);
    QStateWrapper(::QState::ChildMode childMode, ::QState * parent = nullptr);
    QStateWrapper(const QStateWrapper &) = delete;
    QStateWrapper& operator=(const QStateWrapper &) = delete;
    QStateWrapper(QStateWrapper &&) = delete;
    QStateWrapper& operator=(QStateWrapper &&) = delete;
    ~QStateWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * e) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    void onEntry(::QEvent * event) override;
    void onExit(::QEvent * event) override;
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[9] = {false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSTATEWRAPPER_H
