// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSVGGENERATORWRAPPER_H
#define SBK_QSVGGENERATORWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtSvg/qsvggenerator.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QSvgGeneratorWrapper : public QSvgGenerator
{
public:
    QSvgGeneratorWrapper();
    QSvgGeneratorWrapper(::QSvgGenerator::SvgVersion version);
    QSvgGeneratorWrapper(const QSvgGeneratorWrapper &) = delete;
    QSvgGeneratorWrapper& operator=(const QSvgGeneratorWrapper &) = delete;
    QSvgGeneratorWrapper(QSvgGeneratorWrapper &&) = delete;
    QSvgGeneratorWrapper& operator=(QSvgGeneratorWrapper &&) = delete;
    ~QSvgGeneratorWrapper() override;

    int devType() const override;
    static int sbk_o_devType(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void initPainter(::QPainter * painter) const override;
    static void sbk_o_initPainter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter);
    int metric(::QPaintDevice::PaintDeviceMetric metric) const override;
    static int sbk_o_metric(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPaintDevice::PaintDeviceMetric metric);
    ::QPaintEngine * paintEngine() const override;
    static ::QPaintEngine * sbk_o_paintEngine(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QPaintDevice * redirected(::QPoint * offset) const override;
    static ::QPaintDevice * sbk_o_redirected(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPoint * offset);
    ::QPainter * sharedPainter() const override;
    static ::QPainter * sbk_o_sharedPainter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QSVGGENERATORWRAPPER_H
