// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QTEXTTOSPEECHENGINEWRAPPER_H
#define SBK_QTEXTTOSPEECHENGINEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtTextToSpeech/qtexttospeechengine.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QTextToSpeechEngineWrapper : public QTextToSpeechEngine
{
public:
    QTextToSpeechEngineWrapper(::QObject * parent = nullptr);
    QTextToSpeechEngineWrapper(const QTextToSpeechEngineWrapper &) = delete;
    QTextToSpeechEngineWrapper& operator=(const QTextToSpeechEngineWrapper &) = delete;
    QTextToSpeechEngineWrapper(QTextToSpeechEngineWrapper &&) = delete;
    QTextToSpeechEngineWrapper& operator=(QTextToSpeechEngineWrapper &&) = delete;
    ~QTextToSpeechEngineWrapper() override;

    ::QList<QLocale> availableLocales() const override;
    static ::QList<QLocale> sbk_o_availableLocales(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QList<QVoice> availableVoices() const override;
    static ::QList<QVoice> sbk_o_availableVoices(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QFlags<QTextToSpeech::Capability> capabilities() const override;
    static ::QFlags<QTextToSpeech::Capability> sbk_o_capabilities(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void childEvent(::QChildEvent * event) override;
    static void sbk_o_childEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QChildEvent * event);
    void connectNotify(const ::QMetaMethod & signal) override;
    static void sbk_o_connectNotify(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QMetaMethod & signal);
    void customEvent(::QEvent * event) override;
    static void sbk_o_customEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    void disconnectNotify(const ::QMetaMethod & signal) override;
    ::QTextToSpeech::ErrorReason errorReason() const override;
    static ::QTextToSpeech::ErrorReason sbk_o_errorReason(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QString errorString() const override;
    static ::QString sbk_o_errorString(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool event(::QEvent * event) override;
    static bool sbk_o_event(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event);
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    static bool sbk_o_eventFilter(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * watched, ::QEvent * event);
    ::QLocale locale() const override;
    static ::QLocale sbk_o_locale(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void pause(::QTextToSpeech::BoundaryHint boundaryHint) override;
    static void sbk_o_pause(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QTextToSpeech::BoundaryHint boundaryHint);
    double pitch() const override;
    static double sbk_o_pitch(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    double rate() const override;
    void resume() override;
    static void sbk_o_resume(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void say(const ::QString & text) override;
    static void sbk_o_say(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & text);
    bool setLocale(const ::QLocale & locale) override;
    static bool sbk_o_setLocale(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QLocale & locale);
    bool setPitch(double pitch) override;
    static bool sbk_o_setPitch(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, double pitch);
    bool setRate(double rate) override;
    bool setVoice(const ::QVoice & voice) override;
    static bool sbk_o_setVoice(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QVoice & voice);
    bool setVolume(double volume) override;
    ::QTextToSpeech::State state() const override;
    static ::QTextToSpeech::State sbk_o_state(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void stop(::QTextToSpeech::BoundaryHint boundaryHint) override;
    void synthesize(const ::QString & text) override;
    void timerEvent(::QTimerEvent * event) override;
    static void sbk_o_timerEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QTimerEvent * event);
    ::QVoice voice() const override;
    static ::QVoice sbk_o_voice(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    double volume() const override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[28] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QTEXTTOSPEECHENGINEWRAPPER_H
