// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebsockets_python.h"

// main header
#include "qwebsocketserver_wrapper.h"

// Wrappers providing overrides
#include "qmaskgenerator_wrapper.h"

// Extra includes
#include <QWebSocketCorsAuthenticator>

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtNetwork/qabstractsocket.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkproxy.h>
#include <QtNetwork/qssl.h>
#include <QtNetwork/qsslconfiguration.h>
#include <QtNetwork/qsslerror.h>
#include <QtNetwork/qsslpresharedkeyauthenticator.h>
#include <QtNetwork/qtcpsocket.h>
#include <QtWebSockets/qwebsocket.h>
#include <QtWebSockets/qwebsocketcorsauthenticator.h>
#include <QtWebSockets/qwebsocketprotocol.h>
#include <QtWebSockets/qwebsocketserver.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QWebSocketServerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QWebSocketServerWrapper::QWebSocketServerWrapper(const ::QString & serverName, ::QWebSocketServer::SslMode secureMode, ::QObject * parent) : QWebSocketServer(serverName, secureMode, parent)
{
}

void QWebSocketServerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QMaskGeneratorWrapper::sbk_o_childEvent("QWebSocketServer", funcName, gil, pyOverride, event);
}

void QWebSocketServerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QMaskGeneratorWrapper::sbk_o_connectNotify("QWebSocketServer", funcName, gil, pyOverride, signal);
}

void QWebSocketServerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QMaskGeneratorWrapper::sbk_o_customEvent("QWebSocketServer", funcName, gil, pyOverride, event);
}

void QWebSocketServerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QMaskGeneratorWrapper::sbk_o_connectNotify("QWebSocketServer", funcName, gil, pyOverride, signal);
}

bool QWebSocketServerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QMaskGeneratorWrapper::sbk_o_event("QWebSocketServer", funcName, gil, pyOverride, event);
}

bool QWebSocketServerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QMaskGeneratorWrapper::sbk_o_eventFilter("QWebSocketServer", funcName, gil, pyOverride, watched, event);
}

::QWebSocket * QWebSocketServerWrapper::nextPendingConnection()
{
    static const char *funcName = "nextPendingConnection";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWebSocketServer::nextPendingConnection();
    }
    return sbk_o_nextPendingConnection("QWebSocketServer", funcName, gil, pyOverride);
}

::QWebSocket * QWebSocketServerWrapper::sbk_o_nextPendingConnection(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QWebSocket >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QWebSocket *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebSocketServerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QMaskGeneratorWrapper::sbk_o_timerEvent("QWebSocketServer", funcName, gil, pyOverride, event);
}

const QMetaObject *QWebSocketServerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QWebSocketServer::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QWebSocketServerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QWebSocketServer::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QWebSocketServerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QWebSocketServerWrapper *>(this));
    return QWebSocketServer::qt_metacast(_clname);
}

QWebSocketServerWrapper::~QWebSocketServerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebSocketServer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebSocketServer >()))
        return -1;

    QWebSocketServerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOO:QWebSocketServer", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebSocketServer::QWebSocketServer(QString,QWebSocketServer::SslMode,QObject*=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_SslMode_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // QWebSocketServer(QString,QWebSocketServer::SslMode,QObject*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))) {
            overloadId = 0; // QWebSocketServer(QString,QWebSocketServer::SslMode,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 2}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QWebSocketServer::SslMode cppArg1{QWebSocketServer::SecureMode};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return -1;
        ::QObject *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QWebSocketServer(QString,QWebSocketServer::SslMode,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QWebSocketServerWrapper(cppArg0, cppArg1, cppArg2);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QWebSocketServerWrapper(cppArg0, cppArg1, cppArg2);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[2], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QWebSocketServer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QWebSocketServerFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        cppSelf->close();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWebSocketServerFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QWebSocketProtocol::CloseCode cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketProtocol_CloseCode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_handleConnection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocketServer::handleConnection(QTcpSocket*)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]), (pyArg)))) {
        overloadId = 0; // handleConnection(QTcpSocket*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "handleConnection", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTcpSocket *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // handleConnection(QTcpSocket*)const
            const_cast<const ::QWebSocketServer *>(cppSelf)->handleConnection(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWebSocketServerFunc_handshakeTimeout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // handshakeTimeout()const
        std::chrono::milliseconds cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->handshakeTimeout();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_std_chrono_milliseconds_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_handshakeTimeoutMS(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // handshakeTimeoutMS()const
        int cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->handshakeTimeoutMS();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_hasPendingConnections(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasPendingConnections()const
        bool cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->hasPendingConnections();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_isListening(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isListening()const
        bool cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->isListening();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_listen(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "listen", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);

    if (PyArg_ParseTuple(args, "|OO:listen", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebSocketServer::listen(const QHostAddress&=,quint16=)->bool
    if (numArgs == 0) {
        overloadId = 0; // listen(QHostAddress,quint16)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // listen(QHostAddress,quint16)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
            overloadId = 0; // listen(QHostAddress,quint16)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "listen", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"address", 0}, {"port", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0]))))
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "listen", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QHostAddress cppArg0_local(QHostAddress::Any);
        ::QHostAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }
        quint16 cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // listen(QHostAddress,quint16)
            bool cppResult = cppSelf->listen(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_maxPendingConnections(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxPendingConnections()const
        int cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->maxPendingConnections();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_nativeDescriptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QWebSocketServer", "nativeDescriptor() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // nativeDescriptor()const
        qintptr cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->nativeDescriptor();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_nextPendingConnection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nextPendingConnection()
        QWebSocket * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QWebSocketServer::nextPendingConnection()
            : cppSelf->nextPendingConnection();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocket_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_pauseAccepting(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pauseAccepting()
        cppSelf->pauseAccepting();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWebSocketServerFunc_proxy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // proxy()const
        QNetworkProxy cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->proxy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxy_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_resumeAccepting(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resumeAccepting()
        cppSelf->resumeAccepting();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWebSocketServerFunc_secureMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // secureMode()const
        QWebSocketServer::SslMode cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->secureMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_SslMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_serverAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // serverAddress()const
        QHostAddress cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->serverAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_serverName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // serverName()const
        QString cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->serverName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_serverPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // serverPort()const
        quint16 cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->serverPort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_serverUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // serverUrl()const
        QUrl cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->serverUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_setHandshakeTimeout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocketServer::setHandshakeTimeout(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setHandshakeTimeout(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHandshakeTimeout", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHandshakeTimeout(int)
            cppSelf->setHandshakeTimeout(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWebSocketServerFunc_setMaxPendingConnections(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocketServer::setMaxPendingConnections(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMaxPendingConnections(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxPendingConnections", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxPendingConnections(int)
            cppSelf->setMaxPendingConnections(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWebSocketServerFunc_setNativeDescriptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocketServer::setNativeDescriptor(qintptr)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX], (pyArg)))) {
        overloadId = 0; // setNativeDescriptor(qintptr)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNativeDescriptor", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QWebSocketServer", "setNativeDescriptor(qintptr descriptor)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        ::qintptr cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNativeDescriptor(qintptr)
            bool cppResult = cppSelf->setNativeDescriptor(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_setProxy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocketServer::setProxy(QNetworkProxy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxy_IDX]), (pyArg)))) {
        overloadId = 0; // setProxy(QNetworkProxy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProxy", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkProxy cppArg0_local;
        ::QNetworkProxy *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setProxy(QNetworkProxy)
            cppSelf->setProxy(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWebSocketServerFunc_setServerName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocketServer::setServerName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setServerName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setServerName", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setServerName(QString)
            cppSelf->setServerName(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWebSocketServerFunc_setSocketDescriptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocketServer::setSocketDescriptor(qintptr)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX], (pyArg)))) {
        overloadId = 0; // setSocketDescriptor(qintptr)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSocketDescriptor", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);

    // Call function/method
    {
        ::qintptr cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSocketDescriptor(qintptr)
            bool cppResult = cppSelf->setSocketDescriptor(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_setSslConfiguration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocketServer::setSslConfiguration(QSslConfiguration)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), (pyArg)))) {
        overloadId = 0; // setSslConfiguration(QSslConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSslConfiguration", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSslConfiguration cppArg0_local;
        ::QSslConfiguration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSslConfiguration(QSslConfiguration)
            cppSelf->setSslConfiguration(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWebSocketServerFunc_setSupportedSubprotocols(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocketServer::setSupportedSubprotocols(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setSupportedSubprotocols(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSupportedSubprotocols", errInfo, SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSupportedSubprotocols(QStringList)
            cppSelf->setSupportedSubprotocols(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWebSocketServerFunc_socketDescriptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // socketDescriptor()const
        qintptr cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->socketDescriptor();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_sslConfiguration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sslConfiguration()const
        QSslConfiguration cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->sslConfiguration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_supportedSubprotocols(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedSubprotocols()const
        QStringList cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->supportedSubprotocols();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebSocketServerFunc_supportedVersions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedVersions()const
        QList<QWebSocketProtocol::Version> cppResult = const_cast<const ::QWebSocketServer *>(cppSelf)->supportedVersions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWebSocketsTypeConverters[SBK_QtWebSockets_QList_QWebSocketProtocol_Version_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QWebSocketServer_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QWebSocketServer_EnumFlagInfo[] = {
    "SslMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebSocketServer_methods[] = {
    {"close", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_close), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_errorString), METH_NOARGS, nullptr},
    {"handleConnection", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_handleConnection), METH_O, nullptr},
    {"handshakeTimeout", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_handshakeTimeout), METH_NOARGS, nullptr},
    {"handshakeTimeoutMS", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_handshakeTimeoutMS), METH_NOARGS, nullptr},
    {"hasPendingConnections", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_hasPendingConnections), METH_NOARGS, nullptr},
    {"isListening", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_isListening), METH_NOARGS, nullptr},
    {"listen", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_listen), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"maxPendingConnections", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_maxPendingConnections), METH_NOARGS, nullptr},
    {"nativeDescriptor", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_nativeDescriptor), METH_NOARGS, nullptr},
    {"nextPendingConnection", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_nextPendingConnection), METH_NOARGS, nullptr},
    {"pauseAccepting", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_pauseAccepting), METH_NOARGS, nullptr},
    {"proxy", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_proxy), METH_NOARGS, nullptr},
    {"resumeAccepting", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_resumeAccepting), METH_NOARGS, nullptr},
    {"secureMode", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_secureMode), METH_NOARGS, nullptr},
    {"serverAddress", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_serverAddress), METH_NOARGS, nullptr},
    {"serverName", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_serverName), METH_NOARGS, nullptr},
    {"serverPort", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_serverPort), METH_NOARGS, nullptr},
    {"serverUrl", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_serverUrl), METH_NOARGS, nullptr},
    {"setHandshakeTimeout", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_setHandshakeTimeout), METH_O, nullptr},
    {"setMaxPendingConnections", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_setMaxPendingConnections), METH_O, nullptr},
    {"setNativeDescriptor", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_setNativeDescriptor), METH_O, nullptr},
    {"setProxy", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_setProxy), METH_O, nullptr},
    {"setServerName", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_setServerName), METH_O, nullptr},
    {"setSocketDescriptor", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_setSocketDescriptor), METH_O, nullptr},
    {"setSslConfiguration", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_setSslConfiguration), METH_O, nullptr},
    {"setSupportedSubprotocols", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_setSupportedSubprotocols), METH_O, nullptr},
    {"socketDescriptor", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_socketDescriptor), METH_NOARGS, nullptr},
    {"sslConfiguration", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_sslConfiguration), METH_NOARGS, nullptr},
    {"supportedSubprotocols", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_supportedSubprotocols), METH_NOARGS, nullptr},
    {"supportedVersions", reinterpret_cast<PyCFunction>(Sbk_QWebSocketServerFunc_supportedVersions), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QWebSocketServer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QWebSocketServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QWebSocketServerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QWebSocketServer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebSocketServer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebSocketServer_Type = nullptr;
static PyTypeObject *Sbk_QWebSocketServer_TypeF(void)
{
    return _Sbk_QWebSocketServer_Type;
}

static PyType_Slot Sbk_QWebSocketServer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QWebSocketServer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebSocketServer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebSocketServer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebSocketServer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebSocketServer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebSocketServer_spec = {
    "2:PySide6.QtWebSockets.QWebSocketServer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebSocketServer_slots
};

} //extern "C"

static void *Sbk_QWebSocketServer_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QWebSocketServer *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QWebSocketServer_SslMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebSocketServer::SslMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebSocketServer::SslMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebSocketServer_SslMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_SslMode_IDX])))
        return Enum_PythonToCpp_QWebSocketServer_SslMode;
    return {};
}

static PyObject *QWebSocketServer_SslMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebSocketServer::SslMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebSocketServer::SslMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_SslMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebSocketServer_PythonToCpp_QWebSocketServer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebSocketServer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebSocketServer_PythonToCpp_QWebSocketServer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebSocketServer_TypeF()))
        return QWebSocketServer_PythonToCpp_QWebSocketServer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebSocketServer_PTR_CppToPython_QWebSocketServer(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QWebSocketServer *>(const_cast<void *>(cppIn)), Sbk_QWebSocketServer_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebSocketServer_SignatureStrings[] = {
    "PySide6.QtWebSockets.QWebSocketServer(self,serverName:QString,secureMode:PySide6.QtWebSockets.QWebSocketServer.SslMode,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtWebSockets.QWebSocketServer.close(self)",
    "PySide6.QtWebSockets.QWebSocketServer.error(self)->PySide6.QtWebSockets.QWebSocketProtocol.CloseCode",
    "PySide6.QtWebSockets.QWebSocketServer.errorString(self)->QString",
    "PySide6.QtWebSockets.QWebSocketServer.handleConnection(self,socket:PySide6.QtNetwork.QTcpSocket)",
    "PySide6.QtWebSockets.QWebSocketServer.handshakeTimeout(self)->std.chrono.milliseconds",
    "PySide6.QtWebSockets.QWebSocketServer.handshakeTimeoutMS(self)->int",
    "PySide6.QtWebSockets.QWebSocketServer.hasPendingConnections(self)->bool",
    "PySide6.QtWebSockets.QWebSocketServer.isListening(self)->bool",
    "PySide6.QtWebSockets.QWebSocketServer.listen(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress]=QHostAddress.Any,port:quint16=0)->bool",
    "PySide6.QtWebSockets.QWebSocketServer.maxPendingConnections(self)->int",
    "PySide6.QtWebSockets.QWebSocketServer.nativeDescriptor(self)->qintptr",
    "PySide6.QtWebSockets.QWebSocketServer.nextPendingConnection(self)->PySide6.QtWebSockets.QWebSocket",
    "PySide6.QtWebSockets.QWebSocketServer.pauseAccepting(self)",
    "PySide6.QtWebSockets.QWebSocketServer.proxy(self)->PySide6.QtNetwork.QNetworkProxy",
    "PySide6.QtWebSockets.QWebSocketServer.resumeAccepting(self)",
    "PySide6.QtWebSockets.QWebSocketServer.secureMode(self)->PySide6.QtWebSockets.QWebSocketServer.SslMode",
    "PySide6.QtWebSockets.QWebSocketServer.serverAddress(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtWebSockets.QWebSocketServer.serverName(self)->QString",
    "PySide6.QtWebSockets.QWebSocketServer.serverPort(self)->quint16",
    "PySide6.QtWebSockets.QWebSocketServer.serverUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebSockets.QWebSocketServer.setHandshakeTimeout(self,msec:int)",
    "PySide6.QtWebSockets.QWebSocketServer.setMaxPendingConnections(self,numConnections:int)",
    "PySide6.QtWebSockets.QWebSocketServer.setNativeDescriptor(self,descriptor:qintptr)->bool",
    "PySide6.QtWebSockets.QWebSocketServer.setProxy(self,networkProxy:typing.Union[PySide6.QtNetwork.QNetworkProxy, PySide6.QtNetwork.QNetworkProxy.ProxyType])",
    "PySide6.QtWebSockets.QWebSocketServer.setServerName(self,serverName:QString)",
    "PySide6.QtWebSockets.QWebSocketServer.setSocketDescriptor(self,socketDescriptor:qintptr)->bool",
    "PySide6.QtWebSockets.QWebSocketServer.setSslConfiguration(self,sslConfiguration:PySide6.QtNetwork.QSslConfiguration)",
    "PySide6.QtWebSockets.QWebSocketServer.setSupportedSubprotocols(self,protocols:QStringList)",
    "PySide6.QtWebSockets.QWebSocketServer.socketDescriptor(self)->qintptr",
    "PySide6.QtWebSockets.QWebSocketServer.sslConfiguration(self)->PySide6.QtNetwork.QSslConfiguration",
    "PySide6.QtWebSockets.QWebSocketServer.supportedSubprotocols(self)->QStringList",
    "PySide6.QtWebSockets.QWebSocketServer.supportedVersions(self)->QList[PySide6.QtWebSockets.QWebSocketProtocol.Version]",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebSocketServer_SignatureByteSize = 594;
static constexpr uint8_t QWebSocketServer_SignatureBytes[594] = {
    0x78, 0xda, 0x9d, 0x56, 0x3b, 0x6f, 0xdb, 0x30, 0x10, 0xde, 0xf3, 0x2b, 0x3a, 0xd6, 0x80, 0x4a,
    0xb4, 0x4b, 0x06, 0x01, 0x2e, 0x60, 0xb8, 0x43, 0x86, 0xda, 0x95, 0x20, 0xa7, 0x1d, 0x02, 0x0f,
    0x32, 0x75, 0x89, 0x59, 0x53, 0x24, 0x43, 0x9e, 0x52, 0xeb, 0xdf, 0x97, 0x7a, 0x5a, 0x96, 0xe5,
    0x84, 0xf4, 0x62, 0x8b, 0x8f, 0xfb, 0xee, 0xee, 0xbb, 0x17, 0xa3, 0x32, 0x61, 0x19, 0xdc, 0x93,
    0x18, 0xff, 0xc0, 0x2e, 0x91, 0xf4, 0x00, 0x68, 0x48, 0xdc, 0x7f, 0x27, 0xa0, 0xdf, 0x40, 0x7f,
    0x36, 0xc0, 0x9f, 0x03, 0x53, 0x7f, 0xaf, 0xd3, 0x1c, 0xc2, 0x38, 0x41, 0xcd, 0xc4, 0x8b, 0xdd,
    0xa2, 0x85, 0x86, 0x95, 0xcc, 0x20, 0x8c, 0x5c, 0x80, 0x48, 0x62, 0x78, 0x75, 0x3b, 0x50, 0xa9,
    0x06, 0x81, 0x03, 0xa1, 0xa5, 0xd4, 0x40, 0xe2, 0x5f, 0xbb, 0xbf, 0x40, 0x71, 0x2e, 0x0a, 0xce,
    0x15, 0xea, 0xd9, 0x9d, 0x1b, 0x28, 0xe5, 0xd2, 0x40, 0x6d, 0xa3, 0xab, 0x04, 0x68, 0x2d, 0x1b,
    0xaf, 0x66, 0x5f, 0xbe, 0x7f, 0x20, 0x12, 0x69, 0x89, 0x92, 0x4a, 0x4e, 0x96, 0x95, 0x9a, 0xa5,
    0xb5, 0xde, 0x47, 0x49, 0x43, 0x54, 0xa7, 0xaa, 0xe5, 0xcd, 0x11, 0x60, 0x9f, 0x8a, 0x8c, 0x5b,
    0x8d, 0x42, 0x58, 0x52, 0x98, 0x14, 0x6d, 0x18, 0xea, 0x2b, 0x03, 0xea, 0xd6, 0x80, 0xff, 0xa4,
    0x3e, 0x90, 0x78, 0x43, 0x55, 0x23, 0x3f, 0xf3, 0x50, 0x60, 0xf6, 0xe9, 0x01, 0x36, 0x2c, 0x07,
    0x59, 0x60, 0x67, 0xa6, 0xc1, 0x8c, 0xd0, 0xbd, 0x96, 0x42, 0x92, 0x9c, 0x71, 0xce, 0x6c, 0x98,
    0xa5, 0xbd, 0x79, 0x23, 0xea, 0x2a, 0xe9, 0x70, 0x99, 0x40, 0x67, 0x0c, 0x13, 0x81, 0xc8, 0x2c,
    0x57, 0x27, 0xf7, 0x4d, 0x07, 0xb3, 0x93, 0x92, 0x3b, 0xe2, 0x30, 0xf3, 0x93, 0x19, 0x04, 0x31,
    0x88, 0x81, 0x87, 0x34, 0xaf, 0x65, 0x1b, 0xda, 0xd3, 0x2c, 0xd3, 0x60, 0x4c, 0x88, 0xa5, 0xb2,
    0x60, 0xe4, 0x51, 0x58, 0x8b, 0x9e, 0x26, 0x82, 0xf0, 0x20, 0x0d, 0x2e, 0x9a, 0xbb, 0xc1, 0xa7,
    0xf7, 0xcf, 0x49, 0xa2, 0x80, 0xb2, 0x94, 0xb7, 0xcb, 0xed, 0xfc, 0xec, 0x70, 0x21, 0xca, 0x40,
    0x49, 0x8d, 0xe1, 0x6b, 0x61, 0x79, 0xfb, 0x76, 0x3f, 0xff, 0xea, 0x67, 0x7c, 0x9e, 0x1e, 0xaf,
    0x53, 0xe8, 0x1e, 0x09, 0x91, 0x22, 0x7b, 0x83, 0x1f, 0x60, 0xa8, 0x66, 0x0a, 0x4f, 0x55, 0xf3,
    0x6a, 0x21, 0x6c, 0x8d, 0xba, 0xa2, 0xc0, 0x11, 0x2f, 0xac, 0x71, 0x2c, 0x40, 0x47, 0x15, 0x2a,
    0x2d, 0x0c, 0x2c, 0x28, 0x05, 0x85, 0x7d, 0xb4, 0x5d, 0x45, 0xb5, 0x3c, 0x96, 0x97, 0xd6, 0xf4,
    0x31, 0x6b, 0x3f, 0xa2, 0xea, 0x9a, 0x23, 0xa4, 0x0d, 0x61, 0x91, 0xdf, 0x68, 0xce, 0xa9, 0xab,
    0x3a, 0x32, 0x74, 0xde, 0x5c, 0x9d, 0xb5, 0x54, 0x7f, 0x6d, 0xb6, 0xbd, 0xe3, 0xfc, 0x20, 0x27,
    0xbd, 0x90, 0xab, 0x41, 0x71, 0x5b, 0xdf, 0x6b, 0xe4, 0x23, 0x9b, 0xfb, 0x7d, 0xb2, 0x35, 0x25,
    0xe0, 0x25, 0xff, 0xa8, 0xf9, 0xa5, 0x57, 0xcd, 0x98, 0xb1, 0x47, 0xce, 0x50, 0xf8, 0x30, 0xd5,
    0x24, 0x83, 0xdc, 0x06, 0x29, 0xb4, 0x46, 0xb9, 0xc7, 0x14, 0x57, 0x57, 0x0b, 0x32, 0x10, 0x45,
    0x3e, 0xd8, 0xf3, 0xc4, 0x5d, 0x4f, 0x55, 0x68, 0x90, 0xf5, 0xeb, 0xb0, 0x2d, 0x55, 0xbf, 0xf6,
    0x61, 0xea, 0xc9, 0xd7, 0x96, 0x45, 0x20, 0x06, 0x15, 0xf0, 0x61, 0x0b, 0x1c, 0x96, 0xcb, 0x64,
    0x0f, 0x1c, 0x5e, 0x20, 0xf5, 0xef, 0xa6, 0x54, 0xb0, 0xf5, 0xf0, 0x39, 0x39, 0x4f, 0xb1, 0x89,
    0xb7, 0x89, 0x0f, 0x58, 0xbd, 0x1e, 0x13, 0x68, 0x46, 0xbb, 0x37, 0xd3, 0x68, 0xcb, 0xd2, 0x06,
    0xf7, 0x99, 0xbd, 0x14, 0x3a, 0x1d, 0x8c, 0xf1, 0xd1, 0xee, 0xd4, 0x40, 0x1f, 0x4b, 0xfa, 0xf8,
    0x54, 0xa8, 0x6a, 0x78, 0x40, 0x96, 0x14, 0x3b, 0xd5, 0xbe, 0x60, 0xda, 0x64, 0xeb, 0x97, 0x1d,
    0x55, 0xd5, 0x88, 0x74, 0x86, 0x9e, 0xe2, 0xca, 0x7b, 0x1c, 0x98, 0x29, 0x4a, 0xa6, 0xdb, 0xcf,
    0x98, 0x03, 0x57, 0x0d, 0x57, 0xfd, 0x3f, 0xb5, 0xa3, 0xca, 0x6f, 0x5f, 0xb8, 0xdf, 0xa0, 0xcd,
    0x70, 0x90, 0xc6, 0x15, 0xc8, 0x93, 0xeb, 0x13, 0xb2, 0x95, 0xde, 0xde, 0xfd, 0x07, 0xa1, 0xac,
    0x45, 0x5e
};
#endif

PyTypeObject *init_QWebSocketServer(PyObject *module)
{
    if (SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX].type != nullptr)
        return SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebSocketServer_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QWebSocketServer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebSocketServer",
        "QWebSocketServer*",
        &Sbk_QWebSocketServer_spec,
        &Shiboken::callCppDestructor< QWebSocketServer >,
        Sbk_QWebSocketServer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWebSocketServer_TypeF(); // references _Sbk_QWebSocketServer_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebSocketServer_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebSocketServer_SignatureBytes, QWebSocketServer_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebSocketServer_PropertyStrings);
    SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebSocketServer_PythonToCpp_QWebSocketServer_PTR,
        is_QWebSocketServer_PythonToCpp_QWebSocketServer_PTR_Convertible,
        QWebSocketServer_PTR_CppToPython_QWebSocketServer);

    Shiboken::Conversions::registerConverterName(converter, "QWebSocketServer");
    Shiboken::Conversions::registerConverterName(converter, "QWebSocketServer*");
    Shiboken::Conversions::registerConverterName(converter, "QWebSocketServer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebSocketServer).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QWebSocketServerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QWebSocketServer_TypeF(), &Sbk_QWebSocketServer_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWebSocketServer_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SslMode'.
    const char *SslMode_Initializer[] = {
        "SecureMode",
        "NonSecureMode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SslMode_InitializerValues[] = {
        uint8_t(QWebSocketServer::SslMode::SecureMode),   //  0x00  0
        uint8_t(QWebSocketServer::SslMode::NonSecureMode) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebSocketServer_TypeF(),
        "2:PySide6.QtWebSockets.QWebSocketServer.SslMode",
        SslMode_Initializer, SslMode_InitializerValues);
    SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketServer_SslMode_IDX].type = EType;
    // Register converter for enum 'QWebSocketServer::SslMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebSocketServer_SslMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebSocketServer_SslMode,
            is_Enum_PythonToCpp_QWebSocketServer_SslMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebSocketServer::SslMode");
        Shiboken::Conversions::registerConverterAlias(converter, "SslMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SslMode' enum.

    PySide::Signal::registerSignals(pyType, &::QWebSocketServer::staticMetaObject);
    qRegisterMetaType< ::QWebSocketServer::SslMode >("QWebSocketServer::SslMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QWebSocketServer::staticMetaObject, sizeof(QWebSocketServerWrapper));

    return pyType;
}
