// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QABSTRACTITEMVIEWWRAPPER_H
#define SBK_QABSTRACTITEMVIEWWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qabstractitemview.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QAbstractItemViewWrapper : public QAbstractItemView
{
public:
    QAbstractItemViewWrapper(::QWidget * parent = nullptr);
    QAbstractItemViewWrapper(const QAbstractItemViewWrapper &) = delete;
    QAbstractItemViewWrapper& operator=(const QAbstractItemViewWrapper &) = delete;
    QAbstractItemViewWrapper(QAbstractItemViewWrapper &&) = delete;
    QAbstractItemViewWrapper& operator=(QAbstractItemViewWrapper &&) = delete;
    ~QAbstractItemViewWrapper() override;

    void actionEvent(::QActionEvent * event) override;
    void changeEvent(::QEvent * arg__1) override;
    void childEvent(::QChildEvent * event) override;
    void closeEditor(::QWidget * editor, ::QAbstractItemDelegate::EndEditHint hint) override;
    static void sbk_o_closeEditor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * editor, ::QAbstractItemDelegate::EndEditHint hint);
    void closeEvent(::QCloseEvent * event) override;
    void commitData(::QWidget * editor) override;
    static void sbk_o_commitData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * editor);
    void connectNotify(const ::QMetaMethod & signal) override;
    void contextMenuEvent(::QContextMenuEvent * arg__1) override;
    void currentChanged(const ::QModelIndex & current, const ::QModelIndex & previous) override;
    static void sbk_o_currentChanged(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & current, const ::QModelIndex & previous);
    void customEvent(::QEvent * event) override;
    void dataChanged(const ::QModelIndex & topLeft, const ::QModelIndex & bottomRight, const ::QList<int> & roles = QList<int>()) override;
    static void sbk_o_dataChanged(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & topLeft, const ::QModelIndex & bottomRight, const ::QList<int> & roles = QList<int>());
    int devType() const override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    void doItemsLayout() override;
    void dragEnterEvent(::QDragEnterEvent * event) override;
    void dragLeaveEvent(::QDragLeaveEvent * event) override;
    void dragMoveEvent(::QDragMoveEvent * event) override;
    void dropEvent(::QDropEvent * event) override;
    bool edit(const ::QModelIndex & index, ::QAbstractItemView::EditTrigger trigger, ::QEvent * event) override;
    static bool sbk_o_edit(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & index, ::QAbstractItemView::EditTrigger trigger, ::QEvent * event);
    // Inherited overloads, because the using keyword sux
    void edit(const ::QModelIndex & index) { QAbstractItemView::edit(index); }

    void editorDestroyed(::QObject * editor) override;
    static void sbk_o_editorDestroyed(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * editor);
    void enterEvent(::QEnterEvent * event) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * object, ::QEvent * event) override;
    void focusInEvent(::QFocusEvent * event) override;
    bool focusNextPrevChild(bool next) override;
    void focusOutEvent(::QFocusEvent * event) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(::QHideEvent * event) override;
    int horizontalOffset() const override;
    void horizontalScrollbarAction(int action) override;
    void horizontalScrollbarValueChanged(int value) override;
    ::QModelIndex indexAt(const ::QPoint & point) const override;
    static ::QModelIndex sbk_o_indexAt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPoint & point);
    void initPainter(::QPainter * painter) const override;
    void initStyleOption(::QStyleOptionFrame * option) const override;
    void initViewItemOption(::QStyleOptionViewItem * option) const override;
    static void sbk_o_initViewItemOption(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyleOptionViewItem * option);
    void inputMethodEvent(::QInputMethodEvent * event) override;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery query) const override;
    bool isIndexHidden(const ::QModelIndex & index) const override;
    static bool sbk_o_isIndexHidden(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & index);
    ::QAbstractItemDelegate * itemDelegateForIndex(const ::QModelIndex & index) const override;
    static ::QAbstractItemDelegate * sbk_o_itemDelegateForIndex(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & index);
    void keyPressEvent(::QKeyEvent * event) override;
    void keyReleaseEvent(::QKeyEvent * event) override;
    void keyboardSearch(const ::QString & search) override;
    void leaveEvent(::QEvent * event) override;
    int metric(::QPaintDevice::PaintDeviceMetric arg__1) const override;
    ::QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(::QMouseEvent * event) override;
    void mouseMoveEvent(::QMouseEvent * event) override;
    void mousePressEvent(::QMouseEvent * event) override;
    void mouseReleaseEvent(::QMouseEvent * event) override;
    ::QModelIndex moveCursor(::QAbstractItemView::CursorAction cursorAction, ::QFlags<Qt::KeyboardModifier> modifiers) override;
    static ::QModelIndex sbk_o_moveCursor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAbstractItemView::CursorAction cursorAction, ::QFlags<Qt::KeyboardModifier> modifiers);
    void moveEvent(::QMoveEvent * event) override;
    bool nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result) override;
    ::QPaintEngine * paintEngine() const override;
    void paintEvent(::QPaintEvent * arg__1) override;
    ::QPaintDevice * redirected(::QPoint * offset) const override;
    void reset() override;
    void resizeEvent(::QResizeEvent * event) override;
    void rowsAboutToBeRemoved(const ::QModelIndex & parent, int start, int end) override;
    static void sbk_o_rowsAboutToBeRemoved(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & parent, int start, int end);
    void rowsInserted(const ::QModelIndex & parent, int start, int end) override;
    void scrollContentsBy(int dx, int dy) override;
    void scrollTo(const ::QModelIndex & index, ::QAbstractItemView::ScrollHint hint = QAbstractItemView::ScrollHint::EnsureVisible) override;
    static void sbk_o_scrollTo(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & index, ::QAbstractItemView::ScrollHint hint = QAbstractItemView::ScrollHint::EnsureVisible);
    void selectAll() override;
    ::QList<QModelIndex> selectedIndexes() const override;
    static ::QList<QModelIndex> sbk_o_selectedIndexes(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void selectionChanged(const ::QItemSelection & selected, const ::QItemSelection & deselected) override;
    static void sbk_o_selectionChanged(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QItemSelection & selected, const ::QItemSelection & deselected);
    ::QFlags<QItemSelectionModel::SelectionFlag> selectionCommand(const ::QModelIndex & index, const ::QEvent * event = nullptr) const override;
    static ::QFlags<QItemSelectionModel::SelectionFlag> sbk_o_selectionCommand(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & index, const ::QEvent * event = nullptr);
    void setModel(::QAbstractItemModel * model) override;
    static void sbk_o_setModel(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAbstractItemModel * model);
    void setRootIndex(const ::QModelIndex & index) override;
    static void sbk_o_setRootIndex(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & index);
    void setSelection(const ::QRect & rect, ::QFlags<QItemSelectionModel::SelectionFlag> command) override;
    static void sbk_o_setSelection(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRect & rect, ::QFlags<QItemSelectionModel::SelectionFlag> command);
    void setSelectionModel(::QItemSelectionModel * selectionModel) override;
    static void sbk_o_setSelectionModel(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QItemSelectionModel * selectionModel);
    void setVisible(bool visible) override;
    void setupViewport(::QWidget * viewport) override;
    ::QPainter * sharedPainter() const override;
    void showEvent(::QShowEvent * event) override;
    ::QSize sizeHint() const override;
    int sizeHintForColumn(int column) const override;
    int sizeHintForRow(int row) const override;
    void startDrag(::QFlags<Qt::DropAction> supportedActions) override;
    static void sbk_o_startDrag(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<Qt::DropAction> supportedActions);
    void tabletEvent(::QTabletEvent * event) override;
    void timerEvent(::QTimerEvent * event) override;
    void updateEditorData() override;
    void updateEditorGeometries() override;
    void updateGeometries() override;
    int verticalOffset() const override;
    void verticalScrollbarAction(int action) override;
    void verticalScrollbarValueChanged(int value) override;
    bool viewportEvent(::QEvent * event) override;
    ::QSize viewportSizeHint() const override;
    ::QRect visualRect(const ::QModelIndex & index) const override;
    static ::QRect sbk_o_visualRect(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & index);
    ::QRegion visualRegionForSelection(const ::QItemSelection & selection) const override;
    static ::QRegion sbk_o_visualRegionForSelection(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QItemSelection & selection);
    void wheelEvent(::QWheelEvent * arg__1) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[91] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QABSTRACTITEMVIEWWRAPPER_H
