// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qabstractslider_wrapper.h"

// Wrappers providing overrides
#include "qlayoutitem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qwidget_wrapper.h"
#include "qwizardpage_wrapper.h"
#include "qgraphicsitem_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtWidgets/qabstractslider.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractSliderWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractSliderWrapper::QAbstractSliderWrapper(::QWidget * parent) : QAbstractSlider(parent)
{
}

void QAbstractSliderWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QWizardPageWrapper::sbk_o_actionEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::changeEvent(::QEvent * e)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSlider::changeEvent(e);
    }
    QWizardPageWrapper::sbk_o_changeEvent("QAbstractSlider", funcName, gil, pyOverride, e);
}

void QAbstractSliderWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWidgetWrapper::sbk_o_childEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QWizardPageWrapper::sbk_o_closeEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QAbstractSlider", funcName, gil, pyOverride, signal);
}

void QAbstractSliderWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::contextMenuEvent(event);
    }
    QWizardPageWrapper::sbk_o_contextMenuEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

int QAbstractSliderWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QAbstractSlider", funcName, gil, pyOverride);
}

void QAbstractSliderWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QAbstractSlider", funcName, gil, pyOverride, signal);
}

void QAbstractSliderWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragEnterEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragLeaveEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragMoveEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QWizardPageWrapper::sbk_o_dropEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QWizardPageWrapper::sbk_o_enterEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

bool QAbstractSliderWrapper::event(::QEvent * e)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSlider::event(e);
    }
    return QWidgetWrapper::sbk_o_event("QAbstractSlider", funcName, gil, pyOverride, e);
}

bool QAbstractSliderWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QAbstractSlider", funcName, gil, pyOverride, watched, event);
}

void QAbstractSliderWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusInEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusInEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

bool QAbstractSliderWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QWidgetWrapper::sbk_o_focusNextPrevChild("QAbstractSlider", funcName, gil, pyOverride, next);
}

void QAbstractSliderWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusOutEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusOutEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

bool QAbstractSliderWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QAbstractSlider", funcName, gil, pyOverride);
}

int QAbstractSliderWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QAbstractSlider", funcName, gil, pyOverride, arg__1);
}

void QAbstractSliderWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QWizardPageWrapper::sbk_o_hideEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QWidgetWrapper::sbk_o_initPainter("QAbstractSlider", funcName, gil, pyOverride, painter);
}

void QAbstractSliderWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QWizardPageWrapper::sbk_o_inputMethodEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

::QVariant QAbstractSliderWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodQuery(arg__1);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QAbstractSlider", funcName, gil, pyOverride, arg__1);
}

void QAbstractSliderWrapper::keyPressEvent(::QKeyEvent * ev)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSlider::keyPressEvent(ev);
    }
    QWizardPageWrapper::sbk_o_keyPressEvent("QAbstractSlider", funcName, gil, pyOverride, ev);
}

void QAbstractSliderWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyReleaseEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_leaveEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

int QAbstractSliderWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QWidgetWrapper::sbk_o_metric("QAbstractSlider", funcName, gil, pyOverride, arg__1);
}

::QSize QAbstractSliderWrapper::minimumSizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::minimumSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QAbstractSlider", funcName, gil, pyOverride);
}

void QAbstractSliderWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseDoubleClickEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseMoveEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mousePressEvent(event);
    }
    QWizardPageWrapper::sbk_o_mousePressEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseReleaseEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QWizardPageWrapper::sbk_o_moveEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

bool QAbstractSliderWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QWizardPageWrapper::sbk_o_nativeEvent("QAbstractSlider", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QAbstractSliderWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QWidgetWrapper::sbk_o_paintEngine("QAbstractSlider", funcName, gil, pyOverride);
}

void QAbstractSliderWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEvent(event);
    }
    QWizardPageWrapper::sbk_o_paintEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

::QPaintDevice * QAbstractSliderWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QWidgetWrapper::sbk_o_redirected("QAbstractSlider", funcName, gil, pyOverride, offset);
}

void QAbstractSliderWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::resizeEvent(event);
    }
    QWizardPageWrapper::sbk_o_resizeEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QWidgetWrapper::sbk_o_setVisible("QAbstractSlider", funcName, gil, pyOverride, visible);
}

::QPainter * QAbstractSliderWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QWidgetWrapper::sbk_o_sharedPainter("QAbstractSlider", funcName, gil, pyOverride);
}

void QAbstractSliderWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QWizardPageWrapper::sbk_o_showEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

::QSize QAbstractSliderWrapper::sizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QAbstractSlider", funcName, gil, pyOverride);
}

void QAbstractSliderWrapper::sliderChange(::QAbstractSlider::SliderChange change)
{
    static const char *funcName = "sliderChange";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSlider::sliderChange(change);
    }
    sbk_o_sliderChange("QAbstractSlider", funcName, gil, pyOverride, change);
}

void QAbstractSliderWrapper::sbk_o_sliderChange(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAbstractSlider::SliderChange change)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_SliderChange_IDX])))->converter, &change)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_SliderChange_IDX])))->converter, &change)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QAbstractSliderWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QWizardPageWrapper::sbk_o_tabletEvent("QAbstractSlider", funcName, gil, pyOverride, event);
}

void QAbstractSliderWrapper::timerEvent(::QTimerEvent * arg__1)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSlider::timerEvent(arg__1);
    }
    QWidgetWrapper::sbk_o_timerEvent("QAbstractSlider", funcName, gil, pyOverride, arg__1);
}

void QAbstractSliderWrapper::wheelEvent(::QWheelEvent * e)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSlider::wheelEvent(e);
    }
    QWizardPageWrapper::sbk_o_wheelEvent("QAbstractSlider", funcName, gil, pyOverride, e);
}

const QMetaObject *QAbstractSliderWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QAbstractSlider::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstractSliderWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QAbstractSlider::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstractSliderWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstractSliderWrapper *>(this));
    return QAbstractSlider::qt_metacast(_clname);
}

QAbstractSliderWrapper::~QAbstractSliderWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractSlider_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstractSlider >()))
        return -1;

    QAbstractSliderWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QAbstractSlider", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAbstractSlider::QAbstractSlider(QWidget*=)
    if (numArgs == 0) {
        overloadId = 0; // QAbstractSlider(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QAbstractSlider(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractSlider(QWidget*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QAbstractSliderWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QAbstractSliderWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAbstractSlider >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QAbstractSliderFunc_changeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::changeEvent(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "changeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // changeEvent(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSlider::changeEvent(cppArg0)
                : cppSelf->changeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSlider::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSliderFunc_hasTracking(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasTracking()const
        bool cppResult = const_cast<const ::QAbstractSlider *>(cppSelf)->hasTracking();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSliderFunc_invertedAppearance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invertedAppearance()const
        bool cppResult = const_cast<const ::QAbstractSlider *>(cppSelf)->invertedAppearance();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSliderFunc_invertedControls(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invertedControls()const
        bool cppResult = const_cast<const ::QAbstractSlider *>(cppSelf)->invertedControls();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSliderFunc_isSliderDown(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSliderDown()const
        bool cppResult = const_cast<const ::QAbstractSlider *>(cppSelf)->isSliderDown();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSliderFunc_keyPressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::keyPressEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyPressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyPressEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSlider::keyPressEvent(cppArg0)
                : cppSelf->keyPressEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_maximum(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximum()const
        int cppResult = const_cast<const ::QAbstractSlider *>(cppSelf)->maximum();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSliderFunc_minimum(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimum()const
        int cppResult = const_cast<const ::QAbstractSlider *>(cppSelf)->minimum();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSliderFunc_orientation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // orientation()const
        Qt::Orientation cppResult = const_cast<const ::QAbstractSlider *>(cppSelf)->orientation();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSliderFunc_pageStep(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pageStep()const
        int cppResult = const_cast<const ::QAbstractSlider *>(cppSelf)->pageStep();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSliderFunc_repeatAction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // repeatAction()const
        QAbstractSlider::SliderAction cppResult = const_cast<const ::QAbstractSlider *>(cppSelf)->repeatAction();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_SliderAction_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSliderFunc_setInvertedAppearance(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSlider::setInvertedAppearance(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setInvertedAppearance(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInvertedAppearance", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInvertedAppearance(bool)
            cppSelf->setInvertedAppearance(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_setInvertedControls(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSlider::setInvertedControls(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setInvertedControls(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInvertedControls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInvertedControls(bool)
            cppSelf->setInvertedControls(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_setMaximum(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSlider::setMaximum(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMaximum(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaximum", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximum(int)
            cppSelf->setMaximum(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_setMinimum(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSlider::setMinimum(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMinimum(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinimum", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinimum(int)
            cppSelf->setMinimum(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_setOrientation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSlider::setOrientation(Qt::Orientation)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setOrientation(Qt::Orientation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOrientation", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        ::Qt::Orientation cppArg0 = static_cast< ::Qt::Orientation>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOrientation(Qt::Orientation)
            cppSelf->setOrientation(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_setPageStep(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSlider::setPageStep(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setPageStep(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPageStep", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPageStep(int)
            cppSelf->setPageStep(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_setRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractSlider::setRange(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setRange(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRange", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRange(int,int)
            cppSelf->setRange(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_setRepeatAction(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setRepeatAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setRepeatAction", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractSlider::setRepeatAction(QAbstractSlider::SliderAction,int=,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_SliderAction_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setRepeatAction(QAbstractSlider::SliderAction,int,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setRepeatAction(QAbstractSlider::SliderAction,int,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 0; // setRepeatAction(QAbstractSlider::SliderAction,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRepeatAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"thresholdTime", 1}, {"repeatTime", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setRepeatAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);
            }
        }
        ::QAbstractSlider::SliderAction cppArg0{QAbstractSlider::SliderNoAction};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 500;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = 50;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRepeatAction(QAbstractSlider::SliderAction,int,int)
            cppSelf->setRepeatAction(cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_setSingleStep(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSlider::setSingleStep(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSingleStep(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSingleStep", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSingleStep(int)
            cppSelf->setSingleStep(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_setSliderDown(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSlider::setSliderDown(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSliderDown(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSliderDown", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSliderDown(bool)
            cppSelf->setSliderDown(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_setSliderPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSlider::setSliderPosition(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSliderPosition(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSliderPosition", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSliderPosition(int)
            cppSelf->setSliderPosition(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_setTracking(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSlider::setTracking(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setTracking(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTracking", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTracking(bool)
            cppSelf->setTracking(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_setValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSlider::setValue(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setValue(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setValue", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValue(int)
            cppSelf->setValue(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_singleStep(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // singleStep()const
        int cppResult = const_cast<const ::QAbstractSlider *>(cppSelf)->singleStep();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSliderFunc_sliderChange(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSlider::sliderChange(QAbstractSlider::SliderChange)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_SliderChange_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // sliderChange(QAbstractSlider::SliderChange)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "sliderChange", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        ::QAbstractSlider::SliderChange cppArg0{QAbstractSlider::SliderRangeChange};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sliderChange(QAbstractSlider::SliderChange)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSlider::sliderChange(cppArg0)
                : cppSelf->sliderChange(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_sliderPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sliderPosition()const
        int cppResult = const_cast<const ::QAbstractSlider *>(cppSelf)->sliderPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSliderFunc_timerEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::timerEvent(QTimerEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), (pyArg)))) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "timerEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTimerEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // timerEvent(QTimerEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSlider::timerEvent(cppArg0)
                : cppSelf->timerEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_triggerAction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSlider::triggerAction(QAbstractSlider::SliderAction)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_SliderAction_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // triggerAction(QAbstractSlider::SliderAction)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "triggerAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        ::QAbstractSlider::SliderAction cppArg0{QAbstractSlider::SliderNoAction};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // triggerAction(QAbstractSlider::SliderAction)
            cppSelf->triggerAction(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractSliderFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()const
        int cppResult = const_cast<const ::QAbstractSlider *>(cppSelf)->value();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractSliderFunc_wheelEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::wheelEvent(QWheelEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), (pyArg)))) {
        overloadId = 0; // wheelEvent(QWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "wheelEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWheelEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wheelEvent(QWheelEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSlider::wheelEvent(cppArg0)
                : cppSelf->wheelEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QAbstractSlider_PropertyStrings[] = {
    "invertedAppearance::",
    "invertedControls::",
    "maximum::",
    "minimum::",
    "orientation::",
    "pageStep::",
    "singleStep::",
    "sliderDown:isSliderDown:",
    "sliderPosition::",
    "tracking:hasTracking:",
    "value::",
    nullptr // Sentinel
};

static const char *Sbk_QAbstractSlider_EnumFlagInfo[] = {
    "SliderAction:Enum",
    "SliderChange:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractSlider_methods[] = {
    {"changeEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_changeEvent), METH_O, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_event), METH_O, nullptr},
    {"hasTracking", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_hasTracking), METH_NOARGS, nullptr},
    {"invertedAppearance", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_invertedAppearance), METH_NOARGS, nullptr},
    {"invertedControls", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_invertedControls), METH_NOARGS, nullptr},
    {"isSliderDown", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_isSliderDown), METH_NOARGS, nullptr},
    {"keyPressEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_keyPressEvent), METH_O, nullptr},
    {"maximum", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_maximum), METH_NOARGS, nullptr},
    {"minimum", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_minimum), METH_NOARGS, nullptr},
    {"orientation", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_orientation), METH_NOARGS, nullptr},
    {"pageStep", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_pageStep), METH_NOARGS, nullptr},
    {"repeatAction", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_repeatAction), METH_NOARGS, nullptr},
    {"setInvertedAppearance", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_setInvertedAppearance), METH_O, nullptr},
    {"setInvertedControls", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_setInvertedControls), METH_O, nullptr},
    {"setMaximum", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_setMaximum), METH_O, nullptr},
    {"setMinimum", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_setMinimum), METH_O, nullptr},
    {"setOrientation", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_setOrientation), METH_O, nullptr},
    {"setPageStep", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_setPageStep), METH_O, nullptr},
    {"setRange", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_setRange), METH_VARARGS, nullptr},
    {"setRepeatAction", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_setRepeatAction), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setSingleStep", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_setSingleStep), METH_O, nullptr},
    {"setSliderDown", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_setSliderDown), METH_O, nullptr},
    {"setSliderPosition", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_setSliderPosition), METH_O, nullptr},
    {"setTracking", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_setTracking), METH_O, nullptr},
    {"setValue", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_setValue), METH_O, nullptr},
    {"singleStep", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_singleStep), METH_NOARGS, nullptr},
    {"sliderChange", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_sliderChange), METH_O, nullptr},
    {"sliderPosition", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_sliderPosition), METH_NOARGS, nullptr},
    {"timerEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_timerEvent), METH_O, nullptr},
    {"triggerAction", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_triggerAction), METH_O, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_value), METH_NOARGS, nullptr},
    {"wheelEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractSliderFunc_wheelEvent), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractSlider_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstractSlider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractSliderWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractSlider_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractSlider_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QAbstractSliderSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QAbstractSlider *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractSlider_Type = nullptr;
static PyTypeObject *Sbk_QAbstractSlider_TypeF(void)
{
    return _Sbk_QAbstractSlider_Type;
}

static PyType_Slot Sbk_QAbstractSlider_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractSlider_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractSlider_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractSlider_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractSlider_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractSlider_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractSlider_spec = {
    "2:PySide6.QtWidgets.QAbstractSlider",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractSlider_slots
};

} //extern "C"

static void *Sbk_QAbstractSlider_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QAbstractSlider *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAbstractSlider *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QAbstractSlider *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAbstractSlider_SliderAction(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractSlider::SliderAction>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractSlider::SliderAction *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractSlider_SliderAction_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_SliderAction_IDX])))
        return Enum_PythonToCpp_QAbstractSlider_SliderAction;
    return {};
}

static PyObject *QAbstractSlider_SliderAction_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractSlider::SliderAction>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractSlider::SliderAction *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_SliderAction_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractSlider_SliderChange(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractSlider::SliderChange>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractSlider::SliderChange *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractSlider_SliderChange_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_SliderChange_IDX])))
        return Enum_PythonToCpp_QAbstractSlider_SliderChange;
    return {};
}

static PyObject *QAbstractSlider_SliderChange_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractSlider::SliderChange>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractSlider::SliderChange *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_SliderChange_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractSlider_PythonToCpp_QAbstractSlider_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractSlider_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractSlider_PythonToCpp_QAbstractSlider_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractSlider_TypeF()))
        return QAbstractSlider_PythonToCpp_QAbstractSlider_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractSlider_PTR_CppToPython_QAbstractSlider(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAbstractSlider *>(const_cast<void *>(cppIn)), Sbk_QAbstractSlider_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractSlider_SignatureStrings[] = {
    "PySide6.QtWidgets.QAbstractSlider(self,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,minimum:int=None,maximum:int=None,singleStep:int=None,pageStep:int=None,value:int=None,sliderPosition:int=None,tracking:bool=None,orientation:Qt.Orientation=None,invertedAppearance:bool=None,invertedControls:bool=None,sliderDown:bool=None)",
    "PySide6.QtWidgets.QAbstractSlider.changeEvent(self,e:PySide6.QtCore.QEvent)",
    "PySide6.QtWidgets.QAbstractSlider.event(self,e:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QAbstractSlider.hasTracking(self)->bool",
    "PySide6.QtWidgets.QAbstractSlider.invertedAppearance(self)->bool",
    "PySide6.QtWidgets.QAbstractSlider.invertedControls(self)->bool",
    "PySide6.QtWidgets.QAbstractSlider.isSliderDown(self)->bool",
    "PySide6.QtWidgets.QAbstractSlider.keyPressEvent(self,ev:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtWidgets.QAbstractSlider.maximum(self)->int",
    "PySide6.QtWidgets.QAbstractSlider.minimum(self)->int",
    "PySide6.QtWidgets.QAbstractSlider.orientation(self)->PySide6.QtCore.Qt.Orientation",
    "PySide6.QtWidgets.QAbstractSlider.pageStep(self)->int",
    "PySide6.QtWidgets.QAbstractSlider.repeatAction(self)->PySide6.QtWidgets.QAbstractSlider.SliderAction",
    "PySide6.QtWidgets.QAbstractSlider.setInvertedAppearance(self,arg__1:bool)",
    "PySide6.QtWidgets.QAbstractSlider.setInvertedControls(self,arg__1:bool)",
    "PySide6.QtWidgets.QAbstractSlider.setMaximum(self,arg__1:int)",
    "PySide6.QtWidgets.QAbstractSlider.setMinimum(self,arg__1:int)",
    "PySide6.QtWidgets.QAbstractSlider.setOrientation(self,arg__1:PySide6.QtCore.Qt.Orientation)",
    "PySide6.QtWidgets.QAbstractSlider.setPageStep(self,arg__1:int)",
    "PySide6.QtWidgets.QAbstractSlider.setRange(self,min:int,max:int)",
    "PySide6.QtWidgets.QAbstractSlider.setRepeatAction(self,action:PySide6.QtWidgets.QAbstractSlider.SliderAction,thresholdTime:int=500,repeatTime:int=50)",
    "PySide6.QtWidgets.QAbstractSlider.setSingleStep(self,arg__1:int)",
    "PySide6.QtWidgets.QAbstractSlider.setSliderDown(self,arg__1:bool)",
    "PySide6.QtWidgets.QAbstractSlider.setSliderPosition(self,arg__1:int)",
    "PySide6.QtWidgets.QAbstractSlider.setTracking(self,enable:bool)",
    "PySide6.QtWidgets.QAbstractSlider.setValue(self,arg__1:int)",
    "PySide6.QtWidgets.QAbstractSlider.singleStep(self)->int",
    "PySide6.QtWidgets.QAbstractSlider.sliderChange(self,change:PySide6.QtWidgets.QAbstractSlider.SliderChange)",
    "PySide6.QtWidgets.QAbstractSlider.sliderPosition(self)->int",
    "PySide6.QtWidgets.QAbstractSlider.timerEvent(self,arg__1:PySide6.QtCore.QTimerEvent)",
    "PySide6.QtWidgets.QAbstractSlider.triggerAction(self,action:PySide6.QtWidgets.QAbstractSlider.SliderAction)",
    "PySide6.QtWidgets.QAbstractSlider.value(self)->int",
    "PySide6.QtWidgets.QAbstractSlider.wheelEvent(self,e:PySide6.QtGui.QWheelEvent)",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractSlider_SignatureByteSize = 517;
static constexpr uint8_t QAbstractSlider_SignatureBytes[517] = {
    0x78, 0xda, 0xa5, 0x56, 0xc1, 0x6e, 0xa3, 0x30, 0x10, 0xbd, 0xf7, 0x4b, 0x36, 0x15, 0x45, 0xed,
    0x61, 0x7b, 0x40, 0xea, 0x4a, 0x51, 0x76, 0x55, 0x55, 0xd5, 0x36, 0x50, 0xa2, 0xf6, 0x58, 0x39,
    0x61, 0x0a, 0x56, 0x1d, 0x1b, 0xd9, 0x0e, 0xd9, 0xfc, 0xfd, 0x1a, 0x1c, 0xc0, 0xd0, 0xa6, 0x1d,
    0xd3, 0x13, 0x30, 0xf6, 0x7b, 0x7e, 0x99, 0x79, 0xe3, 0x49, 0x7c, 0x48, 0x69, 0x06, 0xd7, 0x61,
    0xa2, 0x9f, 0x69, 0x96, 0x83, 0x56, 0x61, 0x32, 0x5f, 0x2b, 0x2d, 0xc9, 0x46, 0xa7, 0xcc, 0xac,
    0xc8, 0x1f, 0x0a, 0xd8, 0x6b, 0x50, 0x12, 0x09, 0x5c, 0x47, 0xf1, 0xfb, 0xdd, 0xf6, 0xe5, 0x86,
    0xef, 0x18, 0x2b, 0xb5, 0x0c, 0xce, 0xa3, 0x7b, 0x38, 0xec, 0x85, 0xcc, 0x96, 0x9c, 0x1d, 0x6e,
    0x1e, 0x04, 0x87, 0x60, 0x4b, 0x39, 0xdd, 0xee, 0xb6, 0x11, 0xe5, 0xfa, 0x18, 0x20, 0xff, 0x86,
    0x01, 0x45, 0x79, 0xce, 0x20, 0xd5, 0x50, 0xf6, 0xb1, 0x92, 0xe4, 0xa3, 0x48, 0x45, 0xd8, 0x0e,
    0x1c, 0x50, 0x23, 0x2f, 0x16, 0x8a, 0x6a, 0x2a, 0x78, 0x1f, 0xaf, 0xb5, 0xbf, 0x19, 0xc2, 0x68,
    0x2d, 0x04, 0xb3, 0x21, 0x21, 0xa9, 0x51, 0x4f, 0x9a, 0x7d, 0x89, 0x0e, 0x97, 0xfd, 0xa7, 0x5d,
    0xa7, 0xbc, 0x02, 0xa9, 0x21, 0x9b, 0x97, 0x25, 0x10, 0x49, 0xf8, 0x06, 0x1c, 0x70, 0xbb, 0xb8,
    0x10, 0x5c, 0x4b, 0xc1, 0x94, 0xb3, 0x64, 0x25, 0xfc, 0x16, 0x7b, 0xde, 0x07, 0x67, 0x67, 0xf1,
    0x57, 0x29, 0x0d, 0x37, 0x05, 0xe1, 0x39, 0xfc, 0xa9, 0x8c, 0x0a, 0x9b, 0x5e, 0x70, 0x32, 0xbb,
    0x10, 0x12, 0xc2, 0xa4, 0x59, 0xc4, 0x70, 0xc1, 0xd7, 0x2c, 0x17, 0xbf, 0x6a, 0x75, 0x08, 0xae,
    0x82, 0xa8, 0xd5, 0x31, 0x7b, 0x0d, 0x23, 0x1e, 0xf9, 0x3e, 0x83, 0x13, 0x09, 0xda, 0x2c, 0xfb,
    0xc2, 0x55, 0xda, 0xd5, 0xc2, 0x13, 0xfa, 0x06, 0x87, 0x58, 0x82, 0x52, 0x6e, 0x39, 0x2a, 0x27,
    0x93, 0xb7, 0x3b, 0x1a, 0x26, 0xc6, 0xd4, 0xe8, 0x8a, 0x1c, 0xed, 0xdd, 0xca, 0x30, 0xc6, 0xc4,
    0x80, 0x6c, 0x93, 0xf8, 0x81, 0x1c, 0x5f, 0xb7, 0xc0, 0xb1, 0x03, 0x06, 0x6e, 0x47, 0x50, 0xb6,
    0x6d, 0xe7, 0x27, 0x44, 0x82, 0x29, 0xbb, 0x9e, 0x6f, 0x3e, 0x56, 0x72, 0x0a, 0x65, 0x1f, 0x16,
    0x85, 0x38, 0x44, 0x81, 0xbe, 0xfb, 0xd8, 0x66, 0x01, 0x91, 0xf9, 0xcb, 0xcb, 0x55, 0xd3, 0x84,
    0x33, 0x3f, 0xa6, 0x81, 0xdf, 0x26, 0xf0, 0xfc, 0x75, 0x8a, 0xdd, 0xc2, 0x29, 0xce, 0x27, 0x35,
    0xda, 0xa9, 0xba, 0x3f, 0x7a, 0x39, 0x2a, 0x7f, 0xcb, 0xf0, 0xa9, 0x07, 0x90, 0xdc, 0xb1, 0xeb,
    0x03, 0x7f, 0x69, 0x8f, 0xf5, 0x05, 0x67, 0xb1, 0xc6, 0xd9, 0x35, 0xb0, 0xbe, 0xf5, 0x7d, 0x08,
    0xc6, 0x8e, 0x0a, 0x48, 0xf3, 0x1e, 0xf9, 0xd9, 0x2a, 0xd0, 0x85, 0xe9, 0xed, 0x42, 0xb0, 0x6c,
    0x45, 0xb7, 0x76, 0x78, 0xfc, 0xbc, 0xbc, 0x0c, 0xac, 0x5f, 0x9d, 0x10, 0x52, 0x55, 0xda, 0x0d,
    0xaa, 0x89, 0x79, 0x19, 0xdd, 0x52, 0x13, 0x0c, 0x97, 0x0e, 0xc6, 0xde, 0x44, 0x19, 0x83, 0x5b,
    0x3e, 0x00, 0x4e, 0xd6, 0x0c, 0x7c, 0x44, 0x3c, 0xd5, 0xa3, 0x78, 0xd2, 0xd9, 0xc3, 0x04, 0xa2,
    0x2f, 0x18, 0x3b, 0x69, 0x17, 0x45, 0x6f, 0x2b, 0x3b, 0x43, 0xd1, 0x76, 0xb0, 0xd0, 0x19, 0xfa,
    0xa8, 0x41, 0x82, 0xd1, 0x32, 0xb5, 0x71, 0x94, 0x74, 0x06, 0xc9, 0x89, 0x86, 0x5c, 0x75, 0xdb,
    0x30, 0x82, 0xb4, 0xa4, 0x79, 0xde, 0x1a, 0xfa, 0x1b, 0xbd, 0x80, 0x39, 0xab, 0xea, 0x0a, 0x8b,
    0xfe, 0xcd, 0xfb, 0x02, 0x80, 0x9d, 0xf8, 0x2f, 0xd3, 0xcc, 0xce, 0xe7, 0x6e, 0xc3, 0xec, 0xec,
    0x3f, 0x99, 0x7e, 0xd4, 0xf3
};
#endif

PyTypeObject *init_QAbstractSlider(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractSlider_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))));

    _Sbk_QAbstractSlider_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractSlider",
        "QAbstractSlider*",
        &Sbk_QAbstractSlider_spec,
        &Shiboken::callCppDestructor< QAbstractSlider >,
        Sbk_QAbstractSlider_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QAbstractSlider_TypeF(); // references _Sbk_QAbstractSlider_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractSlider_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractSlider_SignatureBytes, QAbstractSlider_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractSlider_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractSlider_PythonToCpp_QAbstractSlider_PTR,
        is_QAbstractSlider_PythonToCpp_QAbstractSlider_PTR_Convertible,
        QAbstractSlider_PTR_CppToPython_QAbstractSlider);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractSlider");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractSlider*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractSlider&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractSlider).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractSliderWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QAbstractSlider_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QAbstractSlider_TypeF(), &Sbk_QAbstractSliderSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAbstractSlider_TypeF(), &Sbk_QAbstractSlider_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAbstractSlider_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SliderAction'.
    const char *SliderAction_Initializer[] = {
        "SliderNoAction",
        "SliderSingleStepAdd",
        "SliderSingleStepSub",
        "SliderPageStepAdd",
        "SliderPageStepSub",
        "SliderToMinimum",
        "SliderToMaximum",
        "SliderMove",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SliderAction_InitializerValues[] = {
        uint8_t(QAbstractSlider::SliderAction::SliderNoAction),      //  0x00  0
        uint8_t(QAbstractSlider::SliderAction::SliderSingleStepAdd), //  0x01  1
        uint8_t(QAbstractSlider::SliderAction::SliderSingleStepSub), //  0x02  2
        uint8_t(QAbstractSlider::SliderAction::SliderPageStepAdd),   //  0x03  3
        uint8_t(QAbstractSlider::SliderAction::SliderPageStepSub),   //  0x04  4
        uint8_t(QAbstractSlider::SliderAction::SliderToMinimum),     //  0x05  5
        uint8_t(QAbstractSlider::SliderAction::SliderToMaximum),     //  0x06  6
        uint8_t(QAbstractSlider::SliderAction::SliderMove)           //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractSlider_TypeF(),
        "2:PySide6.QtWidgets.QAbstractSlider.SliderAction",
        SliderAction_Initializer, SliderAction_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_SliderAction_IDX].type = EType;
    // Register converter for enum 'QAbstractSlider::SliderAction'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractSlider_SliderAction_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractSlider_SliderAction,
            is_Enum_PythonToCpp_QAbstractSlider_SliderAction_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractSlider::SliderAction");
        Shiboken::Conversions::registerConverterAlias(converter, "SliderAction");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SliderAction' enum.

    // Initialization of enum 'SliderChange'.
    const char *SliderChange_Initializer[] = {
        "SliderRangeChange",
        "SliderOrientationChange",
        "SliderStepsChange",
        "SliderValueChange",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SliderChange_InitializerValues[] = {
        uint8_t(QAbstractSlider::SliderChange::SliderRangeChange),       //  0x00  0
        uint8_t(QAbstractSlider::SliderChange::SliderOrientationChange), //  0x01  1
        uint8_t(QAbstractSlider::SliderChange::SliderStepsChange),       //  0x02  2
        uint8_t(QAbstractSlider::SliderChange::SliderValueChange)        //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractSlider_TypeF(),
        "2:PySide6.QtWidgets.QAbstractSlider.SliderChange",
        SliderChange_Initializer, SliderChange_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_SliderChange_IDX].type = EType;
    // Register converter for enum 'QAbstractSlider::SliderChange'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractSlider_SliderChange_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractSlider_SliderChange,
            is_Enum_PythonToCpp_QAbstractSlider_SliderChange_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractSlider::SliderChange");
        Shiboken::Conversions::registerConverterAlias(converter, "SliderChange");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SliderChange' enum.

    PySide::Signal::registerSignals(pyType, &::QAbstractSlider::staticMetaObject);
    qRegisterMetaType< ::QAbstractSlider::SliderAction >("QAbstractSlider::SliderAction");
    qRegisterMetaType< ::QAbstractSlider::SliderChange >("QAbstractSlider::SliderChange");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAbstractSlider::staticMetaObject, sizeof(QAbstractSliderWrapper));

    return pyType;
}
