// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QACCESSIBLEWIDGETWRAPPER_H
#define SBK_QACCESSIBLEWIDGETWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qaccessiblewidget.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QAccessibleWidgetWrapper : public QAccessibleWidget
{
public:
    QAccessibleWidgetWrapper(::QWidget * o, ::QAccessible::Role r = QAccessible::Client, const ::QString & name = QString());
    QAccessibleWidgetWrapper(const QAccessibleWidgetWrapper &) = delete;
    QAccessibleWidgetWrapper& operator=(const QAccessibleWidgetWrapper &) = delete;
    QAccessibleWidgetWrapper(QAccessibleWidgetWrapper &&) = delete;
    QAccessibleWidgetWrapper& operator=(QAccessibleWidgetWrapper &&) = delete;
    ~QAccessibleWidgetWrapper() override;

    ::QStringList actionNames() const override;
    static ::QStringList sbk_o_actionNames(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QColor backgroundColor() const override;
    static ::QColor sbk_o_backgroundColor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QAccessibleInterface * child(int index) const override;
    static ::QAccessibleInterface * sbk_o_child(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int index);
    ::QAccessibleInterface * childAt(int x, int y) const override;
    static ::QAccessibleInterface * sbk_o_childAt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int x, int y);
    int childCount() const override;
    static int sbk_o_childCount(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void doAction(const ::QString & actionName) override;
    static void sbk_o_doAction(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & actionName);
    ::QAccessibleInterface * focusChild() const override;
    static ::QAccessibleInterface * sbk_o_focusChild(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QColor foregroundColor() const override;
    int indexOfChild(const ::QAccessibleInterface * child) const override;
    static int sbk_o_indexOfChild(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QAccessibleInterface * child);
    void * interface_cast(::QAccessible::InterfaceType t) override;
    static void * sbk_o_interface_cast(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAccessible::InterfaceType t);
    bool isValid() const override;
    ::QStringList keyBindingsForAction(const ::QString & actionName) const override;
    static ::QStringList sbk_o_keyBindingsForAction(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & actionName);
    ::QString localizedActionDescription(const ::QString & name) const override;
    static ::QString sbk_o_localizedActionDescription(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & name);
    ::QString localizedActionName(const ::QString & name) const override;
    ::QObject * object() const override;
    static ::QObject * sbk_o_object(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QAccessibleInterface * parent() const override;
    ::QRect rect() const override;
    ::QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>> relations(::QFlags<QAccessible::RelationFlag> match = QAccessible::AllRelations) const override;
    static ::QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>> sbk_o_relations(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<QAccessible::RelationFlag> match = QAccessible::AllRelations);
    ::QAccessible::Role role() const override;
    static ::QAccessible::Role sbk_o_role(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    void setText(::QAccessible::Text t, const ::QString & text) override;
    static void sbk_o_setText(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAccessible::Text t, const ::QString & text);
    ::QAccessible::State state() const override;
    static ::QAccessible::State sbk_o_state(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QString text(::QAccessible::Text t) const override;
    static ::QString sbk_o_text(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAccessible::Text t);
    void virtual_hook(int id, void * data) override;
    static void sbk_o_virtual_hook(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int id, void * data);
    ::QWindow * window() const override;
    static ::QWindow * sbk_o_window(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[24] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QACCESSIBLEWIDGETWRAPPER_H
