// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qgraphicsitemgroup_wrapper.h"

// Wrappers providing overrides
#include "qgraphicspixmapitem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qgraphicsitem_wrapper.h"
#include "qgraphicslayout_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtWidgets/qgraphicsitem.h>
#include <QtWidgets/qgraphicssceneevent.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qcoreevent.h>
#include <qnamespace.h>
#include <qpoint.h>
#include <qrect.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGraphicsItemGroupWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGraphicsItemGroupWrapper::QGraphicsItemGroupWrapper(::QGraphicsItem * parent) : QGraphicsItemGroup(parent)
{
}

void QGraphicsItemGroupWrapper::advance(int phase)
{
    static const char *funcName = "advance";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::advance(phase);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QGraphicsItemGroup", funcName, gil, pyOverride, phase);
}

::QRectF QGraphicsItemGroupWrapper::boundingRect() const
{
    static const char *funcName = "boundingRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItemGroup::boundingRect();
    }
    return QGraphicsItemWrapper::sbk_o_boundingRect("QGraphicsItemGroup", funcName, gil, pyOverride);
}

bool QGraphicsItemGroupWrapper::collidesWithItem(const ::QGraphicsItem * other, ::Qt::ItemSelectionMode mode) const
{
    static const char *funcName = "collidesWithItem";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::collidesWithItem(other, mode);
    }
    return QGraphicsPixmapItemWrapper::sbk_o_collidesWithItem("QGraphicsItemGroup", funcName, gil, pyOverride, other, mode);
}

bool QGraphicsItemGroupWrapper::collidesWithPath(const ::QPainterPath & path, ::Qt::ItemSelectionMode mode) const
{
    static const char *funcName = "collidesWithPath";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::collidesWithPath(path, mode);
    }
    return QGraphicsItemWrapper::sbk_o_collidesWithPath("QGraphicsItemGroup", funcName, gil, pyOverride, path, mode);
}

bool QGraphicsItemGroupWrapper::contains(const ::QPointF & point) const
{
    static const char *funcName = "contains";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::contains(point);
    }
    return QGraphicsItemWrapper::sbk_o_contains("QGraphicsItemGroup", funcName, gil, pyOverride, point);
}

void QGraphicsItemGroupWrapper::contextMenuEvent(::QGraphicsSceneContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::contextMenuEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_contextMenuEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

void QGraphicsItemGroupWrapper::dragEnterEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragEnterEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_dragEnterEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

void QGraphicsItemGroupWrapper::dragLeaveEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragLeaveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_dragLeaveEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

void QGraphicsItemGroupWrapper::dragMoveEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragMoveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_dragMoveEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

void QGraphicsItemGroupWrapper::dropEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dropEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_dropEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

::QVariant QGraphicsItemGroupWrapper::extension(const ::QVariant & variant) const
{
    static const char *funcName = "extension";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::extension(variant);
    }
    return QGraphicsItemWrapper::sbk_o_extension("QGraphicsItemGroup", funcName, gil, pyOverride, variant);
}

void QGraphicsItemGroupWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::focusInEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_focusInEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

void QGraphicsItemGroupWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::focusOutEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_focusOutEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

void QGraphicsItemGroupWrapper::hoverEnterEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::hoverEnterEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_hoverEnterEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

void QGraphicsItemGroupWrapper::hoverLeaveEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::hoverLeaveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_hoverLeaveEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

void QGraphicsItemGroupWrapper::hoverMoveEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::hoverMoveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_hoverMoveEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

void QGraphicsItemGroupWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::inputMethodEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_inputMethodEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

::QVariant QGraphicsItemGroupWrapper::inputMethodQuery(::Qt::InputMethodQuery query) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::inputMethodQuery(query);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QGraphicsItemGroup", funcName, gil, pyOverride, query);
}

bool QGraphicsItemGroupWrapper::isObscuredBy(const ::QGraphicsItem * item) const
{
    static const char *funcName = "isObscuredBy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItemGroup::isObscuredBy(item);
    }
    return QGraphicsPixmapItemWrapper::sbk_o_isObscuredBy("QGraphicsItemGroup", funcName, gil, pyOverride, item);
}

::QVariant QGraphicsItemGroupWrapper::itemChange(::QGraphicsItem::GraphicsItemChange change, const ::QVariant & value)
{
    static const char *funcName = "itemChange";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::itemChange(change, value);
    }
    return QGraphicsItemWrapper::sbk_o_itemChange("QGraphicsItemGroup", funcName, gil, pyOverride, change, value);
}

void QGraphicsItemGroupWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::keyPressEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_keyPressEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

void QGraphicsItemGroupWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::keyReleaseEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_keyReleaseEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

void QGraphicsItemGroupWrapper::mouseDoubleClickEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseDoubleClickEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_mouseDoubleClickEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

void QGraphicsItemGroupWrapper::mouseMoveEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseMoveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_mouseMoveEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

void QGraphicsItemGroupWrapper::mousePressEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mousePressEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_mousePressEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

void QGraphicsItemGroupWrapper::mouseReleaseEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseReleaseEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_mouseReleaseEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

::QPainterPath QGraphicsItemGroupWrapper::opaqueArea() const
{
    static const char *funcName = "opaqueArea";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItemGroup::opaqueArea();
    }
    return QGraphicsItemWrapper::sbk_o_opaqueArea("QGraphicsItemGroup", funcName, gil, pyOverride);
}

void QGraphicsItemGroupWrapper::paint(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget)
{
    static const char *funcName = "paint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItemGroup::paint(painter, option, widget);
    }
    QGraphicsPixmapItemWrapper::sbk_o_paint("QGraphicsItemGroup", funcName, gil, pyOverride, painter, option, widget);
}

bool QGraphicsItemGroupWrapper::sceneEvent(::QEvent * event)
{
    static const char *funcName = "sceneEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::sceneEvent(event);
    }
    return QGraphicsPixmapItemWrapper::sbk_o_sceneEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

bool QGraphicsItemGroupWrapper::sceneEventFilter(::QGraphicsItem * watched, ::QEvent * event)
{
    static const char *funcName = "sceneEventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::sceneEventFilter(watched, event);
    }
    return QGraphicsPixmapItemWrapper::sbk_o_sceneEventFilter("QGraphicsItemGroup", funcName, gil, pyOverride, watched, event);
}

::QPainterPath QGraphicsItemGroupWrapper::shape() const
{
    static const char *funcName = "shape";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::shape();
    }
    return QGraphicsItemWrapper::sbk_o_opaqueArea("QGraphicsItemGroup", funcName, gil, pyOverride);
}

int QGraphicsItemGroupWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItemGroup::type();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QGraphicsItemGroup", funcName, gil, pyOverride);
}

void QGraphicsItemGroupWrapper::wheelEvent(::QGraphicsSceneWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::wheelEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_wheelEvent("QGraphicsItemGroup", funcName, gil, pyOverride, event);
}

QGraphicsItemGroupWrapper::~QGraphicsItemGroupWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsItemGroup_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGraphicsItemGroup >()))
        return -1;

    QGraphicsItemGroupWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]);

    if (PyArg_ParseTuple(args, "|O:QGraphicsItemGroup", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGraphicsItemGroup::QGraphicsItemGroup(QGraphicsItem*=)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsItemGroup(QGraphicsItem*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QGraphicsItemGroup(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QGraphicsItem *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QGraphicsItemGroup(QGraphicsItem*)
            cptr = new QGraphicsItemGroupWrapper(cppArg0);
            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QGraphicsItemGroup >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGraphicsItemGroupFunc_addToGroup(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsItemGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsItemGroup::addToGroup(QGraphicsItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArg)))) {
        overloadId = 0; // addToGroup(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addToGroup", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addToGroup(QGraphicsItem*)
            cppSelf->addToGroup(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsItemGroupFunc_boundingRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsItemGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // boundingRect()const
        QRectF cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QGraphicsItemGroup *>(cppSelf)->::QGraphicsItemGroup::boundingRect()
            : const_cast<const ::QGraphicsItemGroup *>(cppSelf)->boundingRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsItemGroupFunc_isObscuredBy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsItemGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsItem::isObscuredBy(const QGraphicsItem*)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArg)))) {
        overloadId = 0; // isObscuredBy(const QGraphicsItem*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isObscuredBy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isObscuredBy(const QGraphicsItem*)const
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QGraphicsItemGroup *>(cppSelf)->::QGraphicsItemGroup::isObscuredBy(cppArg0)
                : const_cast<const ::QGraphicsItemGroup *>(cppSelf)->isObscuredBy(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsItemGroupFunc_opaqueArea(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsItemGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // opaqueArea()const
        QPainterPath cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QGraphicsItemGroup *>(cppSelf)->::QGraphicsItemGroup::opaqueArea()
            : const_cast<const ::QGraphicsItemGroup *>(cppSelf)->opaqueArea();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsItemGroupFunc_paint(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsItemGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "paint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:paint", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsItem::paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
            overloadId = 0; // paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "paint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"widget", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "paint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOptionGraphicsItem *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QWidget *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsItemGroup::paint(cppArg0, cppArg1, cppArg2)
                : cppSelf->paint(cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsItemGroupFunc_removeFromGroup(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsItemGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsItemGroup::removeFromGroup(QGraphicsItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArg)))) {
        overloadId = 0; // removeFromGroup(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeFromGroup", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeFromGroup(QGraphicsItem*)
            cppSelf->removeFromGroup(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsItemGroupFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsItemGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QGraphicsItemGroup *>(cppSelf)->::QGraphicsItemGroup::type()
            : const_cast<const ::QGraphicsItemGroup *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QGraphicsItemGroup_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGraphicsItemGroup_methods[] = {
    {"addToGroup", reinterpret_cast<PyCFunction>(Sbk_QGraphicsItemGroupFunc_addToGroup), METH_O, nullptr},
    {"boundingRect", reinterpret_cast<PyCFunction>(Sbk_QGraphicsItemGroupFunc_boundingRect), METH_NOARGS, nullptr},
    {"isObscuredBy", reinterpret_cast<PyCFunction>(Sbk_QGraphicsItemGroupFunc_isObscuredBy), METH_O, nullptr},
    {"opaqueArea", reinterpret_cast<PyCFunction>(Sbk_QGraphicsItemGroupFunc_opaqueArea), METH_NOARGS, nullptr},
    {"paint", reinterpret_cast<PyCFunction>(Sbk_QGraphicsItemGroupFunc_paint), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"removeFromGroup", reinterpret_cast<PyCFunction>(Sbk_QGraphicsItemGroupFunc_removeFromGroup), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QGraphicsItemGroupFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGraphicsItemGroup_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGraphicsItemGroup *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGraphicsItemGroupWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGraphicsItemGroup_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGraphicsItemGroup_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGraphicsItemGroup_Type = nullptr;
static PyTypeObject *Sbk_QGraphicsItemGroup_TypeF(void)
{
    return _Sbk_QGraphicsItemGroup_Type;
}

static PyType_Slot Sbk_QGraphicsItemGroup_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGraphicsItemGroup_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGraphicsItemGroup_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGraphicsItemGroup_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGraphicsItemGroup_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGraphicsItemGroup_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGraphicsItemGroup_spec = {
    "2:PySide6.QtWidgets.QGraphicsItemGroup",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGraphicsItemGroup_slots
};

} //extern "C"

static void *Sbk_QGraphicsItemGroup_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QGraphicsItem >())
        return dynamic_cast< ::QGraphicsItemGroup *>(reinterpret_cast< ::QGraphicsItem *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGraphicsItemGroup_PythonToCpp_QGraphicsItemGroup_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGraphicsItemGroup_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGraphicsItemGroup_PythonToCpp_QGraphicsItemGroup_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGraphicsItemGroup_TypeF()))
        return QGraphicsItemGroup_PythonToCpp_QGraphicsItemGroup_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGraphicsItemGroup_PTR_CppToPython_QGraphicsItemGroup(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QGraphicsItemGroup *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QGraphicsItemGroup_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGraphicsItemGroup_SignatureStrings[] = {
    "PySide6.QtWidgets.QGraphicsItemGroup(self,parent:PySide6.QtWidgets.QGraphicsItem=nullptr)",
    "PySide6.QtWidgets.QGraphicsItemGroup.addToGroup(self,item:PySide6.QtWidgets.QGraphicsItem)",
    "PySide6.QtWidgets.QGraphicsItemGroup.boundingRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtWidgets.QGraphicsItemGroup.isObscuredBy(self,item:PySide6.QtWidgets.QGraphicsItem)->bool",
    "PySide6.QtWidgets.QGraphicsItemGroup.opaqueArea(self)->PySide6.QtGui.QPainterPath",
    "PySide6.QtWidgets.QGraphicsItemGroup.paint(self,painter:PySide6.QtGui.QPainter,option:PySide6.QtWidgets.QStyleOptionGraphicsItem,widget:PySide6.QtWidgets.QWidget=nullptr)",
    "PySide6.QtWidgets.QGraphicsItemGroup.removeFromGroup(self,item:PySide6.QtWidgets.QGraphicsItem)",
    "PySide6.QtWidgets.QGraphicsItemGroup.type(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QGraphicsItemGroup_SignatureByteSize = 223;
static constexpr uint8_t QGraphicsItemGroup_SignatureBytes[223] = {
    0x78, 0xda, 0xb5, 0x92, 0x41, 0x6b, 0x02, 0x31, 0x10, 0x85, 0xef, 0xfe, 0x92, 0x0a, 0x6b, 0x8e,
    0x1e, 0x84, 0x0a, 0x6d, 0xc1, 0xc5, 0x93, 0x59, 0x2d, 0x78, 0xce, 0x6e, 0xa6, 0x3a, 0x90, 0xcd,
    0xa4, 0x93, 0x89, 0x65, 0xff, 0xbd, 0xba, 0x45, 0x14, 0x5c, 0xda, 0x78, 0xf0, 0x36, 0xf0, 0xe6,
    0x7d, 0x6f, 0x26, 0x19, 0xdd, 0x6d, 0xd0, 0xc2, 0x54, 0x55, 0xb2, 0x45, 0xbb, 0x03, 0x89, 0xaa,
    0x2a, 0xd9, 0x84, 0x3d, 0x36, 0x71, 0x29, 0xd0, 0x96, 0x4c, 0x29, 0xbc, 0x44, 0x70, 0x5f, 0x45,
    0x30, 0x0c, 0x5e, 0x66, 0xfa, 0x6f, 0xc3, 0xab, 0x4f, 0xce, 0x05, 0xe1, 0xf1, 0x48, 0x67, 0x90,
    0x95, 0xb1, 0xf6, 0x93, 0x6e, 0x42, 0xf0, 0xa4, 0xfc, 0x17, 0x91, 0x89, 0xae, 0x29, 0x79, 0x8b,
    0x7e, 0xb7, 0x86, 0x46, 0x7a, 0xf8, 0x78, 0x32, 0xbf, 0x1a, 0x3f, 0x88, 0x41, 0x55, 0x67, 0x6d,
    0x91, 0x87, 0xc3, 0xb8, 0xaa, 0x63, 0x93, 0x18, 0xec, 0x7b, 0xf7, 0xc0, 0xac, 0x93, 0x79, 0x4d,
    0xe4, 0xf2, 0x22, 0x28, 0x98, 0xef, 0x04, 0x6f, 0x0c, 0xe6, 0x7e, 0xde, 0x32, 0xa1, 0xaa, 0xb4,
    0x41, 0x2f, 0xc0, 0xda, 0xc8, 0x3e, 0x8f, 0x18, 0xce, 0x86, 0xcb, 0xf7, 0xf5, 0xde, 0xd9, 0x30,
    0xb2, 0xa0, 0x20, 0x48, 0x7e, 0x68, 0x9d, 0x8d, 0x74, 0x0e, 0x56, 0xbd, 0x7c, 0x1b, 0x50, 0xfc,
    0xf4, 0x0d, 0x43, 0x8e, 0xdf, 0xe2, 0xc1, 0x4b, 0x60, 0x68, 0xe9, 0x00, 0x0b, 0xa6, 0xf6, 0x39,
    0xe7, 0x20, 0x5d, 0x80, 0xcb, 0xb3, 0x9e, 0x56, 0x1e, 0x1d, 0x01, 0x9a, 0x74, 0x17, 0xee
};
#endif

PyTypeObject *init_QGraphicsItemGroup(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX].type;

    Shiboken::AutoDecRef Sbk_QGraphicsItemGroup_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]))));

    _Sbk_QGraphicsItemGroup_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGraphicsItemGroup",
        "QGraphicsItemGroup*",
        &Sbk_QGraphicsItemGroup_spec,
        &Shiboken::callCppDestructor< QGraphicsItemGroup >,
        Sbk_QGraphicsItemGroup_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGraphicsItemGroup_TypeF(); // references _Sbk_QGraphicsItemGroup_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGraphicsItemGroup_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGraphicsItemGroup_SignatureBytes, QGraphicsItemGroup_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGraphicsItemGroup_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGraphicsItemGroup_PythonToCpp_QGraphicsItemGroup_PTR,
        is_QGraphicsItemGroup_PythonToCpp_QGraphicsItemGroup_PTR_Convertible,
        QGraphicsItemGroup_PTR_CppToPython_QGraphicsItemGroup);

    Shiboken::Conversions::registerConverterName(converter, "QGraphicsItemGroup");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsItemGroup*");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsItemGroup&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGraphicsItemGroup).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGraphicsItemGroupWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QGraphicsItemGroup_TypeF(), &Sbk_QGraphicsItemGroup_typeDiscovery);


    return pyType;
}
