// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QGRAPHICSLAYOUTITEMWRAPPER_H
#define SBK_QGRAPHICSLAYOUTITEMWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qgraphicslayoutitem.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QGraphicsLayoutItemWrapper : public QGraphicsLayoutItem
{
public:
    QGraphicsLayoutItemWrapper(::QGraphicsLayoutItem * parent = nullptr, bool isLayout = false);
    QGraphicsLayoutItemWrapper(const QGraphicsLayoutItemWrapper &) = delete;
    QGraphicsLayoutItemWrapper& operator=(const QGraphicsLayoutItemWrapper &) = delete;
    QGraphicsLayoutItemWrapper(QGraphicsLayoutItemWrapper &&) = delete;
    QGraphicsLayoutItemWrapper& operator=(QGraphicsLayoutItemWrapper &&) = delete;
    ~QGraphicsLayoutItemWrapper() override;

    void getContentsMargins(qreal * left, qreal * top, qreal * right, qreal * bottom) const override;
    static void sbk_o_getContentsMargins(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, qreal * left, qreal * top, qreal * right, qreal * bottom);
    bool isEmpty() const override;
    void setGeometry(const ::QRectF & rect) override;
    static void sbk_o_setGeometry(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRectF & rect);
    ::QSizeF sizeHint(::Qt::SizeHint which, const ::QSizeF & constraint = QSizeF()) const override;
    static ::QSizeF sbk_o_sizeHint(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::Qt::SizeHint which, const ::QSizeF & constraint = QSizeF());
    void updateGeometry() override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[5] = {false, false, false, false, false};
};

#endif // SBK_QGRAPHICSLAYOUTITEMWRAPPER_H
