// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QGRAPHICSLINEARLAYOUTWRAPPER_H
#define SBK_QGRAPHICSLINEARLAYOUTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qgraphicslinearlayout.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QGraphicsLinearLayoutWrapper : public QGraphicsLinearLayout
{
public:
    QGraphicsLinearLayoutWrapper(::QGraphicsLayoutItem * parent = nullptr);
    QGraphicsLinearLayoutWrapper(::Qt::Orientation orientation, ::QGraphicsLayoutItem * parent = nullptr);
    QGraphicsLinearLayoutWrapper(const QGraphicsLinearLayoutWrapper &) = delete;
    QGraphicsLinearLayoutWrapper& operator=(const QGraphicsLinearLayoutWrapper &) = delete;
    QGraphicsLinearLayoutWrapper(QGraphicsLinearLayoutWrapper &&) = delete;
    QGraphicsLinearLayoutWrapper& operator=(QGraphicsLinearLayoutWrapper &&) = delete;
    ~QGraphicsLinearLayoutWrapper() override;

    int count() const override;
    void getContentsMargins(qreal * left, qreal * top, qreal * right, qreal * bottom) const override;
    void invalidate() override;
    bool isEmpty() const override;
    ::QGraphicsLayoutItem * itemAt(int index) const override;
    void removeAt(int index) override;
    void setGeometry(const ::QRectF & rect) override;
    ::QSizeF sizeHint(::Qt::SizeHint which, const ::QSizeF & constraint = QSizeF()) const override;
    void updateGeometry() override;
    void widgetEvent(::QEvent * e) override;
    static void sbk_o_widgetEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * e);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[10] = {false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QGRAPHICSLINEARLAYOUTWRAPPER_H
