// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qgraphicspolygonitem_wrapper.h"

// Wrappers providing overrides
#include "qgraphicspixmapitem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qgraphicsitem_wrapper.h"
#include "qgraphicslayout_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpolygon.h>
#include <QtWidgets/qgraphicsitem.h>
#include <QtWidgets/qgraphicssceneevent.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qcoreevent.h>
#include <qnamespace.h>
#include <qpoint.h>
#include <qrect.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGraphicsPolygonItemWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGraphicsPolygonItemWrapper::QGraphicsPolygonItemWrapper(::QGraphicsItem * parent) : QGraphicsPolygonItem(parent)
{
}

QGraphicsPolygonItemWrapper::QGraphicsPolygonItemWrapper(const ::QPolygonF & polygon, ::QGraphicsItem * parent) : QGraphicsPolygonItem(polygon, parent)
{
}

void QGraphicsPolygonItemWrapper::advance(int phase)
{
    static const char *funcName = "advance";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::advance(phase);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QGraphicsPolygonItem", funcName, gil, pyOverride, phase);
}

::QRectF QGraphicsPolygonItemWrapper::boundingRect() const
{
    static const char *funcName = "boundingRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsPolygonItem::boundingRect();
    }
    return QGraphicsItemWrapper::sbk_o_boundingRect("QGraphicsPolygonItem", funcName, gil, pyOverride);
}

bool QGraphicsPolygonItemWrapper::collidesWithItem(const ::QGraphicsItem * other, ::Qt::ItemSelectionMode mode) const
{
    static const char *funcName = "collidesWithItem";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::collidesWithItem(other, mode);
    }
    return QGraphicsPixmapItemWrapper::sbk_o_collidesWithItem("QGraphicsPolygonItem", funcName, gil, pyOverride, other, mode);
}

bool QGraphicsPolygonItemWrapper::collidesWithPath(const ::QPainterPath & path, ::Qt::ItemSelectionMode mode) const
{
    static const char *funcName = "collidesWithPath";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::collidesWithPath(path, mode);
    }
    return QGraphicsItemWrapper::sbk_o_collidesWithPath("QGraphicsPolygonItem", funcName, gil, pyOverride, path, mode);
}

bool QGraphicsPolygonItemWrapper::contains(const ::QPointF & point) const
{
    static const char *funcName = "contains";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsPolygonItem::contains(point);
    }
    return QGraphicsItemWrapper::sbk_o_contains("QGraphicsPolygonItem", funcName, gil, pyOverride, point);
}

void QGraphicsPolygonItemWrapper::contextMenuEvent(::QGraphicsSceneContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::contextMenuEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_contextMenuEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

void QGraphicsPolygonItemWrapper::dragEnterEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragEnterEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_dragEnterEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

void QGraphicsPolygonItemWrapper::dragLeaveEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragLeaveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_dragLeaveEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

void QGraphicsPolygonItemWrapper::dragMoveEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragMoveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_dragMoveEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

void QGraphicsPolygonItemWrapper::dropEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dropEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_dropEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

::QVariant QGraphicsPolygonItemWrapper::extension(const ::QVariant & variant) const
{
    static const char *funcName = "extension";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsPolygonItem::extension(variant);
    }
    return QGraphicsItemWrapper::sbk_o_extension("QGraphicsPolygonItem", funcName, gil, pyOverride, variant);
}

void QGraphicsPolygonItemWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::focusInEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_focusInEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

void QGraphicsPolygonItemWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::focusOutEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_focusOutEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

void QGraphicsPolygonItemWrapper::hoverEnterEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::hoverEnterEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_hoverEnterEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

void QGraphicsPolygonItemWrapper::hoverLeaveEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::hoverLeaveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_hoverLeaveEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

void QGraphicsPolygonItemWrapper::hoverMoveEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::hoverMoveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_hoverMoveEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

void QGraphicsPolygonItemWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::inputMethodEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_inputMethodEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

::QVariant QGraphicsPolygonItemWrapper::inputMethodQuery(::Qt::InputMethodQuery query) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::inputMethodQuery(query);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QGraphicsPolygonItem", funcName, gil, pyOverride, query);
}

bool QGraphicsPolygonItemWrapper::isObscuredBy(const ::QGraphicsItem * item) const
{
    static const char *funcName = "isObscuredBy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsPolygonItem::isObscuredBy(item);
    }
    return QGraphicsPixmapItemWrapper::sbk_o_isObscuredBy("QGraphicsPolygonItem", funcName, gil, pyOverride, item);
}

::QVariant QGraphicsPolygonItemWrapper::itemChange(::QGraphicsItem::GraphicsItemChange change, const ::QVariant & value)
{
    static const char *funcName = "itemChange";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::itemChange(change, value);
    }
    return QGraphicsItemWrapper::sbk_o_itemChange("QGraphicsPolygonItem", funcName, gil, pyOverride, change, value);
}

void QGraphicsPolygonItemWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::keyPressEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_keyPressEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

void QGraphicsPolygonItemWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::keyReleaseEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_keyReleaseEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

void QGraphicsPolygonItemWrapper::mouseDoubleClickEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseDoubleClickEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_mouseDoubleClickEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

void QGraphicsPolygonItemWrapper::mouseMoveEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseMoveEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_mouseMoveEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

void QGraphicsPolygonItemWrapper::mousePressEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mousePressEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_mousePressEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

void QGraphicsPolygonItemWrapper::mouseReleaseEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseReleaseEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_mouseReleaseEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

::QPainterPath QGraphicsPolygonItemWrapper::opaqueArea() const
{
    static const char *funcName = "opaqueArea";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsPolygonItem::opaqueArea();
    }
    return QGraphicsItemWrapper::sbk_o_opaqueArea("QGraphicsPolygonItem", funcName, gil, pyOverride);
}

void QGraphicsPolygonItemWrapper::paint(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget)
{
    static const char *funcName = "paint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsPolygonItem::paint(painter, option, widget);
    }
    QGraphicsPixmapItemWrapper::sbk_o_paint("QGraphicsPolygonItem", funcName, gil, pyOverride, painter, option, widget);
}

bool QGraphicsPolygonItemWrapper::sceneEvent(::QEvent * event)
{
    static const char *funcName = "sceneEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::sceneEvent(event);
    }
    return QGraphicsPixmapItemWrapper::sbk_o_sceneEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

bool QGraphicsPolygonItemWrapper::sceneEventFilter(::QGraphicsItem * watched, ::QEvent * event)
{
    static const char *funcName = "sceneEventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::sceneEventFilter(watched, event);
    }
    return QGraphicsPixmapItemWrapper::sbk_o_sceneEventFilter("QGraphicsPolygonItem", funcName, gil, pyOverride, watched, event);
}

::QPainterPath QGraphicsPolygonItemWrapper::shape() const
{
    static const char *funcName = "shape";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsPolygonItem::shape();
    }
    return QGraphicsItemWrapper::sbk_o_opaqueArea("QGraphicsPolygonItem", funcName, gil, pyOverride);
}

int QGraphicsPolygonItemWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsPolygonItem::type();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QGraphicsPolygonItem", funcName, gil, pyOverride);
}

void QGraphicsPolygonItemWrapper::wheelEvent(::QGraphicsSceneWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::wheelEvent(event);
    }
    QGraphicsPixmapItemWrapper::sbk_o_wheelEvent("QGraphicsPolygonItem", funcName, gil, pyOverride, event);
}

QGraphicsPolygonItemWrapper::~QGraphicsPolygonItemWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsPolygonItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGraphicsPolygonItem >()))
        return -1;

    QGraphicsPolygonItemWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QGraphicsPolygonItem", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGraphicsPolygonItem::QGraphicsPolygonItem(QGraphicsItem*=)
    // 1: QGraphicsPolygonItem::QGraphicsPolygonItem(QPolygonF,QGraphicsItem*=)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsPolygonItem(QGraphicsItem*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QGraphicsPolygonItem(QPolygonF,QGraphicsItem*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QGraphicsPolygonItem(QPolygonF,QGraphicsItem*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QGraphicsPolygonItem(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGraphicsPolygonItem(QGraphicsItem *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGraphicsItem *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGraphicsPolygonItem(QGraphicsItem*)
                cptr = new QGraphicsPolygonItemWrapper(cppArg0);
                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QGraphicsPolygonItem(const QPolygonF &polygon, QGraphicsItem *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPolygonF cppArg0_local;
            ::QPolygonF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QGraphicsItem *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGraphicsPolygonItem(QPolygonF,QGraphicsItem*)
                cptr = new QGraphicsPolygonItemWrapper(*cppArg0, cppArg1);
                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QGraphicsPolygonItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGraphicsPolygonItemFunc_boundingRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsPolygonItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // boundingRect()const
        QRectF cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->::QGraphicsPolygonItem::boundingRect()
            : const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->boundingRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsPolygonItemFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsPolygonItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsItem::contains(QPointF)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // contains(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contains", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // contains(QPointF)const
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->::QGraphicsPolygonItem::contains(*cppArg0)
                : const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->contains(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsPolygonItemFunc_extension(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsPolygonItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsItem::extension(QVariant)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // extension(QVariant)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "extension", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // extension(QVariant)const
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->::QGraphicsPolygonItem::extension(cppArg0)
                : const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->extension(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsPolygonItemFunc_fillRule(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsPolygonItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fillRule()const
        Qt::FillRule cppResult = const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->fillRule();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FillRule_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsPolygonItemFunc_isObscuredBy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsPolygonItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsItem::isObscuredBy(const QGraphicsItem*)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArg)))) {
        overloadId = 0; // isObscuredBy(const QGraphicsItem*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isObscuredBy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isObscuredBy(const QGraphicsItem*)const
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->::QGraphicsPolygonItem::isObscuredBy(cppArg0)
                : const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->isObscuredBy(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsPolygonItemFunc_opaqueArea(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsPolygonItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // opaqueArea()const
        QPainterPath cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->::QGraphicsPolygonItem::opaqueArea()
            : const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->opaqueArea();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsPolygonItemFunc_paint(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsPolygonItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "paint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:paint", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsItem::paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
            overloadId = 0; // paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "paint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"widget", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "paint", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOptionGraphicsItem *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QWidget *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsPolygonItem::paint(cppArg0, cppArg1, cppArg2)
                : cppSelf->paint(cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsPolygonItemFunc_polygon(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsPolygonItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // polygon()const
        QPolygonF cppResult = const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->polygon();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsPolygonItemFunc_setFillRule(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsPolygonItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsPolygonItem::setFillRule(Qt::FillRule)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FillRule_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFillRule(Qt::FillRule)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFillRule", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);

    // Call function/method
    {
        ::Qt::FillRule cppArg0{Qt::OddEvenFill};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFillRule(Qt::FillRule)
            cppSelf->setFillRule(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsPolygonItemFunc_setPolygon(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsPolygonItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsPolygonItem::setPolygon(QPolygonF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), (pyArg)))) {
        overloadId = 0; // setPolygon(QPolygonF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPolygon", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPolygonF cppArg0_local;
        ::QPolygonF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPolygon(QPolygonF)
            cppSelf->setPolygon(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QGraphicsPolygonItemFunc_shape(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsPolygonItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shape()const
        QPainterPath cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->::QGraphicsPolygonItem::shape()
            : const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->shape();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QGraphicsPolygonItemFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsPolygonItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // type()const
        int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->::QGraphicsPolygonItem::type()
            : const_cast<const ::QGraphicsPolygonItem *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QGraphicsPolygonItem_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGraphicsPolygonItem_methods[] = {
    {"boundingRect", reinterpret_cast<PyCFunction>(Sbk_QGraphicsPolygonItemFunc_boundingRect), METH_NOARGS, nullptr},
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QGraphicsPolygonItemFunc_contains), METH_O, nullptr},
    {"extension", reinterpret_cast<PyCFunction>(Sbk_QGraphicsPolygonItemFunc_extension), METH_O, nullptr},
    {"fillRule", reinterpret_cast<PyCFunction>(Sbk_QGraphicsPolygonItemFunc_fillRule), METH_NOARGS, nullptr},
    {"isObscuredBy", reinterpret_cast<PyCFunction>(Sbk_QGraphicsPolygonItemFunc_isObscuredBy), METH_O, nullptr},
    {"opaqueArea", reinterpret_cast<PyCFunction>(Sbk_QGraphicsPolygonItemFunc_opaqueArea), METH_NOARGS, nullptr},
    {"paint", reinterpret_cast<PyCFunction>(Sbk_QGraphicsPolygonItemFunc_paint), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"polygon", reinterpret_cast<PyCFunction>(Sbk_QGraphicsPolygonItemFunc_polygon), METH_NOARGS, nullptr},
    {"setFillRule", reinterpret_cast<PyCFunction>(Sbk_QGraphicsPolygonItemFunc_setFillRule), METH_O, nullptr},
    {"setPolygon", reinterpret_cast<PyCFunction>(Sbk_QGraphicsPolygonItemFunc_setPolygon), METH_O, nullptr},
    {"shape", reinterpret_cast<PyCFunction>(Sbk_QGraphicsPolygonItemFunc_shape), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QGraphicsPolygonItemFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGraphicsPolygonItem_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGraphicsPolygonItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGraphicsPolygonItemWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGraphicsPolygonItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGraphicsPolygonItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGraphicsPolygonItem_Type = nullptr;
static PyTypeObject *Sbk_QGraphicsPolygonItem_TypeF(void)
{
    return _Sbk_QGraphicsPolygonItem_Type;
}

static PyType_Slot Sbk_QGraphicsPolygonItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGraphicsPolygonItem_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGraphicsPolygonItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGraphicsPolygonItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGraphicsPolygonItem_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGraphicsPolygonItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGraphicsPolygonItem_spec = {
    "2:PySide6.QtWidgets.QGraphicsPolygonItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGraphicsPolygonItem_slots
};

} //extern "C"

static void *Sbk_QGraphicsPolygonItem_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QGraphicsItem >())
        return dynamic_cast< ::QGraphicsPolygonItem *>(reinterpret_cast< ::QGraphicsItem *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGraphicsPolygonItem_PythonToCpp_QGraphicsPolygonItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGraphicsPolygonItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGraphicsPolygonItem_PythonToCpp_QGraphicsPolygonItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGraphicsPolygonItem_TypeF()))
        return QGraphicsPolygonItem_PythonToCpp_QGraphicsPolygonItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGraphicsPolygonItem_PTR_CppToPython_QGraphicsPolygonItem(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QGraphicsPolygonItem *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QGraphicsPolygonItem_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGraphicsPolygonItem_SignatureStrings[] = {
    "1:PySide6.QtWidgets.QGraphicsPolygonItem(self,parent:PySide6.QtWidgets.QGraphicsItem=nullptr)",
    "0:PySide6.QtWidgets.QGraphicsPolygonItem(self,polygon:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF],parent:PySide6.QtWidgets.QGraphicsItem=nullptr)",
    "PySide6.QtWidgets.QGraphicsPolygonItem.boundingRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtWidgets.QGraphicsPolygonItem.contains(self,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->bool",
    "PySide6.QtWidgets.QGraphicsPolygonItem.extension(self,variant:QVariant)->QVariant",
    "PySide6.QtWidgets.QGraphicsPolygonItem.fillRule(self)->PySide6.QtCore.Qt.FillRule",
    "PySide6.QtWidgets.QGraphicsPolygonItem.isObscuredBy(self,item:PySide6.QtWidgets.QGraphicsItem)->bool",
    "PySide6.QtWidgets.QGraphicsPolygonItem.opaqueArea(self)->PySide6.QtGui.QPainterPath",
    "PySide6.QtWidgets.QGraphicsPolygonItem.paint(self,painter:PySide6.QtGui.QPainter,option:PySide6.QtWidgets.QStyleOptionGraphicsItem,widget:PySide6.QtWidgets.QWidget=nullptr)",
    "PySide6.QtWidgets.QGraphicsPolygonItem.polygon(self)->PySide6.QtGui.QPolygonF",
    "PySide6.QtWidgets.QGraphicsPolygonItem.setFillRule(self,rule:PySide6.QtCore.Qt.FillRule)",
    "PySide6.QtWidgets.QGraphicsPolygonItem.setPolygon(self,polygon:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF])",
    "PySide6.QtWidgets.QGraphicsPolygonItem.shape(self)->PySide6.QtGui.QPainterPath",
    "PySide6.QtWidgets.QGraphicsPolygonItem.type(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QGraphicsPolygonItem_SignatureByteSize = 358;
static constexpr uint8_t QGraphicsPolygonItem_SignatureBytes[358] = {
    0x78, 0xda, 0xc5, 0x54, 0x4d, 0x4b, 0xc3, 0x40, 0x10, 0xbd, 0xf7, 0x57, 0xf4, 0x68, 0x21, 0x2e,
    0x7a, 0xf1, 0x10, 0x50, 0x50, 0x31, 0x45, 0x10, 0x9a, 0xb4, 0xa8, 0x07, 0xe9, 0x61, 0x9b, 0x4c,
    0xdb, 0x81, 0xed, 0xee, 0xba, 0x3b, 0x51, 0xf3, 0xef, 0xdd, 0x7c, 0x54, 0x43, 0x9b, 0xe8, 0x06,
    0x04, 0x6f, 0xc3, 0xec, 0xbc, 0x97, 0xf7, 0xde, 0xce, 0xe6, 0x3c, 0x8c, 0x8b, 0x05, 0x66, 0x70,
    0xc1, 0x12, 0x7a, 0xc6, 0x6c, 0x03, 0x64, 0x59, 0x32, 0x35, 0x5c, 0x6f, 0x31, 0xb5, 0xb1, 0x12,
    0xc5, 0x46, 0xc9, 0x7b, 0x82, 0xdd, 0x89, 0x05, 0xb1, 0x0e, 0x34, 0x37, 0x20, 0xe9, 0x27, 0x48,
    0x39, 0x7b, 0x29, 0x73, 0x21, 0x34, 0x99, 0xc9, 0xe8, 0x6c, 0x18, 0x7b, 0xdd, 0x08, 0xa9, 0xd0,
    0x28, 0x37, 0xec, 0x51, 0xa2, 0x92, 0x2f, 0xdf, 0x04, 0xd3, 0x1c, 0x59, 0xd2, 0x80, 0xa2, 0x60,
    0x9c, 0x3c, 0xa0, 0xa5, 0xd6, 0xf1, 0xad, 0x32, 0x50, 0x9e, 0xa3, 0xa4, 0x68, 0x19, 0x8c, 0xbb,
    0x71, 0xed, 0x7e, 0x0d, 0x98, 0x43, 0x5a, 0xce, 0x0f, 0x75, 0xe6, 0xe7, 0x8b, 0xad, 0x54, 0x2e,
    0x33, 0x67, 0xa6, 0xfc, 0x4a, 0x65, 0x72, 0x72, 0x7a, 0xd5, 0xa9, 0xc0, 0x97, 0x30, 0x55, 0x92,
    0x38, 0x4a, 0xbb, 0x4f, 0xcc, 0xb9, 0xed, 0xcb, 0xab, 0x1d, 0xc8, 0xb1, 0xef, 0xaa, 0x7f, 0x1c,
    0x93, 0xe3, 0x26, 0x30, 0x31, 0xa7, 0x2d, 0xbb, 0x13, 0xb0, 0x73, 0x99, 0x2c, 0x9d, 0xe4, 0x95,
    0x52, 0xc2, 0x57, 0x21, 0x7c, 0x10, 0x48, 0xeb, 0xa4, 0xd4, 0x12, 0xdf, 0xb8, 0x41, 0xee, 0x44,
    0x26, 0x4f, 0x75, 0xe1, 0xd8, 0xf6, 0xa5, 0x2f, 0xe3, 0x1a, 0x85, 0x98, 0xe7, 0x02, 0xfa, 0x02,
    0x24, 0x16, 0x35, 0x13, 0xbe, 0x8c, 0x68, 0x67, 0x2b, 0x9b, 0xe6, 0x06, 0xb2, 0x9b, 0xa2, 0x96,
    0x89, 0xae, 0xfd, 0xdb, 0xed, 0x0f, 0x0c, 0x42, 0x69, 0xfe, 0x9a, 0xc3, 0xb5, 0x01, 0x7e, 0x2c,
    0xfc, 0x30, 0x6c, 0x5f, 0x4e, 0x5d, 0x42, 0xf6, 0x6f, 0xb1, 0x42, 0x87, 0xdd, 0xa4, 0x81, 0xd2,
    0xe4, 0xee, 0xa0, 0xcb, 0xd2, 0x82, 0x0a, 0x01, 0xb3, 0xea, 0xb8, 0xed, 0x2e, 0x78, 0xaf, 0x06,
    0xba, 0x10, 0x75, 0x31, 0x78, 0xf9, 0x9b, 0xf7, 0xdc, 0xe7, 0xbe, 0x79, 0xc9, 0xbe, 0x6c, 0x16,
    0x28, 0x6a, 0x2f, 0x42, 0x60, 0x5c, 0x15, 0xf6, 0xef, 0xc2, 0x64, 0x00, 0x71, 0xdc, 0x52, 0xfa,
    0x9f, 0xbf, 0x21, 0x7f, 0xcd, 0x5b, 0xae, 0xe1, 0xef, 0xd6, 0xca, 0x59, 0xfd, 0x62, 0x73, 0xe0,
    0xd1, 0x27, 0xc6, 0x7d, 0x38, 0x25
};
#endif

PyTypeObject *init_QGraphicsPolygonItem(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX].type;

    Shiboken::AutoDecRef Sbk_QGraphicsPolygonItem_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractGraphicsShapeItem_IDX]))));

    _Sbk_QGraphicsPolygonItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGraphicsPolygonItem",
        "QGraphicsPolygonItem*",
        &Sbk_QGraphicsPolygonItem_spec,
        &Shiboken::callCppDestructor< QGraphicsPolygonItem >,
        Sbk_QGraphicsPolygonItem_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGraphicsPolygonItem_TypeF(); // references _Sbk_QGraphicsPolygonItem_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGraphicsPolygonItem_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGraphicsPolygonItem_SignatureBytes, QGraphicsPolygonItem_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGraphicsPolygonItem_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGraphicsPolygonItem_PythonToCpp_QGraphicsPolygonItem_PTR,
        is_QGraphicsPolygonItem_PythonToCpp_QGraphicsPolygonItem_PTR_Convertible,
        QGraphicsPolygonItem_PTR_CppToPython_QGraphicsPolygonItem);

    Shiboken::Conversions::registerConverterName(converter, "QGraphicsPolygonItem");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsPolygonItem*");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsPolygonItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGraphicsPolygonItem).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGraphicsPolygonItemWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QGraphicsPolygonItem_TypeF(), &Sbk_QGraphicsPolygonItem_typeDiscovery);


    return pyType;
}
