// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QLAYOUTITEMWRAPPER_H
#define SBK_QLAYOUTITEMWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qlayoutitem.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QLayoutItemWrapper : public QLayoutItem
{
public:
    QLayoutItemWrapper(::QFlags<Qt::AlignmentFlag> alignment = Qt::Alignment());
    QLayoutItemWrapper(const QLayoutItemWrapper &) = delete;
    QLayoutItemWrapper& operator=(const QLayoutItemWrapper &) = delete;
    QLayoutItemWrapper(QLayoutItemWrapper &&) = delete;
    QLayoutItemWrapper& operator=(QLayoutItemWrapper &&) = delete;
    ~QLayoutItemWrapper() override;

    ::QFlags<QSizePolicy::ControlType> controlTypes() const override;
    static ::QFlags<QSizePolicy::ControlType> sbk_o_controlTypes(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QFlags<Qt::Orientation> expandingDirections() const override;
    static ::QFlags<Qt::Orientation> sbk_o_expandingDirections(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QRect geometry() const override;
    static ::QRect sbk_o_geometry(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool hasHeightForWidth() const override;
    static bool sbk_o_hasHeightForWidth(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    int heightForWidth(int arg__1) const override;
    static int sbk_o_heightForWidth(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int arg__1);
    void invalidate() override;
    static void sbk_o_invalidate(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    bool isEmpty() const override;
    ::QLayout * layout() override;
    static ::QLayout * sbk_o_layout(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QSize maximumSize() const override;
    static ::QSize sbk_o_maximumSize(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    int minimumHeightForWidth(int arg__1) const override;
    ::QSize minimumSize() const override;
    void setGeometry(const ::QRect & arg__1) override;
    static void sbk_o_setGeometry(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRect & arg__1);
    ::QSize sizeHint() const override;
    ::QSpacerItem * spacerItem() override;
    static ::QSpacerItem * sbk_o_spacerItem(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QWidget * widget() const override;
    static ::QWidget * sbk_o_widget(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[15] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QLAYOUTITEMWRAPPER_H
