// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qmdiarea_wrapper.h"

// Wrappers providing overrides
#include "qlayoutitem_wrapper.h"
#include "qtextedit_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qlineedit_wrapper.h"
#include "qabstractscrollarea_wrapper.h"
#include "qwidget_wrapper.h"
#include "qwizardpage_wrapper.h"
#include "qgraphicsitem_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qbrush.h>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtWidgets/qmdiarea.h>
#include <QtWidgets/qmdisubwindow.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qtabwidget.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QMdiAreaWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QMdiAreaWrapper::QMdiAreaWrapper(::QWidget * parent) : QMdiArea(parent)
{
}

void QMdiAreaWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QWizardPageWrapper::sbk_o_actionEvent("QMdiArea", funcName, gil, pyOverride, event);
}

void QMdiAreaWrapper::changeEvent(::QEvent * arg__1)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFrame::changeEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_changeEvent("QMdiArea", funcName, gil, pyOverride, arg__1);
}

void QMdiAreaWrapper::childEvent(::QChildEvent * childEvent)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMdiArea::childEvent(childEvent);
    }
    QWidgetWrapper::sbk_o_childEvent("QMdiArea", funcName, gil, pyOverride, childEvent);
}

void QMdiAreaWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QWizardPageWrapper::sbk_o_closeEvent("QMdiArea", funcName, gil, pyOverride, event);
}

void QMdiAreaWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QMdiArea", funcName, gil, pyOverride, signal);
}

void QMdiAreaWrapper::contextMenuEvent(::QContextMenuEvent * arg__1)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::contextMenuEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_contextMenuEvent("QMdiArea", funcName, gil, pyOverride, arg__1);
}

void QMdiAreaWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QMdiArea", funcName, gil, pyOverride, event);
}

int QMdiAreaWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QMdiArea", funcName, gil, pyOverride);
}

void QMdiAreaWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QMdiArea", funcName, gil, pyOverride, signal);
}

void QMdiAreaWrapper::dragEnterEvent(::QDragEnterEvent * arg__1)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::dragEnterEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_dragEnterEvent("QMdiArea", funcName, gil, pyOverride, arg__1);
}

void QMdiAreaWrapper::dragLeaveEvent(::QDragLeaveEvent * arg__1)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::dragLeaveEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_dragLeaveEvent("QMdiArea", funcName, gil, pyOverride, arg__1);
}

void QMdiAreaWrapper::dragMoveEvent(::QDragMoveEvent * arg__1)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::dragMoveEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_dragMoveEvent("QMdiArea", funcName, gil, pyOverride, arg__1);
}

void QMdiAreaWrapper::dropEvent(::QDropEvent * arg__1)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::dropEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_dropEvent("QMdiArea", funcName, gil, pyOverride, arg__1);
}

void QMdiAreaWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QWizardPageWrapper::sbk_o_enterEvent("QMdiArea", funcName, gil, pyOverride, event);
}

bool QMdiAreaWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMdiArea::event(event);
    }
    return QWidgetWrapper::sbk_o_event("QMdiArea", funcName, gil, pyOverride, event);
}

bool QMdiAreaWrapper::eventFilter(::QObject * object, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMdiArea::eventFilter(object, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QMdiArea", funcName, gil, pyOverride, object, event);
}

void QMdiAreaWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusInEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusInEvent("QMdiArea", funcName, gil, pyOverride, event);
}

bool QMdiAreaWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QWidgetWrapper::sbk_o_focusNextPrevChild("QMdiArea", funcName, gil, pyOverride, next);
}

void QMdiAreaWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusOutEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusOutEvent("QMdiArea", funcName, gil, pyOverride, event);
}

bool QMdiAreaWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QMdiArea", funcName, gil, pyOverride);
}

int QMdiAreaWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QMdiArea", funcName, gil, pyOverride, arg__1);
}

void QMdiAreaWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QWizardPageWrapper::sbk_o_hideEvent("QMdiArea", funcName, gil, pyOverride, event);
}

void QMdiAreaWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QWidgetWrapper::sbk_o_initPainter("QMdiArea", funcName, gil, pyOverride, painter);
}

void QMdiAreaWrapper::initStyleOption(::QStyleOptionFrame * option) const
{
    static const char *funcName = "initStyleOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFrame::initStyleOption(option);
    }
    QLineEditWrapper::sbk_o_initStyleOption("QMdiArea", funcName, gil, pyOverride, option);
}

void QMdiAreaWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QWizardPageWrapper::sbk_o_inputMethodEvent("QMdiArea", funcName, gil, pyOverride, event);
}

::QVariant QMdiAreaWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodQuery(arg__1);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QMdiArea", funcName, gil, pyOverride, arg__1);
}

void QMdiAreaWrapper::keyPressEvent(::QKeyEvent * arg__1)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::keyPressEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_keyPressEvent("QMdiArea", funcName, gil, pyOverride, arg__1);
}

void QMdiAreaWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyReleaseEvent("QMdiArea", funcName, gil, pyOverride, event);
}

void QMdiAreaWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_leaveEvent("QMdiArea", funcName, gil, pyOverride, event);
}

int QMdiAreaWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QWidgetWrapper::sbk_o_metric("QMdiArea", funcName, gil, pyOverride, arg__1);
}

::QSize QMdiAreaWrapper::minimumSizeHint() const
{
    static const char *funcName = "minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMdiArea::minimumSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QMdiArea", funcName, gil, pyOverride);
}

void QMdiAreaWrapper::mouseDoubleClickEvent(::QMouseEvent * arg__1)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::mouseDoubleClickEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_mouseDoubleClickEvent("QMdiArea", funcName, gil, pyOverride, arg__1);
}

void QMdiAreaWrapper::mouseMoveEvent(::QMouseEvent * arg__1)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::mouseMoveEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_mouseMoveEvent("QMdiArea", funcName, gil, pyOverride, arg__1);
}

void QMdiAreaWrapper::mousePressEvent(::QMouseEvent * arg__1)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::mousePressEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_mousePressEvent("QMdiArea", funcName, gil, pyOverride, arg__1);
}

void QMdiAreaWrapper::mouseReleaseEvent(::QMouseEvent * arg__1)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::mouseReleaseEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_mouseReleaseEvent("QMdiArea", funcName, gil, pyOverride, arg__1);
}

void QMdiAreaWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QWizardPageWrapper::sbk_o_moveEvent("QMdiArea", funcName, gil, pyOverride, event);
}

bool QMdiAreaWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QWizardPageWrapper::sbk_o_nativeEvent("QMdiArea", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QMdiAreaWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QWidgetWrapper::sbk_o_paintEngine("QMdiArea", funcName, gil, pyOverride);
}

void QMdiAreaWrapper::paintEvent(::QPaintEvent * paintEvent)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMdiArea::paintEvent(paintEvent);
    }
    QWizardPageWrapper::sbk_o_paintEvent("QMdiArea", funcName, gil, pyOverride, paintEvent);
}

::QPaintDevice * QMdiAreaWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QWidgetWrapper::sbk_o_redirected("QMdiArea", funcName, gil, pyOverride, offset);
}

void QMdiAreaWrapper::resizeEvent(::QResizeEvent * resizeEvent)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMdiArea::resizeEvent(resizeEvent);
    }
    QWizardPageWrapper::sbk_o_resizeEvent("QMdiArea", funcName, gil, pyOverride, resizeEvent);
}

void QMdiAreaWrapper::scrollContentsBy(int dx, int dy)
{
    static const char *funcName = "scrollContentsBy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMdiArea::scrollContentsBy(dx, dy);
    }
    QAbstractScrollAreaWrapper::sbk_o_scrollContentsBy("QMdiArea", funcName, gil, pyOverride, dx, dy);
}

void QMdiAreaWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QWidgetWrapper::sbk_o_setVisible("QMdiArea", funcName, gil, pyOverride, visible);
}

void QMdiAreaWrapper::setupViewport(::QWidget * viewport)
{
    static const char *funcName = "setupViewport";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMdiArea::setupViewport(viewport);
    }
    QTextEditWrapper::sbk_o_setupViewport("QMdiArea", funcName, gil, pyOverride, viewport);
}

::QPainter * QMdiAreaWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QWidgetWrapper::sbk_o_sharedPainter("QMdiArea", funcName, gil, pyOverride);
}

void QMdiAreaWrapper::showEvent(::QShowEvent * showEvent)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMdiArea::showEvent(showEvent);
    }
    QWizardPageWrapper::sbk_o_showEvent("QMdiArea", funcName, gil, pyOverride, showEvent);
}

::QSize QMdiAreaWrapper::sizeHint() const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMdiArea::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QMdiArea", funcName, gil, pyOverride);
}

void QMdiAreaWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QWizardPageWrapper::sbk_o_tabletEvent("QMdiArea", funcName, gil, pyOverride, event);
}

void QMdiAreaWrapper::timerEvent(::QTimerEvent * timerEvent)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMdiArea::timerEvent(timerEvent);
    }
    QWidgetWrapper::sbk_o_timerEvent("QMdiArea", funcName, gil, pyOverride, timerEvent);
}

bool QMdiAreaWrapper::viewportEvent(::QEvent * event)
{
    static const char *funcName = "viewportEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QMdiArea::viewportEvent(event);
    }
    return QTextEditWrapper::sbk_o_viewportEvent("QMdiArea", funcName, gil, pyOverride, event);
}

::QSize QMdiAreaWrapper::viewportSizeHint() const
{
    static const char *funcName = "viewportSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::viewportSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QMdiArea", funcName, gil, pyOverride);
}

void QMdiAreaWrapper::wheelEvent(::QWheelEvent * arg__1)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::wheelEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_wheelEvent("QMdiArea", funcName, gil, pyOverride, arg__1);
}

const QMetaObject *QMdiAreaWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QMdiArea::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QMdiAreaWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QMdiArea::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QMdiAreaWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QMdiAreaWrapper *>(this));
    return QMdiArea::qt_metacast(_clname);
}

QMdiAreaWrapper::~QMdiAreaWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMdiArea_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMdiArea >()))
        return -1;

    QMdiAreaWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QMdiArea", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMdiArea::QMdiArea(QWidget*=)
    if (numArgs == 0) {
        overloadId = 0; // QMdiArea(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QMdiArea(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QMdiArea(QWidget*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QMdiAreaWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QMdiAreaWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QMdiArea >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QMdiAreaFunc_activateNextSubWindow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activateNextSubWindow()
        cppSelf->activateNextSubWindow();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_activatePreviousSubWindow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activatePreviousSubWindow()
        cppSelf->activatePreviousSubWindow();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_activationOrder(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activationOrder()const
        QMdiArea::WindowOrder cppResult = const_cast<const ::QMdiArea *>(cppSelf)->activationOrder();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_WindowOrder_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_activeSubWindow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activeSubWindow()const
        QMdiSubWindow * cppResult = const_cast<const ::QMdiArea *>(cppSelf)->activeSubWindow();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiSubWindow_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_addSubWindow(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addSubWindow", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    if (PyArg_ParseTuple(args, "|OO:addSubWindow", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMdiArea::addSubWindow(QWidget*,QFlags<Qt::WindowType>=)->QMdiSubWindow*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addSubWindow(QWidget*,QFlags<Qt::WindowType>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // addSubWindow(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addSubWindow", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"flags", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "addSubWindow", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::WindowType> cppArg1 = Qt::WindowFlags();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addSubWindow(QWidget*,QFlags<Qt::WindowType>)
            QMdiSubWindow * cppResult = cppSelf->addSubWindow(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiSubWindow_IDX]), cppResult);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyResult);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[0]);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_background(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // background()const
        QBrush cppResult = const_cast<const ::QMdiArea *>(cppSelf)->background();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_cascadeSubWindows(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cascadeSubWindows()
        cppSelf->cascadeSubWindows();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_childEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::childEvent(QChildEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), (pyArg)))) {
        overloadId = 0; // childEvent(QChildEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "childEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QChildEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // childEvent(QChildEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QMdiArea::childEvent(cppArg0)
                : cppSelf->childEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_closeActiveSubWindow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // closeActiveSubWindow()
        cppSelf->closeActiveSubWindow();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_closeAllSubWindows(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // closeAllSubWindows()
        cppSelf->closeAllSubWindows();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_currentSubWindow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentSubWindow()const
        QMdiSubWindow * cppResult = const_cast<const ::QMdiArea *>(cppSelf)->currentSubWindow();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiSubWindow_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_documentMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // documentMode()const
        bool cppResult = const_cast<const ::QMdiArea *>(cppSelf)->documentMode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QMdiArea::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_eventFilter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "eventFilter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QObject::eventFilter(QObject*,QEvent*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // eventFilter(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "eventFilter", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // eventFilter(QObject*,QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QMdiArea::eventFilter(cppArg0, cppArg1)
                : cppSelf->eventFilter(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_minimumSizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumSizeHint()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QMdiArea *>(cppSelf)->::QMdiArea::minimumSizeHint()
            : const_cast<const ::QMdiArea *>(cppSelf)->minimumSizeHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_paintEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::paintEvent(QPaintEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), (pyArg)))) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "paintEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPaintEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paintEvent(QPaintEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QMdiArea::paintEvent(cppArg0)
                : cppSelf->paintEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_removeSubWindow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMdiArea::removeSubWindow(QWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // removeSubWindow(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeSubWindow", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeSubWindow(QWidget*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->removeSubWindow(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_resizeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::resizeEvent(QResizeEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), (pyArg)))) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resizeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QResizeEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeEvent(QResizeEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QMdiArea::resizeEvent(cppArg0)
                : cppSelf->resizeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_scrollContentsBy(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "scrollContentsBy", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractScrollArea::scrollContentsBy(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // scrollContentsBy(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scrollContentsBy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // scrollContentsBy(int,int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QMdiArea::scrollContentsBy(cppArg0, cppArg1)
                : cppSelf->scrollContentsBy(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_setActivationOrder(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMdiArea::setActivationOrder(QMdiArea::WindowOrder)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_WindowOrder_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setActivationOrder(QMdiArea::WindowOrder)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setActivationOrder", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        ::QMdiArea::WindowOrder cppArg0{QMdiArea::CreationOrder};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActivationOrder(QMdiArea::WindowOrder)
            cppSelf->setActivationOrder(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_setActiveSubWindow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMdiArea::setActiveSubWindow(QMdiSubWindow*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiSubWindow_IDX]), (pyArg)))) {
        overloadId = 0; // setActiveSubWindow(QMdiSubWindow*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setActiveSubWindow", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMdiSubWindow *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActiveSubWindow(QMdiSubWindow*)
            cppSelf->setActiveSubWindow(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_setBackground(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMdiArea::setBackground(QBrush)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArg)))) {
        overloadId = 0; // setBackground(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackground", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBrush cppArg0_local;
        ::QBrush *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackground(QBrush)
            cppSelf->setBackground(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_setDocumentMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMdiArea::setDocumentMode(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDocumentMode(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDocumentMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDocumentMode(bool)
            cppSelf->setDocumentMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_setOption(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setOption", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMdiArea::setOption(QMdiArea::AreaOption,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_AreaOption_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setOption(QMdiArea::AreaOption,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setOption(QMdiArea::AreaOption,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"on", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);
            }
        }
        ::QMdiArea::AreaOption cppArg0 = static_cast< ::QMdiArea::AreaOption>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOption(QMdiArea::AreaOption,bool)
            cppSelf->setOption(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_setTabPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMdiArea::setTabPosition(QTabWidget::TabPosition)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTabWidget_TabPosition_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTabPosition(QTabWidget::TabPosition)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTabPosition", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        ::QTabWidget::TabPosition cppArg0{QTabWidget::North};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabPosition(QTabWidget::TabPosition)
            cppSelf->setTabPosition(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_setTabShape(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMdiArea::setTabShape(QTabWidget::TabShape)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTabWidget_TabShape_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTabShape(QTabWidget::TabShape)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTabShape", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        ::QTabWidget::TabShape cppArg0{QTabWidget::Rounded};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabShape(QTabWidget::TabShape)
            cppSelf->setTabShape(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_setTabsClosable(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMdiArea::setTabsClosable(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setTabsClosable(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTabsClosable", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabsClosable(bool)
            cppSelf->setTabsClosable(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_setTabsMovable(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMdiArea::setTabsMovable(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setTabsMovable(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTabsMovable", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabsMovable(bool)
            cppSelf->setTabsMovable(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_setViewMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMdiArea::setViewMode(QMdiArea::ViewMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_ViewMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setViewMode(QMdiArea::ViewMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setViewMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        ::QMdiArea::ViewMode cppArg0{QMdiArea::SubWindowView};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setViewMode(QMdiArea::ViewMode)
            cppSelf->setViewMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_setupViewport(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractScrollArea::setupViewport(QWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // setupViewport(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setupViewport", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setupViewport(QWidget*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QMdiArea::setupViewport(cppArg0)
                : cppSelf->setupViewport(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_showEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::showEvent(QShowEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), (pyArg)))) {
        overloadId = 0; // showEvent(QShowEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "showEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QShowEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // showEvent(QShowEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QMdiArea::showEvent(cppArg0)
                : cppSelf->showEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_sizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizeHint()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QMdiArea *>(cppSelf)->::QMdiArea::sizeHint()
            : const_cast<const ::QMdiArea *>(cppSelf)->sizeHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_subWindowList(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "subWindowList", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    if (PyArg_ParseTuple(args, "|O:subWindowList", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMdiArea::subWindowList(QMdiArea::WindowOrder=)const->QList<QMdiSubWindow*>
    if (numArgs == 0) {
        overloadId = 0; // subWindowList(QMdiArea::WindowOrder)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_WindowOrder_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // subWindowList(QMdiArea::WindowOrder)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "subWindowList", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"order", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_WindowOrder_IDX])))->converter, (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "subWindowList", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);
            }
        }
        ::QMdiArea::WindowOrder cppArg0(QMdiArea::WindowOrder::CreationOrder);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // subWindowList(QMdiArea::WindowOrder)const
            QList<QMdiSubWindow*> cppResult = const_cast<const ::QMdiArea *>(cppSelf)->subWindowList(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QMdiSubWindowPTR_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_tabPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tabPosition()const
        QTabWidget::TabPosition cppResult = const_cast<const ::QMdiArea *>(cppSelf)->tabPosition();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTabWidget_TabPosition_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_tabShape(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tabShape()const
        QTabWidget::TabShape cppResult = const_cast<const ::QMdiArea *>(cppSelf)->tabShape();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTabWidget_TabShape_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_tabsClosable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tabsClosable()const
        bool cppResult = const_cast<const ::QMdiArea *>(cppSelf)->tabsClosable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_tabsMovable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tabsMovable()const
        bool cppResult = const_cast<const ::QMdiArea *>(cppSelf)->tabsMovable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_testOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMdiArea::testOption(QMdiArea::AreaOption)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_AreaOption_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // testOption(QMdiArea::AreaOption)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "testOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        ::QMdiArea::AreaOption cppArg0 = static_cast< ::QMdiArea::AreaOption>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // testOption(QMdiArea::AreaOption)const
            bool cppResult = const_cast<const ::QMdiArea *>(cppSelf)->testOption(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_tileSubWindows(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tileSubWindows()
        cppSelf->tileSubWindows();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_timerEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::timerEvent(QTimerEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), (pyArg)))) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "timerEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTimerEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // timerEvent(QTimerEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QMdiArea::timerEvent(cppArg0)
                : cppSelf->timerEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMdiAreaFunc_viewMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewMode()const
        QMdiArea::ViewMode cppResult = const_cast<const ::QMdiArea *>(cppSelf)->viewMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_ViewMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMdiAreaFunc_viewportEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractScrollArea::viewportEvent(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // viewportEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "viewportEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // viewportEvent(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QMdiArea::viewportEvent(cppArg0)
                : cppSelf->viewportEvent(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QMdiArea_PropertyStrings[] = {
    "activationOrder::",
    "background::",
    "documentMode::",
    "tabPosition::",
    "tabShape::",
    "tabsClosable::",
    "tabsMovable::",
    "viewMode::",
    nullptr // Sentinel
};

static const char *Sbk_QMdiArea_EnumFlagInfo[] = {
    "AreaOption:Flag:AreaOptions",
    "ViewMode:Enum",
    "WindowOrder:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMdiArea_methods[] = {
    {"activateNextSubWindow", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_activateNextSubWindow), METH_NOARGS, nullptr},
    {"activatePreviousSubWindow", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_activatePreviousSubWindow), METH_NOARGS, nullptr},
    {"activationOrder", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_activationOrder), METH_NOARGS, nullptr},
    {"activeSubWindow", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_activeSubWindow), METH_NOARGS, nullptr},
    {"addSubWindow", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_addSubWindow), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"background", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_background), METH_NOARGS, nullptr},
    {"cascadeSubWindows", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_cascadeSubWindows), METH_NOARGS, nullptr},
    {"childEvent", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_childEvent), METH_O, nullptr},
    {"closeActiveSubWindow", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_closeActiveSubWindow), METH_NOARGS, nullptr},
    {"closeAllSubWindows", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_closeAllSubWindows), METH_NOARGS, nullptr},
    {"currentSubWindow", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_currentSubWindow), METH_NOARGS, nullptr},
    {"documentMode", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_documentMode), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_event), METH_O, nullptr},
    {"eventFilter", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_eventFilter), METH_VARARGS, nullptr},
    {"minimumSizeHint", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_minimumSizeHint), METH_NOARGS, nullptr},
    {"paintEvent", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_paintEvent), METH_O, nullptr},
    {"removeSubWindow", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_removeSubWindow), METH_O, nullptr},
    {"resizeEvent", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_resizeEvent), METH_O, nullptr},
    {"scrollContentsBy", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_scrollContentsBy), METH_VARARGS, nullptr},
    {"setActivationOrder", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_setActivationOrder), METH_O, nullptr},
    {"setActiveSubWindow", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_setActiveSubWindow), METH_O, nullptr},
    {"setBackground", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_setBackground), METH_O, nullptr},
    {"setDocumentMode", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_setDocumentMode), METH_O, nullptr},
    {"setOption", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_setOption), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setTabPosition", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_setTabPosition), METH_O, nullptr},
    {"setTabShape", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_setTabShape), METH_O, nullptr},
    {"setTabsClosable", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_setTabsClosable), METH_O, nullptr},
    {"setTabsMovable", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_setTabsMovable), METH_O, nullptr},
    {"setViewMode", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_setViewMode), METH_O, nullptr},
    {"setupViewport", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_setupViewport), METH_O, nullptr},
    {"showEvent", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_showEvent), METH_O, nullptr},
    {"sizeHint", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_sizeHint), METH_NOARGS, nullptr},
    {"subWindowList", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_subWindowList), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"tabPosition", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_tabPosition), METH_NOARGS, nullptr},
    {"tabShape", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_tabShape), METH_NOARGS, nullptr},
    {"tabsClosable", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_tabsClosable), METH_NOARGS, nullptr},
    {"tabsMovable", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_tabsMovable), METH_NOARGS, nullptr},
    {"testOption", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_testOption), METH_O, nullptr},
    {"tileSubWindows", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_tileSubWindows), METH_NOARGS, nullptr},
    {"timerEvent", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_timerEvent), METH_O, nullptr},
    {"viewMode", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_viewMode), METH_NOARGS, nullptr},
    {"viewportEvent", reinterpret_cast<PyCFunction>(Sbk_QMdiAreaFunc_viewportEvent), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QMdiArea_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QMdiArea *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QMdiAreaWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QMdiArea_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMdiArea_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QMdiAreaSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QMdiArea *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX]))
        return static_cast< ::QAbstractScrollArea *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX]))
        return static_cast< ::QFrame *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMdiArea_Type = nullptr;
static PyTypeObject *Sbk_QMdiArea_TypeF(void)
{
    return _Sbk_QMdiArea_Type;
}

static PyType_Slot Sbk_QMdiArea_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QMdiArea_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMdiArea_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMdiArea_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMdiArea_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMdiArea_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMdiArea_spec = {
    "2:PySide6.QtWidgets.QMdiArea",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMdiArea_slots
};

} //extern "C"

static void *Sbk_QMdiArea_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QMdiArea *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QMdiArea *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QMdiArea *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QMdiArea_AreaOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMdiArea::AreaOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMdiArea::AreaOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMdiArea_AreaOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_AreaOption_IDX])))
        return Enum_PythonToCpp_QMdiArea_AreaOption;
    return {};
}

static PyObject *QMdiArea_AreaOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMdiArea::AreaOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMdiArea::AreaOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_AreaOption_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QMdiArea_AreaOption(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QMdiArea::AreaOption>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QMdiArea::AreaOption> *>(cppOut) = value;

}

static PyObject *QMdiArea_AreaOption_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QMdiArea::AreaOption> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_AreaOption_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QMdiArea_WindowOrder(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMdiArea::WindowOrder>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMdiArea::WindowOrder *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMdiArea_WindowOrder_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_WindowOrder_IDX])))
        return Enum_PythonToCpp_QMdiArea_WindowOrder;
    return {};
}

static PyObject *QMdiArea_WindowOrder_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMdiArea::WindowOrder>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMdiArea::WindowOrder *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_WindowOrder_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QMdiArea_ViewMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMdiArea::ViewMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMdiArea::ViewMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMdiArea_ViewMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_ViewMode_IDX])))
        return Enum_PythonToCpp_QMdiArea_ViewMode;
    return {};
}

static PyObject *QMdiArea_ViewMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMdiArea::ViewMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMdiArea::ViewMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_ViewMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMdiArea_PythonToCpp_QMdiArea_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMdiArea_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMdiArea_PythonToCpp_QMdiArea_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMdiArea_TypeF()))
        return QMdiArea_PythonToCpp_QMdiArea_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMdiArea_PTR_CppToPython_QMdiArea(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QMdiArea *>(const_cast<void *>(cppIn)), Sbk_QMdiArea_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMdiArea_SignatureStrings[] = {
    "PySide6.QtWidgets.QMdiArea(self,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,background:QBrush=None,activationOrder:QMdiArea.WindowOrder=None,viewMode:QMdiArea.ViewMode=None,documentMode:bool=None,tabsClosable:bool=None,tabsMovable:bool=None,tabShape:QTabWidget.TabShape=None,tabPosition:QTabWidget.TabPosition=None)",
    "PySide6.QtWidgets.QMdiArea.activateNextSubWindow(self)",
    "PySide6.QtWidgets.QMdiArea.activatePreviousSubWindow(self)",
    "PySide6.QtWidgets.QMdiArea.activationOrder(self)->PySide6.QtWidgets.QMdiArea.WindowOrder",
    "PySide6.QtWidgets.QMdiArea.activeSubWindow(self)->PySide6.QtWidgets.QMdiSubWindow",
    "PySide6.QtWidgets.QMdiArea.addSubWindow(self,widget:PySide6.QtWidgets.QWidget,flags:PySide6.QtCore.Qt.WindowType=Qt.WindowFlags())->PySide6.QtWidgets.QMdiSubWindow",
    "PySide6.QtWidgets.QMdiArea.background(self)->PySide6.QtGui.QBrush",
    "PySide6.QtWidgets.QMdiArea.cascadeSubWindows(self)",
    "PySide6.QtWidgets.QMdiArea.childEvent(self,childEvent:PySide6.QtCore.QChildEvent)",
    "PySide6.QtWidgets.QMdiArea.closeActiveSubWindow(self)",
    "PySide6.QtWidgets.QMdiArea.closeAllSubWindows(self)",
    "PySide6.QtWidgets.QMdiArea.currentSubWindow(self)->PySide6.QtWidgets.QMdiSubWindow",
    "PySide6.QtWidgets.QMdiArea.documentMode(self)->bool",
    "PySide6.QtWidgets.QMdiArea.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QMdiArea.eventFilter(self,object:PySide6.QtCore.QObject,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QMdiArea.minimumSizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QMdiArea.paintEvent(self,paintEvent:PySide6.QtGui.QPaintEvent)",
    "PySide6.QtWidgets.QMdiArea.removeSubWindow(self,widget:PySide6.QtWidgets.QWidget)",
    "PySide6.QtWidgets.QMdiArea.resizeEvent(self,resizeEvent:PySide6.QtGui.QResizeEvent)",
    "PySide6.QtWidgets.QMdiArea.scrollContentsBy(self,dx:int,dy:int)",
    "PySide6.QtWidgets.QMdiArea.setActivationOrder(self,order:PySide6.QtWidgets.QMdiArea.WindowOrder)",
    "PySide6.QtWidgets.QMdiArea.setActiveSubWindow(self,window:PySide6.QtWidgets.QMdiSubWindow)",
    "PySide6.QtWidgets.QMdiArea.setBackground(self,background:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap])",
    "PySide6.QtWidgets.QMdiArea.setDocumentMode(self,enabled:bool)",
    "PySide6.QtWidgets.QMdiArea.setOption(self,option:PySide6.QtWidgets.QMdiArea.AreaOption,on:bool=true)",
    "PySide6.QtWidgets.QMdiArea.setTabPosition(self,position:PySide6.QtWidgets.QTabWidget.TabPosition)",
    "PySide6.QtWidgets.QMdiArea.setTabShape(self,shape:PySide6.QtWidgets.QTabWidget.TabShape)",
    "PySide6.QtWidgets.QMdiArea.setTabsClosable(self,closable:bool)",
    "PySide6.QtWidgets.QMdiArea.setTabsMovable(self,movable:bool)",
    "PySide6.QtWidgets.QMdiArea.setViewMode(self,mode:PySide6.QtWidgets.QMdiArea.ViewMode)",
    "PySide6.QtWidgets.QMdiArea.setupViewport(self,viewport:PySide6.QtWidgets.QWidget)",
    "PySide6.QtWidgets.QMdiArea.showEvent(self,showEvent:PySide6.QtGui.QShowEvent)",
    "PySide6.QtWidgets.QMdiArea.sizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QMdiArea.subWindowList(self,order:PySide6.QtWidgets.QMdiArea.WindowOrder=QMdiArea.WindowOrder.CreationOrder)->QList[PySide6.QtWidgets.QMdiSubWindow]",
    "PySide6.QtWidgets.QMdiArea.tabPosition(self)->PySide6.QtWidgets.QTabWidget.TabPosition",
    "PySide6.QtWidgets.QMdiArea.tabShape(self)->PySide6.QtWidgets.QTabWidget.TabShape",
    "PySide6.QtWidgets.QMdiArea.tabsClosable(self)->bool",
    "PySide6.QtWidgets.QMdiArea.tabsMovable(self)->bool",
    "PySide6.QtWidgets.QMdiArea.testOption(self,opton:PySide6.QtWidgets.QMdiArea.AreaOption)->bool",
    "PySide6.QtWidgets.QMdiArea.tileSubWindows(self)",
    "PySide6.QtWidgets.QMdiArea.timerEvent(self,timerEvent:PySide6.QtCore.QTimerEvent)",
    "PySide6.QtWidgets.QMdiArea.viewMode(self)->PySide6.QtWidgets.QMdiArea.ViewMode",
    "PySide6.QtWidgets.QMdiArea.viewportEvent(self,event:PySide6.QtCore.QEvent)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QMdiArea_SignatureByteSize = 773;
static constexpr uint8_t QMdiArea_SignatureBytes[773] = {
    0x78, 0xda, 0xad, 0x57, 0x4b, 0x73, 0xd3, 0x30, 0x10, 0xbe, 0xf3, 0x2b, 0x38, 0xb6, 0x8c, 0xf1,
    0x91, 0x83, 0x67, 0xca, 0x4c, 0x1b, 0xda, 0xc2, 0x40, 0x1b, 0x87, 0x04, 0x7a, 0xe8, 0xf4, 0x20,
    0x5b, 0xdb, 0x44, 0x20, 0x5b, 0x1e, 0x49, 0x76, 0x6a, 0x7e, 0x3d, 0xb2, 0xe4, 0x57, 0x6c, 0x47,
    0x72, 0x28, 0x97, 0xc6, 0xda, 0xc7, 0xa7, 0x7d, 0x6b, 0x1b, 0x96, 0x6b, 0x82, 0xe1, 0x83, 0xbf,
    0x92, 0x0f, 0x04, 0x6f, 0x41, 0x0a, 0x7f, 0x75, 0x87, 0xc9, 0x25, 0x07, 0x74, 0x26, 0x80, 0x3e,
    0x7b, 0x19, 0xe2, 0x90, 0xca, 0x20, 0x1c, 0x8b, 0x99, 0x8f, 0x8b, 0x34, 0xa7, 0x34, 0x93, 0xdc,
    0x7b, 0x17, 0x7c, 0x85, 0x72, 0xcf, 0x38, 0x5e, 0xa6, 0xb4, 0xbc, 0xb8, 0x67, 0x29, 0x78, 0x11,
    0x8a, 0x7f, 0x6f, 0x39, 0xcb, 0x53, 0x1c, 0xac, 0xae, 0x78, 0x2e, 0x76, 0x86, 0x8c, 0x62, 0x49,
    0x0a, 0x24, 0x09, 0x4b, 0x97, 0x1c, 0x03, 0x0f, 0x9a, 0x0b, 0xfd, 0x07, 0x92, 0x62, 0xb6, 0xd7,
    0x44, 0x23, 0x59, 0x10, 0xd8, 0xdf, 0x31, 0x0c, 0x9d, 0xc8, 0xcf, 0x9a, 0x62, 0xf8, 0x98, 0xc5,
    0x79, 0xa2, 0xcc, 0xd3, 0x32, 0x11, 0x63, 0xd4, 0x90, 0x25, 0x8a, 0xc4, 0x82, 0x32, 0x81, 0x22,
    0x3a, 0x24, 0xdf, 0xb1, 0x62, 0x4c, 0x5d, 0xef, 0x50, 0xa6, 0xee, 0xd8, 0xa0, 0xc8, 0xf8, 0xe4,
    0x6f, 0x6a, 0x5a, 0x2b, 0x11, 0x32, 0x41, 0x2a, 0x83, 0x07, 0x42, 0x0d, 0x59, 0xcb, 0x9d, 0xbf,
    0x09, 0x8f, 0xc6, 0xd2, 0xaf, 0x7d, 0x86, 0x7b, 0x78, 0x91, 0xeb, 0x3c, 0x32, 0x9e, 0xea, 0x08,
    0xcf, 0x52, 0x0b, 0x39, 0x14, 0x84, 0xe5, 0xe2, 0x74, 0xd5, 0x26, 0xca, 0x46, 0xe1, 0xfd, 0x47,
    0x8b, 0x46, 0x2f, 0xfc, 0x4e, 0x60, 0x18, 0x58, 0x72, 0x0c, 0xb8, 0x15, 0xb3, 0x22, 0x62, 0x7c,
    0x08, 0xe7, 0xed, 0xb5, 0xc8, 0xf1, 0xaa, 0xf3, 0x9e, 0x29, 0xda, 0x8a, 0x1e, 0x7f, 0xc1, 0x38,
    0xa8, 0x9f, 0xda, 0x87, 0x4d, 0xa9, 0x72, 0xd7, 0x9e, 0x6e, 0x2a, 0xd9, 0xb3, 0xf3, 0xd7, 0xd9,
    0xd8, 0xd5, 0xf2, 0xd8, 0xe1, 0xdb, 0x9c, 0xf8, 0xa6, 0xc0, 0x6d, 0x08, 0x31, 0x12, 0x31, 0xc2,
    0x5d, 0xe0, 0x84, 0x3b, 0x87, 0xf1, 0x8e, 0x50, 0x7c, 0x5d, 0xa8, 0x0a, 0x37, 0x61, 0xe9, 0xce,
    0x23, 0xd7, 0x17, 0x2d, 0xcb, 0x8e, 0xa8, 0xda, 0x02, 0x2e, 0xa7, 0x32, 0xe8, 0xd6, 0xa2, 0xf4,
    0x24, 0xdb, 0x73, 0x5e, 0x4d, 0x8e, 0xff, 0x59, 0x27, 0xfd, 0x76, 0x6f, 0xe0, 0xaa, 0x46, 0xb6,
    0xe9, 0x40, 0x17, 0x3d, 0x98, 0x0c, 0x9c, 0x89, 0xd9, 0x4c, 0xa0, 0x1b, 0x42, 0x65, 0xdd, 0x4b,
    0x1e, 0x8b, 0x7e, 0x41, 0x3c, 0xc6, 0x5b, 0x6a, 0xf2, 0x2b, 0x2f, 0x4b, 0x48, 0x4a, 0x92, 0x3c,
    0x59, 0x93, 0x3f, 0xf0, 0x99, 0xd4, 0xf6, 0x1f, 0xc4, 0xce, 0xc0, 0x55, 0x7c, 0x1b, 0x4c, 0x86,
    0x94, 0x72, 0xaf, 0x7e, 0xba, 0x73, 0x30, 0xa8, 0xde, 0xb0, 0xe5, 0x58, 0x93, 0xca, 0x21, 0x61,
    0xc3, 0xca, 0x71, 0x36, 0xab, 0x03, 0x51, 0x28, 0x27, 0x7a, 0x36, 0xf6, 0x08, 0x43, 0x23, 0xbf,
    0x77, 0x2c, 0x2b, 0xa6, 0x88, 0x39, 0xa3, 0x74, 0xc1, 0x52, 0xa9, 0x24, 0xc5, 0x55, 0x69, 0x80,
    0xf1, 0x4b, 0xa0, 0x7c, 0xf4, 0x70, 0x59, 0xfd, 0xd8, 0xf5, 0x41, 0x5e, 0x4e, 0x4c, 0x4f, 0x8f,
    0xe9, 0xe7, 0x6a, 0xde, 0x04, 0x9d, 0x75, 0xc1, 0x38, 0x92, 0xd5, 0x77, 0xe0, 0x68, 0x11, 0x17,
    0xf4, 0xd5, 0xe1, 0xa8, 0xea, 0x3f, 0xc3, 0xb2, 0xcc, 0x48, 0xba, 0xf5, 0x7f, 0xa4, 0xca, 0xb1,
    0xc7, 0xa9, 0x01, 0xe6, 0xbd, 0x1d, 0xcf, 0x54, 0xcd, 0x58, 0xcb, 0x92, 0xc2, 0x14, 0xf7, 0x96,
    0xb2, 0x08, 0xa9, 0x60, 0x53, 0xc6, 0xfb, 0x6c, 0x0d, 0x39, 0x4d, 0xbd, 0xe5, 0x08, 0x13, 0x95,
    0x99, 0x11, 0xe3, 0x4b, 0x82, 0xb6, 0x30, 0xa2, 0x86, 0xe4, 0x25, 0x41, 0xd9, 0x93, 0xcb, 0xeb,
    0x4f, 0xc3, 0xe1, 0xe0, 0x41, 0x5a, 0x3d, 0xf5, 0x58, 0xbf, 0xf5, 0x2e, 0xed, 0x65, 0x56, 0xe5,
    0xba, 0x4e, 0xb3, 0xfe, 0xb6, 0xe5, 0xb9, 0xfa, 0x63, 0x34, 0x3c, 0x25, 0xa8, 0x77, 0x09, 0xc9,
    0x73, 0x70, 0x5d, 0xd2, 0xdb, 0x18, 0xea, 0x7e, 0x6c, 0xd6, 0x8a, 0x09, 0xbd, 0xc9, 0x45, 0x63,
    0xc6, 0x0d, 0x7a, 0x71, 0x31, 0xf0, 0x42, 0xef, 0x35, 0x2e, 0x6c, 0xad, 0x30, 0x03, 0xb8, 0x5d,
    0xa9, 0xea, 0xb7, 0xa8, 0xbf, 0x60, 0xcd, 0x51, 0xaf, 0x57, 0x2f, 0xa3, 0x9d, 0xf4, 0xf6, 0x30,
    0x97, 0x72, 0xb3, 0xf3, 0x35, 0x9a, 0x18, 0x6c, 0xb9, 0x69, 0xa4, 0x5d, 0xa8, 0x79, 0x56, 0x49,
    0x66, 0x8c, 0xd7, 0x73, 0xa7, 0xa8, 0x4f, 0xff, 0x38, 0xc7, 0xc4, 0x8e, 0xed, 0x7b, 0x53, 0xac,
    0x3d, 0x0e, 0x67, 0xd8, 0xba, 0x61, 0xd8, 0xd1, 0x5e, 0x39, 0xf8, 0x45, 0x33, 0x2b, 0xbe, 0x11,
    0x21, 0x4f, 0x1f, 0x5e, 0x17, 0x53, 0x44, 0x7f, 0xa1, 0x08, 0xed, 0x44, 0x54, 0x46, 0xad, 0x2a,
    0xf0, 0x47, 0xc7, 0xb0, 0x7a, 0xb2, 0x99, 0x29, 0x07, 0x0d, 0x31, 0xbd, 0x1e, 0x4c, 0x76, 0x82,
    0x03, 0xb6, 0xeb, 0x82, 0x19, 0x98, 0x5a, 0xd8, 0x01, 0x78, 0x58, 0xfd, 0x33, 0x9e, 0x70, 0x39,
    0x28, 0xf9, 0x39, 0x2a, 0x20, 0x86, 0x83, 0x68, 0xee, 0x1c, 0x9a, 0x83, 0x4e, 0xe8, 0x49, 0xcb,
    0xa7, 0x24, 0x09, 0xf0, 0x5e, 0x49, 0x77, 0xe7, 0xd1, 0x5a, 0xb3, 0x69, 0x59, 0x56, 0xc4, 0xa2,
    0xdf, 0xc8, 0xf6, 0xff, 0x45, 0x9a, 0x2e, 0x76, 0xc1, 0x55, 0x1d, 0x7b, 0x7d, 0xd2, 0x8a, 0xf7,
    0x17, 0x13, 0xcd, 0x66, 0xd2
};
#endif

PyTypeObject *init_QMdiArea(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX].type;

    Shiboken::AutoDecRef Sbk_QMdiArea_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX]))));

    _Sbk_QMdiArea_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMdiArea",
        "QMdiArea*",
        &Sbk_QMdiArea_spec,
        &Shiboken::callCppDestructor< QMdiArea >,
        Sbk_QMdiArea_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QMdiArea_TypeF(); // references _Sbk_QMdiArea_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMdiArea_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMdiArea_SignatureBytes, QMdiArea_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMdiArea_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMdiArea_PythonToCpp_QMdiArea_PTR,
        is_QMdiArea_PythonToCpp_QMdiArea_PTR_Convertible,
        QMdiArea_PTR_CppToPython_QMdiArea);

    Shiboken::Conversions::registerConverterName(converter, "QMdiArea");
    Shiboken::Conversions::registerConverterName(converter, "QMdiArea*");
    Shiboken::Conversions::registerConverterName(converter, "QMdiArea&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMdiArea).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QMdiAreaWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QMdiArea_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QMdiArea_TypeF(), &Sbk_QMdiAreaSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QMdiArea_TypeF(), &Sbk_QMdiArea_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QMdiArea_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'AreaOption'.
    const char *AreaOption_Initializer[] = {
        "DontMaximizeSubWindowOnActivation",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AreaOption_InitializerValues[] = {
        uint8_t(QMdiArea::AreaOption::DontMaximizeSubWindowOnActivation) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMdiArea_TypeF(),
        "2:PySide6.QtWidgets.QMdiArea.AreaOption",
        AreaOption_Initializer, AreaOption_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_AreaOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QMdiArea_AreaOption_IDX].type =
        EType;
    // Register converter for enum 'QMdiArea::AreaOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMdiArea_AreaOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMdiArea_AreaOption,
            is_Enum_PythonToCpp_QMdiArea_AreaOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMdiArea::AreaOption");
        Shiboken::Conversions::registerConverterAlias(converter, "AreaOption");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QMdiArea_AreaOption_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QMdiArea_AreaOption,
            is_Enum_PythonToCpp_QMdiArea_AreaOption_Convertible);
        // Register converter for flag 'QFlags<QMdiArea::AreaOption>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QMdiArea::AreaOption>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QMdiArea::AreaOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'AreaOption' enum/flags.

    // Initialization of enum 'WindowOrder'.
    const char *WindowOrder_Initializer[] = {
        "CreationOrder",
        "StackingOrder",
        "ActivationHistoryOrder",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t WindowOrder_InitializerValues[] = {
        uint8_t(QMdiArea::WindowOrder::CreationOrder),         //  0x00  0
        uint8_t(QMdiArea::WindowOrder::StackingOrder),         //  0x01  1
        uint8_t(QMdiArea::WindowOrder::ActivationHistoryOrder) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMdiArea_TypeF(),
        "2:PySide6.QtWidgets.QMdiArea.WindowOrder",
        WindowOrder_Initializer, WindowOrder_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_WindowOrder_IDX].type = EType;
    // Register converter for enum 'QMdiArea::WindowOrder'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMdiArea_WindowOrder_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMdiArea_WindowOrder,
            is_Enum_PythonToCpp_QMdiArea_WindowOrder_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMdiArea::WindowOrder");
        Shiboken::Conversions::registerConverterAlias(converter, "WindowOrder");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'WindowOrder' enum.

    // Initialization of enum 'ViewMode'.
    const char *ViewMode_Initializer[] = {
        "SubWindowView",
        "TabbedView",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ViewMode_InitializerValues[] = {
        uint8_t(QMdiArea::ViewMode::SubWindowView), //  0x00  0
        uint8_t(QMdiArea::ViewMode::TabbedView)     //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMdiArea_TypeF(),
        "2:PySide6.QtWidgets.QMdiArea.ViewMode",
        ViewMode_Initializer, ViewMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_ViewMode_IDX].type = EType;
    // Register converter for enum 'QMdiArea::ViewMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMdiArea_ViewMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMdiArea_ViewMode,
            is_Enum_PythonToCpp_QMdiArea_ViewMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMdiArea::ViewMode");
        Shiboken::Conversions::registerConverterAlias(converter, "ViewMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ViewMode' enum.

    PySide::Signal::registerSignals(pyType, &::QMdiArea::staticMetaObject);
    qRegisterMetaType< ::QMdiArea::AreaOption >("QMdiArea::AreaOption");
    qRegisterMetaType< ::QMdiArea::WindowOrder >("QMdiArea::WindowOrder");
    qRegisterMetaType< ::QMdiArea::ViewMode >("QMdiArea::ViewMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QMdiArea::staticMetaObject, sizeof(QMdiAreaWrapper));

    return pyType;
}
