// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qspaceritem_wrapper.h"

// Wrappers providing overrides
#include "qlayoutitem_wrapper.h"

// Argument includes
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qlayoutitem.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qwidget.h>
#include <qrect.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSpacerItemWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSpacerItemWrapper::QSpacerItemWrapper(int w, int h, ::QSizePolicy::Policy hData, ::QSizePolicy::Policy vData) : QSpacerItem(w, h, hData, vData)
{
}

::QFlags<QSizePolicy::ControlType> QSpacerItemWrapper::controlTypes() const
{
    static const char *funcName = "controlTypes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayoutItem::controlTypes();
    }
    return QLayoutItemWrapper::sbk_o_controlTypes("QSpacerItem", funcName, gil, pyOverride);
}

::QFlags<Qt::Orientation> QSpacerItemWrapper::expandingDirections() const
{
    static const char *funcName = "expandingDirections";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSpacerItem::expandingDirections();
    }
    return QLayoutItemWrapper::sbk_o_expandingDirections("QSpacerItem", funcName, gil, pyOverride);
}

::QRect QSpacerItemWrapper::geometry() const
{
    static const char *funcName = "geometry";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSpacerItem::geometry();
    }
    return QLayoutItemWrapper::sbk_o_geometry("QSpacerItem", funcName, gil, pyOverride);
}

bool QSpacerItemWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayoutItem::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QSpacerItem", funcName, gil, pyOverride);
}

int QSpacerItemWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayoutItem::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QSpacerItem", funcName, gil, pyOverride, arg__1);
}

void QSpacerItemWrapper::invalidate()
{
    static const char *funcName = "invalidate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayoutItem::invalidate();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QSpacerItem", funcName, gil, pyOverride);
}

bool QSpacerItemWrapper::isEmpty() const
{
    static const char *funcName = "isEmpty";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSpacerItem::isEmpty();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QSpacerItem", funcName, gil, pyOverride);
}

::QLayout * QSpacerItemWrapper::layout()
{
    static const char *funcName = "layout";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayoutItem::layout();
    }
    return sbk_o_layout("QSpacerItem", funcName, gil, pyOverride);
}

::QLayout * QSpacerItemWrapper::sbk_o_layout(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLayout_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QLayout >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QLayout *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSize QSpacerItemWrapper::maximumSize() const
{
    static const char *funcName = "maximumSize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSpacerItem::maximumSize();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QSpacerItem", funcName, gil, pyOverride);
}

int QSpacerItemWrapper::minimumHeightForWidth(int arg__1) const
{
    static const char *funcName = "minimumHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayoutItem::minimumHeightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QSpacerItem", funcName, gil, pyOverride, arg__1);
}

::QSize QSpacerItemWrapper::minimumSize() const
{
    static const char *funcName = "minimumSize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSpacerItem::minimumSize();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QSpacerItem", funcName, gil, pyOverride);
}

void QSpacerItemWrapper::setGeometry(const ::QRect & arg__1)
{
    static const char *funcName = "setGeometry";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSpacerItem::setGeometry(arg__1);
    }
    QLayoutItemWrapper::sbk_o_setGeometry("QSpacerItem", funcName, gil, pyOverride, arg__1);
}

::QSize QSpacerItemWrapper::sizeHint() const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSpacerItem::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QSpacerItem", funcName, gil, pyOverride);
}

::QSpacerItem * QSpacerItemWrapper::spacerItem()
{
    static const char *funcName = "spacerItem";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSpacerItem::spacerItem();
    }
    return sbk_o_spacerItem("QSpacerItem", funcName, gil, pyOverride);
}

::QSpacerItem * QSpacerItemWrapper::sbk_o_spacerItem(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QSpacerItem >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSpacerItem *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QWidget * QSpacerItemWrapper::widget() const
{
    static const char *funcName = "widget";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayoutItem::widget();
    }
    return sbk_o_widget("QSpacerItem", funcName, gil, pyOverride);
}

::QWidget * QSpacerItemWrapper::sbk_o_widget(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QWidget >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QWidget *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QSpacerItemWrapper::~QSpacerItemWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSpacerItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSpacerItem >()))
        return -1;

    QSpacerItemWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QSpacerItem", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSpacerItem::QSpacerItem(int,int,QSizePolicy::Policy=,QSizePolicy::Policy=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // QSpacerItem(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_Policy_IDX])))->converter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // QSpacerItem(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_Policy_IDX])))->converter, (pyArgs[3])))) {
                overloadId = 0; // QSpacerItem(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"hData", 2}, {"vData", 3}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_Policy_IDX])))->converter, (pyArgs[2]))))
                || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_Policy_IDX])))->converter, (pyArgs[3]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QSizePolicy::Policy cppArg2(QSizePolicy::Minimum);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QSizePolicy::Policy cppArg3(QSizePolicy::Minimum);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSpacerItem(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
            cptr = new QSpacerItemWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSpacerItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSpacerItemFunc_changeSize(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpacerItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "changeSize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:changeSize", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSpacerItem::changeSize(int,int,QSizePolicy::Policy=,QSizePolicy::Policy=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // changeSize(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_Policy_IDX])))->converter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // changeSize(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_Policy_IDX])))->converter, (pyArgs[3])))) {
                overloadId = 0; // changeSize(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "changeSize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"hData", 2}, {"vData", 3}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_Policy_IDX])))->converter, (pyArgs[2]))))
                || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_Policy_IDX])))->converter, (pyArgs[3]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "changeSize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QSizePolicy::Policy cppArg2(QSizePolicy::Minimum);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QSizePolicy::Policy cppArg3(QSizePolicy::Minimum);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // changeSize(int,int,QSizePolicy::Policy,QSizePolicy::Policy)
            cppSelf->changeSize(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSpacerItemFunc_expandingDirections(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpacerItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // expandingDirections()const
        QFlags<Qt::Orientation> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSpacerItem *>(cppSelf)->::QSpacerItem::expandingDirections()
            : const_cast<const ::QSpacerItem *>(cppSelf)->expandingDirections();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_Orientation_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSpacerItemFunc_geometry(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpacerItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // geometry()const
        QRect cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSpacerItem *>(cppSelf)->::QSpacerItem::geometry()
            : const_cast<const ::QSpacerItem *>(cppSelf)->geometry();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSpacerItemFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpacerItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSpacerItem *>(cppSelf)->::QSpacerItem::isEmpty()
            : const_cast<const ::QSpacerItem *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSpacerItemFunc_maximumSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpacerItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumSize()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSpacerItem *>(cppSelf)->::QSpacerItem::maximumSize()
            : const_cast<const ::QSpacerItem *>(cppSelf)->maximumSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSpacerItemFunc_minimumSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpacerItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumSize()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSpacerItem *>(cppSelf)->::QSpacerItem::minimumSize()
            : const_cast<const ::QSpacerItem *>(cppSelf)->minimumSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSpacerItemFunc_setGeometry(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpacerItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLayoutItem::setGeometry(QRect)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArg)))) {
        overloadId = 0; // setGeometry(QRect)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGeometry", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRect cppArg0_local;
        ::QRect *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setGeometry(QRect)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSpacerItem::setGeometry(*cppArg0)
                : cppSelf->setGeometry(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSpacerItemFunc_sizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpacerItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizeHint()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSpacerItem *>(cppSelf)->::QSpacerItem::sizeHint()
            : const_cast<const ::QSpacerItem *>(cppSelf)->sizeHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSpacerItemFunc_sizePolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpacerItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizePolicy()const
        QSizePolicy cppResult = const_cast<const ::QSpacerItem *>(cppSelf)->sizePolicy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSpacerItemFunc_spacerItem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSpacerItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // spacerItem()
        QSpacerItem * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QSpacerItem::spacerItem()
            : cppSelf->spacerItem();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]), cppResult);

        // Ownership transferences.
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QSpacerItem_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSpacerItem_methods[] = {
    {"changeSize", reinterpret_cast<PyCFunction>(Sbk_QSpacerItemFunc_changeSize), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"expandingDirections", reinterpret_cast<PyCFunction>(Sbk_QSpacerItemFunc_expandingDirections), METH_NOARGS, nullptr},
    {"geometry", reinterpret_cast<PyCFunction>(Sbk_QSpacerItemFunc_geometry), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QSpacerItemFunc_isEmpty), METH_NOARGS, nullptr},
    {"maximumSize", reinterpret_cast<PyCFunction>(Sbk_QSpacerItemFunc_maximumSize), METH_NOARGS, nullptr},
    {"minimumSize", reinterpret_cast<PyCFunction>(Sbk_QSpacerItemFunc_minimumSize), METH_NOARGS, nullptr},
    {"setGeometry", reinterpret_cast<PyCFunction>(Sbk_QSpacerItemFunc_setGeometry), METH_O, nullptr},
    {"sizeHint", reinterpret_cast<PyCFunction>(Sbk_QSpacerItemFunc_sizeHint), METH_NOARGS, nullptr},
    {"sizePolicy", reinterpret_cast<PyCFunction>(Sbk_QSpacerItemFunc_sizePolicy), METH_NOARGS, nullptr},
    {"spacerItem", reinterpret_cast<PyCFunction>(Sbk_QSpacerItemFunc_spacerItem), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSpacerItem_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSpacerItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSpacerItemWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSpacerItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSpacerItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSpacerItem_Type = nullptr;
static PyTypeObject *Sbk_QSpacerItem_TypeF(void)
{
    return _Sbk_QSpacerItem_Type;
}

static PyType_Slot Sbk_QSpacerItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSpacerItem_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSpacerItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSpacerItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSpacerItem_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSpacerItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSpacerItem_spec = {
    "2:PySide6.QtWidgets.QSpacerItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSpacerItem_slots
};

} //extern "C"

static void *Sbk_QSpacerItem_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QLayoutItem >())
        return dynamic_cast< ::QSpacerItem *>(reinterpret_cast< ::QLayoutItem *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSpacerItem_PythonToCpp_QSpacerItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSpacerItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSpacerItem_PythonToCpp_QSpacerItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSpacerItem_TypeF()))
        return QSpacerItem_PythonToCpp_QSpacerItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSpacerItem_PTR_CppToPython_QSpacerItem(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QSpacerItem *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QSpacerItem_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSpacerItem_SignatureStrings[] = {
    "PySide6.QtWidgets.QSpacerItem(self,w:int,h:int,hData:PySide6.QtWidgets.QSizePolicy.Policy=QSizePolicy.Minimum,vData:PySide6.QtWidgets.QSizePolicy.Policy=QSizePolicy.Minimum)",
    "PySide6.QtWidgets.QSpacerItem.changeSize(self,w:int,h:int,hData:PySide6.QtWidgets.QSizePolicy.Policy=QSizePolicy.Minimum,vData:PySide6.QtWidgets.QSizePolicy.Policy=QSizePolicy.Minimum)",
    "PySide6.QtWidgets.QSpacerItem.expandingDirections(self)->PySide6.QtCore.Qt.Orientation",
    "PySide6.QtWidgets.QSpacerItem.geometry(self)->PySide6.QtCore.QRect",
    "PySide6.QtWidgets.QSpacerItem.isEmpty(self)->bool",
    "PySide6.QtWidgets.QSpacerItem.maximumSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QSpacerItem.minimumSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QSpacerItem.setGeometry(self,arg__1:PySide6.QtCore.QRect)",
    "PySide6.QtWidgets.QSpacerItem.sizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QSpacerItem.sizePolicy(self)->PySide6.QtWidgets.QSizePolicy",
    "PySide6.QtWidgets.QSpacerItem.spacerItem(self)->PySide6.QtWidgets.QSpacerItem",
    nullptr}; // Sentinel
#else
static constexpr size_t QSpacerItem_SignatureByteSize = 232;
static constexpr uint8_t QSpacerItem_SignatureBytes[232] = {
    0x78, 0xda, 0xd5, 0x93, 0x3d, 0x0b, 0xc2, 0x30, 0x10, 0x86, 0x77, 0x7f, 0x89, 0x42, 0x0d, 0xb8,
    0x38, 0x14, 0x74, 0x51, 0x51, 0x07, 0xb1, 0xda, 0xc1, 0x51, 0x62, 0x7b, 0xc6, 0x83, 0x26, 0x29,
    0xc9, 0xa9, 0xad, 0xbf, 0xde, 0xd6, 0x42, 0x55, 0xac, 0x66, 0xe8, 0xe4, 0x92, 0x83, 0xe4, 0xde,
    0xe7, 0x3e, 0x13, 0xe4, 0x21, 0xc6, 0x30, 0x64, 0x1b, 0xda, 0x61, 0x2c, 0x80, 0x2c, 0xdb, 0x84,
    0x29, 0x8f, 0xc0, 0x2c, 0x09, 0x64, 0xd7, 0x42, 0x72, 0xf4, 0xae, 0x3e, 0x2a, 0xf2, 0x4e, 0xd5,
    0x39, 0xe5, 0xc4, 0xfd, 0xa0, 0x41, 0x84, 0x37, 0x08, 0x74, 0x82, 0x51, 0xce, 0x2a, 0x33, 0x7a,
    0xbd, 0x5a, 0xa1, 0x42, 0x79, 0x96, 0xde, 0xa5, 0x95, 0xbc, 0xd7, 0x09, 0x7e, 0x65, 0xcb, 0xa2,
    0x13, 0x57, 0x02, 0x4a, 0xdd, 0x9f, 0x25, 0x0e, 0x59, 0xca, 0x55, 0x8c, 0x4a, 0x4c, 0xd1, 0x40,
    0x44, 0xa8, 0x95, 0x7d, 0x54, 0xd0, 0xeb, 0x8f, 0x9f, 0xc2, 0x89, 0x36, 0x50, 0x18, 0xb6, 0x36,
    0x08, 0x8a, 0x78, 0xe9, 0xe5, 0xc0, 0x0a, 0xd0, 0x12, 0xc8, 0xe4, 0xdf, 0x58, 0xdb, 0x22, 0x96,
    0x03, 0x81, 0x76, 0x26, 0x53, 0xaa, 0x09, 0x07, 0xad, 0x13, 0x87, 0x42, 0xf2, 0xac, 0x2c, 0xb9,
    0x9e, 0x42, 0x43, 0xdc, 0xf2, 0xcd, 0x45, 0xa9, 0x1a, 0xd7, 0x92, 0x62, 0x81, 0xe6, 0xaf, 0x3d,
    0xf0, 0xb8, 0x11, 0xfb, 0xfd, 0xc0, 0x6f, 0x6a, 0x84, 0x6b, 0x46, 0xb6, 0x08, 0xb7, 0x28, 0x36,
    0xa9, 0x4d, 0x3a, 0xf5, 0x62, 0x7c, 0x42, 0x1a, 0x16, 0xca, 0x45, 0x7b, 0xff, 0xa6, 0x5f, 0x68,
    0xb5, 0x53, 0xe7, 0x0e, 0x19, 0xe0, 0x6a, 0xe5
};
#endif

PyTypeObject *init_QSpacerItem(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX].type;

    Shiboken::AutoDecRef Sbk_QSpacerItem_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLayoutItem_IDX]))));

    _Sbk_QSpacerItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSpacerItem",
        "QSpacerItem*",
        &Sbk_QSpacerItem_spec,
        &Shiboken::callCppDestructor< QSpacerItem >,
        Sbk_QSpacerItem_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSpacerItem_TypeF(); // references _Sbk_QSpacerItem_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSpacerItem_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSpacerItem_SignatureBytes, QSpacerItem_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSpacerItem_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSpacerItem_PythonToCpp_QSpacerItem_PTR,
        is_QSpacerItem_PythonToCpp_QSpacerItem_PTR_Convertible,
        QSpacerItem_PTR_CppToPython_QSpacerItem);

    Shiboken::Conversions::registerConverterName(converter, "QSpacerItem");
    Shiboken::Conversions::registerConverterName(converter, "QSpacerItem*");
    Shiboken::Conversions::registerConverterName(converter, "QSpacerItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSpacerItem).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSpacerItemWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSpacerItem_TypeF(), &Sbk_QSpacerItem_typeDiscovery);

    qRegisterMetaType< ::QSpacerItem *>();

    return pyType;
}
