// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSPACERITEMWRAPPER_H
#define SBK_QSPACERITEMWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qlayoutitem.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QSpacerItemWrapper : public QSpacerItem
{
public:
    QSpacerItemWrapper(int w, int h, ::QSizePolicy::Policy hData = QSizePolicy::Minimum, ::QSizePolicy::Policy vData = QSizePolicy::Minimum);
    QSpacerItemWrapper(const QSpacerItemWrapper &) = delete;
    QSpacerItemWrapper& operator=(const QSpacerItemWrapper &) = delete;
    QSpacerItemWrapper(QSpacerItemWrapper &&) = delete;
    QSpacerItemWrapper& operator=(QSpacerItemWrapper &&) = delete;
    ~QSpacerItemWrapper() override;

    ::QFlags<QSizePolicy::ControlType> controlTypes() const override;
    ::QFlags<Qt::Orientation> expandingDirections() const override;
    ::QRect geometry() const override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void invalidate() override;
    bool isEmpty() const override;
    ::QLayout * layout() override;
    static ::QLayout * sbk_o_layout(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QSize maximumSize() const override;
    int minimumHeightForWidth(int arg__1) const override;
    ::QSize minimumSize() const override;
    void setGeometry(const ::QRect & arg__1) override;
    ::QSize sizeHint() const override;
    ::QSpacerItem * spacerItem() override;
    static ::QSpacerItem * sbk_o_spacerItem(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QWidget * widget() const override;
    static ::QWidget * sbk_o_widget(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[15] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSPACERITEMWRAPPER_H
