// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSTACKEDLAYOUTWRAPPER_H
#define SBK_QSTACKEDLAYOUTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qstackedlayout.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QStackedLayoutWrapper : public QStackedLayout
{
public:
    QStackedLayoutWrapper();
    QStackedLayoutWrapper(::QLayout * parentLayout);
    QStackedLayoutWrapper(::QWidget * parent);
    QStackedLayoutWrapper(const QStackedLayoutWrapper &) = delete;
    QStackedLayoutWrapper& operator=(const QStackedLayoutWrapper &) = delete;
    QStackedLayoutWrapper(QStackedLayoutWrapper &&) = delete;
    QStackedLayoutWrapper& operator=(QStackedLayoutWrapper &&) = delete;
    ~QStackedLayoutWrapper() override;

    void addItem(::QLayoutItem * item) override;
    static void sbk_o_addItem(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QLayoutItem * item);
    void childEvent(::QChildEvent * e) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    ::QFlags<QSizePolicy::ControlType> controlTypes() const override;
    int count() const override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QFlags<Qt::Orientation> expandingDirections() const override;
    ::QRect geometry() const override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int width) const override;
    int indexOf(const ::QLayoutItem * arg__1) const override;
    int indexOf(const ::QWidget * arg__1) const override;
    void invalidate() override;
    bool isEmpty() const override;
    ::QLayoutItem * itemAt(int arg__1) const override;
    static ::QLayoutItem * sbk_o_itemAt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int arg__1);
    ::QLayout * layout() override;
    ::QSize maximumSize() const override;
    int minimumHeightForWidth(int arg__1) const override;
    ::QSize minimumSize() const override;
    ::QLayoutItem * replaceWidget(::QWidget * from, ::QWidget * to, ::QFlags<Qt::FindChildOption> options = Qt::FindChildrenRecursively) override;
    static ::QLayoutItem * sbk_o_replaceWidget(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * from, ::QWidget * to, ::QFlags<Qt::FindChildOption> options = Qt::FindChildrenRecursively);
    void setGeometry(const ::QRect & rect) override;
    void setSpacing(int arg__1) override;
    ::QSize sizeHint() const override;
    ::QSpacerItem * spacerItem() override;
    int spacing() const override;
    ::QLayoutItem * takeAt(int arg__1) override;
    static ::QLayoutItem * sbk_o_takeAt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int arg__1);
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[30] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSTACKEDLAYOUTWRAPPER_H
