// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSTYLEWRAPPER_H
#define SBK_QSTYLEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qstyle.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QStyleWrapper : public QStyle
{
public:
    QStyleWrapper();
    QStyleWrapper(const QStyleWrapper &) = delete;
    QStyleWrapper& operator=(const QStyleWrapper &) = delete;
    QStyleWrapper(QStyleWrapper &&) = delete;
    QStyleWrapper& operator=(QStyleWrapper &&) = delete;
    ~QStyleWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    void drawComplexControl(::QStyle::ComplexControl cc, const ::QStyleOptionComplex * opt, ::QPainter * p, const ::QWidget * widget = nullptr) const override;
    static void sbk_o_drawComplexControl(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyle::ComplexControl cc, const ::QStyleOptionComplex * opt, ::QPainter * p, const ::QWidget * widget = nullptr);
    void drawControl(::QStyle::ControlElement element, const ::QStyleOption * opt, ::QPainter * p, const ::QWidget * widget = nullptr) const override;
    static void sbk_o_drawControl(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyle::ControlElement element, const ::QStyleOption * opt, ::QPainter * p, const ::QWidget * widget = nullptr);
    void drawItemPixmap(::QPainter * painter, const ::QRect & rect, int alignment, const ::QPixmap & pixmap) const override;
    static void sbk_o_drawItemPixmap(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QRect & rect, int alignment, const ::QPixmap & pixmap);
    void drawItemText(::QPainter * painter, const ::QRect & rect, int flags, const ::QPalette & pal, bool enabled, const ::QString & text, ::QPalette::ColorRole textRole = QPalette::NoRole) const override;
    static void sbk_o_drawItemText(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QRect & rect, int flags, const ::QPalette & pal, bool enabled, const ::QString & text, ::QPalette::ColorRole textRole = QPalette::NoRole);
    void drawPrimitive(::QStyle::PrimitiveElement pe, const ::QStyleOption * opt, ::QPainter * p, const ::QWidget * widget = nullptr) const override;
    static void sbk_o_drawPrimitive(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyle::PrimitiveElement pe, const ::QStyleOption * opt, ::QPainter * p, const ::QWidget * widget = nullptr);
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QPixmap generatedIconPixmap(::QIcon::Mode iconMode, const ::QPixmap & pixmap, const ::QStyleOption * opt) const override;
    static ::QPixmap sbk_o_generatedIconPixmap(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QIcon::Mode iconMode, const ::QPixmap & pixmap, const ::QStyleOption * opt);
    ::QStyle::SubControl hitTestComplexControl(::QStyle::ComplexControl cc, const ::QStyleOptionComplex * opt, const ::QPoint & pt, const ::QWidget * widget = nullptr) const override;
    static ::QStyle::SubControl sbk_o_hitTestComplexControl(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyle::ComplexControl cc, const ::QStyleOptionComplex * opt, const ::QPoint & pt, const ::QWidget * widget = nullptr);
    ::QRect itemPixmapRect(const ::QRect & r, int flags, const ::QPixmap & pixmap) const override;
    static ::QRect sbk_o_itemPixmapRect(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRect & r, int flags, const ::QPixmap & pixmap);
    ::QRect itemTextRect(const ::QFontMetrics & fm, const ::QRect & r, int flags, bool enabled, const ::QString & text) const override;
    static ::QRect sbk_o_itemTextRect(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QFontMetrics & fm, const ::QRect & r, int flags, bool enabled, const ::QString & text);
    int layoutSpacing(::QSizePolicy::ControlType control1, ::QSizePolicy::ControlType control2, ::Qt::Orientation orientation, const ::QStyleOption * option = nullptr, const ::QWidget * widget = nullptr) const override;
    static int sbk_o_layoutSpacing(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QSizePolicy::ControlType control1, ::QSizePolicy::ControlType control2, ::Qt::Orientation orientation, const ::QStyleOption * option = nullptr, const ::QWidget * widget = nullptr);
    int pixelMetric(::QStyle::PixelMetric metric, const ::QStyleOption * option = nullptr, const ::QWidget * widget = nullptr) const override;
    static int sbk_o_pixelMetric(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyle::PixelMetric metric, const ::QStyleOption * option = nullptr, const ::QWidget * widget = nullptr);
    void polish(::QApplication * application) override;
    static void sbk_o_polish(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QApplication * application);
    void polish(::QPalette & palette) override;
    static void sbk_o_polish(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPalette & palette);
    void polish(::QWidget * widget) override;
    ::QSize sizeFromContents(::QStyle::ContentsType ct, const ::QStyleOption * opt, const ::QSize & contentsSize, const ::QWidget * w = nullptr) const override;
    static ::QSize sbk_o_sizeFromContents(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyle::ContentsType ct, const ::QStyleOption * opt, const ::QSize & contentsSize, const ::QWidget * w = nullptr);
    ::QIcon standardIcon(::QStyle::StandardPixmap standardIcon, const ::QStyleOption * option = nullptr, const ::QWidget * widget = nullptr) const override;
    static ::QIcon sbk_o_standardIcon(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyle::StandardPixmap standardIcon, const ::QStyleOption * option = nullptr, const ::QWidget * widget = nullptr);
    ::QPalette standardPalette() const override;
    static ::QPalette sbk_o_standardPalette(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QPixmap standardPixmap(::QStyle::StandardPixmap standardPixmap, const ::QStyleOption * opt = nullptr, const ::QWidget * widget = nullptr) const override;
    static ::QPixmap sbk_o_standardPixmap(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyle::StandardPixmap standardPixmap, const ::QStyleOption * opt = nullptr, const ::QWidget * widget = nullptr);
    int styleHint(::QStyle::StyleHint stylehint, const ::QStyleOption * opt = nullptr, const ::QWidget * widget = nullptr, ::QStyleHintReturn * returnData = nullptr) const override;
    static int sbk_o_styleHint(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyle::StyleHint stylehint, const ::QStyleOption * opt = nullptr, const ::QWidget * widget = nullptr, ::QStyleHintReturn * returnData = nullptr);
    ::QRect subControlRect(::QStyle::ComplexControl cc, const ::QStyleOptionComplex * opt, ::QStyle::SubControl sc, const ::QWidget * widget = nullptr) const override;
    static ::QRect sbk_o_subControlRect(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyle::ComplexControl cc, const ::QStyleOptionComplex * opt, ::QStyle::SubControl sc, const ::QWidget * widget = nullptr);
    ::QRect subElementRect(::QStyle::SubElement subElement, const ::QStyleOption * option, const ::QWidget * widget = nullptr) const override;
    static ::QRect sbk_o_subElementRect(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyle::SubElement subElement, const ::QStyleOption * option, const ::QWidget * widget = nullptr);
    void timerEvent(::QTimerEvent * event) override;
    void unpolish(::QApplication * application) override;
    void unpolish(::QWidget * widget) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[30] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSTYLEWRAPPER_H
