// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QSTYLEDITEMDELEGATEWRAPPER_H
#define SBK_QSTYLEDITEMDELEGATEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qstyleditemdelegate.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QStyledItemDelegateWrapper : public QStyledItemDelegate
{
public:
    QStyledItemDelegateWrapper(::QObject * parent = nullptr);
    QStyledItemDelegateWrapper(const QStyledItemDelegateWrapper &) = delete;
    QStyledItemDelegateWrapper& operator=(const QStyledItemDelegateWrapper &) = delete;
    QStyledItemDelegateWrapper(QStyledItemDelegateWrapper &&) = delete;
    QStyledItemDelegateWrapper& operator=(QStyledItemDelegateWrapper &&) = delete;
    ~QStyledItemDelegateWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    ::QWidget * createEditor(::QWidget * parent, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) const override;
    static ::QWidget * sbk_o_createEditor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * parent, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);
    void customEvent(::QEvent * event) override;
    void destroyEditor(::QWidget * editor, const ::QModelIndex & index) const override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    ::QString displayText(const ::QVariant & value, const ::QLocale & locale) const override;
    static ::QString sbk_o_displayText(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QVariant & value, const ::QLocale & locale);
    bool editorEvent(::QEvent * event, ::QAbstractItemModel * model, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) override;
    static bool sbk_o_editorEvent(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QEvent * event, ::QAbstractItemModel * model, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * object, ::QEvent * event) override;
    bool helpEvent(::QHelpEvent * event, ::QAbstractItemView * view, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) override;
    void initStyleOption(::QStyleOptionViewItem * option, const ::QModelIndex & index) const override;
    static void sbk_o_initStyleOption(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyleOptionViewItem * option, const ::QModelIndex & index);
    void paint(::QPainter * painter, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) const override;
    static void sbk_o_paint(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QStyleOptionViewItem & option, const ::QModelIndex & index);
    ::QList<int> paintingRoles() const override;
    void setEditorData(::QWidget * editor, const ::QModelIndex & index) const override;
    static void sbk_o_setEditorData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * editor, const ::QModelIndex & index);
    void setModelData(::QWidget * editor, ::QAbstractItemModel * model, const ::QModelIndex & index) const override;
    static void sbk_o_setModelData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * editor, ::QAbstractItemModel * model, const ::QModelIndex & index);
    ::QSize sizeHint(const ::QStyleOptionViewItem & option, const ::QModelIndex & index) const override;
    void timerEvent(::QTimerEvent * event) override;
    void updateEditorGeometry(::QWidget * editor, const ::QStyleOptionViewItem & option, const ::QModelIndex & index) const override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[19] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QSTYLEDITEMDELEGATEWRAPPER_H
