// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QTABLEWIDGETITEMWRAPPER_H
#define SBK_QTABLEWIDGETITEMWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qtablewidget.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QTableWidgetItemWrapper : public QTableWidgetItem
{
public:
    QTableWidgetItemWrapper(const ::QIcon & icon, const ::QString & text, int type = QTableWidgetItem::ItemType::Type);
    QTableWidgetItemWrapper(const ::QString & text, int type = QTableWidgetItem::ItemType::Type);
    QTableWidgetItemWrapper(int type = QTableWidgetItem::ItemType::Type);
    QTableWidgetItemWrapper(const QTableWidgetItemWrapper &) = delete;
    QTableWidgetItemWrapper(const QTableWidgetItem& self) : QTableWidgetItem(self)
    {
    }
    QTableWidgetItemWrapper& operator=(const QTableWidgetItemWrapper &) = delete;
    QTableWidgetItemWrapper(QTableWidgetItemWrapper &&) = delete;
    QTableWidgetItemWrapper& operator=(QTableWidgetItemWrapper &&) = delete;
    ~QTableWidgetItemWrapper() override;

    ::QTableWidgetItem * clone() const override;
    static ::QTableWidgetItem * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QVariant data(int role) const override;
    static ::QVariant sbk_o_data(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int role);
    bool operator<(const ::QTableWidgetItem & other) const override;
    static bool sbk_o_op_lt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QTableWidgetItem & other);
    void read(::QDataStream & in) override;
    void setData(int role, const ::QVariant & value) override;
    static void sbk_o_setData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int role, const ::QVariant & value);
    void write(::QDataStream & out) const override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QTABLEWIDGETITEMWRAPPER_H
