// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QTREEWIDGETITEMWRAPPER_H
#define SBK_QTREEWIDGETITEMWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qtreewidget.h>

namespace Shiboken { class AutoDecRef; class GilState; }

class QTreeWidgetItemWrapper : public QTreeWidgetItem
{
public:
    QTreeWidgetItemWrapper(::QTreeWidget * treeview, ::QTreeWidgetItem * after, int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(::QTreeWidget * treeview, const ::QStringList & strings, int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(::QTreeWidget * treeview, int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(::QTreeWidgetItem * parent, ::QTreeWidgetItem * after, int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(::QTreeWidgetItem * parent, const ::QStringList & strings, int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(::QTreeWidgetItem * parent, int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(const ::QStringList & strings, int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(int type = QTreeWidgetItem::ItemType::Type);
    QTreeWidgetItemWrapper(const QTreeWidgetItemWrapper &) = delete;
    QTreeWidgetItemWrapper(const QTreeWidgetItem& self) : QTreeWidgetItem(self)
    {
    }
    QTreeWidgetItemWrapper& operator=(const QTreeWidgetItemWrapper &) = delete;
    QTreeWidgetItemWrapper(QTreeWidgetItemWrapper &&) = delete;
    QTreeWidgetItemWrapper& operator=(QTreeWidgetItemWrapper &&) = delete;
    ~QTreeWidgetItemWrapper() override;

    ::QTreeWidgetItem * clone() const override;
    static ::QTreeWidgetItem * sbk_o_clone(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride);
    ::QVariant data(int column, int role) const override;
    static ::QVariant sbk_o_data(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int column, int role);
    bool operator<(const ::QTreeWidgetItem & other) const override;
    static bool sbk_o_op_lt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QTreeWidgetItem & other);
    void read(::QDataStream & in) override;
    static void sbk_o_read(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QDataStream & in);
    void setData(int column, int role, const ::QVariant & value) override;
    static void sbk_o_setData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int column, int role, const ::QVariant & value);
    void write(::QDataStream & out) const override;
    static void sbk_o_write(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QDataStream & out);
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable bool m_PyMethodCache[6] = {false, false, false, false, false, false};
};

#endif // SBK_QTREEWIDGETITEMWRAPPER_H
