// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qvboxlayout_wrapper.h"

// Wrappers providing overrides
#include "qlayout_wrapper.h"
#include "qlayoutitem_wrapper.h"
#include "qspaceritem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qstackedlayout_wrapper.h"
#include "qwidget_wrapper.h"
#include "qgraphicslayout_wrapper.h"

// Argument includes
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qlayoutitem.h>
#include <QtWidgets/qwidget.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qrect.h>
#include <qsize.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QVBoxLayoutWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QVBoxLayoutWrapper::QVBoxLayoutWrapper()
{
}

QVBoxLayoutWrapper::QVBoxLayoutWrapper(::QWidget * parent) : QVBoxLayout(parent)
{
}

void QVBoxLayoutWrapper::addItem(::QLayoutItem * arg__1)
{
    static const char *funcName = "addItem";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::addItem(arg__1);
    }
    QStackedLayoutWrapper::sbk_o_addItem("QVBoxLayout", funcName, gil, pyOverride, arg__1);
}

void QVBoxLayoutWrapper::childEvent(::QChildEvent * e)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayout::childEvent(e);
    }
    QWidgetWrapper::sbk_o_childEvent("QVBoxLayout", funcName, gil, pyOverride, e);
}

void QVBoxLayoutWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QVBoxLayout", funcName, gil, pyOverride, signal);
}

::QFlags<QSizePolicy::ControlType> QVBoxLayoutWrapper::controlTypes() const
{
    static const char *funcName = "controlTypes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayout::controlTypes();
    }
    return QLayoutItemWrapper::sbk_o_controlTypes("QVBoxLayout", funcName, gil, pyOverride);
}

int QVBoxLayoutWrapper::count() const
{
    static const char *funcName = "count";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::count();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QVBoxLayout", funcName, gil, pyOverride);
}

void QVBoxLayoutWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QVBoxLayout", funcName, gil, pyOverride, event);
}

void QVBoxLayoutWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QVBoxLayout", funcName, gil, pyOverride, signal);
}

bool QVBoxLayoutWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QWidgetWrapper::sbk_o_event("QVBoxLayout", funcName, gil, pyOverride, event);
}

bool QVBoxLayoutWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QVBoxLayout", funcName, gil, pyOverride, watched, event);
}

::QFlags<Qt::Orientation> QVBoxLayoutWrapper::expandingDirections() const
{
    static const char *funcName = "expandingDirections";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::expandingDirections();
    }
    return QLayoutItemWrapper::sbk_o_expandingDirections("QVBoxLayout", funcName, gil, pyOverride);
}

::QRect QVBoxLayoutWrapper::geometry() const
{
    static const char *funcName = "geometry";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayout::geometry();
    }
    return QLayoutItemWrapper::sbk_o_geometry("QVBoxLayout", funcName, gil, pyOverride);
}

bool QVBoxLayoutWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QVBoxLayout", funcName, gil, pyOverride);
}

int QVBoxLayoutWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QVBoxLayout", funcName, gil, pyOverride, arg__1);
}

int QVBoxLayoutWrapper::indexOf(const ::QLayoutItem * arg__1) const
{
    static const char *funcName = "indexOf";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayout::indexOf(arg__1);
    }
    return QLayoutWrapper::sbk_o_indexOf("QVBoxLayout", funcName, gil, pyOverride, arg__1);
}

int QVBoxLayoutWrapper::indexOf(const ::QWidget * arg__1) const
{
    static const char *funcName = "indexOf";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayout::indexOf(arg__1);
    }
    return QLayoutWrapper::sbk_o_indexOf("QVBoxLayout", funcName, gil, pyOverride, arg__1);
}

void QVBoxLayoutWrapper::invalidate()
{
    static const char *funcName = "invalidate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::invalidate();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QVBoxLayout", funcName, gil, pyOverride);
}

bool QVBoxLayoutWrapper::isEmpty() const
{
    static const char *funcName = "isEmpty";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayout::isEmpty();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QVBoxLayout", funcName, gil, pyOverride);
}

::QLayoutItem * QVBoxLayoutWrapper::itemAt(int arg__1) const
{
    static const char *funcName = "itemAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::itemAt(arg__1);
    }
    return QStackedLayoutWrapper::sbk_o_itemAt("QVBoxLayout", funcName, gil, pyOverride, arg__1);
}

::QLayout * QVBoxLayoutWrapper::layout()
{
    static const char *funcName = "layout";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayout::layout();
    }
    return QSpacerItemWrapper::sbk_o_layout("QVBoxLayout", funcName, gil, pyOverride);
}

::QSize QVBoxLayoutWrapper::maximumSize() const
{
    static const char *funcName = "maximumSize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::maximumSize();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QVBoxLayout", funcName, gil, pyOverride);
}

int QVBoxLayoutWrapper::minimumHeightForWidth(int arg__1) const
{
    static const char *funcName = "minimumHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::minimumHeightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QVBoxLayout", funcName, gil, pyOverride, arg__1);
}

::QSize QVBoxLayoutWrapper::minimumSize() const
{
    static const char *funcName = "minimumSize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::minimumSize();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QVBoxLayout", funcName, gil, pyOverride);
}

::QLayoutItem * QVBoxLayoutWrapper::replaceWidget(::QWidget * from, ::QWidget * to, ::QFlags<Qt::FindChildOption> options)
{
    static const char *funcName = "replaceWidget";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayout::replaceWidget(from, to, options);
    }
    return QStackedLayoutWrapper::sbk_o_replaceWidget("QVBoxLayout", funcName, gil, pyOverride, from, to, options);
}

void QVBoxLayoutWrapper::setGeometry(const ::QRect & arg__1)
{
    static const char *funcName = "setGeometry";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::setGeometry(arg__1);
    }
    QLayoutItemWrapper::sbk_o_setGeometry("QVBoxLayout", funcName, gil, pyOverride, arg__1);
}

void QVBoxLayoutWrapper::setSpacing(int spacing)
{
    static const char *funcName = "setSpacing";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::setSpacing(spacing);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QVBoxLayout", funcName, gil, pyOverride, spacing);
}

::QSize QVBoxLayoutWrapper::sizeHint() const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QVBoxLayout", funcName, gil, pyOverride);
}

::QSpacerItem * QVBoxLayoutWrapper::spacerItem()
{
    static const char *funcName = "spacerItem";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayoutItem::spacerItem();
    }
    return QSpacerItemWrapper::sbk_o_spacerItem("QVBoxLayout", funcName, gil, pyOverride);
}

int QVBoxLayoutWrapper::spacing() const
{
    static const char *funcName = "spacing";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::spacing();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QVBoxLayout", funcName, gil, pyOverride);
}

::QLayoutItem * QVBoxLayoutWrapper::takeAt(int arg__1)
{
    static const char *funcName = "takeAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QBoxLayout::takeAt(arg__1);
    }
    return QStackedLayoutWrapper::sbk_o_takeAt("QVBoxLayout", funcName, gil, pyOverride, arg__1);
}

void QVBoxLayoutWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWidgetWrapper::sbk_o_timerEvent("QVBoxLayout", funcName, gil, pyOverride, event);
}

::QWidget * QVBoxLayoutWrapper::widget() const
{
    static const char *funcName = "widget";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QLayoutItem::widget();
    }
    return QSpacerItemWrapper::sbk_o_widget("QVBoxLayout", funcName, gil, pyOverride);
}

const QMetaObject *QVBoxLayoutWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QVBoxLayout::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QVBoxLayoutWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QVBoxLayout::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QVBoxLayoutWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QVBoxLayoutWrapper *>(this));
    return QVBoxLayout::qt_metacast(_clname);
}

QVBoxLayoutWrapper::~QVBoxLayoutWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QVBoxLayout_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QVBoxLayout >()))
        return -1;

    QVBoxLayoutWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QVBoxLayout", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QVBoxLayout::QVBoxLayout()
    // 1: QVBoxLayout::QVBoxLayout(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QVBoxLayout()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QVBoxLayout(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QVBoxLayout_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QVBoxLayout_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QVBoxLayout()
        {
            if (kwds && PyDict_Size(kwds) > 0)
                errInfo.reset(PyDict_Copy(kwds));

            // QVBoxLayout()
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QVBoxLayoutWrapper();
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QVBoxLayoutWrapper();
            }

            break;
        }
        case 1: // QVBoxLayout(QWidget *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0)
                errInfo.reset(PyDict_Copy(kwds));
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QVBoxLayout(QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QVBoxLayoutWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QVBoxLayoutWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QVBoxLayout >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QVBoxLayout_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QVBoxLayout_IDX]);
    };


    return 1;
}


static const char *Sbk_QVBoxLayout_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QVBoxLayout_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QVBoxLayout_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QVBoxLayout *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QVBoxLayout_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QVBoxLayoutWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QVBoxLayout_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QVBoxLayout_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QVBoxLayoutSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QVBoxLayout *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QBoxLayout_IDX]))
        return static_cast< ::QBoxLayout *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLayout_IDX]))
        return static_cast< ::QLayout *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLayoutItem_IDX]))
        return static_cast< ::QLayoutItem *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QVBoxLayout_Type = nullptr;
static PyTypeObject *Sbk_QVBoxLayout_TypeF(void)
{
    return _Sbk_QVBoxLayout_Type;
}

static PyType_Slot Sbk_QVBoxLayout_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QVBoxLayout_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QVBoxLayout_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QVBoxLayout_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QVBoxLayout_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QVBoxLayout_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QVBoxLayout_spec = {
    "2:PySide6.QtWidgets.QVBoxLayout",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QVBoxLayout_slots
};

} //extern "C"

static void *Sbk_QVBoxLayout_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QLayout >())
        return dynamic_cast< ::QVBoxLayout *>(reinterpret_cast< ::QLayout *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QVBoxLayout *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QLayoutItem >())
        return dynamic_cast< ::QVBoxLayout *>(reinterpret_cast< ::QLayoutItem *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QVBoxLayout_PythonToCpp_QVBoxLayout_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QVBoxLayout_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QVBoxLayout_PythonToCpp_QVBoxLayout_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QVBoxLayout_TypeF()))
        return QVBoxLayout_PythonToCpp_QVBoxLayout_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QVBoxLayout_PTR_CppToPython_QVBoxLayout(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QVBoxLayout *>(const_cast<void *>(cppIn)), Sbk_QVBoxLayout_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QVBoxLayout_SignatureStrings[] = {
    "1:PySide6.QtWidgets.QVBoxLayout(self)",
    "0:PySide6.QtWidgets.QVBoxLayout(self,parent:PySide6.QtWidgets.QWidget)",
    nullptr}; // Sentinel
#else
static constexpr size_t QVBoxLayout_SignatureByteSize = 62;
static constexpr uint8_t QVBoxLayout_SignatureBytes[62] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0xcf,
    0x4c, 0x49, 0x4f, 0x2d, 0x29, 0xd6, 0x0b, 0x0c, 0x73, 0xca, 0xaf, 0xf0, 0x49, 0xac, 0xcc, 0x2f,
    0x2d, 0xd1, 0x28, 0x4e, 0xcd, 0x49, 0xd3, 0xe4, 0x32, 0x20, 0x42, 0x95, 0x4e, 0x41, 0x62, 0x51,
    0x6a, 0x5e, 0x09, 0x36, 0x95, 0x10, 0x86, 0x26, 0x17, 0x00, 0x3f, 0x2f, 0x26, 0x95
};
#endif

PyTypeObject *init_QVBoxLayout(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QVBoxLayout_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QVBoxLayout_IDX].type;

    Shiboken::AutoDecRef Sbk_QVBoxLayout_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QBoxLayout_IDX]))));

    _Sbk_QVBoxLayout_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QVBoxLayout",
        "QVBoxLayout*",
        &Sbk_QVBoxLayout_spec,
        &Shiboken::callCppDestructor< QVBoxLayout >,
        Sbk_QVBoxLayout_Type_bases.object(),
        0);
    auto *pyType = Sbk_QVBoxLayout_TypeF(); // references _Sbk_QVBoxLayout_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QVBoxLayout_SignatureStrings);
#else
    InitSignatureBytes(pyType, QVBoxLayout_SignatureBytes, QVBoxLayout_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QVBoxLayout_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QVBoxLayout_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QVBoxLayout_PythonToCpp_QVBoxLayout_PTR,
        is_QVBoxLayout_PythonToCpp_QVBoxLayout_PTR_Convertible,
        QVBoxLayout_PTR_CppToPython_QVBoxLayout);

    Shiboken::Conversions::registerConverterName(converter, "QVBoxLayout");
    Shiboken::Conversions::registerConverterName(converter, "QVBoxLayout*");
    Shiboken::Conversions::registerConverterName(converter, "QVBoxLayout&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QVBoxLayout).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QVBoxLayoutWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLayout_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QVBoxLayout_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QVBoxLayout_TypeF(), &Sbk_QVBoxLayoutSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QVBoxLayout_TypeF(), &Sbk_QVBoxLayout_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QVBoxLayout::staticMetaObject, sizeof(QVBoxLayoutWrapper));

    return pyType;
}
