// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qwizard_wrapper.h"

// Wrappers providing overrides
#include "qlayoutitem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qwidget_wrapper.h"
#include "qwizardpage_wrapper.h"
#include "qgraphicsitem_wrapper.h"
#include "qgraphicslayout_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpixmap.h>
#include <QtWidgets/qabstractbutton.h>
#include <QtWidgets/qwidget.h>
#include <QtWidgets/qwizard.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QWizardWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QWizardWrapper::QWizardWrapper(::QWidget * parent, ::QFlags<Qt::WindowType> flags) : QWizard(parent, flags)
{
}

void QWizardWrapper::accept()
{
    static const char *funcName = "accept";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::accept();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QWizard", funcName, gil, pyOverride);
}

void QWizardWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QWizardPageWrapper::sbk_o_actionEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::changeEvent(event);
    }
    QWizardPageWrapper::sbk_o_changeEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWidgetWrapper::sbk_o_childEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::cleanupPage(int id)
{
    static const char *funcName = "cleanupPage";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWizard::cleanupPage(id);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QWizard", funcName, gil, pyOverride, id);
}

void QWizardWrapper::closeEvent(::QCloseEvent * arg__1)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::closeEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_closeEvent("QWizard", funcName, gil, pyOverride, arg__1);
}

void QWizardWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QWizard", funcName, gil, pyOverride, signal);
}

void QWizardWrapper::contextMenuEvent(::QContextMenuEvent * arg__1)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::contextMenuEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_contextMenuEvent("QWizard", funcName, gil, pyOverride, arg__1);
}

void QWizardWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QWizard", funcName, gil, pyOverride, event);
}

int QWizardWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QWizard", funcName, gil, pyOverride);
}

void QWizardWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QWizard", funcName, gil, pyOverride, signal);
}

void QWizardWrapper::done(int result)
{
    static const char *funcName = "done";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWizard::done(result);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QWizard", funcName, gil, pyOverride, result);
}

void QWizardWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragEnterEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragLeaveEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragMoveEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QWizardPageWrapper::sbk_o_dropEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QWizardPageWrapper::sbk_o_enterEvent("QWizard", funcName, gil, pyOverride, event);
}

bool QWizardWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWizard::event(event);
    }
    return QWidgetWrapper::sbk_o_event("QWizard", funcName, gil, pyOverride, event);
}

bool QWizardWrapper::eventFilter(::QObject * arg__1, ::QEvent * arg__2)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::eventFilter(arg__1, arg__2);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QWizard", funcName, gil, pyOverride, arg__1, arg__2);
}

int QWizardWrapper::exec()
{
    static const char *funcName = "exec";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::exec();
    }
    return sbk_o_exec("QWizard", funcName, gil, pyOverride);
}

int QWizardWrapper::sbk_o_exec(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);

    return cppResult;
}

void QWizardWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusInEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusInEvent("QWizard", funcName, gil, pyOverride, event);
}

bool QWizardWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QWidgetWrapper::sbk_o_focusNextPrevChild("QWizard", funcName, gil, pyOverride, next);
}

void QWizardWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusOutEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusOutEvent("QWizard", funcName, gil, pyOverride, event);
}

bool QWizardWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QWizard", funcName, gil, pyOverride);
}

int QWizardWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QWizard", funcName, gil, pyOverride, arg__1);
}

void QWizardWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QWizardPageWrapper::sbk_o_hideEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QWidgetWrapper::sbk_o_initPainter("QWizard", funcName, gil, pyOverride, painter);
}

void QWizardWrapper::initializePage(int id)
{
    static const char *funcName = "initializePage";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWizard::initializePage(id);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QWizard", funcName, gil, pyOverride, id);
}

void QWizardWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QWizardPageWrapper::sbk_o_inputMethodEvent("QWizard", funcName, gil, pyOverride, event);
}

::QVariant QWizardWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodQuery(arg__1);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QWizard", funcName, gil, pyOverride, arg__1);
}

void QWizardWrapper::keyPressEvent(::QKeyEvent * arg__1)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::keyPressEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_keyPressEvent("QWizard", funcName, gil, pyOverride, arg__1);
}

void QWizardWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyReleaseEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_leaveEvent("QWizard", funcName, gil, pyOverride, event);
}

int QWizardWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QWidgetWrapper::sbk_o_metric("QWizard", funcName, gil, pyOverride, arg__1);
}

::QSize QWizardWrapper::minimumSizeHint() const
{
    static const char *funcName = "minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::minimumSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QWizard", funcName, gil, pyOverride);
}

void QWizardWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseDoubleClickEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseMoveEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mousePressEvent(event);
    }
    QWizardPageWrapper::sbk_o_mousePressEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseReleaseEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QWizardPageWrapper::sbk_o_moveEvent("QWizard", funcName, gil, pyOverride, event);
}

bool QWizardWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QWizardPageWrapper::sbk_o_nativeEvent("QWizard", funcName, gil, pyOverride, eventType, message, result);
}

int QWizardWrapper::nextId() const
{
    static const char *funcName = "nextId";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWizard::nextId();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QWizard", funcName, gil, pyOverride);
}

void QWizardWrapper::open()
{
    static const char *funcName = "open";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::open();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QWizard", funcName, gil, pyOverride);
}

::QPaintEngine * QWizardWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QWidgetWrapper::sbk_o_paintEngine("QWizard", funcName, gil, pyOverride);
}

void QWizardWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWizard::paintEvent(event);
    }
    QWizardPageWrapper::sbk_o_paintEvent("QWizard", funcName, gil, pyOverride, event);
}

::QPaintDevice * QWizardWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QWidgetWrapper::sbk_o_redirected("QWizard", funcName, gil, pyOverride, offset);
}

void QWizardWrapper::reject()
{
    static const char *funcName = "reject";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::reject();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QWizard", funcName, gil, pyOverride);
}

void QWizardWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWizard::resizeEvent(event);
    }
    QWizardPageWrapper::sbk_o_resizeEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::setVisible(bool visible)
{
    static const char *funcName = "setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWizard::setVisible(visible);
    }
    QWidgetWrapper::sbk_o_setVisible("QWizard", funcName, gil, pyOverride, visible);
}

::QPainter * QWizardWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QWidgetWrapper::sbk_o_sharedPainter("QWizard", funcName, gil, pyOverride);
}

void QWizardWrapper::showEvent(::QShowEvent * arg__1)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDialog::showEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_showEvent("QWizard", funcName, gil, pyOverride, arg__1);
}

::QSize QWizardWrapper::sizeHint() const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWizard::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QWizard", funcName, gil, pyOverride);
}

void QWizardWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[52], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QWizardPageWrapper::sbk_o_tabletEvent("QWizard", funcName, gil, pyOverride, event);
}

void QWizardWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[53], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWidgetWrapper::sbk_o_timerEvent("QWizard", funcName, gil, pyOverride, event);
}

bool QWizardWrapper::validateCurrentPage()
{
    static const char *funcName = "validateCurrentPage";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[54], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWizard::validateCurrentPage();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QWizard", funcName, gil, pyOverride);
}

void QWizardWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[55], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::wheelEvent(event);
    }
    QWizardPageWrapper::sbk_o_wheelEvent("QWizard", funcName, gil, pyOverride, event);
}

const QMetaObject *QWizardWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QWizard::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QWizardWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QWizard::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QWizardWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QWizardWrapper *>(this));
    return QWizard::qt_metacast(_clname);
}

QWizardWrapper::~QWizardWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWizard_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWizard >()))
        return -1;

    QWizardWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QWizard", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWizard::QWizard(QWidget*=,QFlags<Qt::WindowType>=)
    if (numArgs == 0) {
        overloadId = 0; // QWizard(QWidget*,QFlags<Qt::WindowType>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QWizard(QWidget*,QFlags<Qt::WindowType>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // QWizard(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"parent", 0}, {"flags", 1}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::WindowType> cppArg1 = Qt::WindowFlags();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QWizard(QWidget*,QFlags<Qt::WindowType>)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QWizardWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QWizardWrapper(cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QWizard >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QWizardFunc_addPage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::addPage(QWizardPage*)->int
    if ((pyArg != Py_None && (pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizardPage_IDX]), (pyArg))))) {
        overloadId = 0; // addPage(QWizardPage*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addPage", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWizardPage *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addPage(QWizardPage*)
            int cppResult = cppSelf->addPage(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_back(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // back()
        cppSelf->back();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_button(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::button(QWizard::WizardButton)const->QAbstractButton*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardButton_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // button(QWizard::WizardButton)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "button", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        ::QWizard::WizardButton cppArg0{QWizard::BackButton};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // button(QWizard::WizardButton)const
            QAbstractButton * cppResult = const_cast<const ::QWizard *>(cppSelf)->button(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractButton_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_buttonText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::buttonText(QWizard::WizardButton)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardButton_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // buttonText(QWizard::WizardButton)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "buttonText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        ::QWizard::WizardButton cppArg0{QWizard::BackButton};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // buttonText(QWizard::WizardButton)const
            QString cppResult = const_cast<const ::QWizard *>(cppSelf)->buttonText(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_cleanupPage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::cleanupPage(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // cleanupPage(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "cleanupPage", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // cleanupPage(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWizard::cleanupPage(cppArg0)
                : cppSelf->cleanupPage(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_currentId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentId()const
        int cppResult = const_cast<const ::QWizard *>(cppSelf)->currentId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_currentPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentPage()const
        QWizardPage * cppResult = const_cast<const ::QWizard *>(cppSelf)->currentPage();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizardPage_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_done(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDialog::done(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // done(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "done", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // done(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWizard::done(cppArg0)
                : cppSelf->done(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWizard::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_field(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::field(QString)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // field(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "field", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // field(QString)const
            QVariant cppResult = const_cast<const ::QWizard *>(cppSelf)->field(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_hasVisitedPage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::hasVisitedPage(int)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // hasVisitedPage(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasVisitedPage", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasVisitedPage(int)const
            bool cppResult = const_cast<const ::QWizard *>(cppSelf)->hasVisitedPage(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_initializePage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::initializePage(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // initializePage(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "initializePage", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // initializePage(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWizard::initializePage(cppArg0)
                : cppSelf->initializePage(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_next(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // next()
        cppSelf->next();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_nextId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nextId()const
        int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QWizard *>(cppSelf)->::QWizard::nextId()
            : const_cast<const ::QWizard *>(cppSelf)->nextId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_options(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // options()const
        QFlags<QWizard::WizardOption> cppResult = const_cast<const ::QWizard *>(cppSelf)->options();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QWizard_WizardOption_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_page(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::page(int)const->QWizardPage*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // page(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "page", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // page(int)const
            QWizardPage * cppResult = const_cast<const ::QWizard *>(cppSelf)->page(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizardPage_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_pageIds(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pageIds()const
        QList<int> cppResult = const_cast<const ::QWizard *>(cppSelf)->pageIds();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_paintEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::paintEvent(QPaintEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), (pyArg)))) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "paintEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPaintEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paintEvent(QPaintEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWizard::paintEvent(cppArg0)
                : cppSelf->paintEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_pixmap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::pixmap(QWizard::WizardPixmap)const->QPixmap
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardPixmap_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // pixmap(QWizard::WizardPixmap)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "pixmap", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        ::QWizard::WizardPixmap cppArg0{QWizard::WatermarkPixmap};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // pixmap(QWizard::WizardPixmap)const
            QPixmap cppResult = const_cast<const ::QWizard *>(cppSelf)->pixmap(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_removePage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::removePage(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // removePage(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removePage", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removePage(int)
            cppSelf->removePage(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_resizeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::resizeEvent(QResizeEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), (pyArg)))) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resizeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QResizeEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeEvent(QResizeEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWizard::resizeEvent(cppArg0)
                : cppSelf->resizeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_restart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // restart()
        cppSelf->restart();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setButton(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setButton", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWizard::setButton(QWizard::WizardButton,QAbstractButton*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardButton_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractButton_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setButton(QWizard::WizardButton,QAbstractButton*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setButton", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        ::QWizard::WizardButton cppArg0{QWizard::BackButton};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QAbstractButton *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setButton(QWizard::WizardButton,QAbstractButton*)
            cppSelf->setButton(cppArg0, cppArg1);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[1]);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setButtonLayout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::setButtonLayout(QList<QWizard::WizardButton>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QWizard_WizardButton_IDX], (pyArg)))) {
        overloadId = 0; // setButtonLayout(QList<QWizard::WizardButton>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setButtonLayout", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        ::QList<QWizard::WizardButton> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setButtonLayout(QList<QWizard::WizardButton>)
            cppSelf->setButtonLayout(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setButtonText(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setButtonText", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWizard::setButtonText(QWizard::WizardButton,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardButton_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // setButtonText(QWizard::WizardButton,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setButtonText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        ::QWizard::WizardButton cppArg0{QWizard::BackButton};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setButtonText(QWizard::WizardButton,QString)
            cppSelf->setButtonText(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setCurrentId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::setCurrentId(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCurrentId(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCurrentId", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrentId(int)
            cppSelf->setCurrentId(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setDefaultProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDefaultProperty", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWizard::setDefaultProperty(const char*,const char*,const char*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))) {
        overloadId = 0; // setDefaultProperty(const char*,const char*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDefaultProperty", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        const char* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        const char* cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultProperty(const char*,const char*,const char*)
            cppSelf->setDefaultProperty(cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setField(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setField", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWizard::setField(QString,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // setField(QString,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setField", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setField(QString,QVariant)
            cppSelf->setField(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setOption(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setOption", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWizard::setOption(QWizard::WizardOption,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardOption_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setOption(QWizard::WizardOption,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setOption(QWizard::WizardOption,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"on", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);
            }
        }
        ::QWizard::WizardOption cppArg0 = static_cast< ::QWizard::WizardOption>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOption(QWizard::WizardOption,bool)
            cppSelf->setOption(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setOptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::setOptions(QFlags<QWizard::WizardOption>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QWizard_WizardOption_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setOptions(QFlags<QWizard::WizardOption>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOptions", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        ::QFlags<QWizard::WizardOption> cppArg0 = QFlags<QWizard::WizardOption>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOptions(QFlags<QWizard::WizardOption>)
            cppSelf->setOptions(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setPage(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setPage", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWizard::setPage(int,QWizardPage*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizardPage_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setPage(int,QWizardPage*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPage", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QWizardPage *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPage(int,QWizardPage*)
            cppSelf->setPage(cppArg0, cppArg1);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[1]);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setPixmap(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setPixmap", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWizard::setPixmap(QWizard::WizardPixmap,QPixmap)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardPixmap_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setPixmap(QWizard::WizardPixmap,QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPixmap", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        ::QWizard::WizardPixmap cppArg0{QWizard::WatermarkPixmap};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPixmap cppArg1_local;
        ::QPixmap *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPixmap(QWizard::WizardPixmap,QPixmap)
            cppSelf->setPixmap(cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setSideWidget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::setSideWidget(QWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // setSideWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSideWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSideWidget(QWidget*)
            cppSelf->setSideWidget(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setStartId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::setStartId(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setStartId(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStartId", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStartId(int)
            cppSelf->setStartId(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setSubTitleFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::setSubTitleFormat(Qt::TextFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TextFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSubTitleFormat(Qt::TextFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSubTitleFormat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        ::Qt::TextFormat cppArg0{Qt::PlainText};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSubTitleFormat(Qt::TextFormat)
            cppSelf->setSubTitleFormat(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setTitleFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::setTitleFormat(Qt::TextFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TextFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTitleFormat(Qt::TextFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTitleFormat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        ::Qt::TextFormat cppArg0{Qt::PlainText};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTitleFormat(Qt::TextFormat)
            cppSelf->setTitleFormat(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::setVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVisible", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVisible(bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWizard::setVisible(cppArg0)
                : cppSelf->setVisible(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_setWizardStyle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::setWizardStyle(QWizard::WizardStyle)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardStyle_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setWizardStyle(QWizard::WizardStyle)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWizardStyle", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        ::QWizard::WizardStyle cppArg0{QWizard::ClassicStyle};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWizardStyle(QWizard::WizardStyle)
            cppSelf->setWizardStyle(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QWizardFunc_sideWidget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sideWidget()const
        QWidget * cppResult = const_cast<const ::QWizard *>(cppSelf)->sideWidget();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_sizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizeHint()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QWizard *>(cppSelf)->::QWizard::sizeHint()
            : const_cast<const ::QWizard *>(cppSelf)->sizeHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_startId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // startId()const
        int cppResult = const_cast<const ::QWizard *>(cppSelf)->startId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_subTitleFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // subTitleFormat()const
        Qt::TextFormat cppResult = const_cast<const ::QWizard *>(cppSelf)->subTitleFormat();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TextFormat_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_testOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWizard::testOption(QWizard::WizardOption)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardOption_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // testOption(QWizard::WizardOption)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "testOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);

    // Call function/method
    {
        ::QWizard::WizardOption cppArg0 = static_cast< ::QWizard::WizardOption>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // testOption(QWizard::WizardOption)const
            bool cppResult = const_cast<const ::QWizard *>(cppSelf)->testOption(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_titleFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // titleFormat()const
        Qt::TextFormat cppResult = const_cast<const ::QWizard *>(cppSelf)->titleFormat();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TextFormat_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_validateCurrentPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // validateCurrentPage()
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QWizard::validateCurrentPage()
            : cppSelf->validateCurrentPage();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_visitedIds(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // visitedIds()const
        QList<int> cppResult = const_cast<const ::QWizard *>(cppSelf)->visitedIds();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWizardFunc_wizardStyle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wizardStyle()const
        QWizard::WizardStyle cppResult = const_cast<const ::QWizard *>(cppSelf)->wizardStyle();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardStyle_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QWizard_PropertyStrings[] = {
    "currentId::",
    "options::",
    "startId::",
    "subTitleFormat::",
    "titleFormat::",
    "wizardStyle::",
    nullptr // Sentinel
};

static const char *Sbk_QWizard_EnumFlagInfo[] = {
    "WizardButton:Enum",
    "WizardOption:Flag:WizardOptions",
    "WizardPixmap:Enum",
    "WizardStyle:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWizard_methods[] = {
    {"addPage", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_addPage), METH_O, nullptr},
    {"back", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_back), METH_NOARGS, nullptr},
    {"button", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_button), METH_O, nullptr},
    {"buttonText", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_buttonText), METH_O, nullptr},
    {"cleanupPage", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_cleanupPage), METH_O, nullptr},
    {"currentId", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_currentId), METH_NOARGS, nullptr},
    {"currentPage", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_currentPage), METH_NOARGS, nullptr},
    {"done", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_done), METH_O, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_event), METH_O, nullptr},
    {"field", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_field), METH_O, nullptr},
    {"hasVisitedPage", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_hasVisitedPage), METH_O, nullptr},
    {"initializePage", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_initializePage), METH_O, nullptr},
    {"next", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_next), METH_NOARGS, nullptr},
    {"nextId", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_nextId), METH_NOARGS, nullptr},
    {"options", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_options), METH_NOARGS, nullptr},
    {"page", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_page), METH_O, nullptr},
    {"pageIds", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_pageIds), METH_NOARGS, nullptr},
    {"paintEvent", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_paintEvent), METH_O, nullptr},
    {"pixmap", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_pixmap), METH_O, nullptr},
    {"removePage", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_removePage), METH_O, nullptr},
    {"resizeEvent", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_resizeEvent), METH_O, nullptr},
    {"restart", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_restart), METH_NOARGS, nullptr},
    {"setButton", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setButton), METH_VARARGS, nullptr},
    {"setButtonLayout", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setButtonLayout), METH_O, nullptr},
    {"setButtonText", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setButtonText), METH_VARARGS, nullptr},
    {"setCurrentId", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setCurrentId), METH_O, nullptr},
    {"setDefaultProperty", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setDefaultProperty), METH_VARARGS, nullptr},
    {"setField", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setField), METH_VARARGS, nullptr},
    {"setOption", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setOption), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setOptions", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setOptions), METH_O, nullptr},
    {"setPage", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setPage), METH_VARARGS, nullptr},
    {"setPixmap", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setPixmap), METH_VARARGS, nullptr},
    {"setSideWidget", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setSideWidget), METH_O, nullptr},
    {"setStartId", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setStartId), METH_O, nullptr},
    {"setSubTitleFormat", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setSubTitleFormat), METH_O, nullptr},
    {"setTitleFormat", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setTitleFormat), METH_O, nullptr},
    {"setVisible", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setVisible), METH_O, nullptr},
    {"setWizardStyle", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_setWizardStyle), METH_O, nullptr},
    {"sideWidget", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_sideWidget), METH_NOARGS, nullptr},
    {"sizeHint", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_sizeHint), METH_NOARGS, nullptr},
    {"startId", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_startId), METH_NOARGS, nullptr},
    {"subTitleFormat", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_subTitleFormat), METH_NOARGS, nullptr},
    {"testOption", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_testOption), METH_O, nullptr},
    {"titleFormat", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_titleFormat), METH_NOARGS, nullptr},
    {"validateCurrentPage", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_validateCurrentPage), METH_NOARGS, nullptr},
    {"visitedIds", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_visitedIds), METH_NOARGS, nullptr},
    {"wizardStyle", reinterpret_cast<PyCFunction>(Sbk_QWizardFunc_wizardStyle), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QWizard_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QWizard *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QWizardWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QWizard_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWizard_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QWizardSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QWizard *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX]))
        return static_cast< ::QDialog *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWizard_Type = nullptr;
static PyTypeObject *Sbk_QWizard_TypeF(void)
{
    return _Sbk_QWizard_Type;
}

static PyType_Slot Sbk_QWizard_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QWizard_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWizard_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWizard_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWizard_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWizard_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWizard_spec = {
    "2:PySide6.QtWidgets.QWizard",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWizard_slots
};

} //extern "C"

static void *Sbk_QWizard_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QWizard *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QWizard *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QWizard *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QWizard_WizardButton(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWizard::WizardButton>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWizard::WizardButton *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWizard_WizardButton_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardButton_IDX])))
        return Enum_PythonToCpp_QWizard_WizardButton;
    return {};
}

static PyObject *QWizard_WizardButton_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWizard::WizardButton>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWizard::WizardButton *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardButton_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWizard_WizardPixmap(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWizard::WizardPixmap>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWizard::WizardPixmap *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWizard_WizardPixmap_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardPixmap_IDX])))
        return Enum_PythonToCpp_QWizard_WizardPixmap;
    return {};
}

static PyObject *QWizard_WizardPixmap_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWizard::WizardPixmap>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWizard::WizardPixmap *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardPixmap_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWizard_WizardStyle(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWizard::WizardStyle>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWizard::WizardStyle *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWizard_WizardStyle_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardStyle_IDX])))
        return Enum_PythonToCpp_QWizard_WizardStyle;
    return {};
}

static PyObject *QWizard_WizardStyle_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWizard::WizardStyle>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWizard::WizardStyle *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardStyle_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWizard_WizardOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWizard::WizardOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWizard::WizardOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWizard_WizardOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardOption_IDX])))
        return Enum_PythonToCpp_QWizard_WizardOption;
    return {};
}

static PyObject *QWizard_WizardOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWizard::WizardOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWizard::WizardOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardOption_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QWizard_WizardOption(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QWizard::WizardOption>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QWizard::WizardOption> *>(cppOut) = value;

}

static PyObject *QWizard_WizardOption_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QWizard::WizardOption> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardOption_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWizard_PythonToCpp_QWizard_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWizard_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWizard_PythonToCpp_QWizard_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWizard_TypeF()))
        return QWizard_PythonToCpp_QWizard_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWizard_PTR_CppToPython_QWizard(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QWizard *>(const_cast<void *>(cppIn)), Sbk_QWizard_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWizard_SignatureStrings[] = {
    "PySide6.QtWidgets.QWizard(self,parent:PySide6.QtWidgets.QWidget=nullptr,flags:PySide6.QtCore.Qt.WindowType=Qt.WindowFlags(),*:KeywordOnly=None,wizardStyle:QWizard.WizardStyle=None,options:PySide6.QtWidgets.QWizard.WizardOption=None,titleFormat:Qt.TextFormat=None,subTitleFormat:Qt.TextFormat=None,startId:int=None,currentId:int=None)",
    "PySide6.QtWidgets.QWizard.addPage(self,page:PySide6.QtWidgets.QWizardPage)->int",
    "PySide6.QtWidgets.QWizard.back(self)",
    "PySide6.QtWidgets.QWizard.button(self,which:PySide6.QtWidgets.QWizard.WizardButton)->PySide6.QtWidgets.QAbstractButton",
    "PySide6.QtWidgets.QWizard.buttonText(self,which:PySide6.QtWidgets.QWizard.WizardButton)->QString",
    "PySide6.QtWidgets.QWizard.cleanupPage(self,id:int)",
    "PySide6.QtWidgets.QWizard.currentId(self)->int",
    "PySide6.QtWidgets.QWizard.currentPage(self)->PySide6.QtWidgets.QWizardPage",
    "PySide6.QtWidgets.QWizard.done(self,result:int)",
    "PySide6.QtWidgets.QWizard.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QWizard.field(self,name:QString)->QVariant",
    "PySide6.QtWidgets.QWizard.hasVisitedPage(self,id:int)->bool",
    "PySide6.QtWidgets.QWizard.initializePage(self,id:int)",
    "PySide6.QtWidgets.QWizard.next(self)",
    "PySide6.QtWidgets.QWizard.nextId(self)->int",
    "PySide6.QtWidgets.QWizard.options(self)->PySide6.QtWidgets.QWizard.WizardOption",
    "PySide6.QtWidgets.QWizard.page(self,id:int)->PySide6.QtWidgets.QWizardPage",
    "PySide6.QtWidgets.QWizard.pageIds(self)->QList[int]",
    "PySide6.QtWidgets.QWizard.paintEvent(self,event:PySide6.QtGui.QPaintEvent)",
    "PySide6.QtWidgets.QWizard.pixmap(self,which:PySide6.QtWidgets.QWizard.WizardPixmap)->PySide6.QtGui.QPixmap",
    "PySide6.QtWidgets.QWizard.removePage(self,id:int)",
    "PySide6.QtWidgets.QWizard.resizeEvent(self,event:PySide6.QtGui.QResizeEvent)",
    "PySide6.QtWidgets.QWizard.restart(self)",
    "PySide6.QtWidgets.QWizard.setButton(self,which:PySide6.QtWidgets.QWizard.WizardButton,button:PySide6.QtWidgets.QAbstractButton)",
    "PySide6.QtWidgets.QWizard.setButtonLayout(self,layout:QList[PySide6.QtWidgets.QWizard.WizardButton])",
    "PySide6.QtWidgets.QWizard.setButtonText(self,which:PySide6.QtWidgets.QWizard.WizardButton,text:QString)",
    "PySide6.QtWidgets.QWizard.setCurrentId(self,id:int)",
    "PySide6.QtWidgets.QWizard.setDefaultProperty(self,className:char*,property:char*,changedSignal:char*)",
    "PySide6.QtWidgets.QWizard.setField(self,name:QString,value:QVariant)",
    "PySide6.QtWidgets.QWizard.setOption(self,option:PySide6.QtWidgets.QWizard.WizardOption,on:bool=true)",
    "PySide6.QtWidgets.QWizard.setOptions(self,options:PySide6.QtWidgets.QWizard.WizardOption)",
    "PySide6.QtWidgets.QWizard.setPage(self,id:int,page:PySide6.QtWidgets.QWizardPage)",
    "PySide6.QtWidgets.QWizard.setPixmap(self,which:PySide6.QtWidgets.QWizard.WizardPixmap,pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage])",
    "PySide6.QtWidgets.QWizard.setSideWidget(self,widget:PySide6.QtWidgets.QWidget)",
    "PySide6.QtWidgets.QWizard.setStartId(self,id:int)",
    "PySide6.QtWidgets.QWizard.setSubTitleFormat(self,format:PySide6.QtCore.Qt.TextFormat)",
    "PySide6.QtWidgets.QWizard.setTitleFormat(self,format:PySide6.QtCore.Qt.TextFormat)",
    "PySide6.QtWidgets.QWizard.setVisible(self,visible:bool)",
    "PySide6.QtWidgets.QWizard.setWizardStyle(self,style:PySide6.QtWidgets.QWizard.WizardStyle)",
    "PySide6.QtWidgets.QWizard.sideWidget(self)->PySide6.QtWidgets.QWidget",
    "PySide6.QtWidgets.QWizard.sizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QWizard.startId(self)->int",
    "PySide6.QtWidgets.QWizard.subTitleFormat(self)->PySide6.QtCore.Qt.TextFormat",
    "PySide6.QtWidgets.QWizard.testOption(self,option:PySide6.QtWidgets.QWizard.WizardOption)->bool",
    "PySide6.QtWidgets.QWizard.titleFormat(self)->PySide6.QtCore.Qt.TextFormat",
    "PySide6.QtWidgets.QWizard.validateCurrentPage(self)->bool",
    "PySide6.QtWidgets.QWizard.visitedIds(self)->QList[int]",
    "PySide6.QtWidgets.QWizard.wizardStyle(self)->PySide6.QtWidgets.QWizard.WizardStyle",
    nullptr}; // Sentinel
#else
static constexpr size_t QWizard_SignatureByteSize = 755;
static constexpr uint8_t QWizard_SignatureBytes[755] = {
    0x78, 0xda, 0xb5, 0x56, 0xc1, 0x72, 0xda, 0x30, 0x10, 0xbd, 0xe7, 0x2b, 0x7a, 0x4c, 0x32, 0x2e,
    0xc7, 0x1e, 0x3c, 0x43, 0x67, 0x5a, 0x9a, 0xb4, 0x99, 0x66, 0x12, 0x28, 0x34, 0x1c, 0x32, 0x39,
    0x08, 0x7b, 0x31, 0x9a, 0x0a, 0xd9, 0x23, 0xad, 0x21, 0xce, 0xd7, 0x57, 0xd2, 0x3a, 0x60, 0xc0,
    0x48, 0x86, 0x69, 0x2f, 0x20, 0xc9, 0xbb, 0xef, 0xad, 0x77, 0x57, 0xcf, 0x3b, 0xac, 0xc6, 0x3c,
    0x85, 0x4f, 0xbd, 0x11, 0x4e, 0x79, 0x9a, 0x01, 0xea, 0xde, 0x68, 0xca, 0xdf, 0x98, 0x4a, 0x2f,
    0x35, 0x88, 0x79, 0x54, 0x30, 0x05, 0x12, 0xe3, 0x61, 0x9b, 0x95, 0x5d, 0xf4, 0x65, 0x29, 0x44,
    0x81, 0x2a, 0x9a, 0x0b, 0x96, 0xe9, 0x86, 0xdd, 0x20, 0x57, 0x60, 0xfe, 0x7a, 0x53, 0x2e, 0xd3,
    0x7c, 0x3d, 0xa9, 0x0a, 0xe8, 0x6f, 0x76, 0xb7, 0xd6, 0xf6, 0xf2, 0x2a, 0xba, 0x8e, 0x7f, 0x42,
    0xb5, 0xce, 0x55, 0xfa, 0x28, 0x45, 0xd5, 0x7f, 0xc8, 0x25, 0x44, 0x6b, 0xc7, 0x3d, 0xc6, 0x4a,
    0x40, 0x5c, 0x07, 0xd2, 0x9b, 0x6e, 0xcf, 0xc8, 0x28, 0x2f, 0x90, 0xe7, 0x52, 0xb7, 0x47, 0xd5,
    0x70, 0x79, 0x74, 0x76, 0xe4, 0x83, 0x1c, 0x05, 0xdc, 0xe6, 0x6a, 0xc9, 0x30, 0x36, 0x81, 0x4c,
    0xe0, 0x15, 0x69, 0x47, 0x8f, 0x75, 0x39, 0x9b, 0x04, 0x2c, 0x90, 0x29, 0xbc, 0x4b, 0x63, 0x2e,
    0xeb, 0x83, 0xa4, 0x54, 0x36, 0x37, 0x8d, 0xa3, 0xab, 0x8b, 0xe3, 0x11, 0xb1, 0x34, 0x1d, 0xb2,
    0x0c, 0xde, 0xb3, 0x9a, 0xc1, 0xf1, 0xe8, 0xad, 0xdd, 0xd5, 0xc7, 0xcf, 0x06, 0xd5, 0x83, 0x37,
    0x63, 0xc9, 0x1f, 0x07, 0xe6, 0x23, 0x9d, 0x95, 0x88, 0xb9, 0x24, 0xce, 0xf5, 0x82, 0x27, 0x8b,
    0x60, 0xca, 0xbe, 0x3a, 0x0f, 0xc3, 0xde, 0x62, 0xf8, 0x65, 0xa6, 0x51, 0xb1, 0x04, 0xc9, 0x26,
    0x48, 0x6b, 0x13, 0x78, 0x16, 0xf5, 0x68, 0x8c, 0x8a, 0xcb, 0xcc, 0x43, 0x90, 0x08, 0x60, 0xb2,
    0x2c, 0xb6, 0x09, 0xe5, 0xae, 0x08, 0xbe, 0x54, 0x6c, 0xaa, 0x45, 0x49, 0x0b, 0xa5, 0xb7, 0x36,
    0xdf, 0x30, 0xb4, 0x67, 0x64, 0x5b, 0x2f, 0x0f, 0x54, 0x6a, 0x3a, 0x83, 0xa2, 0x54, 0xa0, 0x4b,
    0x81, 0xa1, 0x48, 0x61, 0x65, 0x88, 0xc9, 0xc1, 0x2d, 0x0f, 0x2e, 0xd5, 0x8d, 0x3d, 0x35, 0x01,
    0xcd, 0xf2, 0x5c, 0x78, 0x70, 0xe6, 0x1c, 0x44, 0x7d, 0x8b, 0x25, 0x5b, 0x9a, 0xeb, 0x44, 0x69,
    0xb5, 0x09, 0x7e, 0x62, 0x8a, 0x33, 0xef, 0xfb, 0x2f, 0x98, 0x7e, 0xe2, 0x9a, 0x23, 0xa4, 0x07,
    0x49, 0x0e, 0x12, 0x73, 0xc9, 0x91, 0x33, 0xc1, 0xdf, 0xe0, 0x94, 0x02, 0xc9, 0xf7, 0x76, 0x09,
    0x19, 0x75, 0x2d, 0x61, 0xad, 0x12, 0xc1, 0xf2, 0xed, 0x88, 0x85, 0x07, 0xaf, 0x38, 0x4c, 0xc4,
    0xb9, 0x2d, 0x61, 0xa1, 0xee, 0xd2, 0x4d, 0x68, 0xa3, 0x7b, 0xae, 0xf1, 0xd9, 0x40, 0xbe, 0x78,
    0x7d, 0x8c, 0xc1, 0xcd, 0xf1, 0xde, 0xf8, 0x5e, 0xf2, 0xde, 0x68, 0xb8, 0x31, 0xf2, 0x65, 0xb1,
    0xe0, 0xaf, 0x4b, 0x56, 0x9c, 0x72, 0x37, 0x87, 0xce, 0x63, 0xe7, 0x8d, 0x89, 0xcf, 0x9d, 0x7b,
    0xa8, 0x14, 0x2c, 0xf3, 0xd5, 0x49, 0x7d, 0x60, 0x2e, 0x89, 0xe9, 0x9c, 0xd0, 0x8b, 0xfe, 0xda,
    0x5a, 0x05, 0xc0, 0xac, 0x6c, 0x07, 0xfb, 0x4a, 0x43, 0xad, 0x6a, 0xa7, 0x0b, 0x56, 0x44, 0x6a,
    0x17, 0x07, 0x05, 0xb3, 0x13, 0xff, 0x3d, 0xab, 0xf2, 0xb2, 0x7e, 0x71, 0xe1, 0xd6, 0x31, 0x75,
    0x47, 0xb7, 0x60, 0x5e, 0x3a, 0x91, 0x9c, 0xa7, 0xcc, 0x11, 0x1a, 0xb7, 0x8d, 0x8a, 0xf8, 0x79,
    0x06, 0x3b, 0x6a, 0xdb, 0xa1, 0xea, 0xc6, 0xe7, 0x1b, 0xcc, 0x99, 0x91, 0xc7, 0xa1, 0xca, 0x0b,
    0x50, 0x58, 0x91, 0x67, 0x22, 0x98, 0xd6, 0x0f, 0x56, 0xbe, 0x92, 0x05, 0x53, 0xd7, 0x51, 0x51,
    0x3f, 0xad, 0xb7, 0xe6, 0x57, 0x66, 0x90, 0x8e, 0x79, 0x26, 0x99, 0xa0, 0xb3, 0x00, 0xcb, 0x6d,
    0xbb, 0x2a, 0x46, 0x2b, 0x26, 0x4a, 0xb3, 0xab, 0x95, 0x31, 0x00, 0x42, 0x5a, 0x41, 0x28, 0x24,
    0x33, 0x1d, 0x67, 0x91, 0xc8, 0x58, 0x5a, 0xf5, 0xec, 0xa3, 0x2a, 0xa1, 0x13, 0x89, 0x6e, 0xb2,
    0x74, 0x1d, 0x79, 0x02, 0xc8, 0xfb, 0xd7, 0xb1, 0xcb, 0x3c, 0x12, 0x40, 0x3c, 0x53, 0x51, 0x22,
    0x92, 0xa2, 0x18, 0xab, 0xc2, 0x14, 0xa1, 0xf7, 0x5b, 0x9a, 0xe0, 0x9f, 0x5b, 0x35, 0x26, 0xfa,
    0xb0, 0x77, 0x7c, 0xb7, 0x34, 0x61, 0x85, 0xfa, 0xdd, 0x3e, 0xa2, 0xe3, 0x3a, 0x36, 0xb7, 0x3e,
    0x3e, 0xce, 0x86, 0xe0, 0x68, 0x06, 0x3c, 0xa1, 0xa9, 0xc7, 0x3b, 0x73, 0x25, 0x39, 0xce, 0x69,
    0xc6, 0x3c, 0x9c, 0x95, 0xb7, 0x23, 0x67, 0x00, 0xf5, 0x3f, 0x40, 0xda, 0xaf, 0xfd, 0x4c, 0xd4,
    0x6d, 0xb1, 0xa2, 0x8d, 0x6b, 0xd5, 0x80, 0x5f, 0x63, 0x38, 0x27, 0x5f, 0xed, 0x66, 0xf7, 0x50,
    0xf9, 0x9d, 0x83, 0x17, 0x7a, 0xb7, 0x72, 0xc7, 0x3e, 0xb6, 0x76, 0xe1, 0x45, 0x79, 0x83, 0x1f,
    0x5c, 0xb6, 0x60, 0x50, 0x82, 0xc6, 0xe6, 0xb9, 0xcf, 0xbd, 0x51, 0xef, 0xe0, 0xbc, 0xa1, 0x0f,
    0x4b, 0xdd, 0xc2, 0xd8, 0x2c, 0x89, 0x07, 0x0c, 0xcd, 0x87, 0xeb, 0x6c, 0x95, 0x09, 0x8f, 0x68,
    0xf8, 0xcf, 0x02, 0x35, 0xba, 0xc9, 0x53, 0x86, 0x30, 0x38, 0x1c, 0x98, 0x03, 0x31, 0xac, 0x68,
    0xbe, 0x3c, 0x75, 0x0e, 0x5a, 0xef, 0x35, 0x5c, 0x87, 0xd1, 0xce, 0x19, 0x5f, 0xfc, 0x05, 0xb2,
    0x82, 0x6f, 0xcb
};
#endif

PyTypeObject *init_QWizard(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX].type;

    Shiboken::AutoDecRef Sbk_QWizard_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX]))));

    _Sbk_QWizard_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWizard",
        "QWizard*",
        &Sbk_QWizard_spec,
        &Shiboken::callCppDestructor< QWizard >,
        Sbk_QWizard_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QWizard_TypeF(); // references _Sbk_QWizard_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWizard_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWizard_SignatureBytes, QWizard_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWizard_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWizard_PythonToCpp_QWizard_PTR,
        is_QWizard_PythonToCpp_QWizard_PTR_Convertible,
        QWizard_PTR_CppToPython_QWizard);

    Shiboken::Conversions::registerConverterName(converter, "QWizard");
    Shiboken::Conversions::registerConverterName(converter, "QWizard*");
    Shiboken::Conversions::registerConverterName(converter, "QWizard&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWizard).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QWizardWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QWizard_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QWizard_TypeF(), &Sbk_QWizardSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QWizard_TypeF(), &Sbk_QWizard_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWizard_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'WizardButton'.
    const char *WizardButton_Initializer[] = {
        "BackButton",
        "NextButton",
        "CommitButton",
        "FinishButton",
        "CancelButton",
        "HelpButton",
        "CustomButton1",
        "CustomButton2",
        "CustomButton3",
        "Stretch",
        "NoButton",
        "NStandardButtons",
        "NButtons",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t WizardButton_InitializerValues[] = {
        int8_t(QWizard::WizardButton::BackButton),       //  0x00  0
        int8_t(QWizard::WizardButton::NextButton),       //  0x01  1
        int8_t(QWizard::WizardButton::CommitButton),     //  0x02  2
        int8_t(QWizard::WizardButton::FinishButton),     //  0x03  3
        int8_t(QWizard::WizardButton::CancelButton),     //  0x04  4
        int8_t(QWizard::WizardButton::HelpButton),       //  0x05  5
        int8_t(QWizard::WizardButton::CustomButton1),    //  0x06  6
        int8_t(QWizard::WizardButton::CustomButton2),    //  0x07  7
        int8_t(QWizard::WizardButton::CustomButton3),    //  0x08  8
        int8_t(QWizard::WizardButton::Stretch),          //  0x09  9
        int8_t(QWizard::WizardButton::NoButton),         // -0x01 -1
        int8_t(QWizard::WizardButton::NStandardButtons), //  0x06  6
        int8_t(QWizard::WizardButton::NButtons)          //  0x09  9
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWizard_TypeF(),
        "2:PySide6.QtWidgets.QWizard.WizardButton",
        WizardButton_Initializer, WizardButton_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardButton_IDX].type = EType;
    // Register converter for enum 'QWizard::WizardButton'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWizard_WizardButton_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWizard_WizardButton,
            is_Enum_PythonToCpp_QWizard_WizardButton_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWizard::WizardButton");
        Shiboken::Conversions::registerConverterAlias(converter, "WizardButton");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'WizardButton' enum.

    // Initialization of enum 'WizardPixmap'.
    const char *WizardPixmap_Initializer[] = {
        "WatermarkPixmap",
        "LogoPixmap",
        "BannerPixmap",
        "BackgroundPixmap",
        "NPixmaps",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t WizardPixmap_InitializerValues[] = {
        uint8_t(QWizard::WizardPixmap::WatermarkPixmap),  //  0x00  0
        uint8_t(QWizard::WizardPixmap::LogoPixmap),       //  0x01  1
        uint8_t(QWizard::WizardPixmap::BannerPixmap),     //  0x02  2
        uint8_t(QWizard::WizardPixmap::BackgroundPixmap), //  0x03  3
        uint8_t(QWizard::WizardPixmap::NPixmaps)          //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWizard_TypeF(),
        "2:PySide6.QtWidgets.QWizard.WizardPixmap",
        WizardPixmap_Initializer, WizardPixmap_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardPixmap_IDX].type = EType;
    // Register converter for enum 'QWizard::WizardPixmap'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWizard_WizardPixmap_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWizard_WizardPixmap,
            is_Enum_PythonToCpp_QWizard_WizardPixmap_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWizard::WizardPixmap");
        Shiboken::Conversions::registerConverterAlias(converter, "WizardPixmap");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'WizardPixmap' enum.

    // Initialization of enum 'WizardStyle'.
    const char *WizardStyle_Initializer[] = {
        "ClassicStyle",
        "ModernStyle",
        "MacStyle",
        "AeroStyle",
        "NStyles",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t WizardStyle_InitializerValues[] = {
        uint8_t(QWizard::WizardStyle::ClassicStyle), //  0x00  0
        uint8_t(QWizard::WizardStyle::ModernStyle),  //  0x01  1
        uint8_t(QWizard::WizardStyle::MacStyle),     //  0x02  2
        uint8_t(QWizard::WizardStyle::AeroStyle),    //  0x03  3
        uint8_t(QWizard::WizardStyle::NStyles)       //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWizard_TypeF(),
        "2:PySide6.QtWidgets.QWizard.WizardStyle",
        WizardStyle_Initializer, WizardStyle_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardStyle_IDX].type = EType;
    // Register converter for enum 'QWizard::WizardStyle'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWizard_WizardStyle_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWizard_WizardStyle,
            is_Enum_PythonToCpp_QWizard_WizardStyle_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWizard::WizardStyle");
        Shiboken::Conversions::registerConverterAlias(converter, "WizardStyle");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'WizardStyle' enum.

    // Initialization of enum 'WizardOption'.
    const char *WizardOption_Initializer[] = {
        "IndependentPages",
        "IgnoreSubTitles",
        "ExtendedWatermarkPixmap",
        "NoDefaultButton",
        "NoBackButtonOnStartPage",
        "NoBackButtonOnLastPage",
        "DisabledBackButtonOnLastPage",
        "HaveNextButtonOnLastPage",
        "HaveFinishButtonOnEarlyPages",
        "NoCancelButton",
        "CancelButtonOnLeft",
        "HaveHelpButton",
        "HelpButtonOnRight",
        "HaveCustomButton1",
        "HaveCustomButton2",
        "HaveCustomButton3",
        "NoCancelButtonOnLastPage",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t WizardOption_InitializerValues[] = {
        uint32_t(QWizard::WizardOption::IndependentPages),             //  0x00000001  1
        uint32_t(QWizard::WizardOption::IgnoreSubTitles),              //  0x00000002  2
        uint32_t(QWizard::WizardOption::ExtendedWatermarkPixmap),      //  0x00000004  4
        uint32_t(QWizard::WizardOption::NoDefaultButton),              //  0x00000008  8
        uint32_t(QWizard::WizardOption::NoBackButtonOnStartPage),      //  0x00000010  16
        uint32_t(QWizard::WizardOption::NoBackButtonOnLastPage),       //  0x00000020  32
        uint32_t(QWizard::WizardOption::DisabledBackButtonOnLastPage), //  0x00000040  64
        uint32_t(QWizard::WizardOption::HaveNextButtonOnLastPage),     //  0x00000080  128
        uint32_t(QWizard::WizardOption::HaveFinishButtonOnEarlyPages), //  0x00000100  256
        uint32_t(QWizard::WizardOption::NoCancelButton),               //  0x00000200  512
        uint32_t(QWizard::WizardOption::CancelButtonOnLeft),           //  0x00000400  1024
        uint32_t(QWizard::WizardOption::HaveHelpButton),               //  0x00000800  2048
        uint32_t(QWizard::WizardOption::HelpButtonOnRight),            //  0x00001000  4096
        uint32_t(QWizard::WizardOption::HaveCustomButton1),            //  0x00002000  8192
        uint32_t(QWizard::WizardOption::HaveCustomButton2),            //  0x00004000  16384
        uint32_t(QWizard::WizardOption::HaveCustomButton3),            //  0x00008000  32768
        uint32_t(QWizard::WizardOption::NoCancelButtonOnLastPage)      //  0x00010000  65536
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWizard_TypeF(),
        "2:PySide6.QtWidgets.QWizard.WizardOption",
        WizardOption_Initializer, WizardOption_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QWizard_WizardOption_IDX].type =
        EType;
    // Register converter for enum 'QWizard::WizardOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWizard_WizardOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWizard_WizardOption,
            is_Enum_PythonToCpp_QWizard_WizardOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWizard::WizardOption");
        Shiboken::Conversions::registerConverterAlias(converter, "WizardOption");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QWizard_WizardOption_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QWizard_WizardOption,
            is_Enum_PythonToCpp_QWizard_WizardOption_Convertible);
        // Register converter for flag 'QFlags<QWizard::WizardOption>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QWizard::WizardOption>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QWizard::WizardOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'WizardOption' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QWizard::staticMetaObject);
    qRegisterMetaType< ::QWizard::WizardButton >("QWizard::WizardButton");
    qRegisterMetaType< ::QWizard::WizardPixmap >("QWizard::WizardPixmap");
    qRegisterMetaType< ::QWizard::WizardStyle >("QWizard::WizardStyle");
    qRegisterMetaType< ::QWizard::WizardOption >("QWizard::WizardOption");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QWizard::staticMetaObject, sizeof(QWizardWrapper));

    return pyType;
}
