// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcharts_python.h"

// main header
#include "qchart_wrapper.h"

// Wrappers providing overrides
#include "qlegend_wrapper.h"
#include "qxymodelmapper_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtCharts/qabstractaxis.h>
#include <QtCharts/qabstractseries.h>
#include <QtCharts/qchart.h>
#include <QtCharts/qlegend.h>
#include <QtGui/qbrush.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpen.h>
#include <QtWidgets/qgraphicsitem.h>
#include <QtWidgets/qgraphicssceneevent.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qcoreevent.h>
#include <qeasingcurve.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QChartWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QChartWrapper::QChartWrapper(::QChart::ChartType type, ::QGraphicsItem * parent, ::QFlags<Qt::WindowType> wFlags) : QChart(type, parent, wFlags)
{
}

QChartWrapper::QChartWrapper(::QGraphicsItem * parent, ::QFlags<Qt::WindowType> wFlags) : QChart(parent, wFlags)
{
}

void QChartWrapper::advance(int phase)
{
    static const char *funcName = "advance";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::advance(phase);
    }
    QLegendWrapper::sbk_o_advance("QChart", funcName, gil, pyOverride, phase);
}

::QRectF QChartWrapper::boundingRect() const
{
    static const char *funcName = "boundingRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::boundingRect();
    }
    return QLegendWrapper::sbk_o_boundingRect("QChart", funcName, gil, pyOverride);
}

void QChartWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::changeEvent(event);
    }
    QLegendWrapper::sbk_o_changeEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_childEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::closeEvent(event);
    }
    QLegendWrapper::sbk_o_closeEvent("QChart", funcName, gil, pyOverride, event);
}

bool QChartWrapper::collidesWithItem(const ::QGraphicsItem * other, ::Qt::ItemSelectionMode mode) const
{
    static const char *funcName = "collidesWithItem";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::collidesWithItem(other, mode);
    }
    return QLegendWrapper::sbk_o_collidesWithItem("QChart", funcName, gil, pyOverride, other, mode);
}

bool QChartWrapper::collidesWithPath(const ::QPainterPath & path, ::Qt::ItemSelectionMode mode) const
{
    static const char *funcName = "collidesWithPath";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::collidesWithPath(path, mode);
    }
    return QLegendWrapper::sbk_o_collidesWithPath("QChart", funcName, gil, pyOverride, path, mode);
}

void QChartWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QChart", funcName, gil, pyOverride, signal);
}

bool QChartWrapper::contains(const ::QPointF & point) const
{
    static const char *funcName = "contains";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::contains(point);
    }
    return QLegendWrapper::sbk_o_contains("QChart", funcName, gil, pyOverride, point);
}

void QChartWrapper::contextMenuEvent(::QGraphicsSceneContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::contextMenuEvent(event);
    }
    QLegendWrapper::sbk_o_contextMenuEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_customEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QXYModelMapperWrapper::sbk_o_connectNotify("QChart", funcName, gil, pyOverride, signal);
}

void QChartWrapper::dragEnterEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragEnterEvent(event);
    }
    QLegendWrapper::sbk_o_dragEnterEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::dragLeaveEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragLeaveEvent(event);
    }
    QLegendWrapper::sbk_o_dragLeaveEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::dragMoveEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dragMoveEvent(event);
    }
    QLegendWrapper::sbk_o_dragMoveEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::dropEvent(::QGraphicsSceneDragDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::dropEvent(event);
    }
    QLegendWrapper::sbk_o_dropEvent("QChart", funcName, gil, pyOverride, event);
}

bool QChartWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::event(event);
    }
    return QXYModelMapperWrapper::sbk_o_event("QChart", funcName, gil, pyOverride, event);
}

bool QChartWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QXYModelMapperWrapper::sbk_o_eventFilter("QChart", funcName, gil, pyOverride, watched, event);
}

::QVariant QChartWrapper::extension(const ::QVariant & variant) const
{
    static const char *funcName = "extension";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::extension(variant);
    }
    return QLegendWrapper::sbk_o_extension("QChart", funcName, gil, pyOverride, variant);
}

void QChartWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::focusInEvent(event);
    }
    QLegendWrapper::sbk_o_focusInEvent("QChart", funcName, gil, pyOverride, event);
}

bool QChartWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::focusNextPrevChild(next);
    }
    return QLegendWrapper::sbk_o_focusNextPrevChild("QChart", funcName, gil, pyOverride, next);
}

void QChartWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::focusOutEvent(event);
    }
    QLegendWrapper::sbk_o_focusOutEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::getContentsMargins(qreal * left, qreal * top, qreal * right, qreal * bottom) const
{
    static const char *funcName = "getContentsMargins";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::getContentsMargins(left, top, right, bottom);
    }
    QLegendWrapper::sbk_o_getContentsMargins("QChart", funcName, gil, pyOverride, left, top, right, bottom);
}

void QChartWrapper::grabKeyboardEvent(::QEvent * event)
{
    static const char *funcName = "grabKeyboardEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::grabKeyboardEvent(event);
    }
    QLegendWrapper::sbk_o_grabKeyboardEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::grabMouseEvent(::QEvent * event)
{
    static const char *funcName = "grabMouseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::grabMouseEvent(event);
    }
    QLegendWrapper::sbk_o_grabMouseEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::hideEvent(event);
    }
    QLegendWrapper::sbk_o_hideEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::hoverEnterEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::hoverEnterEvent(event);
    }
    QLegendWrapper::sbk_o_hoverEnterEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::hoverLeaveEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::hoverLeaveEvent(event);
    }
    QLegendWrapper::sbk_o_hoverLeaveEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::hoverMoveEvent(::QGraphicsSceneHoverEvent * event)
{
    static const char *funcName = "hoverMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::hoverMoveEvent(event);
    }
    QLegendWrapper::sbk_o_hoverMoveEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::initStyleOption(::QStyleOption * option) const
{
    static const char *funcName = "initStyleOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::initStyleOption(option);
    }
    QLegendWrapper::sbk_o_initStyleOption("QChart", funcName, gil, pyOverride, option);
}

void QChartWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::inputMethodEvent(event);
    }
    QLegendWrapper::sbk_o_inputMethodEvent("QChart", funcName, gil, pyOverride, event);
}

::QVariant QChartWrapper::inputMethodQuery(::Qt::InputMethodQuery query) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::inputMethodQuery(query);
    }
    return QLegendWrapper::sbk_o_inputMethodQuery("QChart", funcName, gil, pyOverride, query);
}

bool QChartWrapper::isEmpty() const
{
    static const char *funcName = "isEmpty";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsLayoutItem::isEmpty();
    }
    return QLegendWrapper::sbk_o_isEmpty("QChart", funcName, gil, pyOverride);
}

bool QChartWrapper::isObscuredBy(const ::QGraphicsItem * item) const
{
    static const char *funcName = "isObscuredBy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::isObscuredBy(item);
    }
    return QLegendWrapper::sbk_o_isObscuredBy("QChart", funcName, gil, pyOverride, item);
}

::QVariant QChartWrapper::itemChange(::QGraphicsItem::GraphicsItemChange change, const ::QVariant & value)
{
    static const char *funcName = "itemChange";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::itemChange(change, value);
    }
    return QLegendWrapper::sbk_o_itemChange("QChart", funcName, gil, pyOverride, change, value);
}

void QChartWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::keyPressEvent(event);
    }
    QLegendWrapper::sbk_o_keyPressEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::keyReleaseEvent(event);
    }
    QLegendWrapper::sbk_o_keyReleaseEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::mouseDoubleClickEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseDoubleClickEvent(event);
    }
    QLegendWrapper::sbk_o_mouseDoubleClickEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::mouseMoveEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseMoveEvent(event);
    }
    QLegendWrapper::sbk_o_mouseMoveEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::mousePressEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mousePressEvent(event);
    }
    QLegendWrapper::sbk_o_mousePressEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::mouseReleaseEvent(::QGraphicsSceneMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::mouseReleaseEvent(event);
    }
    QLegendWrapper::sbk_o_mouseReleaseEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::moveEvent(::QGraphicsSceneMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::moveEvent(event);
    }
    QLegendWrapper::sbk_o_moveEvent("QChart", funcName, gil, pyOverride, event);
}

::QPainterPath QChartWrapper::opaqueArea() const
{
    static const char *funcName = "opaqueArea";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::opaqueArea();
    }
    return QLegendWrapper::sbk_o_opaqueArea("QChart", funcName, gil, pyOverride);
}

void QChartWrapper::paint(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget)
{
    static const char *funcName = "paint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::paint(painter, option, widget);
    }
    QLegendWrapper::sbk_o_paint("QChart", funcName, gil, pyOverride, painter, option, widget);
}

void QChartWrapper::paintWindowFrame(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget)
{
    static const char *funcName = "paintWindowFrame";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::paintWindowFrame(painter, option, widget);
    }
    QLegendWrapper::sbk_o_paintWindowFrame("QChart", funcName, gil, pyOverride, painter, option, widget);
}

void QChartWrapper::polishEvent()
{
    static const char *funcName = "polishEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::polishEvent();
    }
    QLegendWrapper::sbk_o_polishEvent("QChart", funcName, gil, pyOverride);
}

::QVariant QChartWrapper::propertyChange(const ::QString & propertyName, const ::QVariant & value)
{
    static const char *funcName = "propertyChange";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::propertyChange(propertyName, value);
    }
    return QLegendWrapper::sbk_o_propertyChange("QChart", funcName, gil, pyOverride, propertyName, value);
}

void QChartWrapper::resizeEvent(::QGraphicsSceneResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::resizeEvent(event);
    }
    QLegendWrapper::sbk_o_resizeEvent("QChart", funcName, gil, pyOverride, event);
}

bool QChartWrapper::sceneEvent(::QEvent * event)
{
    static const char *funcName = "sceneEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::sceneEvent(event);
    }
    return QLegendWrapper::sbk_o_sceneEvent("QChart", funcName, gil, pyOverride, event);
}

bool QChartWrapper::sceneEventFilter(::QGraphicsItem * watched, ::QEvent * event)
{
    static const char *funcName = "sceneEventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::sceneEventFilter(watched, event);
    }
    return QLegendWrapper::sbk_o_sceneEventFilter("QChart", funcName, gil, pyOverride, watched, event);
}

void QChartWrapper::setGeometry(const ::QRectF & rect)
{
    // This method belongs to a property.
    static const char *funcName = "2:setGeometry";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::setGeometry(rect);
    }
    QLegendWrapper::sbk_o_setGeometry("QChart", funcName, gil, pyOverride, rect);
}

::QPainterPath QChartWrapper::shape() const
{
    static const char *funcName = "shape";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::shape();
    }
    return QLegendWrapper::sbk_o_opaqueArea("QChart", funcName, gil, pyOverride);
}

void QChartWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[52], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::showEvent(event);
    }
    QLegendWrapper::sbk_o_showEvent("QChart", funcName, gil, pyOverride, event);
}

::QSizeF QChartWrapper::sizeHint(::Qt::SizeHint which, const ::QSizeF & constraint) const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[53], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::sizeHint(which, constraint);
    }
    return QLegendWrapper::sbk_o_sizeHint("QChart", funcName, gil, pyOverride, which, constraint);
}

void QChartWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[54], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QXYModelMapperWrapper::sbk_o_timerEvent("QChart", funcName, gil, pyOverride, event);
}

int QChartWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[55], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::type();
    }
    return QLegendWrapper::sbk_o_type("QChart", funcName, gil, pyOverride);
}

void QChartWrapper::ungrabKeyboardEvent(::QEvent * event)
{
    static const char *funcName = "ungrabKeyboardEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[56], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::ungrabKeyboardEvent(event);
    }
    QLegendWrapper::sbk_o_ungrabKeyboardEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::ungrabMouseEvent(::QEvent * event)
{
    static const char *funcName = "ungrabMouseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[57], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::ungrabMouseEvent(event);
    }
    QLegendWrapper::sbk_o_ungrabMouseEvent("QChart", funcName, gil, pyOverride, event);
}

void QChartWrapper::updateGeometry()
{
    static const char *funcName = "updateGeometry";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[58], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::updateGeometry();
    }
    QLegendWrapper::sbk_o_polishEvent("QChart", funcName, gil, pyOverride);
}

void QChartWrapper::wheelEvent(::QGraphicsSceneWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[59], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsItem::wheelEvent(event);
    }
    QLegendWrapper::sbk_o_wheelEvent("QChart", funcName, gil, pyOverride, event);
}

bool QChartWrapper::windowFrameEvent(::QEvent * e)
{
    static const char *funcName = "windowFrameEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[60], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::windowFrameEvent(e);
    }
    return QLegendWrapper::sbk_o_windowFrameEvent("QChart", funcName, gil, pyOverride, e);
}

::Qt::WindowFrameSection QChartWrapper::windowFrameSectionAt(const ::QPointF & pos) const
{
    static const char *funcName = "windowFrameSectionAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[61], nameCache));
    if (pyOverride.isNull()) {
        return this->::QGraphicsWidget::windowFrameSectionAt(pos);
    }
    return QLegendWrapper::sbk_o_windowFrameSectionAt("QChart", funcName, gil, pyOverride, pos);
}

const QMetaObject *QChartWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QChart::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QChartWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QChart::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QChartWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QChartWrapper *>(this));
    return QChart::qt_metacast(_clname);
}

QChartWrapper::~QChartWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QChart_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QChart >()))
        return -1;

    QChartWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOO:QChart", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QChart::QChart(QChart::ChartType,QGraphicsItem*,QFlags<Qt::WindowType>)
    // 1: QChart::QChart(QGraphicsItem*=,QFlags<Qt::WindowType>=)
    if (numArgs == 0) {
        overloadId = 1; // QChart(QGraphicsItem*,QFlags<Qt::WindowType>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QChart(QGraphicsItem*,QFlags<Qt::WindowType>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 1; // QChart(QGraphicsItem*,QFlags<Qt::WindowType>)
        }
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_ChartType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[2])))) {
        overloadId = 0; // QChart(QChart::ChartType,QGraphicsItem*,QFlags<Qt::WindowType>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QChart(QChart::ChartType type, QGraphicsItem *parent, QFlags<Qt::WindowType> wFlags)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);
            }
            ::QChart::ChartType cppArg0{QChart::ChartTypeUndefined};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QGraphicsItem *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::WindowType> cppArg2 = QFlags<Qt::WindowType>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QChart(QChart::ChartType,QGraphicsItem*,QFlags<Qt::WindowType>)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QChartWrapper(cppArg0, cppArg1, cppArg2);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QChartWrapper(cppArg0, cppArg1, cppArg2);
                }

            }
            break;
        }
        case 1: // QChart(QGraphicsItem *parent, QFlags<Qt::WindowType> wFlags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"parent", 0}, {"wFlags", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[0]))))
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGraphicsItem *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<Qt::WindowType> cppArg1 = Qt::WindowFlags();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QChart(QGraphicsItem*,QFlags<Qt::WindowType>)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QChartWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QChartWrapper(cppArg0, cppArg1);
                }

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QChart >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QChartFunc_addAxis(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addAxis", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QChart::addAxis(QAbstractAxis*,QFlags<Qt::AlignmentFlag>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractAxis_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
        overloadId = 0; // addAxis(QAbstractAxis*,QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addAxis", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QAbstractAxis *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::AlignmentFlag> cppArg1 = QFlags<Qt::AlignmentFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addAxis(QAbstractAxis*,QFlags<Qt::AlignmentFlag>)
            cppSelf->addAxis(cppArg0, cppArg1);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[0]);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_addSeries(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::addSeries(QAbstractSeries*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArg)))) {
        overloadId = 0; // addSeries(QAbstractSeries*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addSeries", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractSeries *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addSeries(QAbstractSeries*)
            cppSelf->addSeries(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_animationDuration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // animationDuration()const
        int cppResult = const_cast<const ::QChart *>(cppSelf)->animationDuration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_animationEasingCurve(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // animationEasingCurve()const
        QEasingCurve cppResult = const_cast<const ::QChart *>(cppSelf)->animationEasingCurve();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_animationOptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // animationOptions()const
        QFlags<QChart::AnimationOption> cppResult = const_cast<const ::QChart *>(cppSelf)->animationOptions();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QFlags_QChart_AnimationOption_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_axes(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "axes", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    if (PyArg_ParseTuple(args, "|OO:axes", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QChart::axes(QFlags<Qt::Orientation>=,QAbstractSeries*=)const->QList<QAbstractAxis*>
    if (numArgs == 0) {
        overloadId = 0; // axes(QFlags<Qt::Orientation>,QAbstractSeries*)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_Orientation_IDX])))->flagsConverter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // axes(QFlags<Qt::Orientation>,QAbstractSeries*)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArgs[1])))) {
            overloadId = 0; // axes(QFlags<Qt::Orientation>,QAbstractSeries*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "axes", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"orientation", 0}, {"series", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_Orientation_IDX])))->flagsConverter, (pyArgs[0]))))
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "axes", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);
            }
        }
        ::QFlags<Qt::Orientation> cppArg0(Qt::Horizontal|Qt::Vertical);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QAbstractSeries *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // axes(QFlags<Qt::Orientation>,QAbstractSeries*)const
            QList<QAbstractAxis*> cppResult = const_cast<const ::QChart *>(cppSelf)->axes(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtChartsTypeConverters[SBK_QtCharts_QList_QAbstractAxisPTR_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_axisX(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "axisX", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    if (PyArg_ParseTuple(args, "|O:axisX", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QChart::axisX(QAbstractSeries*=)const->QAbstractAxis*
    if (numArgs == 0) {
        overloadId = 0; // axisX(QAbstractSeries*)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArgs[0])))) {
        overloadId = 0; // axisX(QAbstractSeries*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "axisX", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QChart", "axisX(QAbstractSeries *series) const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"series", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "axisX", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QAbstractSeries *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // axisX(QAbstractSeries*)const
            QAbstractAxis * cppResult = const_cast<const ::QChart *>(cppSelf)->axisX(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractAxis_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_axisY(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "axisY", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    if (PyArg_ParseTuple(args, "|O:axisY", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QChart::axisY(QAbstractSeries*=)const->QAbstractAxis*
    if (numArgs == 0) {
        overloadId = 0; // axisY(QAbstractSeries*)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArgs[0])))) {
        overloadId = 0; // axisY(QAbstractSeries*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "axisY", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QChart", "axisY(QAbstractSeries *series) const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"series", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "axisY", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QAbstractSeries *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // axisY(QAbstractSeries*)const
            QAbstractAxis * cppResult = const_cast<const ::QChart *>(cppSelf)->axisY(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractAxis_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_backgroundBrush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // backgroundBrush()const
        QBrush cppResult = const_cast<const ::QChart *>(cppSelf)->backgroundBrush();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_backgroundPen(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // backgroundPen()const
        QPen cppResult = const_cast<const ::QChart *>(cppSelf)->backgroundPen();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_backgroundRoundness(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // backgroundRoundness()const
        qreal cppResult = const_cast<const ::QChart *>(cppSelf)->backgroundRoundness();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_chartType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // chartType()const
        QChart::ChartType cppResult = const_cast<const ::QChart *>(cppSelf)->chartType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_ChartType_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_createDefaultAxes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createDefaultAxes()
        cppSelf->createDefaultAxes();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_isBackgroundVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isBackgroundVisible()const
        bool cppResult = const_cast<const ::QChart *>(cppSelf)->isBackgroundVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_isDropShadowEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDropShadowEnabled()const
        bool cppResult = const_cast<const ::QChart *>(cppSelf)->isDropShadowEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_isPlotAreaBackgroundVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isPlotAreaBackgroundVisible()const
        bool cppResult = const_cast<const ::QChart *>(cppSelf)->isPlotAreaBackgroundVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_isZoomed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isZoomed()
        bool cppResult = cppSelf->isZoomed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_legend(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // legend()const
        QLegend * cppResult = const_cast<const ::QChart *>(cppSelf)->legend();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QLegend_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_locale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // locale()const
        QLocale cppResult = const_cast<const ::QChart *>(cppSelf)->locale();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_localizeNumbers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localizeNumbers()const
        bool cppResult = const_cast<const ::QChart *>(cppSelf)->localizeNumbers();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_mapToPosition(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "mapToPosition", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    if (PyArg_ParseTuple(args, "|OO:mapToPosition", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QChart::mapToPosition(QPointF,QAbstractSeries*=)->QPointF
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // mapToPosition(QPointF,QAbstractSeries*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArgs[1])))) {
            overloadId = 0; // mapToPosition(QPointF,QAbstractSeries*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mapToPosition", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"series", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "mapToPosition", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QAbstractSeries *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mapToPosition(QPointF,QAbstractSeries*)
            QPointF cppResult = cppSelf->mapToPosition(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_mapToValue(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "mapToValue", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    if (PyArg_ParseTuple(args, "|OO:mapToValue", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QChart::mapToValue(QPointF,QAbstractSeries*=)->QPointF
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // mapToValue(QPointF,QAbstractSeries*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArgs[1])))) {
            overloadId = 0; // mapToValue(QPointF,QAbstractSeries*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mapToValue", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"series", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "mapToValue", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QAbstractSeries *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mapToValue(QPointF,QAbstractSeries*)
            QPointF cppResult = cppSelf->mapToValue(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_margins(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // margins()const
        QMargins cppResult = const_cast<const ::QChart *>(cppSelf)->margins();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMargins_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_plotArea(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // plotArea()const
        QRectF cppResult = const_cast<const ::QChart *>(cppSelf)->plotArea();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_plotAreaBackgroundBrush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // plotAreaBackgroundBrush()const
        QBrush cppResult = const_cast<const ::QChart *>(cppSelf)->plotAreaBackgroundBrush();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_plotAreaBackgroundPen(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // plotAreaBackgroundPen()const
        QPen cppResult = const_cast<const ::QChart *>(cppSelf)->plotAreaBackgroundPen();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_removeAllSeries(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeAllSeries()
        cppSelf->removeAllSeries();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_removeAxis(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::removeAxis(QAbstractAxis*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractAxis_IDX]), (pyArg)))) {
        overloadId = 0; // removeAxis(QAbstractAxis*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAxis", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractAxis *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAxis(QAbstractAxis*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcharts.cpp (qchart-releaseownership)]
            Shiboken::Object::releaseOwnership(pyArg);
            // END of custom code block [file: ../glue/qtcharts.cpp (qchart-releaseownership)]
            // ========================================================================
            // End of code injection

            cppSelf->removeAxis(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_removeSeries(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::removeSeries(QAbstractSeries*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArg)))) {
        overloadId = 0; // removeSeries(QAbstractSeries*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeSeries", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractSeries *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeSeries(QAbstractSeries*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcharts.cpp (qchart-releaseownership)]
            Shiboken::Object::releaseOwnership(pyArg);
            // END of custom code block [file: ../glue/qtcharts.cpp (qchart-releaseownership)]
            // ========================================================================
            // End of code injection

            cppSelf->removeSeries(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_scroll(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "scroll", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QChart::scroll(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 0; // scroll(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scroll", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // scroll(qreal,qreal)
            cppSelf->scroll(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_series(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // series()const
        QList<QAbstractSeries*> cppResult = const_cast<const ::QChart *>(cppSelf)->series();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtChartsTypeConverters[SBK_QtCharts_QList_QAbstractSeriesPTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_setAnimationDuration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setAnimationDuration(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setAnimationDuration(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAnimationDuration", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAnimationDuration(int)
            cppSelf->setAnimationDuration(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setAnimationEasingCurve(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setAnimationEasingCurve(QEasingCurve)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), (pyArg)))) {
        overloadId = 0; // setAnimationEasingCurve(QEasingCurve)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAnimationEasingCurve", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEasingCurve cppArg0_local;
        ::QEasingCurve *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setAnimationEasingCurve(QEasingCurve)
            cppSelf->setAnimationEasingCurve(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setAnimationOptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setAnimationOptions(QFlags<QChart::AnimationOption>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QFlags_QChart_AnimationOption_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setAnimationOptions(QFlags<QChart::AnimationOption>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAnimationOptions", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        ::QFlags<QChart::AnimationOption> cppArg0 = QFlags<QChart::AnimationOption>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAnimationOptions(QFlags<QChart::AnimationOption>)
            cppSelf->setAnimationOptions(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setAxisX(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setAxisX", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setAxisX", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QChart::setAxisX(QAbstractAxis*,QAbstractSeries*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractAxis_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setAxisX(QAbstractAxis*,QAbstractSeries*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArgs[1])))) {
            overloadId = 0; // setAxisX(QAbstractAxis*,QAbstractSeries*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setAxisX", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QChart", "setAxisX(QAbstractAxis *axis, QAbstractSeries *series)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"series", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setAxisX", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QAbstractAxis *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QAbstractSeries *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAxisX(QAbstractAxis*,QAbstractSeries*)
            cppSelf->setAxisX(cppArg0, cppArg1);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[0]);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[1]);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setAxisY(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setAxisY", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setAxisY", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QChart::setAxisY(QAbstractAxis*,QAbstractSeries*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractAxis_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setAxisY(QAbstractAxis*,QAbstractSeries*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArgs[1])))) {
            overloadId = 0; // setAxisY(QAbstractAxis*,QAbstractSeries*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setAxisY", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QChart", "setAxisY(QAbstractAxis *axis, QAbstractSeries *series)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"series", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QAbstractSeries_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setAxisY", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QAbstractAxis *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QAbstractSeries *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAxisY(QAbstractAxis*,QAbstractSeries*)
            cppSelf->setAxisY(cppArg0, cppArg1);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[0]);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[1]);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setBackgroundBrush(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setBackgroundBrush(QBrush)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArg)))) {
        overloadId = 0; // setBackgroundBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackgroundBrush", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBrush cppArg0_local;
        ::QBrush *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackgroundBrush(QBrush)
            cppSelf->setBackgroundBrush(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setBackgroundPen(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setBackgroundPen(QPen)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArg)))) {
        overloadId = 0; // setBackgroundPen(QPen)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackgroundPen", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPen cppArg0_local;
        ::QPen *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackgroundPen(QPen)
            cppSelf->setBackgroundPen(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setBackgroundRoundness(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setBackgroundRoundness(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setBackgroundRoundness(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackgroundRoundness", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackgroundRoundness(qreal)
            cppSelf->setBackgroundRoundness(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setBackgroundVisible(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setBackgroundVisible", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    if (PyArg_ParseTuple(args, "|O:setBackgroundVisible", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QChart::setBackgroundVisible(bool=)
    if (numArgs == 0) {
        overloadId = 0; // setBackgroundVisible(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // setBackgroundVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setBackgroundVisible", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"visible", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setBackgroundVisible", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackgroundVisible(bool)
            cppSelf->setBackgroundVisible(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setDropShadowEnabled(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setDropShadowEnabled", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    if (PyArg_ParseTuple(args, "|O:setDropShadowEnabled", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QChart::setDropShadowEnabled(bool=)
    if (numArgs == 0) {
        overloadId = 0; // setDropShadowEnabled(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // setDropShadowEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDropShadowEnabled", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"enabled", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setDropShadowEnabled", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDropShadowEnabled(bool)
            cppSelf->setDropShadowEnabled(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setLocale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setLocale(QLocale)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocale", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocale(QLocale)
            cppSelf->setLocale(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setLocalizeNumbers(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setLocalizeNumbers(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setLocalizeNumbers(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocalizeNumbers", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocalizeNumbers(bool)
            cppSelf->setLocalizeNumbers(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setMargins(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setMargins(QMargins)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMargins_IDX]), (pyArg)))) {
        overloadId = 0; // setMargins(QMargins)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMargins", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMargins cppArg0_local;
        ::QMargins *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setMargins(QMargins)
            cppSelf->setMargins(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setPlotArea(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setPlotArea(QRectF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
        overloadId = 0; // setPlotArea(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPlotArea", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPlotArea(QRectF)
            cppSelf->setPlotArea(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setPlotAreaBackgroundBrush(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setPlotAreaBackgroundBrush(QBrush)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArg)))) {
        overloadId = 0; // setPlotAreaBackgroundBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPlotAreaBackgroundBrush", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBrush cppArg0_local;
        ::QBrush *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPlotAreaBackgroundBrush(QBrush)
            cppSelf->setPlotAreaBackgroundBrush(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setPlotAreaBackgroundPen(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setPlotAreaBackgroundPen(QPen)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArg)))) {
        overloadId = 0; // setPlotAreaBackgroundPen(QPen)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPlotAreaBackgroundPen", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPen cppArg0_local;
        ::QPen *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPlotAreaBackgroundPen(QPen)
            cppSelf->setPlotAreaBackgroundPen(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setPlotAreaBackgroundVisible(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setPlotAreaBackgroundVisible", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    if (PyArg_ParseTuple(args, "|O:setPlotAreaBackgroundVisible", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QChart::setPlotAreaBackgroundVisible(bool=)
    if (numArgs == 0) {
        overloadId = 0; // setPlotAreaBackgroundVisible(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // setPlotAreaBackgroundVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPlotAreaBackgroundVisible", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"visible", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setPlotAreaBackgroundVisible", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPlotAreaBackgroundVisible(bool)
            cppSelf->setPlotAreaBackgroundVisible(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setTheme(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setTheme(QChart::ChartTheme)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_ChartTheme_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTheme(QChart::ChartTheme)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTheme", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        ::QChart::ChartTheme cppArg0{QChart::ChartThemeLight};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTheme(QChart::ChartTheme)
            cppSelf->setTheme(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setTitle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setTitle(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setTitle(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTitle", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTitle(QString)
            cppSelf->setTitle(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setTitleBrush(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setTitleBrush(QBrush)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArg)))) {
        overloadId = 0; // setTitleBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTitleBrush", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBrush cppArg0_local;
        ::QBrush *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTitleBrush(QBrush)
            cppSelf->setTitleBrush(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_setTitleFont(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::setTitleFont(QFont)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // setTitleFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTitleFont", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTitleFont(QFont)
            cppSelf->setTitleFont(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_theme(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // theme()const
        QChart::ChartTheme cppResult = const_cast<const ::QChart *>(cppSelf)->theme();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_ChartTheme_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_title(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // title()const
        QString cppResult = const_cast<const ::QChart *>(cppSelf)->title();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_titleBrush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // titleBrush()const
        QBrush cppResult = const_cast<const ::QChart *>(cppSelf)->titleBrush();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_titleFont(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // titleFont()const
        QFont cppResult = const_cast<const ::QChart *>(cppSelf)->titleFont();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QChartFunc_zoom(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QChart::zoom(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // zoom(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "zoom", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // zoom(qreal)
            cppSelf->zoom(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_zoomIn(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "zoomIn", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QChart::zoomIn()
    // 1: QChart::zoomIn(QRectF)
    if (numArgs == 0) {
        overloadId = 0; // zoomIn()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        overloadId = 1; // zoomIn(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "zoomIn", errInfo, SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // zoomIn()
        {

            // zoomIn()
            cppSelf->zoomIn();
            break;
        }
        case 1: // zoomIn(const QRectF &rect)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // zoomIn(QRectF)
                cppSelf->zoomIn(*cppArg0);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_zoomOut(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // zoomOut()
        cppSelf->zoomOut();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QChartFunc_zoomReset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // zoomReset()
        cppSelf->zoomReset();
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QChart_PropertyStrings[] = {
    "animationDuration::",
    "animationEasingCurve::",
    "animationOptions::",
    "backgroundRoundness::",
    "backgroundVisible:isBackgroundVisible:",
    "chartType:",
    "dropShadowEnabled:isDropShadowEnabled:",
    "locale::",
    "localizeNumbers::",
    "margins::",
    "plotArea::",
    "plotAreaBackgroundVisible:isPlotAreaBackgroundVisible:",
    "theme::",
    "title::",
    nullptr // Sentinel
};

static const char *Sbk_QChart_EnumFlagInfo[] = {
    "AnimationOption:Flag:AnimationOptions",
    "ChartTheme:Enum",
    "ChartType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QChart_methods[] = {
    {"addAxis", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_addAxis), METH_VARARGS, nullptr},
    {"addSeries", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_addSeries), METH_O, nullptr},
    {"animationDuration", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_animationDuration), METH_NOARGS, nullptr},
    {"animationEasingCurve", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_animationEasingCurve), METH_NOARGS, nullptr},
    {"animationOptions", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_animationOptions), METH_NOARGS, nullptr},
    {"axes", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_axes), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"axisX", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_axisX), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"axisY", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_axisY), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"backgroundBrush", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_backgroundBrush), METH_NOARGS, nullptr},
    {"backgroundPen", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_backgroundPen), METH_NOARGS, nullptr},
    {"backgroundRoundness", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_backgroundRoundness), METH_NOARGS, nullptr},
    {"chartType", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_chartType), METH_NOARGS, nullptr},
    {"createDefaultAxes", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_createDefaultAxes), METH_NOARGS, nullptr},
    {"isBackgroundVisible", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_isBackgroundVisible), METH_NOARGS, nullptr},
    {"isDropShadowEnabled", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_isDropShadowEnabled), METH_NOARGS, nullptr},
    {"isPlotAreaBackgroundVisible", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_isPlotAreaBackgroundVisible), METH_NOARGS, nullptr},
    {"isZoomed", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_isZoomed), METH_NOARGS, nullptr},
    {"legend", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_legend), METH_NOARGS, nullptr},
    {"locale", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_locale), METH_NOARGS, nullptr},
    {"localizeNumbers", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_localizeNumbers), METH_NOARGS, nullptr},
    {"mapToPosition", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_mapToPosition), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"mapToValue", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_mapToValue), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"margins", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_margins), METH_NOARGS, nullptr},
    {"plotArea", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_plotArea), METH_NOARGS, nullptr},
    {"plotAreaBackgroundBrush", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_plotAreaBackgroundBrush), METH_NOARGS, nullptr},
    {"plotAreaBackgroundPen", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_plotAreaBackgroundPen), METH_NOARGS, nullptr},
    {"removeAllSeries", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_removeAllSeries), METH_NOARGS, nullptr},
    {"removeAxis", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_removeAxis), METH_O, nullptr},
    {"removeSeries", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_removeSeries), METH_O, nullptr},
    {"scroll", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_scroll), METH_VARARGS, nullptr},
    {"series", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_series), METH_NOARGS, nullptr},
    {"setAnimationDuration", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setAnimationDuration), METH_O, nullptr},
    {"setAnimationEasingCurve", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setAnimationEasingCurve), METH_O, nullptr},
    {"setAnimationOptions", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setAnimationOptions), METH_O, nullptr},
    {"setAxisX", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setAxisX), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setAxisY", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setAxisY), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setBackgroundBrush", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setBackgroundBrush), METH_O, nullptr},
    {"setBackgroundPen", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setBackgroundPen), METH_O, nullptr},
    {"setBackgroundRoundness", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setBackgroundRoundness), METH_O, nullptr},
    {"setBackgroundVisible", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setBackgroundVisible), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setDropShadowEnabled", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setDropShadowEnabled), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setLocale", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setLocale), METH_O, nullptr},
    {"setLocalizeNumbers", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setLocalizeNumbers), METH_O, nullptr},
    {"setMargins", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setMargins), METH_O, nullptr},
    {"setPlotArea", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setPlotArea), METH_O, nullptr},
    {"setPlotAreaBackgroundBrush", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setPlotAreaBackgroundBrush), METH_O, nullptr},
    {"setPlotAreaBackgroundPen", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setPlotAreaBackgroundPen), METH_O, nullptr},
    {"setPlotAreaBackgroundVisible", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setPlotAreaBackgroundVisible), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setTheme", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setTheme), METH_O, nullptr},
    {"setTitle", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setTitle), METH_O, nullptr},
    {"setTitleBrush", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setTitleBrush), METH_O, nullptr},
    {"setTitleFont", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_setTitleFont), METH_O, nullptr},
    {"theme", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_theme), METH_NOARGS, nullptr},
    {"title", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_title), METH_NOARGS, nullptr},
    {"titleBrush", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_titleBrush), METH_NOARGS, nullptr},
    {"titleFont", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_titleFont), METH_NOARGS, nullptr},
    {"zoom", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_zoom), METH_O, nullptr},
    {"zoomIn", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_zoomIn), METH_VARARGS, nullptr},
    {"zoomOut", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_zoomOut), METH_NOARGS, nullptr},
    {"zoomReset", reinterpret_cast<PyCFunction>(Sbk_QChartFunc_zoomReset), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QChart_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QChart *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QChartWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QChart_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QChart_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QChartSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QChart *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]))
        return static_cast< ::QGraphicsWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsObject_IDX]))
        return static_cast< ::QGraphicsObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]))
        return static_cast< ::QGraphicsItem *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX]))
        return static_cast< ::QGraphicsLayoutItem *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QChart_Type = nullptr;
static PyTypeObject *Sbk_QChart_TypeF(void)
{
    return _Sbk_QChart_Type;
}

static PyType_Slot Sbk_QChart_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QChart_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QChart_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QChart_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QChart_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QChart_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QChart_spec = {
    "2:PySide6.QtCharts.QChart",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QChart_slots
};

} //extern "C"

static void *Sbk_QChart_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QGraphicsItem >())
        return dynamic_cast< ::QChart *>(reinterpret_cast< ::QGraphicsItem *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QChart *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QGraphicsLayoutItem >())
        return dynamic_cast< ::QChart *>(reinterpret_cast< ::QGraphicsLayoutItem *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QChart_ChartType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QChart::ChartType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QChart::ChartType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QChart_ChartType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_ChartType_IDX])))
        return Enum_PythonToCpp_QChart_ChartType;
    return {};
}

static PyObject *QChart_ChartType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QChart::ChartType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QChart::ChartType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_ChartType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QChart_ChartTheme(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QChart::ChartTheme>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QChart::ChartTheme *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QChart_ChartTheme_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_ChartTheme_IDX])))
        return Enum_PythonToCpp_QChart_ChartTheme;
    return {};
}

static PyObject *QChart_ChartTheme_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QChart::ChartTheme>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QChart::ChartTheme *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_ChartTheme_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QChart_AnimationOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QChart::AnimationOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QChart::AnimationOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QChart_AnimationOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_AnimationOption_IDX])))
        return Enum_PythonToCpp_QChart_AnimationOption;
    return {};
}

static PyObject *QChart_AnimationOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QChart::AnimationOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QChart::AnimationOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_AnimationOption_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QChart_AnimationOption(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QChart::AnimationOption>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QChart::AnimationOption> *>(cppOut) = value;

}

static PyObject *QChart_AnimationOption_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QChart::AnimationOption> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtChartsTypeStructs[SBK_QChart_AnimationOption_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QChart_PythonToCpp_QChart_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QChart_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QChart_PythonToCpp_QChart_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QChart_TypeF()))
        return QChart_PythonToCpp_QChart_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QChart_PTR_CppToPython_QChart(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QChart *>(const_cast<void *>(cppIn)), Sbk_QChart_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QChart_SignatureStrings[] = {
    "1:PySide6.QtCharts.QChart(self,type:PySide6.QtCharts.QChart.ChartType,parent:PySide6.QtWidgets.QGraphicsItem,wFlags:PySide6.QtCore.Qt.WindowType,*:KeywordOnly=None,theme:QChart.ChartTheme=None,title:QString=None,backgroundVisible:bool=None,dropShadowEnabled:bool=None,backgroundRoundness:qreal=None,animationOptions:PySide6.QtCharts.QChart.AnimationOption=None,animationDuration:int=None,animationEasingCurve:QEasingCurve=None,margins:QMargins=None,chartType:QChart.ChartType=None,plotAreaBackgroundVisible:bool=None,localizeNumbers:bool=None,locale:QLocale=None,plotArea:QRectF=None)",
    "0:PySide6.QtCharts.QChart(self,parent:PySide6.QtWidgets.QGraphicsItem=nullptr,wFlags:PySide6.QtCore.Qt.WindowType=Qt.WindowFlags(),*:KeywordOnly=None,theme:QChart.ChartTheme=None,title:QString=None,backgroundVisible:bool=None,dropShadowEnabled:bool=None,backgroundRoundness:qreal=None,animationOptions:PySide6.QtCharts.QChart.AnimationOption=None,animationDuration:int=None,animationEasingCurve:QEasingCurve=None,margins:QMargins=None,chartType:QChart.ChartType=None,plotAreaBackgroundVisible:bool=None,localizeNumbers:bool=None,locale:QLocale=None,plotArea:QRectF=None)",
    "PySide6.QtCharts.QChart.addAxis(self,axis:PySide6.QtCharts.QAbstractAxis,alignment:PySide6.QtCore.Qt.AlignmentFlag)",
    "PySide6.QtCharts.QChart.addSeries(self,series:PySide6.QtCharts.QAbstractSeries)",
    "PySide6.QtCharts.QChart.animationDuration(self)->int",
    "PySide6.QtCharts.QChart.animationEasingCurve(self)->PySide6.QtCore.QEasingCurve",
    "PySide6.QtCharts.QChart.animationOptions(self)->PySide6.QtCharts.QChart.AnimationOption",
    "PySide6.QtCharts.QChart.axes(self,orientation:PySide6.QtCore.Qt.Orientation=Qt.Horizontal|Qt.Vertical,series:PySide6.QtCharts.QAbstractSeries=nullptr)->QList[PySide6.QtCharts.QAbstractAxis]",
    "PySide6.QtCharts.QChart.axisX(self,series:PySide6.QtCharts.QAbstractSeries=nullptr)->PySide6.QtCharts.QAbstractAxis",
    "PySide6.QtCharts.QChart.axisY(self,series:PySide6.QtCharts.QAbstractSeries=nullptr)->PySide6.QtCharts.QAbstractAxis",
    "PySide6.QtCharts.QChart.backgroundBrush(self)->PySide6.QtGui.QBrush",
    "PySide6.QtCharts.QChart.backgroundPen(self)->PySide6.QtGui.QPen",
    "PySide6.QtCharts.QChart.backgroundRoundness(self)->qreal",
    "PySide6.QtCharts.QChart.chartType(self)->PySide6.QtCharts.QChart.ChartType",
    "PySide6.QtCharts.QChart.createDefaultAxes(self)",
    "PySide6.QtCharts.QChart.isBackgroundVisible(self)->bool",
    "PySide6.QtCharts.QChart.isDropShadowEnabled(self)->bool",
    "PySide6.QtCharts.QChart.isPlotAreaBackgroundVisible(self)->bool",
    "PySide6.QtCharts.QChart.isZoomed(self)->bool",
    "PySide6.QtCharts.QChart.legend(self)->PySide6.QtCharts.QLegend",
    "PySide6.QtCharts.QChart.locale(self)->PySide6.QtCore.QLocale",
    "PySide6.QtCharts.QChart.localizeNumbers(self)->bool",
    "PySide6.QtCharts.QChart.mapToPosition(self,value:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],series:PySide6.QtCharts.QAbstractSeries=nullptr)->PySide6.QtCore.QPointF",
    "PySide6.QtCharts.QChart.mapToValue(self,position:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],series:PySide6.QtCharts.QAbstractSeries=nullptr)->PySide6.QtCore.QPointF",
    "PySide6.QtCharts.QChart.margins(self)->PySide6.QtCore.QMargins",
    "PySide6.QtCharts.QChart.plotArea(self)->PySide6.QtCore.QRectF",
    "PySide6.QtCharts.QChart.plotAreaBackgroundBrush(self)->PySide6.QtGui.QBrush",
    "PySide6.QtCharts.QChart.plotAreaBackgroundPen(self)->PySide6.QtGui.QPen",
    "PySide6.QtCharts.QChart.removeAllSeries(self)",
    "PySide6.QtCharts.QChart.removeAxis(self,axis:PySide6.QtCharts.QAbstractAxis)",
    "PySide6.QtCharts.QChart.removeSeries(self,series:PySide6.QtCharts.QAbstractSeries)",
    "PySide6.QtCharts.QChart.scroll(self,dx:qreal,dy:qreal)",
    "PySide6.QtCharts.QChart.series(self)->QList[PySide6.QtCharts.QAbstractSeries]",
    "PySide6.QtCharts.QChart.setAnimationDuration(self,msecs:int)",
    "PySide6.QtCharts.QChart.setAnimationEasingCurve(self,curve:typing.Union[PySide6.QtCore.QEasingCurve, PySide6.QtCore.QEasingCurve.Type])",
    "PySide6.QtCharts.QChart.setAnimationOptions(self,options:PySide6.QtCharts.QChart.AnimationOption)",
    "PySide6.QtCharts.QChart.setAxisX(self,axis:PySide6.QtCharts.QAbstractAxis,series:PySide6.QtCharts.QAbstractSeries=nullptr)",
    "PySide6.QtCharts.QChart.setAxisY(self,axis:PySide6.QtCharts.QAbstractAxis,series:PySide6.QtCharts.QAbstractSeries=nullptr)",
    "PySide6.QtCharts.QChart.setBackgroundBrush(self,brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap])",
    "PySide6.QtCharts.QChart.setBackgroundPen(self,pen:typing.Union[PySide6.QtGui.QPen, PySide6.QtCore.Qt.PenStyle, PySide6.QtGui.QColor])",
    "PySide6.QtCharts.QChart.setBackgroundRoundness(self,diameter:qreal)",
    "PySide6.QtCharts.QChart.setBackgroundVisible(self,visible:bool=true)",
    "PySide6.QtCharts.QChart.setDropShadowEnabled(self,enabled:bool=true)",
    "PySide6.QtCharts.QChart.setLocale(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])",
    "PySide6.QtCharts.QChart.setLocalizeNumbers(self,localize:bool)",
    "PySide6.QtCharts.QChart.setMargins(self,margins:PySide6.QtCore.QMargins)",
    "PySide6.QtCharts.QChart.setPlotArea(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtCharts.QChart.setPlotAreaBackgroundBrush(self,brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap])",
    "PySide6.QtCharts.QChart.setPlotAreaBackgroundPen(self,pen:typing.Union[PySide6.QtGui.QPen, PySide6.QtCore.Qt.PenStyle, PySide6.QtGui.QColor])",
    "PySide6.QtCharts.QChart.setPlotAreaBackgroundVisible(self,visible:bool=true)",
    "PySide6.QtCharts.QChart.setTheme(self,theme:PySide6.QtCharts.QChart.ChartTheme)",
    "PySide6.QtCharts.QChart.setTitle(self,title:QString)",
    "PySide6.QtCharts.QChart.setTitleBrush(self,brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap])",
    "PySide6.QtCharts.QChart.setTitleFont(self,font:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "PySide6.QtCharts.QChart.theme(self)->PySide6.QtCharts.QChart.ChartTheme",
    "PySide6.QtCharts.QChart.title(self)->QString",
    "PySide6.QtCharts.QChart.titleBrush(self)->PySide6.QtGui.QBrush",
    "PySide6.QtCharts.QChart.titleFont(self)->PySide6.QtGui.QFont",
    "PySide6.QtCharts.QChart.zoom(self,factor:qreal)",
    "1:PySide6.QtCharts.QChart.zoomIn(self)",
    "0:PySide6.QtCharts.QChart.zoomIn(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtCharts.QChart.zoomOut(self)",
    "PySide6.QtCharts.QChart.zoomReset(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t QChart_SignatureByteSize = 1089;
static constexpr uint8_t QChart_SignatureBytes[1089] = {
    0x78, 0xda, 0xed, 0x58, 0x4b, 0x8f, 0xdb, 0x36, 0x10, 0xbe, 0xf7, 0x57, 0xe4, 0x18, 0x17, 0xaa,
    0xd0, 0x5c, 0x7a, 0x30, 0xb0, 0x05, 0xbc, 0xcf, 0x2e, 0xea, 0x64, 0xed, 0x75, 0xba, 0x69, 0x1a,
    0xf8, 0x40, 0x4b, 0xb3, 0x36, 0x51, 0x8a, 0x74, 0x49, 0x6a, 0x77, 0xbd, 0xc8, 0x8f, 0xef, 0x90,
    0x7a, 0x98, 0x96, 0x44, 0x4a, 0x4e, 0xd3, 0x06, 0x6d, 0x7a, 0xb1, 0x68, 0xce, 0x8b, 0x33, 0x1c,
    0xce, 0x7c, 0xe4, 0xab, 0xf1, 0x6c, 0xb7, 0xa0, 0x29, 0xfc, 0x10, 0xcf, 0xf5, 0xd9, 0x86, 0x48,
    0xad, 0xe2, 0xb9, 0xfd, 0xbe, 0x54, 0xc0, 0xee, 0x23, 0xbd, 0xdb, 0x82, 0x8f, 0x23, 0xb6, 0xbf,
    0x6f, 0x91, 0x23, 0xda, 0x12, 0x09, 0x5c, 0x3b, 0x8c, 0xef, 0x68, 0xba, 0x06, 0xc3, 0x79, 0x25,
    0xc9, 0x76, 0x43, 0x13, 0x75, 0xad, 0x21, 0x8b, 0x1e, 0x2f, 0x19, 0x59, 0x2b, 0x57, 0x9f, 0x90,
    0x80, 0x9f, 0xf8, 0x1d, 0xe5, 0xa9, 0x78, 0xb4, 0xaa, 0xbe, 0x1d, 0xff, 0x0c, 0xbb, 0x47, 0x21,
    0xd3, 0x1b, 0xce, 0x76, 0x27, 0x6f, 0x04, 0x87, 0x48, 0x6f, 0x20, 0x83, 0xf1, 0x81, 0x51, 0x33,
    0x53, 0x12, 0xa9, 0x66, 0x48, 0x5c, 0x68, 0x49, 0xf9, 0xba, 0x98, 0x5a, 0x91, 0xe4, 0xf7, 0xb5,
    0x14, 0x39, 0x4f, 0xef, 0xa8, 0xa2, 0x2b, 0x24, 0xaf, 0x84, 0x60, 0x05, 0x2d, 0x95, 0x62, 0xbb,
    0xd8, 0x10, 0xb4, 0x76, 0xc1, 0x09, 0x92, 0x52, 0x87, 0xb6, 0x97, 0xbb, 0x35, 0x3f, 0x1c, 0x94,
    0x1a, 0xff, 0x21, 0x81, 0x94, 0x64, 0xc2, 0x69, 0x46, 0x34, 0x15, 0xfc, 0x66, 0x6b, 0x7e, 0x95,
    0x37, 0x2e, 0x93, 0x43, 0xc6, 0x86, 0xf4, 0x79, 0x2e, 0xed, 0x77, 0x4c, 0xb9, 0x6e, 0x90, 0x2e,
    0x88, 0x42, 0x27, 0xce, 0x72, 0xf9, 0x80, 0x1e, 0x39, 0x7f, 0x0a, 0xb6, 0x8c, 0xc8, 0x35, 0x45,
    0xb3, 0xf3, 0xd7, 0xc5, 0xa0, 0x98, 0x4d, 0xaa, 0x4d, 0x18, 0x37, 0x77, 0xa5, 0xa0, 0x6f, 0x99,
    0xd0, 0x13, 0x74, 0xe2, 0x34, 0x10, 0x14, 0x26, 0x12, 0xc2, 0xe8, 0x33, 0xbc, 0xc9, 0xb3, 0x15,
    0x48, 0xd5, 0xa4, 0xa0, 0xea, 0xa9, 0xfd, 0x1e, 0x6a, 0x1c, 0xcf, 0x6f, 0x21, 0xd1, 0x97, 0x76,
    0x72, 0xf4, 0xcd, 0xf7, 0xe1, 0x44, 0x1a, 0x96, 0x21, 0x27, 0x3c, 0x67, 0x6c, 0xab, 0xe5, 0x90,
    0x4c, 0x39, 0xa9, 0xff, 0x59, 0xde, 0x97, 0xa3, 0xff, 0x53, 0xe7, 0x5f, 0x9a, 0x3a, 0xbe, 0x60,
    0x90, 0x34, 0x9d, 0x3c, 0x51, 0x55, 0x24, 0x10, 0xc1, 0x51, 0x47, 0xd8, 0x26, 0x2b, 0xa5, 0x25,
    0x49, 0xb4, 0x61, 0x8c, 0x70, 0x25, 0x6b, 0x9e, 0x1d, 0xe6, 0x59, 0x95, 0x38, 0x93, 0x8a, 0x66,
    0xb2, 0x25, 0x68, 0x73, 0x01, 0x92, 0x42, 0x69, 0x55, 0xd9, 0x71, 0xc0, 0x6e, 0xc1, 0x1c, 0xd0,
    0xd7, 0xdc, 0x3b, 0xab, 0x77, 0xf4, 0xdd, 0x8f, 0xb8, 0x85, 0xfd, 0x42, 0xce, 0x46, 0x56, 0x72,
    0x4d, 0xcf, 0x1c, 0x96, 0x7e, 0x7d, 0x65, 0xfa, 0x75, 0xe8, 0x0a, 0x65, 0xa1, 0x5f, 0xef, 0x53,
    0x15, 0x27, 0x81, 0x51, 0xe0, 0xba, 0x48, 0xce, 0x76, 0xec, 0x6f, 0xf6, 0x54, 0x73, 0x6a, 0x7f,
    0x42, 0xee, 0x67, 0x81, 0x13, 0xec, 0x23, 0xfe, 0xbb, 0x03, 0xa9, 0x29, 0xa6, 0xc8, 0xd0, 0x58,
    0x57, 0x35, 0x02, 0xd7, 0x3f, 0x9f, 0x52, 0xa5, 0x3f, 0x84, 0x93, 0x62, 0x19, 0x58, 0x3d, 0x55,
    0xbf, 0x1e, 0xb5, 0xcd, 0x8e, 0xe9, 0xb0, 0xd1, 0xa0, 0xcd, 0xf7, 0xff, 0xb0, 0xcd, 0x7d, 0x6d,
    0x3a, 0x95, 0xb9, 0xda, 0xb4, 0x37, 0xff, 0x2a, 0xa7, 0xf1, 0xdc, 0xd2, 0x06, 0xe8, 0x98, 0x01,
    0xf7, 0x68, 0x40, 0xca, 0x00, 0xf9, 0xba, 0x3e, 0x56, 0x5a, 0x6c, 0x99, 0xf4, 0x0a, 0xd6, 0x35,
    0xaa, 0x2f, 0x67, 0xeb, 0xda, 0xe5, 0x57, 0x85, 0x86, 0x34, 0x9c, 0xc3, 0x3d, 0xc9, 0x19, 0x46,
    0xac, 0x4c, 0x5d, 0xff, 0xd1, 0xa5, 0xaa, 0x55, 0xf8, 0xaa, 0x45, 0x98, 0x2a, 0x17, 0x90, 0x3b,
    0x6f, 0x76, 0x8a, 0x81, 0x72, 0x33, 0x5f, 0xc1, 0x1d, 0x28, 0xff, 0x9b, 0x10, 0xd9, 0x40, 0x63,
    0x0c, 0xd6, 0xc0, 0x53, 0x7f, 0x50, 0xa7, 0x96, 0xee, 0x17, 0xb7, 0x45, 0xdd, 0x57, 0x93, 0x8a,
    0x92, 0x1f, 0x16, 0xde, 0xf7, 0x8c, 0x41, 0xeb, 0xcd, 0xc8, 0xf6, 0xad, 0x98, 0x09, 0x45, 0xeb,
    0x1a, 0x1a, 0x3d, 0x10, 0x96, 0xc3, 0x18, 0x11, 0x2a, 0xd6, 0xbf, 0xf8, 0x17, 0x8e, 0xf3, 0x1f,
    0x9a, 0x0b, 0x99, 0x09, 0x2c, 0xb3, 0x97, 0xd1, 0x8b, 0xce, 0x79, 0x77, 0xba, 0x48, 0x60, 0x82,
    0xb3, 0x20, 0x67, 0x44, 0x6f, 0xe2, 0x0b, 0x06, 0xa6, 0x59, 0x2c, 0xff, 0xda, 0x31, 0x75, 0x16,
    0x11, 0xf6, 0xec, 0xce, 0xf8, 0x52, 0x22, 0xa5, 0xd2, 0xc9, 0xff, 0x82, 0x67, 0x16, 0x6c, 0xf8,
    0xb2, 0xa4, 0xc4, 0x22, 0x5e, 0xf1, 0x0a, 0x2c, 0xf8, 0xe4, 0x2d, 0x84, 0xe8, 0x95, 0x3e, 0xfd,
    0x0c, 0xd5, 0xaf, 0xad, 0xeb, 0xd3, 0xaa, 0xa0, 0x84, 0x4c, 0x3c, 0xc0, 0x84, 0x31, 0x07, 0x62,
    0x8c, 0xfa, 0xb8, 0x8f, 0x41, 0x40, 0x7d, 0xca, 0x3e, 0x2b, 0xb4, 0x51, 0x89, 0x14, 0x8c, 0x15,
    0xca, 0xd2, 0xa7, 0x02, 0xee, 0x46, 0xe9, 0xae, 0x18, 0x04, 0xc4, 0x1c, 0xdf, 0xfb, 0x5b, 0x78,
    0xb1, 0x88, 0x65, 0x40, 0x9b, 0x9e, 0x74, 0x42, 0xac, 0x28, 0x53, 0x90, 0x28, 0x83, 0x94, 0x47,
    0x83, 0x84, 0x9b, 0x50, 0x2b, 0x4a, 0x2c, 0x96, 0x0e, 0x1e, 0x42, 0x47, 0xa6, 0x7d, 0x12, 0x1d,
    0x62, 0x6c, 0xfa, 0xd2, 0x72, 0xd8, 0x3a, 0x5c, 0x88, 0x16, 0x89, 0xe3, 0xae, 0x0b, 0x61, 0x0b,
    0x7b, 0xb8, 0x33, 0x04, 0x4b, 0x1f, 0x5b, 0x1d, 0xfa, 0x4c, 0xbf, 0xff, 0x32, 0xa6, 0xbb, 0x8e,
    0x7f, 0xb4, 0x32, 0x43, 0xdf, 0xd6, 0xee, 0xeb, 0x41, 0x7b, 0x4f, 0x75, 0x6c, 0x09, 0x0b, 0xbd,
    0x63, 0xd0, 0x45, 0xbd, 0x62, 0x62, 0x45, 0xd8, 0x99, 0x60, 0x42, 0xb6, 0x6a, 0x70, 0xf7, 0x2c,
    0xde, 0x7e, 0x53, 0x03, 0x8e, 0x5b, 0x84, 0xeb, 0x8c, 0xac, 0xa1, 0x5d, 0xc8, 0xe9, 0x13, 0xf6,
    0x8b, 0xe5, 0x40, 0x97, 0xab, 0x2a, 0x15, 0x6d, 0x81, 0x07, 0xdd, 0x45, 0xc6, 0x2e, 0x77, 0x70,
    0xba, 0xe5, 0xea, 0xde, 0x97, 0xa1, 0xab, 0x38, 0x44, 0x7c, 0x51, 0x4a, 0x49, 0x06, 0xd8, 0x8c,
    0xfa, 0xeb, 0x84, 0xee, 0xc6, 0x41, 0xd1, 0x83, 0x7b, 0x0b, 0xd5, 0x32, 0x87, 0xa0, 0x92, 0x6e,
    0x30, 0x16, 0x81, 0x7b, 0x87, 0xef, 0x55, 0x32, 0xdd, 0xe3, 0x9d, 0xea, 0x62, 0x1b, 0xac, 0x0c,
    0x05, 0x7f, 0x3b, 0xa6, 0xc5, 0x7c, 0x3c, 0x25, 0x7c, 0x9d, 0xe3, 0xfe, 0x2e, 0xfb, 0x8d, 0x36,
    0x70, 0x52, 0x7d, 0xe1, 0xb6, 0x0b, 0x0f, 0x8a, 0xbf, 0x76, 0xda, 0x6f, 0xfd, 0x02, 0xe0, 0x69,
    0xc2, 0x41, 0x45, 0x33, 0xb7, 0x11, 0x47, 0x12, 0xdb, 0x6e, 0xd8, 0x79, 0xdb, 0x98, 0xdb, 0xbe,
    0x9b, 0xe9, 0xe5, 0x20, 0x43, 0x5f, 0xe1, 0xa1, 0x9d, 0x79, 0x21, 0xc6, 0x97, 0x38, 0xbc, 0xe1,
    0x8b, 0xc8, 0x91, 0x07, 0xd0, 0xbe, 0xb8, 0x95, 0xcf, 0xc9, 0xf6, 0x39, 0x2e, 0x7c, 0x85, 0x33,
    0x2c, 0x61, 0x7d, 0xe6, 0xd9, 0xae, 0xd4, 0xe7, 0xbe, 0xe0, 0xf5, 0x0b, 0x7d, 0x35, 0xd9, 0x64,
    0xbd, 0xbd, 0x14, 0xbc, 0x7c, 0x7c, 0xbd, 0xc7, 0x51, 0xd0, 0x57, 0xc3, 0x1a, 0xbd, 0x28, 0xe3,
    0x58, 0x0f, 0x0c, 0x34, 0x0b, 0xd8, 0xd1, 0xf5, 0xbe, 0xf6, 0x5e, 0xcb, 0x0d, 0xa7, 0x5f, 0x4f,
    0xbd, 0x9f, 0x06, 0x0f, 0x16, 0xa6, 0xc3, 0xcc, 0x9f, 0x8e, 0xe4, 0xf5, 0x41, 0x60, 0xda, 0xd2,
    0x86, 0xe4, 0x15, 0x7e, 0xc6, 0xeb, 0x75, 0x19, 0x50, 0x04, 0x21, 0xa2, 0xee, 0x60, 0xaf, 0xc6,
    0x21, 0x89, 0xeb, 0xf2, 0xa6, 0xe0, 0x7f, 0x21, 0x77, 0xd9, 0xfe, 0xb6, 0xf2, 0x6a, 0x6c, 0xdc,
    0xe4, 0xba, 0xe7, 0xce, 0x61, 0xb8, 0x6e, 0x01, 0x33, 0xa8, 0xe4, 0xfb, 0x13, 0x1c, 0x87, 0x73,
    0xcb
};
#endif

PyTypeObject *init_QChart(PyObject *module)
{
    if (SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX].type != nullptr)
        return SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX].type;

    Shiboken::AutoDecRef Sbk_QChart_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]))));

    _Sbk_QChart_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QChart",
        "QChart*",
        &Sbk_QChart_spec,
        &Shiboken::callCppDestructor< QChart >,
        Sbk_QChart_Type_bases.object(),
        0);
    auto *pyType = Sbk_QChart_TypeF(); // references _Sbk_QChart_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QChart_SignatureStrings);
#else
    InitSignatureBytes(pyType, QChart_SignatureBytes, QChart_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QChart_PropertyStrings);
    SbkPySide6_QtChartsTypeStructs[SBK_QChart_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QChart_PythonToCpp_QChart_PTR,
        is_QChart_PythonToCpp_QChart_PTR_Convertible,
        QChart_PTR_CppToPython_QChart);

    Shiboken::Conversions::registerConverterName(converter, "QChart");
    Shiboken::Conversions::registerConverterName(converter, "QChart*");
    Shiboken::Conversions::registerConverterName(converter, "QChart&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QChart).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QChartWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QChart_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QChart_TypeF(), &Sbk_QChartSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QChart_TypeF(), &Sbk_QChart_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QChart_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ChartType'.
    const char *ChartType_Initializer[] = {
        "ChartTypeUndefined",
        "ChartTypeCartesian",
        "ChartTypePolar",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ChartType_InitializerValues[] = {
        uint8_t(QChart::ChartType::ChartTypeUndefined), //  0x00  0
        uint8_t(QChart::ChartType::ChartTypeCartesian), //  0x01  1
        uint8_t(QChart::ChartType::ChartTypePolar)      //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QChart_TypeF(),
        "2:PySide6.QtCharts.QChart.ChartType",
        ChartType_Initializer, ChartType_InitializerValues);
    SbkPySide6_QtChartsTypeStructs[SBK_QChart_ChartType_IDX].type = EType;
    // Register converter for enum 'QChart::ChartType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QChart_ChartType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QChart_ChartType,
            is_Enum_PythonToCpp_QChart_ChartType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QChart::ChartType");
        Shiboken::Conversions::registerConverterAlias(converter, "ChartType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ChartType' enum.

    // Initialization of enum 'ChartTheme'.
    const char *ChartTheme_Initializer[] = {
        "ChartThemeLight",
        "ChartThemeBlueCerulean",
        "ChartThemeDark",
        "ChartThemeBrownSand",
        "ChartThemeBlueNcs",
        "ChartThemeHighContrast",
        "ChartThemeBlueIcy",
        "ChartThemeQt",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ChartTheme_InitializerValues[] = {
        uint8_t(QChart::ChartTheme::ChartThemeLight),        //  0x00  0
        uint8_t(QChart::ChartTheme::ChartThemeBlueCerulean), //  0x01  1
        uint8_t(QChart::ChartTheme::ChartThemeDark),         //  0x02  2
        uint8_t(QChart::ChartTheme::ChartThemeBrownSand),    //  0x03  3
        uint8_t(QChart::ChartTheme::ChartThemeBlueNcs),      //  0x04  4
        uint8_t(QChart::ChartTheme::ChartThemeHighContrast), //  0x05  5
        uint8_t(QChart::ChartTheme::ChartThemeBlueIcy),      //  0x06  6
        uint8_t(QChart::ChartTheme::ChartThemeQt)            //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QChart_TypeF(),
        "2:PySide6.QtCharts.QChart.ChartTheme",
        ChartTheme_Initializer, ChartTheme_InitializerValues);
    SbkPySide6_QtChartsTypeStructs[SBK_QChart_ChartTheme_IDX].type = EType;
    // Register converter for enum 'QChart::ChartTheme'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QChart_ChartTheme_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QChart_ChartTheme,
            is_Enum_PythonToCpp_QChart_ChartTheme_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QChart::ChartTheme");
        Shiboken::Conversions::registerConverterAlias(converter, "ChartTheme");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ChartTheme' enum.

    // Initialization of enum 'AnimationOption'.
    const char *AnimationOption_Initializer[] = {
        "NoAnimation",
        "GridAxisAnimations",
        "SeriesAnimations",
        "AllAnimations",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AnimationOption_InitializerValues[] = {
        uint8_t(QChart::AnimationOption::NoAnimation),        //  0x00  0
        uint8_t(QChart::AnimationOption::GridAxisAnimations), //  0x01  1
        uint8_t(QChart::AnimationOption::SeriesAnimations),   //  0x02  2
        uint8_t(QChart::AnimationOption::AllAnimations)       //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QChart_TypeF(),
        "2:PySide6.QtCharts.QChart.AnimationOption",
        AnimationOption_Initializer, AnimationOption_InitializerValues);
    SbkPySide6_QtChartsTypeStructs[SBK_QChart_AnimationOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtChartsTypeStructs[SBK_QFlags_QChart_AnimationOption_IDX].type =
        EType;
    // Register converter for enum 'QChart::AnimationOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QChart_AnimationOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QChart_AnimationOption,
            is_Enum_PythonToCpp_QChart_AnimationOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QChart::AnimationOption");
        Shiboken::Conversions::registerConverterAlias(converter, "AnimationOption");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QChart_AnimationOption_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QChart_AnimationOption,
            is_Enum_PythonToCpp_QChart_AnimationOption_Convertible);
        // Register converter for flag 'QFlags<QChart::AnimationOption>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QChart::AnimationOption>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QChart::AnimationOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'AnimationOption' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QChart::staticMetaObject);
    qRegisterMetaType< ::QChart::ChartType >("QChart::ChartType");
    qRegisterMetaType< ::QChart::ChartTheme >("QChart::ChartTheme");
    qRegisterMetaType< ::QChart::AnimationOption >("QChart::AnimationOption");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QChart::staticMetaObject, sizeof(QChartWrapper));

    return pyType;
}
