// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qmetamethod_wrapper.h"

// Extra includes
#include <pysidesignal.h>
#include "glue/core_snippets_p.h"

// Argument includes
#include <QList>
#include <qbytearray.h>
#include <qbytearrayview.h>
#include <qmetaobject.h>
#include <qmetatype.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qtcorehelper.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (qmetamethod-invoke-helpers)]
static InvokeMetaMethodFunc
    createInvokeMetaMethodFunc(const QMetaMethod &method, QObject *object,
                               Qt::ConnectionType type = Qt::AutoConnection)
{
    return [&method, object, type](QGenericArgument a0, QGenericArgument a1,
                                   QGenericArgument a2, QGenericArgument a3,
                                   QGenericArgument a4, QGenericArgument a5,
                                   QGenericArgument a6, QGenericArgument a7,
                                   QGenericArgument a8, QGenericArgument a9) -> bool
    {
        return method.invoke(object, type, a0, a1, a2, a3, a4, a5, a6, a7, a8, a9);
    };
}

static InvokeMetaMethodFuncWithReturn
    createInvokeMetaMethodFuncWithReturn(const QMetaMethod &method, QObject *object,
                                         Qt::ConnectionType type = Qt::AutoConnection)
{
    return [&method, object, type](QGenericReturnArgument r,
                                   QGenericArgument a0, QGenericArgument a1,
                                   QGenericArgument a2, QGenericArgument a3,
                                   QGenericArgument a4, QGenericArgument a5,
                                   QGenericArgument a6, QGenericArgument a7,
                                   QGenericArgument a8, QGenericArgument a9) -> bool
    {
        return method.invoke(object, type, r, a0, a1, a2, a3, a4, a5, a6, a7, a8, a9);
    };
}
// END of custom code block [file: ../glue/qtcore.cpp (qmetamethod-invoke-helpers)]
// ========================================================================
// End of code injection



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMetaMethod_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMetaMethod >()))
        return -1;

    ::QMetaMethod *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QMetaMethod", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMetaMethod::QMetaMethod()
    // 1: QMetaMethod::QMetaMethod(QMetaMethod)
    if (numArgs == 0) {
        overloadId = 0; // QMetaMethod()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QMetaMethod(QMetaMethod)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QMetaMethod()
        {

            // QMetaMethod()
            cptr = new ::QMetaMethod();
            break;
        }
        case 1: // QMetaMethod(const QMetaMethod &QMetaMethod)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QMetaMethod cppArg0_local;
            ::QMetaMethod *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QMetaMethod(QMetaMethod)
                cptr = new ::QMetaMethod(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMetaMethod >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMetaMethodFunc_access(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // access()const
        QMetaMethod::Access cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->access();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_Access_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_enclosingMetaObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // enclosingMetaObject()const
        const QMetaObject * cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->enclosingMetaObject();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_fromSignal(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMetaMethod::fromSignal(PySideSignalInstance)->QMetaMethod
    if (PySide::Signal::checkInstanceType(pyArg)) {
        overloadId = 0; // fromSignal(PySideSignalInstance)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromSignal", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromSignal(PySideSignalInstance)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qmetamethod-from-signal)]
            auto *signalInst = reinterpret_cast<PySideSignalInstance *>(pyArg);
            const auto data = PySide::Signal::getEmitterData(signalInst);
            const auto result = data.methodIndex != -1
                ? data.emitter->metaObject()->method(data.methodIndex)
                : QMetaMethod{};
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &result);
            // END of custom code block [file: ../glue/qtcore.cpp (qmetamethod-from-signal)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_invoke(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[13];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 13));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "invoke", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOOOOOOOO:invoke", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9]), &(pyArgs[10]), &(pyArgs[11]), &(pyArgs[12])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMetaMethod::invoke(QObject*,QGenericArgument,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=)const->bool
    // 1: QMetaMethod::invoke(QObject*,QGenericReturnArgument,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=)const->bool
    // 2: QMetaMethod::invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=)const->bool
    // 3: QMetaMethod::invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=)const->bool
    // 4: QMetaMethod::invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=)->PyObject*
    // 5: QMetaMethod::invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=)->PyObject*
    // 6: QMetaMethod::invoke(QObject*,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=)->PyObject*
    // 7: QMetaMethod::invoke(QObject*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=)->PyObject*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 6; // invoke(QObject*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericReturnArgumentHolder_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 7; // invoke(QObject*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 7; // invoke(QObject*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 7; // invoke(QObject*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 7; // invoke(QObject*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 7; // invoke(QObject*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6])))) {
                                if (numArgs == 7) {
                                    overloadId = 7; // invoke(QObject*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                } else if (numArgs >= 8
                                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7])))) {
                                    if (numArgs == 8) {
                                        overloadId = 7; // invoke(QObject*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                    } else if (numArgs >= 9
                                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8])))) {
                                        if (numArgs == 9) {
                                            overloadId = 7; // invoke(QObject*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                        } else if (numArgs >= 10
                                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9])))) {
                                            if (numArgs == 10) {
                                                overloadId = 7; // invoke(QObject*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                            } else if (numArgs >= 11
                                                && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10])))) {
                                                if (numArgs == 11) {
                                                    overloadId = 7; // invoke(QObject*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                                } else if (numArgs >= 12
                                                    && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[11])))) {
                                                    overloadId = 7; // invoke(QObject*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 6; // invoke(QObject*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 6; // invoke(QObject*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 6; // invoke(QObject*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 6; // invoke(QObject*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 6; // invoke(QObject*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6])))) {
                                if (numArgs == 7) {
                                    overloadId = 6; // invoke(QObject*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                } else if (numArgs >= 8
                                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7])))) {
                                    if (numArgs == 8) {
                                        overloadId = 6; // invoke(QObject*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                    } else if (numArgs >= 9
                                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8])))) {
                                        if (numArgs == 9) {
                                            overloadId = 6; // invoke(QObject*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                        } else if (numArgs >= 10
                                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9])))) {
                                            if (numArgs == 10) {
                                                overloadId = 6; // invoke(QObject*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                            } else if (numArgs >= 11
                                                && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10])))) {
                                                overloadId = 6; // invoke(QObject*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 4; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericReturnArgumentHolder_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 5; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 5; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 5; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 5; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6])))) {
                                if (numArgs == 7) {
                                    overloadId = 5; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                } else if (numArgs >= 8
                                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7])))) {
                                    if (numArgs == 8) {
                                        overloadId = 5; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                    } else if (numArgs >= 9
                                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8])))) {
                                        if (numArgs == 9) {
                                            overloadId = 5; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                        } else if (numArgs >= 10
                                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9])))) {
                                            if (numArgs == 10) {
                                                overloadId = 5; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                            } else if (numArgs >= 11
                                                && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10])))) {
                                                if (numArgs == 11) {
                                                    overloadId = 5; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                                } else if (numArgs >= 12
                                                    && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[11])))) {
                                                    if (numArgs == 12) {
                                                        overloadId = 5; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                                    } else if (numArgs >= 13
                                                        && (pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[12])))) {
                                                        overloadId = 5; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 4; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 4; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 4; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 4; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6])))) {
                                if (numArgs == 7) {
                                    overloadId = 4; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                } else if (numArgs >= 8
                                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7])))) {
                                    if (numArgs == 8) {
                                        overloadId = 4; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                    } else if (numArgs >= 9
                                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8])))) {
                                        if (numArgs == 9) {
                                            overloadId = 4; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                        } else if (numArgs >= 10
                                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9])))) {
                                            if (numArgs == 10) {
                                                overloadId = 4; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                            } else if (numArgs >= 11
                                                && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10])))) {
                                                if (numArgs == 11) {
                                                    overloadId = 4; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                                } else if (numArgs >= 12
                                                    && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[11])))) {
                                                    overloadId = 4; // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6])))) {
                                if (numArgs == 7) {
                                    overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                } else if (numArgs >= 8
                                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7])))) {
                                    if (numArgs == 8) {
                                        overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                    } else if (numArgs >= 9
                                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8])))) {
                                        if (numArgs == 9) {
                                            overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        } else if (numArgs >= 10
                                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9])))) {
                                            if (numArgs == 10) {
                                                overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                            } else if (numArgs >= 11
                                                && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10])))) {
                                                if (numArgs == 11) {
                                                    overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                } else if (numArgs >= 12
                                                    && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11])))) {
                                                    if (numArgs == 12) {
                                                        overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                    } else if (numArgs >= 13
                                                        && (pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[12])))) {
                                                        overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6])))) {
                                if (numArgs == 7) {
                                    overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                } else if (numArgs >= 8
                                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7])))) {
                                    if (numArgs == 8) {
                                        overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                    } else if (numArgs >= 9
                                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8])))) {
                                        if (numArgs == 9) {
                                            overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        } else if (numArgs >= 10
                                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9])))) {
                                            if (numArgs == 10) {
                                                overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                            } else if (numArgs >= 11
                                                && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10])))) {
                                                if (numArgs == 11) {
                                                    overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                } else if (numArgs >= 12
                                                    && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11])))) {
                                                    overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6])))) {
                                if (numArgs == 7) {
                                    overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                } else if (numArgs >= 8
                                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7])))) {
                                    if (numArgs == 8) {
                                        overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                    } else if (numArgs >= 9
                                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8])))) {
                                        if (numArgs == 9) {
                                            overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        } else if (numArgs >= 10
                                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9])))) {
                                            if (numArgs == 10) {
                                                overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                            } else if (numArgs >= 11
                                                && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10])))) {
                                                if (numArgs == 11) {
                                                    overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                } else if (numArgs >= 12
                                                    && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11])))) {
                                                    overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6])))) {
                                if (numArgs == 7) {
                                    overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                } else if (numArgs >= 8
                                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7])))) {
                                    if (numArgs == 8) {
                                        overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                    } else if (numArgs >= 9
                                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8])))) {
                                        if (numArgs == 9) {
                                            overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        } else if (numArgs >= 10
                                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9])))) {
                                            if (numArgs == 10) {
                                                overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                            } else if (numArgs >= 11
                                                && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10])))) {
                                                overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "invoke", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // invoke(QObject *object, QGenericArgument val0, QGenericArgument val1, QGenericArgument val2, QGenericArgument val3, QGenericArgument val4, QGenericArgument val5, QGenericArgument val6, QGenericArgument val7, QGenericArgument val8, QGenericArgument val9) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[9] = {{"val1", 2}, {"val2", 3}, {"val3", 4}, {"val4", 5}, {"val5", 6}, {"val6", 7}, {"val7", 8}, {"val8", 9}, {"val9", 10}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 9, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[2]))))
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3]))))
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4]))))
                    || (pyArgs[5] != nullptr && !(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5]))))
                    || (pyArgs[6] != nullptr && !(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6]))))
                    || (pyArgs[7] != nullptr && !(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7]))))
                    || (pyArgs[8] != nullptr && !(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8]))))
                    || (pyArgs[9] != nullptr && !(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9]))))
                    || (pyArgs[10] != nullptr && !(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "invoke", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QGenericArgument cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QGenericArgument cppArg2 = QGenericArgument();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QGenericArgument cppArg3 = QGenericArgument();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QGenericArgument cppArg4 = QGenericArgument();
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QGenericArgument cppArg5 = QGenericArgument();
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QGenericArgument cppArg6 = QGenericArgument();
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QGenericArgument cppArg7 = QGenericArgument();
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QGenericArgument cppArg8 = QGenericArgument();
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QGenericArgument cppArg9 = QGenericArgument();
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QGenericArgument cppArg10 = QGenericArgument();
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);

            if (Shiboken::Errors::occurred() == nullptr) {
                // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                bool cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->invoke(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // invoke(QObject *object, QGenericReturnArgument returnValue, QGenericArgument val0, QGenericArgument val1, QGenericArgument val2, QGenericArgument val3, QGenericArgument val4, QGenericArgument val5, QGenericArgument val6, QGenericArgument val7, QGenericArgument val8, QGenericArgument val9) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[10] = {{"val0", 2}, {"val1", 3}, {"val2", 4}, {"val3", 5}, {"val4", 6}, {"val5", 7}, {"val6", 8}, {"val7", 9}, {"val8", 10}, {"val9", 11}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 10, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[2]))))
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3]))))
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4]))))
                    || (pyArgs[5] != nullptr && !(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5]))))
                    || (pyArgs[6] != nullptr && !(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6]))))
                    || (pyArgs[7] != nullptr && !(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7]))))
                    || (pyArgs[8] != nullptr && !(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8]))))
                    || (pyArgs[9] != nullptr && !(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9]))))
                    || (pyArgs[10] != nullptr && !(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10]))))
                    || (pyArgs[11] != nullptr && !(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "invoke", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QGenericReturnArgument cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QGenericArgument cppArg2 = QGenericArgument(nullptr);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QGenericArgument cppArg3 = QGenericArgument();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QGenericArgument cppArg4 = QGenericArgument();
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QGenericArgument cppArg5 = QGenericArgument();
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QGenericArgument cppArg6 = QGenericArgument();
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QGenericArgument cppArg7 = QGenericArgument();
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QGenericArgument cppArg8 = QGenericArgument();
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QGenericArgument cppArg9 = QGenericArgument();
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QGenericArgument cppArg10 = QGenericArgument();
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QGenericArgument cppArg11 = QGenericArgument();
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);

            if (Shiboken::Errors::occurred() == nullptr) {
                // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                bool cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->invoke(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // invoke(QObject *object, Qt::ConnectionType connectionType, QGenericArgument val0, QGenericArgument val1, QGenericArgument val2, QGenericArgument val3, QGenericArgument val4, QGenericArgument val5, QGenericArgument val6, QGenericArgument val7, QGenericArgument val8, QGenericArgument val9) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[9] = {{"val1", 3}, {"val2", 4}, {"val3", 5}, {"val4", 6}, {"val5", 7}, {"val6", 8}, {"val7", 9}, {"val8", 10}, {"val9", 11}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 9, errInfo, pyArgs)
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3]))))
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4]))))
                    || (pyArgs[5] != nullptr && !(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5]))))
                    || (pyArgs[6] != nullptr && !(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6]))))
                    || (pyArgs[7] != nullptr && !(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7]))))
                    || (pyArgs[8] != nullptr && !(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8]))))
                    || (pyArgs[9] != nullptr && !(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9]))))
                    || (pyArgs[10] != nullptr && !(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10]))))
                    || (pyArgs[11] != nullptr && !(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "invoke", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::ConnectionType cppArg1{Qt::AutoConnection};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QGenericArgument cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QGenericArgument cppArg3 = QGenericArgument();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QGenericArgument cppArg4 = QGenericArgument();
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QGenericArgument cppArg5 = QGenericArgument();
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QGenericArgument cppArg6 = QGenericArgument();
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QGenericArgument cppArg7 = QGenericArgument();
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QGenericArgument cppArg8 = QGenericArgument();
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QGenericArgument cppArg9 = QGenericArgument();
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QGenericArgument cppArg10 = QGenericArgument();
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QGenericArgument cppArg11 = QGenericArgument();
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);

            if (Shiboken::Errors::occurred() == nullptr) {
                // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                bool cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->invoke(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 3: // invoke(QObject *object, Qt::ConnectionType connectionType, QGenericReturnArgument returnValue, QGenericArgument val0, QGenericArgument val1, QGenericArgument val2, QGenericArgument val3, QGenericArgument val4, QGenericArgument val5, QGenericArgument val6, QGenericArgument val7, QGenericArgument val8, QGenericArgument val9) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[10] = {{"val0", 3}, {"val1", 4}, {"val2", 5}, {"val3", 6}, {"val4", 7}, {"val5", 8}, {"val6", 9}, {"val7", 10}, {"val8", 11}, {"val9", 12}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 10, errInfo, pyArgs)
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3]))))
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4]))))
                    || (pyArgs[5] != nullptr && !(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5]))))
                    || (pyArgs[6] != nullptr && !(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6]))))
                    || (pyArgs[7] != nullptr && !(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7]))))
                    || (pyArgs[8] != nullptr && !(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8]))))
                    || (pyArgs[9] != nullptr && !(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9]))))
                    || (pyArgs[10] != nullptr && !(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10]))))
                    || (pyArgs[11] != nullptr && !(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11]))))
                    || (pyArgs[12] != nullptr && !(pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[12]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "invoke", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::ConnectionType cppArg1{Qt::AutoConnection};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QGenericReturnArgument cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QGenericArgument cppArg3 = QGenericArgument(nullptr);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QGenericArgument cppArg4 = QGenericArgument();
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QGenericArgument cppArg5 = QGenericArgument();
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QGenericArgument cppArg6 = QGenericArgument();
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QGenericArgument cppArg7 = QGenericArgument();
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QGenericArgument cppArg8 = QGenericArgument();
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QGenericArgument cppArg9 = QGenericArgument();
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QGenericArgument cppArg10 = QGenericArgument();
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QGenericArgument cppArg11 = QGenericArgument();
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);
            if (!Shiboken::Object::isValid(pyArgs[12]))
                return {};
            ::QGenericArgument cppArg12 = QGenericArgument();
            if (pythonToCpp[12])
                pythonToCpp[12](pyArgs[12], &cppArg12);

            if (Shiboken::Errors::occurred() == nullptr) {
                // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                bool cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->invoke(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 4: // invoke(QObject *object, Qt::ConnectionType type, QtCoreHelper::QGenericArgumentHolder val0, QtCoreHelper::QGenericArgumentHolder val1, QtCoreHelper::QGenericArgumentHolder val2, QtCoreHelper::QGenericArgumentHolder val3, QtCoreHelper::QGenericArgumentHolder val4, QtCoreHelper::QGenericArgumentHolder val5, QtCoreHelper::QGenericArgumentHolder val6, QtCoreHelper::QGenericArgumentHolder val7, QtCoreHelper::QGenericArgumentHolder val8, QtCoreHelper::QGenericArgumentHolder val9)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[10] = {{"val0", 2}, {"val1", 3}, {"val2", 4}, {"val3", 5}, {"val4", 6}, {"val5", 7}, {"val6", 8}, {"val7", 9}, {"val8", 10}, {"val9", 11}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 10, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[2]))))
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[3]))))
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4]))))
                    || (pyArgs[5] != nullptr && !(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5]))))
                    || (pyArgs[6] != nullptr && !(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6]))))
                    || (pyArgs[7] != nullptr && !(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7]))))
                    || (pyArgs[8] != nullptr && !(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8]))))
                    || (pyArgs[9] != nullptr && !(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9]))))
                    || (pyArgs[10] != nullptr && !(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10]))))
                    || (pyArgs[11] != nullptr && !(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[11]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "invoke", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            ::Qt::ConnectionType cppArg1{Qt::AutoConnection};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg2{};
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg3{};
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            SBK_UNUSED(cppArg3)
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg4{};
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            SBK_UNUSED(cppArg4)
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg5{};
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            SBK_UNUSED(cppArg5)
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg6{};
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            SBK_UNUSED(cppArg6)
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg7{};
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            SBK_UNUSED(cppArg7)
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg8{};
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            SBK_UNUSED(cppArg8)
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg9{};
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            SBK_UNUSED(cppArg9)
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg10{};
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            SBK_UNUSED(cppArg10)
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg11{};
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);
            SBK_UNUSED(cppArg11)

            if (Shiboken::Errors::occurred() == nullptr) {
                // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmetamethod-invoke-conn-type)]
                pyResult = invokeMetaMethod(createInvokeMetaMethodFunc(*cppSelf, cppArg0, cppArg1),
                                            cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11);
                // END of custom code block [file: ../glue/qtcore.cpp (qmetamethod-invoke-conn-type)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 5: // invoke(QObject *object, Qt::ConnectionType type, QtCoreHelper::QGenericReturnArgumentHolder ret, QtCoreHelper::QGenericArgumentHolder val0, QtCoreHelper::QGenericArgumentHolder val1, QtCoreHelper::QGenericArgumentHolder val2, QtCoreHelper::QGenericArgumentHolder val3, QtCoreHelper::QGenericArgumentHolder val4, QtCoreHelper::QGenericArgumentHolder val5, QtCoreHelper::QGenericArgumentHolder val6, QtCoreHelper::QGenericArgumentHolder val7, QtCoreHelper::QGenericArgumentHolder val8, QtCoreHelper::QGenericArgumentHolder val9)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[10] = {{"val0", 3}, {"val1", 4}, {"val2", 5}, {"val3", 6}, {"val4", 7}, {"val5", 8}, {"val6", 9}, {"val7", 10}, {"val8", 11}, {"val9", 12}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 10, errInfo, pyArgs)
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[3]))))
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4]))))
                    || (pyArgs[5] != nullptr && !(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5]))))
                    || (pyArgs[6] != nullptr && !(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6]))))
                    || (pyArgs[7] != nullptr && !(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7]))))
                    || (pyArgs[8] != nullptr && !(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8]))))
                    || (pyArgs[9] != nullptr && !(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9]))))
                    || (pyArgs[10] != nullptr && !(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10]))))
                    || (pyArgs[11] != nullptr && !(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[11]))))
                    || (pyArgs[12] != nullptr && !(pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[12]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "invoke", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            ::Qt::ConnectionType cppArg1{Qt::AutoConnection};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QtCoreHelper::QGenericReturnArgumentHolder cppArg2 = ::QtCoreHelper::QGenericReturnArgumentHolder(::QMetaType(), static_cast<void*>(nullptr));
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg3{};
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            SBK_UNUSED(cppArg3)
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg4{};
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            SBK_UNUSED(cppArg4)
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg5{};
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            SBK_UNUSED(cppArg5)
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg6{};
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            SBK_UNUSED(cppArg6)
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg7{};
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            SBK_UNUSED(cppArg7)
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg8{};
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            SBK_UNUSED(cppArg8)
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg9{};
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            SBK_UNUSED(cppArg9)
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg10{};
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            SBK_UNUSED(cppArg10)
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg11{};
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);
            SBK_UNUSED(cppArg11)
            if (!Shiboken::Object::isValid(pyArgs[12]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg12{};
            if (pythonToCpp[12])
                pythonToCpp[12](pyArgs[12], &cppArg12);
            SBK_UNUSED(cppArg12)

            if (Shiboken::Errors::occurred() == nullptr) {
                // invoke(QObject*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmetamethod-invoke-conn-type-return-arg)]
                pyResult = invokeMetaMethodWithReturn(createInvokeMetaMethodFuncWithReturn(*cppSelf, cppArg0, cppArg1),
                                                      cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12);
                // END of custom code block [file: ../glue/qtcore.cpp (qmetamethod-invoke-conn-type-return-arg)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 6: // invoke(QObject *object, QtCoreHelper::QGenericArgumentHolder val0, QtCoreHelper::QGenericArgumentHolder val1, QtCoreHelper::QGenericArgumentHolder val2, QtCoreHelper::QGenericArgumentHolder val3, QtCoreHelper::QGenericArgumentHolder val4, QtCoreHelper::QGenericArgumentHolder val5, QtCoreHelper::QGenericArgumentHolder val6, QtCoreHelper::QGenericArgumentHolder val7, QtCoreHelper::QGenericArgumentHolder val8, QtCoreHelper::QGenericArgumentHolder val9)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[10] = {{"val0", 1}, {"val1", 2}, {"val2", 3}, {"val3", 4}, {"val4", 5}, {"val5", 6}, {"val6", 7}, {"val7", 8}, {"val8", 9}, {"val9", 10}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 10, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[1]))))
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[2]))))
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[3]))))
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4]))))
                    || (pyArgs[5] != nullptr && !(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5]))))
                    || (pyArgs[6] != nullptr && !(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6]))))
                    || (pyArgs[7] != nullptr && !(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7]))))
                    || (pyArgs[8] != nullptr && !(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8]))))
                    || (pyArgs[9] != nullptr && !(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9]))))
                    || (pyArgs[10] != nullptr && !(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "invoke", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg1{};
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg2{};
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg3{};
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            SBK_UNUSED(cppArg3)
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg4{};
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            SBK_UNUSED(cppArg4)
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg5{};
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            SBK_UNUSED(cppArg5)
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg6{};
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            SBK_UNUSED(cppArg6)
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg7{};
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            SBK_UNUSED(cppArg7)
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg8{};
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            SBK_UNUSED(cppArg8)
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg9{};
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            SBK_UNUSED(cppArg9)
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg10{};
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            SBK_UNUSED(cppArg10)

            if (Shiboken::Errors::occurred() == nullptr) {
                // invoke(QObject*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmetamethod-invoke)]
                pyResult = invokeMetaMethod(createInvokeMetaMethodFunc(*cppSelf, cppArg0),
                                            cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10);
                // END of custom code block [file: ../glue/qtcore.cpp (qmetamethod-invoke)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 7: // invoke(QObject *object, QtCoreHelper::QGenericReturnArgumentHolder ret, QtCoreHelper::QGenericArgumentHolder val0, QtCoreHelper::QGenericArgumentHolder val1, QtCoreHelper::QGenericArgumentHolder val2, QtCoreHelper::QGenericArgumentHolder val3, QtCoreHelper::QGenericArgumentHolder val4, QtCoreHelper::QGenericArgumentHolder val5, QtCoreHelper::QGenericArgumentHolder val6, QtCoreHelper::QGenericArgumentHolder val7, QtCoreHelper::QGenericArgumentHolder val8, QtCoreHelper::QGenericArgumentHolder val9)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[10] = {{"val0", 2}, {"val1", 3}, {"val2", 4}, {"val3", 5}, {"val4", 6}, {"val5", 7}, {"val6", 8}, {"val7", 9}, {"val8", 10}, {"val9", 11}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 10, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[2]))))
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[3]))))
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4]))))
                    || (pyArgs[5] != nullptr && !(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5]))))
                    || (pyArgs[6] != nullptr && !(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6]))))
                    || (pyArgs[7] != nullptr && !(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7]))))
                    || (pyArgs[8] != nullptr && !(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8]))))
                    || (pyArgs[9] != nullptr && !(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9]))))
                    || (pyArgs[10] != nullptr && !(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10]))))
                    || (pyArgs[11] != nullptr && !(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[11]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "invoke", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QtCoreHelper::QGenericReturnArgumentHolder cppArg1 = ::QtCoreHelper::QGenericReturnArgumentHolder(::QMetaType(), static_cast<void*>(nullptr));
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg2{};
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg3{};
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            SBK_UNUSED(cppArg3)
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg4{};
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            SBK_UNUSED(cppArg4)
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg5{};
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            SBK_UNUSED(cppArg5)
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg6{};
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            SBK_UNUSED(cppArg6)
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg7{};
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            SBK_UNUSED(cppArg7)
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg8{};
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            SBK_UNUSED(cppArg8)
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg9{};
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            SBK_UNUSED(cppArg9)
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg10{};
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            SBK_UNUSED(cppArg10)
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg11{};
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);
            SBK_UNUSED(cppArg11)

            if (Shiboken::Errors::occurred() == nullptr) {
                // invoke(QObject*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmetamethod-invoke-return-arg)]
                pyResult = invokeMetaMethodWithReturn(createInvokeMetaMethodFuncWithReturn(*cppSelf, cppArg0),
                                                      cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11);
                // END of custom code block [file: ../glue/qtcore.cpp (qmetamethod-invoke-return-arg)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_invokeOnGadget(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[12];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 12));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "invokeOnGadget", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOOOOOOO:invokeOnGadget", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9]), &(pyArgs[10]), &(pyArgs[11])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMetaMethod::invokeOnGadget(void*,QGenericArgument,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=)const->bool
    // 1: QMetaMethod::invokeOnGadget(void*,QGenericReturnArgument,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=)const->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // invokeOnGadget(void*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // invokeOnGadget(void*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 1; // invokeOnGadget(void*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 1; // invokeOnGadget(void*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 1; // invokeOnGadget(void*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6])))) {
                                if (numArgs == 7) {
                                    overloadId = 1; // invokeOnGadget(void*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                } else if (numArgs >= 8
                                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7])))) {
                                    if (numArgs == 8) {
                                        overloadId = 1; // invokeOnGadget(void*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                    } else if (numArgs >= 9
                                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8])))) {
                                        if (numArgs == 9) {
                                            overloadId = 1; // invokeOnGadget(void*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        } else if (numArgs >= 10
                                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9])))) {
                                            if (numArgs == 10) {
                                                overloadId = 1; // invokeOnGadget(void*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                            } else if (numArgs >= 11
                                                && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10])))) {
                                                if (numArgs == 11) {
                                                    overloadId = 1; // invokeOnGadget(void*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                } else if (numArgs >= 12
                                                    && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11])))) {
                                                    overloadId = 1; // invokeOnGadget(void*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // invokeOnGadget(void*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // invokeOnGadget(void*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // invokeOnGadget(void*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 0; // invokeOnGadget(void*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 0; // invokeOnGadget(void*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6])))) {
                                if (numArgs == 7) {
                                    overloadId = 0; // invokeOnGadget(void*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                } else if (numArgs >= 8
                                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7])))) {
                                    if (numArgs == 8) {
                                        overloadId = 0; // invokeOnGadget(void*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                    } else if (numArgs >= 9
                                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8])))) {
                                        if (numArgs == 9) {
                                            overloadId = 0; // invokeOnGadget(void*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        } else if (numArgs >= 10
                                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9])))) {
                                            if (numArgs == 10) {
                                                overloadId = 0; // invokeOnGadget(void*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                            } else if (numArgs >= 11
                                                && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10])))) {
                                                overloadId = 0; // invokeOnGadget(void*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "invokeOnGadget", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // invokeOnGadget(void *gadget, QGenericArgument val0, QGenericArgument val1, QGenericArgument val2, QGenericArgument val3, QGenericArgument val4, QGenericArgument val5, QGenericArgument val6, QGenericArgument val7, QGenericArgument val8, QGenericArgument val9) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[9] = {{"val1", 2}, {"val2", 3}, {"val3", 4}, {"val4", 5}, {"val5", 6}, {"val6", 7}, {"val7", 8}, {"val8", 9}, {"val9", 10}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 9, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[2]))))
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3]))))
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4]))))
                    || (pyArgs[5] != nullptr && !(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5]))))
                    || (pyArgs[6] != nullptr && !(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6]))))
                    || (pyArgs[7] != nullptr && !(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7]))))
                    || (pyArgs[8] != nullptr && !(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8]))))
                    || (pyArgs[9] != nullptr && !(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9]))))
                    || (pyArgs[10] != nullptr && !(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "invokeOnGadget", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);
                }
            }
            void* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QGenericArgument cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QGenericArgument cppArg2 = QGenericArgument();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QGenericArgument cppArg3 = QGenericArgument();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QGenericArgument cppArg4 = QGenericArgument();
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QGenericArgument cppArg5 = QGenericArgument();
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QGenericArgument cppArg6 = QGenericArgument();
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QGenericArgument cppArg7 = QGenericArgument();
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QGenericArgument cppArg8 = QGenericArgument();
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QGenericArgument cppArg9 = QGenericArgument();
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QGenericArgument cppArg10 = QGenericArgument();
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);

            if (Shiboken::Errors::occurred() == nullptr) {
                // invokeOnGadget(void*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                bool cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->invokeOnGadget(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // invokeOnGadget(void *gadget, QGenericReturnArgument returnValue, QGenericArgument val0, QGenericArgument val1, QGenericArgument val2, QGenericArgument val3, QGenericArgument val4, QGenericArgument val5, QGenericArgument val6, QGenericArgument val7, QGenericArgument val8, QGenericArgument val9) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[10] = {{"val0", 2}, {"val1", 3}, {"val2", 4}, {"val3", 5}, {"val4", 6}, {"val5", 7}, {"val6", 8}, {"val7", 9}, {"val8", 10}, {"val9", 11}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 10, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[2]))))
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3]))))
                    || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4]))))
                    || (pyArgs[5] != nullptr && !(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5]))))
                    || (pyArgs[6] != nullptr && !(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6]))))
                    || (pyArgs[7] != nullptr && !(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7]))))
                    || (pyArgs[8] != nullptr && !(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8]))))
                    || (pyArgs[9] != nullptr && !(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9]))))
                    || (pyArgs[10] != nullptr && !(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10]))))
                    || (pyArgs[11] != nullptr && !(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "invokeOnGadget", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);
                }
            }
            void* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QGenericReturnArgument cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QGenericArgument cppArg2 = QGenericArgument(nullptr);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QGenericArgument cppArg3 = QGenericArgument();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QGenericArgument cppArg4 = QGenericArgument();
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QGenericArgument cppArg5 = QGenericArgument();
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QGenericArgument cppArg6 = QGenericArgument();
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QGenericArgument cppArg7 = QGenericArgument();
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QGenericArgument cppArg8 = QGenericArgument();
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QGenericArgument cppArg9 = QGenericArgument();
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QGenericArgument cppArg10 = QGenericArgument();
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QGenericArgument cppArg11 = QGenericArgument();
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);

            if (Shiboken::Errors::occurred() == nullptr) {
                // invokeOnGadget(void*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                bool cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->invokeOnGadget(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_isConst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isConst()const
        bool cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->isConst();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_methodIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // methodIndex()const
        int cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->methodIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_methodSignature(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // methodSignature()const
        QByteArray cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->methodSignature();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_methodType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // methodType()const
        QMetaMethod::MethodType cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->methodType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_MethodType_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // name()const
        QByteArray cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_nameView(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nameView()const
        QByteArrayView cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->nameView();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QByteArrayView_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_parameterCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parameterCount()const
        int cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->parameterCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_parameterMetaType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaMethod::parameterMetaType(int)const->QMetaType
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // parameterMetaType(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "parameterMetaType", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // parameterMetaType(int)const
            QMetaType cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->parameterMetaType(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_parameterNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parameterNames()const
        QList<QByteArray> cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->parameterNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_parameterType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaMethod::parameterType(int)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // parameterType(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "parameterType", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // parameterType(int)const
            int cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->parameterType(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_parameterTypeName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaMethod::parameterTypeName(int)const->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // parameterTypeName(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "parameterTypeName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // parameterTypeName(int)const
            QByteArray cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->parameterTypeName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_parameterTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parameterTypes()const
        QList<QByteArray> cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->parameterTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_relativeMethodIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // relativeMethodIndex()const
        int cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->relativeMethodIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_returnMetaType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // returnMetaType()const
        QMetaType cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->returnMetaType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_returnType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // returnType()const
        int cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->returnType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_revision(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // revision()const
        int cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->revision();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_tag(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tag()const
        const char * cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->tag();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethodFunc_typeName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // typeName()const
        const char * cppResult = const_cast<const ::QMetaMethod *>(cppSelf)->typeName();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QMetaMethod__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMetaMethod_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QMetaMethod_EnumFlagInfo[] = {
    "Access:Enum",
    "MethodType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMetaMethod_methods[] = {
    {"access", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_access), METH_NOARGS, nullptr},
    {"enclosingMetaObject", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_enclosingMetaObject), METH_NOARGS, nullptr},
    {"fromSignal", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_fromSignal), METH_O|METH_STATIC, nullptr},
    {"invoke", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_invoke), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"invokeOnGadget", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_invokeOnGadget), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isConst", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_isConst), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_isValid), METH_NOARGS, nullptr},
    {"methodIndex", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_methodIndex), METH_NOARGS, nullptr},
    {"methodSignature", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_methodSignature), METH_NOARGS, nullptr},
    {"methodType", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_methodType), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_name), METH_NOARGS, nullptr},
    {"nameView", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_nameView), METH_NOARGS, nullptr},
    {"parameterCount", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_parameterCount), METH_NOARGS, nullptr},
    {"parameterMetaType", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_parameterMetaType), METH_O, nullptr},
    {"parameterNames", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_parameterNames), METH_NOARGS, nullptr},
    {"parameterType", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_parameterType), METH_O, nullptr},
    {"parameterTypeName", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_parameterTypeName), METH_O, nullptr},
    {"parameterTypes", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_parameterTypes), METH_NOARGS, nullptr},
    {"relativeMethodIndex", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_relativeMethodIndex), METH_NOARGS, nullptr},
    {"returnMetaType", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_returnMetaType), METH_NOARGS, nullptr},
    {"returnType", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_returnType), METH_NOARGS, nullptr},
    {"revision", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_revision), METH_NOARGS, nullptr},
    {"tag", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_tag), METH_NOARGS, nullptr},
    {"typeName", reinterpret_cast<PyCFunction>(Sbk_QMetaMethodFunc_typeName), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QMetaMethod__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QMetaMethod_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArg)))) {
                // operator!=(const QMetaMethod &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMetaMethod cppArg0_local;
                ::QMetaMethod *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArg)))) {
                // operator==(const QMetaMethod &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMetaMethod cppArg0_local;
                ::QMetaMethod *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QMetaMethod_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMetaMethod_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMetaMethod_Type = nullptr;
static PyTypeObject *Sbk_QMetaMethod_TypeF(void)
{
    return _Sbk_QMetaMethod_Type;
}

static PyType_Slot Sbk_QMetaMethod_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMetaMethod_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMetaMethod_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QMetaMethod_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMetaMethod_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMetaMethod_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMetaMethod_spec = {
    "2:PySide6.QtCore.QMetaMethod",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMetaMethod_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QMetaMethod_Access(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMetaMethod::Access>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMetaMethod::Access *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMetaMethod_Access_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_Access_IDX])))
        return Enum_PythonToCpp_QMetaMethod_Access;
    return {};
}

static PyObject *QMetaMethod_Access_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMetaMethod::Access>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMetaMethod::Access *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_Access_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QMetaMethod_MethodType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMetaMethod::MethodType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMetaMethod::MethodType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QMetaMethod_MethodType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_MethodType_IDX])))
        return Enum_PythonToCpp_QMetaMethod_MethodType;
    return {};
}

static PyObject *QMetaMethod_MethodType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QMetaMethod::MethodType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QMetaMethod::MethodType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_MethodType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMetaMethod_PythonToCpp_QMetaMethod_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMetaMethod_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMetaMethod_PythonToCpp_QMetaMethod_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMetaMethod_TypeF()))
        return QMetaMethod_PythonToCpp_QMetaMethod_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMetaMethod_PTR_CppToPython_QMetaMethod(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QMetaMethod_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QMetaMethod_COPY_CppToPython_QMetaMethod(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QMetaMethod *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QMetaMethod_TypeF(), new ::QMetaMethod(*source), true, true);
}

// Python to C++ copy conversion.
static void QMetaMethod_PythonToCpp_QMetaMethod_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QMetaMethod *>(cppOut) = *reinterpret_cast< ::QMetaMethod *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QMetaMethod_PythonToCpp_QMetaMethod_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QMetaMethod_TypeF()))
        return QMetaMethod_PythonToCpp_QMetaMethod_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMetaMethod_SignatureStrings[] = {
    "1:PySide6.QtCore.QMetaMethod(self)",
    "0:PySide6.QtCore.QMetaMethod(self,QMetaMethod:PySide6.QtCore.QMetaMethod)",
    "PySide6.QtCore.QMetaMethod.access(self)->PySide6.QtCore.QMetaMethod.Access",
    "PySide6.QtCore.QMetaMethod.enclosingMetaObject(self)->PySide6.QtCore.QMetaObject",
    "PySide6.QtCore.QMetaMethod.fromSignal(signal:PySideSignalInstance)->PySide6.QtCore.QMetaMethod",
    "7:PySide6.QtCore.QMetaMethod.invoke(self,object:PySide6.QtCore.QObject,val0:PySide6.QtCore.QGenericArgument,val1:PySide6.QtCore.QGenericArgument=QGenericArgument(),val2:PySide6.QtCore.QGenericArgument=QGenericArgument(),val3:PySide6.QtCore.QGenericArgument=QGenericArgument(),val4:PySide6.QtCore.QGenericArgument=QGenericArgument(),val5:PySide6.QtCore.QGenericArgument=QGenericArgument(),val6:PySide6.QtCore.QGenericArgument=QGenericArgument(),val7:PySide6.QtCore.QGenericArgument=QGenericArgument(),val8:PySide6.QtCore.QGenericArgument=QGenericArgument(),val9:PySide6.QtCore.QGenericArgument=QGenericArgument())->bool",
    "6:PySide6.QtCore.QMetaMethod.invoke(self,object:PySide6.QtCore.QObject,returnValue:PySide6.QtCore.QGenericReturnArgument,val0:PySide6.QtCore.QGenericArgument=QGenericArgument(nullptr),val1:PySide6.QtCore.QGenericArgument=QGenericArgument(),val2:PySide6.QtCore.QGenericArgument=QGenericArgument(),val3:PySide6.QtCore.QGenericArgument=QGenericArgument(),val4:PySide6.QtCore.QGenericArgument=QGenericArgument(),val5:PySide6.QtCore.QGenericArgument=QGenericArgument(),val6:PySide6.QtCore.QGenericArgument=QGenericArgument(),val7:PySide6.QtCore.QGenericArgument=QGenericArgument(),val8:PySide6.QtCore.QGenericArgument=QGenericArgument(),val9:PySide6.QtCore.QGenericArgument=QGenericArgument())->bool",
    "5:PySide6.QtCore.QMetaMethod.invoke(self,object:PySide6.QtCore.QObject,connectionType:PySide6.QtCore.Qt.ConnectionType,val0:PySide6.QtCore.QGenericArgument,val1:PySide6.QtCore.QGenericArgument=QGenericArgument(),val2:PySide6.QtCore.QGenericArgument=QGenericArgument(),val3:PySide6.QtCore.QGenericArgument=QGenericArgument(),val4:PySide6.QtCore.QGenericArgument=QGenericArgument(),val5:PySide6.QtCore.QGenericArgument=QGenericArgument(),val6:PySide6.QtCore.QGenericArgument=QGenericArgument(),val7:PySide6.QtCore.QGenericArgument=QGenericArgument(),val8:PySide6.QtCore.QGenericArgument=QGenericArgument(),val9:PySide6.QtCore.QGenericArgument=QGenericArgument())->bool",
    "4:PySide6.QtCore.QMetaMethod.invoke(self,object:PySide6.QtCore.QObject,connectionType:PySide6.QtCore.Qt.ConnectionType,returnValue:PySide6.QtCore.QGenericReturnArgument,val0:PySide6.QtCore.QGenericArgument=QGenericArgument(nullptr),val1:PySide6.QtCore.QGenericArgument=QGenericArgument(),val2:PySide6.QtCore.QGenericArgument=QGenericArgument(),val3:PySide6.QtCore.QGenericArgument=QGenericArgument(),val4:PySide6.QtCore.QGenericArgument=QGenericArgument(),val5:PySide6.QtCore.QGenericArgument=QGenericArgument(),val6:PySide6.QtCore.QGenericArgument=QGenericArgument(),val7:PySide6.QtCore.QGenericArgument=QGenericArgument(),val8:PySide6.QtCore.QGenericArgument=QGenericArgument(),val9:PySide6.QtCore.QGenericArgument=QGenericArgument())->bool",
    "3:PySide6.QtCore.QMetaMethod.invoke(self,object:PySide6.QtCore.QObject,type:PySide6.QtCore.Qt.ConnectionType,val0:PySide6.QtCore.QGenericArgumentHolder={},val1:PySide6.QtCore.QGenericArgumentHolder={},val2:PySide6.QtCore.QGenericArgumentHolder={},val3:PySide6.QtCore.QGenericArgumentHolder={},val4:PySide6.QtCore.QGenericArgumentHolder={},val5:PySide6.QtCore.QGenericArgumentHolder={},val6:PySide6.QtCore.QGenericArgumentHolder={},val7:PySide6.QtCore.QGenericArgumentHolder={},val8:PySide6.QtCore.QGenericArgumentHolder={},val9:PySide6.QtCore.QGenericArgumentHolder={})->PyObject",
    "2:PySide6.QtCore.QMetaMethod.invoke(self,object:PySide6.QtCore.QObject,type:PySide6.QtCore.Qt.ConnectionType,ret:PySide6.QtCore.QGenericReturnArgumentHolder,val0:PySide6.QtCore.QGenericArgumentHolder={},val1:PySide6.QtCore.QGenericArgumentHolder={},val2:PySide6.QtCore.QGenericArgumentHolder={},val3:PySide6.QtCore.QGenericArgumentHolder={},val4:PySide6.QtCore.QGenericArgumentHolder={},val5:PySide6.QtCore.QGenericArgumentHolder={},val6:PySide6.QtCore.QGenericArgumentHolder={},val7:PySide6.QtCore.QGenericArgumentHolder={},val8:PySide6.QtCore.QGenericArgumentHolder={},val9:PySide6.QtCore.QGenericArgumentHolder={})->PyObject",
    "1:PySide6.QtCore.QMetaMethod.invoke(self,object:PySide6.QtCore.QObject,val0:PySide6.QtCore.QGenericArgumentHolder={},val1:PySide6.QtCore.QGenericArgumentHolder={},val2:PySide6.QtCore.QGenericArgumentHolder={},val3:PySide6.QtCore.QGenericArgumentHolder={},val4:PySide6.QtCore.QGenericArgumentHolder={},val5:PySide6.QtCore.QGenericArgumentHolder={},val6:PySide6.QtCore.QGenericArgumentHolder={},val7:PySide6.QtCore.QGenericArgumentHolder={},val8:PySide6.QtCore.QGenericArgumentHolder={},val9:PySide6.QtCore.QGenericArgumentHolder={})->PyObject",
    "0:PySide6.QtCore.QMetaMethod.invoke(self,object:PySide6.QtCore.QObject,ret:PySide6.QtCore.QGenericReturnArgumentHolder,val0:PySide6.QtCore.QGenericArgumentHolder={},val1:PySide6.QtCore.QGenericArgumentHolder={},val2:PySide6.QtCore.QGenericArgumentHolder={},val3:PySide6.QtCore.QGenericArgumentHolder={},val4:PySide6.QtCore.QGenericArgumentHolder={},val5:PySide6.QtCore.QGenericArgumentHolder={},val6:PySide6.QtCore.QGenericArgumentHolder={},val7:PySide6.QtCore.QGenericArgumentHolder={},val8:PySide6.QtCore.QGenericArgumentHolder={},val9:PySide6.QtCore.QGenericArgumentHolder={})->PyObject",
    "1:PySide6.QtCore.QMetaMethod.invokeOnGadget(self,gadget:void,val0:PySide6.QtCore.QGenericArgument,val1:PySide6.QtCore.QGenericArgument=QGenericArgument(),val2:PySide6.QtCore.QGenericArgument=QGenericArgument(),val3:PySide6.QtCore.QGenericArgument=QGenericArgument(),val4:PySide6.QtCore.QGenericArgument=QGenericArgument(),val5:PySide6.QtCore.QGenericArgument=QGenericArgument(),val6:PySide6.QtCore.QGenericArgument=QGenericArgument(),val7:PySide6.QtCore.QGenericArgument=QGenericArgument(),val8:PySide6.QtCore.QGenericArgument=QGenericArgument(),val9:PySide6.QtCore.QGenericArgument=QGenericArgument())->bool",
    "0:PySide6.QtCore.QMetaMethod.invokeOnGadget(self,gadget:void,returnValue:PySide6.QtCore.QGenericReturnArgument,val0:PySide6.QtCore.QGenericArgument=QGenericArgument(nullptr),val1:PySide6.QtCore.QGenericArgument=QGenericArgument(),val2:PySide6.QtCore.QGenericArgument=QGenericArgument(),val3:PySide6.QtCore.QGenericArgument=QGenericArgument(),val4:PySide6.QtCore.QGenericArgument=QGenericArgument(),val5:PySide6.QtCore.QGenericArgument=QGenericArgument(),val6:PySide6.QtCore.QGenericArgument=QGenericArgument(),val7:PySide6.QtCore.QGenericArgument=QGenericArgument(),val8:PySide6.QtCore.QGenericArgument=QGenericArgument(),val9:PySide6.QtCore.QGenericArgument=QGenericArgument())->bool",
    "PySide6.QtCore.QMetaMethod.isConst(self)->bool",
    "PySide6.QtCore.QMetaMethod.isValid(self)->bool",
    "PySide6.QtCore.QMetaMethod.methodIndex(self)->int",
    "PySide6.QtCore.QMetaMethod.methodSignature(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QMetaMethod.methodType(self)->PySide6.QtCore.QMetaMethod.MethodType",
    "PySide6.QtCore.QMetaMethod.name(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QMetaMethod.nameView(self)->QByteArrayView",
    "PySide6.QtCore.QMetaMethod.parameterCount(self)->int",
    "PySide6.QtCore.QMetaMethod.parameterMetaType(self,index:int)->PySide6.QtCore.QMetaType",
    "PySide6.QtCore.QMetaMethod.parameterNames(self)->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtCore.QMetaMethod.parameterType(self,index:int)->int",
    "PySide6.QtCore.QMetaMethod.parameterTypeName(self,index:int)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QMetaMethod.parameterTypes(self)->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtCore.QMetaMethod.relativeMethodIndex(self)->int",
    "PySide6.QtCore.QMetaMethod.returnMetaType(self)->PySide6.QtCore.QMetaType",
    "PySide6.QtCore.QMetaMethod.returnType(self)->int",
    "PySide6.QtCore.QMetaMethod.revision(self)->int",
    "PySide6.QtCore.QMetaMethod.tag(self)->char*",
    "PySide6.QtCore.QMetaMethod.typeName(self)->char*",
    "PySide6.QtCore.QMetaMethod.__copy__(self)->typing.Self",
    "PySide6.QtCore.QMetaMethod.__ne__(self,rhs:PySide6.QtCore.QMetaMethod)->bool",
    "PySide6.QtCore.QMetaMethod.__eq__(self,rhs:PySide6.QtCore.QMetaMethod)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QMetaMethod_SignatureByteSize = 632;
static constexpr uint8_t QMetaMethod_SignatureBytes[632] = {
    0x78, 0xda, 0xed, 0x59, 0x5d, 0x6f, 0xd3, 0x30, 0x14, 0x7d, 0xef, 0x2f, 0x69, 0x51, 0x88, 0xfa,
    0xdd, 0xad, 0xd2, 0x90, 0x4a, 0x1f, 0xc6, 0x24, 0xba, 0x51, 0x8a, 0xf6, 0x82, 0x50, 0xe4, 0x25,
    0x77, 0xa9, 0x21, 0xb5, 0x8b, 0xed, 0x14, 0x22, 0xc4, 0x7f, 0xc7, 0x49, 0x9a, 0xd0, 0x52, 0xe2,
    0x38, 0x59, 0x54, 0x04, 0xf8, 0xa1, 0x72, 0xeb, 0x9e, 0x73, 0x72, 0x7d, 0x7d, 0x72, 0x9b, 0x5b,
    0xf7, 0xa6, 0x6f, 0xa2, 0x15, 0xf6, 0x60, 0x6c, 0x2f, 0xc5, 0x9c, 0x32, 0xb0, 0x97, 0x0b, 0x10,
    0x48, 0xbe, 0xd6, 0xd4, 0x6b, 0x73, 0x08, 0x1e, 0x3b, 0xad, 0x6e, 0x19, 0xc4, 0x3a, 0x98, 0x50,
    0x60, 0x3b, 0xad, 0xe2, 0xef, 0x6c, 0xe4, 0xba, 0xc0, 0x79, 0x7a, 0xc5, 0xe7, 0x2f, 0x14, 0xc0,
    0x59, 0x02, 0x54, 0x49, 0x01, 0x71, 0x03, 0xca, 0x31, 0xf1, 0xe3, 0xb9, 0xbb, 0x87, 0x8f, 0xe0,
    0x0a, 0x95, 0x6e, 0x8a, 0x50, 0x09, 0x3e, 0x32, 0xba, 0x59, 0x61, 0x9f, 0xa0, 0xa0, 0xcd, 0x93,
    0x61, 0xbf, 0xc8, 0x74, 0xee, 0x86, 0x70, 0x81, 0x88, 0x0b, 0xca, 0xb0, 0x5b, 0x13, 0x45, 0x62,
    0x6c, 0x4c, 0x76, 0xf4, 0x13, 0xa4, 0xb9, 0xa4, 0x49, 0x38, 0x27, 0xe8, 0x34, 0x4a, 0x6b, 0x87,
    0x82, 0xd3, 0xed, 0xb8, 0x06, 0x02, 0x0c, 0xbb, 0x33, 0xe6, 0x87, 0x1b, 0x20, 0x09, 0xa8, 0x57,
    0x06, 0xba, 0xfa, 0x75, 0xa2, 0xdd, 0x89, 0x79, 0xfd, 0x9a, 0xbc, 0x41, 0x4d, 0xde, 0xb0, 0x26,
    0x6f, 0x54, 0x93, 0x37, 0xae, 0xc9, 0x9b, 0xd4, 0xe4, 0x5d, 0xd4, 0xe4, 0x5d, 0xd6, 0xe0, 0x49,
    0x03, 0x3e, 0x50, 0x1a, 0xb4, 0xc6, 0xcd, 0x58, 0x8d, 0x81, 0x08, 0x19, 0xb9, 0x47, 0x41, 0x08,
    0x45, 0xc1, 0xbc, 0x4d, 0x20, 0x87, 0xbe, 0xeb, 0x56, 0x8f, 0x9b, 0x84, 0x41, 0xb0, 0x15, 0xac,
    0x63, 0x6c, 0xfb, 0x7f, 0xdb, 0x76, 0xd4, 0x8c, 0x6d, 0x5d, 0x4a, 0x88, 0x1c, 0x31, 0x25, 0xef,
    0xa2, 0xed, 0xa9, 0x73, 0x85, 0x3d, 0x3f, 0x02, 0x98, 0x8a, 0x6a, 0xac, 0x59, 0x6a, 0xcd, 0xe1,
    0x9f, 0xb1, 0xa6, 0xa9, 0xc0, 0xc6, 0xe6, 0xe7, 0xb4, 0xf9, 0xa0, 0x19, 0x9b, 0x8b, 0xc6, 0xea,
    0xee, 0x2b, 0x1a, 0x78, 0xc0, 0xae, 0xbe, 0x7d, 0xd7, 0x72, 0xe6, 0x11, 0xba, 0x5f, 0x09, 0x3d,
    0xa8, 0x84, 0x1e, 0x56, 0x42, 0x8f, 0x2a, 0xa1, 0xc7, 0x95, 0xd0, 0x93, 0x4a, 0xe8, 0x8b, 0x4a,
    0xe8, 0x4b, 0x6d, 0x74, 0xd2, 0xf9, 0xec, 0xdb, 0xa8, 0xfe, 0x39, 0x3d, 0x24, 0x0b, 0xa4, 0x5e,
    0x61, 0x4c, 0x43, 0x35, 0x9e, 0xfb, 0x37, 0x3d, 0xd7, 0x3b, 0x5f, 0x6f, 0x6d, 0xdc, 0xf1, 0xd7,
    0xb9, 0xa3, 0xdb, 0x58, 0x3b, 0x6c, 0x6a, 0x8d, 0x71, 0x93, 0x46, 0xad, 0xb9, 0x23, 0xd7, 0xc8,
    0xf3, 0x21, 0xfd, 0xd3, 0xd1, 0xf2, 0x93, 0xf7, 0xd3, 0x1d, 0xc5, 0x9e, 0xe9, 0x35, 0xcd, 0x43,
    0x78, 0xe9, 0x43, 0x78, 0xf7, 0x29, 0x06, 0x33, 0x1d, 0xa3, 0x31, 0xeb, 0x39, 0xcd, 0xaa, 0xb2,
    0x2a, 0x97, 0x0f, 0xeb, 0x3c, 0x3f, 0x79, 0x29, 0x87, 0x4b, 0xd7, 0x62, 0x4f, 0x17, 0xbe, 0x49,
    0x86, 0x1b, 0xe2, 0xc1, 0xd7, 0x8c, 0x82, 0x89, 0x28, 0x67, 0x24, 0x47, 0x36, 0xf2, 0x06, 0x80,
    0xa2, 0x13, 0xa1, 0x97, 0x91, 0x80, 0x19, 0x63, 0x28, 0x2a, 0xd7, 0x8a, 0x5b, 0x10, 0x8d, 0x03,
    0xab, 0x45, 0x0e, 0x56, 0x49, 0x12, 0xb4, 0x79, 0x5a, 0x4c, 0xb1, 0xc0, 0x3d, 0x86, 0x2f, 0x99,
    0xc8, 0x4f, 0x56, 0x3c, 0xab, 0x62, 0x6e, 0x11, 0x93, 0x5c, 0x01, 0x6c, 0x4e, 0x43, 0x22, 0x34,
    0xd3, 0x99, 0x93, 0xe2, 0xb9, 0x3c, 0x13, 0x16, 0x8e, 0x77, 0x64, 0x2a, 0xb9, 0x05, 0x39, 0x29,
    0x4b, 0x43, 0x2e, 0x7b, 0x2b, 0x87, 0xfc, 0x38, 0x70, 0xf9, 0x1a, 0x73, 0xf1, 0xbe, 0x30, 0x2d,
    0x1f, 0xb4, 0x14, 0x7f, 0x1f, 0xa4, 0xee, 0x32, 0x63, 0xf6, 0x6d, 0xb6, 0x47, 0xca, 0x65, 0x6a,
    0xed, 0xd6, 0x91, 0x6e, 0x23, 0xeb, 0x64, 0x10, 0x20, 0x81, 0x77, 0xb0, 0xa8, 0x7c, 0x67, 0xa4,
    0x3f, 0x1a, 0x47, 0xfb, 0x58, 0x73, 0xf7, 0x52, 0xa5, 0x43, 0x95, 0xd2, 0x4b, 0xef, 0x30, 0x97,
    0xdd, 0xbc, 0x26, 0x5c, 0x20, 0x3f, 0x43, 0xba, 0x6b, 0xc4, 0x9e, 0x29, 0xb1, 0x87, 0x1b, 0xa6,
    0x43, 0x70, 0x1c, 0x97, 0x6e, 0x23, 0xc7, 0xc9, 0x08, 0x52, 0x00, 0x13, 0xdf, 0x5e, 0xc9, 0x4f,
    0x6a, 0x1a, 0x81, 0x3d, 0xc9, 0x62, 0x6b, 0xae, 0x3a, 0xff, 0x2e, 0x2f, 0x6b, 0x8e, 0x03, 0x9f,
    0xab, 0x89, 0xfd, 0x00, 0xf1, 0x0c, 0x7d, 0x31
};
#endif

PyTypeObject *init_QMetaMethod(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX].type;

    Shiboken::AutoDecRef Sbk_QMetaMethod_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QMetaMethod_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMetaMethod",
        "QMetaMethod",
        &Sbk_QMetaMethod_spec,
        &Shiboken::callCppDestructor< ::QMetaMethod >,
        Sbk_QMetaMethod_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QMetaMethod_TypeF(); // references _Sbk_QMetaMethod_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMetaMethod_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMetaMethod_SignatureBytes, QMetaMethod_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMetaMethod_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMetaMethod_PythonToCpp_QMetaMethod_PTR,
        is_QMetaMethod_PythonToCpp_QMetaMethod_PTR_Convertible,
        QMetaMethod_PTR_CppToPython_QMetaMethod,
        QMetaMethod_COPY_CppToPython_QMetaMethod);

    Shiboken::Conversions::registerConverterName(converter, "QMetaMethod");
    Shiboken::Conversions::registerConverterName(converter, "QMetaMethod*");
    Shiboken::Conversions::registerConverterName(converter, "QMetaMethod&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMetaMethod).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QMetaMethod_PythonToCpp_QMetaMethod_COPY,
        is_QMetaMethod_PythonToCpp_QMetaMethod_COPY_Convertible);


    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QMetaMethod_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Access'.
    const char *Access_Initializer[] = {
        "Private",
        "Protected",
        "Public",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Access_InitializerValues[] = {
        uint8_t(QMetaMethod::Access::Private),   //  0x00  0
        uint8_t(QMetaMethod::Access::Protected), //  0x01  1
        uint8_t(QMetaMethod::Access::Public)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMetaMethod_TypeF(),
        "2:PySide6.QtCore.QMetaMethod.Access",
        Access_Initializer, Access_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_Access_IDX].type = EType;
    // Register converter for enum 'QMetaMethod::Access'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMetaMethod_Access_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMetaMethod_Access,
            is_Enum_PythonToCpp_QMetaMethod_Access_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMetaMethod::Access");
        Shiboken::Conversions::registerConverterAlias(converter, "Access");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Access' enum.

    // Initialization of enum 'MethodType'.
    const char *MethodType_Initializer[] = {
        "Method",
        "Signal",
        "Slot",
        "Constructor",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MethodType_InitializerValues[] = {
        uint8_t(QMetaMethod::MethodType::Method),     //  0x00  0
        uint8_t(QMetaMethod::MethodType::Signal),     //  0x01  1
        uint8_t(QMetaMethod::MethodType::Slot),       //  0x02  2
        uint8_t(QMetaMethod::MethodType::Constructor) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMetaMethod_TypeF(),
        "2:PySide6.QtCore.QMetaMethod.MethodType",
        MethodType_Initializer, MethodType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_MethodType_IDX].type = EType;
    // Register converter for enum 'QMetaMethod::MethodType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMetaMethod_MethodType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QMetaMethod_MethodType,
            is_Enum_PythonToCpp_QMetaMethod_MethodType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QMetaMethod::MethodType");
        Shiboken::Conversions::registerConverterAlias(converter, "MethodType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'MethodType' enum.


    qRegisterMetaType< ::QMetaMethod >("QMetaMethod");
    qRegisterMetaType< ::QMetaMethod::Access >("QMetaMethod::Access");
    qRegisterMetaType< ::QMetaMethod::MethodType >("QMetaMethod::MethodType");

    return pyType;
}

