// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qsortfilterproxymodel_wrapper.h"

// Wrappers providing overrides
#include "qabstractitemmodel_wrapper.h"
#include "qsortfilterproxymodel_wrapper.h"
#include "qabstractproxymodel_wrapper.h"
#include "qconcatenatetablesproxymodel_wrapper.h"
#include "qobject_wrapper.h"
#include "qrunnable_wrapper.h"
#include "qtranslator_wrapper.h"
#include "qmimedata_wrapper.h"

// Extra includes
#include <QItemSelection>
#include <QSize>
#include <QStringList>

// Argument includes
#include <QHash>
#include <QList>
#include <QMap>
#include <QString>
#include <QStringList>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qmimedata.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qregularexpression.h>
#include <qsize.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSortFilterProxyModelWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSortFilterProxyModelWrapper::QSortFilterProxyModelWrapper(::QObject * parent) : QSortFilterProxyModel(parent)
{
}

::QModelIndex QSortFilterProxyModelWrapper::buddy(const ::QModelIndex & index) const
{
    static const char *funcName = "buddy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::buddy(index);
    }
    return QAbstractItemModelWrapper::sbk_o_buddy("QSortFilterProxyModel", funcName, gil, pyOverride, index);
}

bool QSortFilterProxyModelWrapper::canDropMimeData(const ::QMimeData * data, ::Qt::DropAction action, int row, int column, const ::QModelIndex & parent) const
{
    static const char *funcName = "canDropMimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::canDropMimeData(data, action, row, column, parent);
    }
    return QAbstractItemModelWrapper::sbk_o_canDropMimeData("QSortFilterProxyModel", funcName, gil, pyOverride, data, action, row, column, parent);
}

bool QSortFilterProxyModelWrapper::canFetchMore(const ::QModelIndex & parent) const
{
    static const char *funcName = "canFetchMore";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::canFetchMore(parent);
    }
    return QAbstractItemModelWrapper::sbk_o_canFetchMore("QSortFilterProxyModel", funcName, gil, pyOverride, parent);
}

void QSortFilterProxyModelWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QTranslatorWrapper::sbk_o_childEvent("QSortFilterProxyModel", funcName, gil, pyOverride, event);
}

bool QSortFilterProxyModelWrapper::clearItemData(const ::QModelIndex & index)
{
    static const char *funcName = "clearItemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::clearItemData(index);
    }
    return QAbstractItemModelWrapper::sbk_o_canFetchMore("QSortFilterProxyModel", funcName, gil, pyOverride, index);
}

int QSortFilterProxyModelWrapper::columnCount(const ::QModelIndex & parent) const
{
    static const char *funcName = "columnCount";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::columnCount(parent);
    }
    return QAbstractItemModelWrapper::sbk_o_columnCount("QSortFilterProxyModel", funcName, gil, pyOverride, parent);
}

void QSortFilterProxyModelWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QSortFilterProxyModel", funcName, gil, pyOverride, signal);
}

void QSortFilterProxyModelWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QTranslatorWrapper::sbk_o_customEvent("QSortFilterProxyModel", funcName, gil, pyOverride, event);
}

::QVariant QSortFilterProxyModelWrapper::data(const ::QModelIndex & index, int role) const
{
    static const char *funcName = "data";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::data(index, role);
    }
    return QConcatenateTablesProxyModelWrapper::sbk_o_data("QSortFilterProxyModel", funcName, gil, pyOverride, index, role);
}

void QSortFilterProxyModelWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QObjectWrapper::sbk_o_connectNotify("QSortFilterProxyModel", funcName, gil, pyOverride, signal);
}

bool QSortFilterProxyModelWrapper::dropMimeData(const ::QMimeData * data, ::Qt::DropAction action, int row, int column, const ::QModelIndex & parent)
{
    static const char *funcName = "dropMimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::dropMimeData(data, action, row, column, parent);
    }
    return QAbstractItemModelWrapper::sbk_o_canDropMimeData("QSortFilterProxyModel", funcName, gil, pyOverride, data, action, row, column, parent);
}

bool QSortFilterProxyModelWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QTranslatorWrapper::sbk_o_event("QSortFilterProxyModel", funcName, gil, pyOverride, event);
}

bool QSortFilterProxyModelWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QTranslatorWrapper::sbk_o_eventFilter("QSortFilterProxyModel", funcName, gil, pyOverride, watched, event);
}

void QSortFilterProxyModelWrapper::fetchMore(const ::QModelIndex & parent)
{
    static const char *funcName = "fetchMore";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::fetchMore(parent);
    }
    QAbstractItemModelWrapper::sbk_o_fetchMore("QSortFilterProxyModel", funcName, gil, pyOverride, parent);
}

bool QSortFilterProxyModelWrapper::filterAcceptsColumn(int source_column, const ::QModelIndex & source_parent) const
{
    static const char *funcName = "filterAcceptsColumn";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::filterAcceptsColumn(source_column, source_parent);
    }
    return sbk_o_filterAcceptsColumn("QSortFilterProxyModel", funcName, gil, pyOverride, source_column, source_parent);
}

bool QSortFilterProxyModelWrapper::sbk_o_filterAcceptsColumn(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, int source_column, const ::QModelIndex & source_parent)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &source_column),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &source_parent)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(iN)",
        source_column,
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &source_parent)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSortFilterProxyModelWrapper::filterAcceptsRow(int source_row, const ::QModelIndex & source_parent) const
{
    static const char *funcName = "filterAcceptsRow";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::filterAcceptsRow(source_row, source_parent);
    }
    return QSortFilterProxyModelWrapper::sbk_o_filterAcceptsColumn("QSortFilterProxyModel", funcName, gil, pyOverride, source_row, source_parent);
}

::QFlags<Qt::ItemFlag> QSortFilterProxyModelWrapper::flags(const ::QModelIndex & index) const
{
    static const char *funcName = "flags";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::flags(index);
    }
    return QAbstractItemModelWrapper::sbk_o_flags("QSortFilterProxyModel", funcName, gil, pyOverride, index);
}

bool QSortFilterProxyModelWrapper::hasChildren(const ::QModelIndex & parent) const
{
    static const char *funcName = "hasChildren";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::hasChildren(parent);
    }
    return QAbstractItemModelWrapper::sbk_o_canFetchMore("QSortFilterProxyModel", funcName, gil, pyOverride, parent);
}

::QVariant QSortFilterProxyModelWrapper::headerData(int section, ::Qt::Orientation orientation, int role) const
{
    static const char *funcName = "headerData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::headerData(section, orientation, role);
    }
    return QAbstractItemModelWrapper::sbk_o_headerData("QSortFilterProxyModel", funcName, gil, pyOverride, section, orientation, role);
}

::QModelIndex QSortFilterProxyModelWrapper::index(int row, int column, const ::QModelIndex & parent) const
{
    static const char *funcName = "index";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::index(row, column, parent);
    }
    return QAbstractItemModelWrapper::sbk_o_index("QSortFilterProxyModel", funcName, gil, pyOverride, row, column, parent);
}

bool QSortFilterProxyModelWrapper::insertColumns(int column, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "insertColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::insertColumns(column, count, parent);
    }
    return QAbstractItemModelWrapper::sbk_o_insertColumns("QSortFilterProxyModel", funcName, gil, pyOverride, column, count, parent);
}

bool QSortFilterProxyModelWrapper::insertRows(int row, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "insertRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::insertRows(row, count, parent);
    }
    return QAbstractItemModelWrapper::sbk_o_insertColumns("QSortFilterProxyModel", funcName, gil, pyOverride, row, count, parent);
}

::QMap<int,QVariant> QSortFilterProxyModelWrapper::itemData(const ::QModelIndex & index) const
{
    static const char *funcName = "itemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::itemData(index);
    }
    return QAbstractItemModelWrapper::sbk_o_itemData("QSortFilterProxyModel", funcName, gil, pyOverride, index);
}

bool QSortFilterProxyModelWrapper::lessThan(const ::QModelIndex & source_left, const ::QModelIndex & source_right) const
{
    static const char *funcName = "lessThan";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::lessThan(source_left, source_right);
    }
    return sbk_o_lessThan("QSortFilterProxyModel", funcName, gil, pyOverride, source_left, source_right);
}

bool QSortFilterProxyModelWrapper::sbk_o_lessThan(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & source_left, const ::QModelIndex & source_right)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &source_left),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &source_right)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &source_left),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &source_right)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QModelIndex QSortFilterProxyModelWrapper::mapFromSource(const ::QModelIndex & sourceIndex) const
{
    static const char *funcName = "mapFromSource";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::mapFromSource(sourceIndex);
    }
    return QAbstractItemModelWrapper::sbk_o_buddy("QSortFilterProxyModel", funcName, gil, pyOverride, sourceIndex);
}

::QItemSelection QSortFilterProxyModelWrapper::mapSelectionFromSource(const ::QItemSelection & sourceSelection) const
{
    static const char *funcName = "mapSelectionFromSource";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::mapSelectionFromSource(sourceSelection);
    }
    return QAbstractProxyModelWrapper::sbk_o_mapSelectionFromSource("QSortFilterProxyModel", funcName, gil, pyOverride, sourceSelection);
}

::QItemSelection QSortFilterProxyModelWrapper::mapSelectionToSource(const ::QItemSelection & proxySelection) const
{
    static const char *funcName = "mapSelectionToSource";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::mapSelectionToSource(proxySelection);
    }
    return QAbstractProxyModelWrapper::sbk_o_mapSelectionFromSource("QSortFilterProxyModel", funcName, gil, pyOverride, proxySelection);
}

::QModelIndex QSortFilterProxyModelWrapper::mapToSource(const ::QModelIndex & proxyIndex) const
{
    static const char *funcName = "mapToSource";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::mapToSource(proxyIndex);
    }
    return QAbstractItemModelWrapper::sbk_o_buddy("QSortFilterProxyModel", funcName, gil, pyOverride, proxyIndex);
}

::QList<QModelIndex> QSortFilterProxyModelWrapper::match(const ::QModelIndex & start, int role, const ::QVariant & value, int hits, ::QFlags<Qt::MatchFlag> flags) const
{
    static const char *funcName = "match";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::match(start, role, value, hits, flags);
    }
    return QAbstractItemModelWrapper::sbk_o_match("QSortFilterProxyModel", funcName, gil, pyOverride, start, role, value, hits, flags);
}

::QMimeData * QSortFilterProxyModelWrapper::mimeData(const ::QList<QModelIndex> & indexes) const
{
    static const char *funcName = "mimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::mimeData(indexes);
    }
    return QConcatenateTablesProxyModelWrapper::sbk_o_mimeData("QSortFilterProxyModel", funcName, gil, pyOverride, indexes);
}

::QStringList QSortFilterProxyModelWrapper::mimeTypes() const
{
    static const char *funcName = "mimeTypes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::mimeTypes();
    }
    return QMimeDataWrapper::sbk_o_formats("QSortFilterProxyModel", funcName, gil, pyOverride);
}

bool QSortFilterProxyModelWrapper::moveColumns(const ::QModelIndex & sourceParent, int sourceColumn, int count, const ::QModelIndex & destinationParent, int destinationChild)
{
    static const char *funcName = "moveColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::moveColumns(sourceParent, sourceColumn, count, destinationParent, destinationChild);
    }
    return QAbstractItemModelWrapper::sbk_o_moveColumns("QSortFilterProxyModel", funcName, gil, pyOverride, sourceParent, sourceColumn, count, destinationParent, destinationChild);
}

bool QSortFilterProxyModelWrapper::moveRows(const ::QModelIndex & sourceParent, int sourceRow, int count, const ::QModelIndex & destinationParent, int destinationChild)
{
    static const char *funcName = "moveRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::moveRows(sourceParent, sourceRow, count, destinationParent, destinationChild);
    }
    return QAbstractItemModelWrapper::sbk_o_moveColumns("QSortFilterProxyModel", funcName, gil, pyOverride, sourceParent, sourceRow, count, destinationParent, destinationChild);
}

void QSortFilterProxyModelWrapper::multiData(const ::QModelIndex & index, ::QModelRoleDataSpan roleDataSpan) const
{
    static const char *funcName = "multiData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::multiData(index, roleDataSpan);
    }
    QAbstractItemModelWrapper::sbk_o_multiData("QSortFilterProxyModel", funcName, gil, pyOverride, index, roleDataSpan);
}

::QModelIndex QSortFilterProxyModelWrapper::parent(const ::QModelIndex & child) const
{
    static const char *funcName = "parent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::parent(child);
    }
    return QAbstractItemModelWrapper::sbk_o_buddy("QSortFilterProxyModel", funcName, gil, pyOverride, child);
}

bool QSortFilterProxyModelWrapper::removeColumns(int column, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "removeColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::removeColumns(column, count, parent);
    }
    return QAbstractItemModelWrapper::sbk_o_insertColumns("QSortFilterProxyModel", funcName, gil, pyOverride, column, count, parent);
}

bool QSortFilterProxyModelWrapper::removeRows(int row, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "removeRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::removeRows(row, count, parent);
    }
    return QAbstractItemModelWrapper::sbk_o_insertColumns("QSortFilterProxyModel", funcName, gil, pyOverride, row, count, parent);
}

void QSortFilterProxyModelWrapper::resetInternalData()
{
    static const char *funcName = "resetInternalData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::resetInternalData();
    }
    QRunnableWrapper::sbk_o_run("QSortFilterProxyModel", funcName, gil, pyOverride);
}

void QSortFilterProxyModelWrapper::revert()
{
    static const char *funcName = "revert";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::revert();
    }
    QRunnableWrapper::sbk_o_run("QSortFilterProxyModel", funcName, gil, pyOverride);
}

::QHash<int,QByteArray> QSortFilterProxyModelWrapper::roleNames() const
{
    static const char *funcName = "roleNames";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::roleNames();
    }
    return QAbstractItemModelWrapper::sbk_o_roleNames("QSortFilterProxyModel", funcName, gil, pyOverride);
}

int QSortFilterProxyModelWrapper::rowCount(const ::QModelIndex & parent) const
{
    static const char *funcName = "rowCount";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::rowCount(parent);
    }
    return QAbstractItemModelWrapper::sbk_o_columnCount("QSortFilterProxyModel", funcName, gil, pyOverride, parent);
}

bool QSortFilterProxyModelWrapper::setData(const ::QModelIndex & index, const ::QVariant & value, int role)
{
    static const char *funcName = "setData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::setData(index, value, role);
    }
    return QAbstractItemModelWrapper::sbk_o_setData("QSortFilterProxyModel", funcName, gil, pyOverride, index, value, role);
}

bool QSortFilterProxyModelWrapper::setHeaderData(int section, ::Qt::Orientation orientation, const ::QVariant & value, int role)
{
    static const char *funcName = "setHeaderData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::setHeaderData(section, orientation, value, role);
    }
    return QAbstractItemModelWrapper::sbk_o_setHeaderData("QSortFilterProxyModel", funcName, gil, pyOverride, section, orientation, value, role);
}

bool QSortFilterProxyModelWrapper::setItemData(const ::QModelIndex & index, const ::QMap<int,QVariant> & roles)
{
    static const char *funcName = "setItemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::setItemData(index, roles);
    }
    return QAbstractItemModelWrapper::sbk_o_setItemData("QSortFilterProxyModel", funcName, gil, pyOverride, index, roles);
}

void QSortFilterProxyModelWrapper::setSourceModel(::QAbstractItemModel * sourceModel)
{
    static const char *funcName = "setSourceModel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::setSourceModel(sourceModel);
    }
    sbk_o_setSourceModel("QSortFilterProxyModel", funcName, gil, pyOverride, sourceModel);
}

void QSortFilterProxyModelWrapper::sbk_o_setSourceModel(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAbstractItemModel * sourceModel)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), sourceModel)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), sourceModel)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

::QModelIndex QSortFilterProxyModelWrapper::sibling(int row, int column, const ::QModelIndex & idx) const
{
    static const char *funcName = "sibling";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::sibling(row, column, idx);
    }
    return QAbstractItemModelWrapper::sbk_o_index("QSortFilterProxyModel", funcName, gil, pyOverride, row, column, idx);
}

void QSortFilterProxyModelWrapper::sort(int column, ::Qt::SortOrder order)
{
    static const char *funcName = "sort";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::sort(column, order);
    }
    QAbstractItemModelWrapper::sbk_o_sort("QSortFilterProxyModel", funcName, gil, pyOverride, column, order);
}

::QSize QSortFilterProxyModelWrapper::span(const ::QModelIndex & index) const
{
    static const char *funcName = "span";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::span(index);
    }
    return QAbstractItemModelWrapper::sbk_o_span("QSortFilterProxyModel", funcName, gil, pyOverride, index);
}

bool QSortFilterProxyModelWrapper::submit()
{
    static const char *funcName = "submit";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::submit();
    }
    return QTranslatorWrapper::sbk_o_isEmpty("QSortFilterProxyModel", funcName, gil, pyOverride);
}

::QFlags<Qt::DropAction> QSortFilterProxyModelWrapper::supportedDragActions() const
{
    static const char *funcName = "supportedDragActions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::supportedDragActions();
    }
    return QAbstractItemModelWrapper::sbk_o_supportedDragActions("QSortFilterProxyModel", funcName, gil, pyOverride);
}

::QFlags<Qt::DropAction> QSortFilterProxyModelWrapper::supportedDropActions() const
{
    static const char *funcName = "supportedDropActions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::supportedDropActions();
    }
    return QAbstractItemModelWrapper::sbk_o_supportedDragActions("QSortFilterProxyModel", funcName, gil, pyOverride);
}

void QSortFilterProxyModelWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QTranslatorWrapper::sbk_o_timerEvent("QSortFilterProxyModel", funcName, gil, pyOverride, event);
}

const QMetaObject *QSortFilterProxyModelWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSortFilterProxyModel::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSortFilterProxyModelWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSortFilterProxyModel::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSortFilterProxyModelWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QSortFilterProxyModelWrapper *>(this));
    return QSortFilterProxyModel::qt_metacast(_clname);
}

QSortFilterProxyModelWrapper::~QSortFilterProxyModelWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSortFilterProxyModel_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSortFilterProxyModel >()))
        return -1;

    QSortFilterProxyModelWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QSortFilterProxyModel", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSortFilterProxyModel::QSortFilterProxyModel(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QSortFilterProxyModel(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QSortFilterProxyModel(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSortFilterProxyModel(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QSortFilterProxyModelWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QSortFilterProxyModelWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSortFilterProxyModel >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QSortFilterProxyModelFunc_autoAcceptChildRows(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoAcceptChildRows()const
        bool cppResult = const_cast<const ::QSortFilterProxyModel *>(cppSelf)->autoAcceptChildRows();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_beginFilterChange(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // beginFilterChange()
        cppSelf->beginFilterChange();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_buddy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemModel::buddy(QModelIndex)const->QModelIndex
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // buddy(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "buddy", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // buddy(QModelIndex)const
            QModelIndex cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::buddy(*cppArg0)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->buddy(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_canFetchMore(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemModel::canFetchMore(QModelIndex)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // canFetchMore(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "canFetchMore", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // canFetchMore(QModelIndex)const
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::canFetchMore(*cppArg0)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->canFetchMore(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_columnCount(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "columnCount", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|O:columnCount", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::columnCount(const QModelIndex&=)const->int
    if (numArgs == 0) {
        overloadId = 0; // columnCount(QModelIndex)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        overloadId = 0; // columnCount(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "columnCount", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "columnCount", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local = QModelIndex();
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // columnCount(QModelIndex)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::columnCount(*cppArg0)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->columnCount(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_data(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|OO:data", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::data(QModelIndex,int=)const->QVariant
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // data(QModelIndex,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // data(QModelIndex,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1 = Qt::DisplayRole;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // data(QModelIndex,int)const
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::data(*cppArg0, cppArg1)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->data(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_dropMimeData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "dropMimeData", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::dropMimeData(const QMimeData*,Qt::DropAction,int,int,QModelIndex)->bool
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DropAction_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[4])))) {
        overloadId = 0; // dropMimeData(const QMimeData*,Qt::DropAction,int,int,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dropMimeData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QMimeData *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::DropAction cppArg1{Qt::IgnoreAction};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        if (!Shiboken::Object::isValid(pyArgs[4]))
            return {};
        ::QModelIndex cppArg4_local;
        ::QModelIndex *cppArg4 = &cppArg4_local;
        if (pythonToCpp[4].isValue())
            pythonToCpp[4](pyArgs[4], &cppArg4_local);
        else
            pythonToCpp[4](pyArgs[4], &cppArg4);


        if (Shiboken::Errors::occurred() == nullptr) {
            // dropMimeData(const QMimeData*,Qt::DropAction,int,int,QModelIndex)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSortFilterProxyModel::dropMimeData(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4)
                : cppSelf->dropMimeData(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_dynamicSortFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dynamicSortFilter()const
        bool cppResult = const_cast<const ::QSortFilterProxyModel *>(cppSelf)->dynamicSortFilter();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_fetchMore(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemModel::fetchMore(QModelIndex)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // fetchMore(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fetchMore", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fetchMore(QModelIndex)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSortFilterProxyModel::fetchMore(*cppArg0)
                : cppSelf->fetchMore(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_filterAcceptsColumn(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "filterAcceptsColumn", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSortFilterProxyModel::filterAcceptsColumn(int,QModelIndex)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[1])))) {
        overloadId = 0; // filterAcceptsColumn(int,QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "filterAcceptsColumn", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QModelIndex cppArg1_local;
        ::QModelIndex *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // filterAcceptsColumn(int,QModelIndex)const
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::filterAcceptsColumn(cppArg0, *cppArg1)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->filterAcceptsColumn(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_filterAcceptsRow(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "filterAcceptsRow", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSortFilterProxyModel::filterAcceptsRow(int,QModelIndex)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[1])))) {
        overloadId = 0; // filterAcceptsRow(int,QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "filterAcceptsRow", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QModelIndex cppArg1_local;
        ::QModelIndex *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // filterAcceptsRow(int,QModelIndex)const
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::filterAcceptsRow(cppArg0, *cppArg1)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->filterAcceptsRow(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_filterCaseSensitivity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filterCaseSensitivity()const
        Qt::CaseSensitivity cppResult = const_cast<const ::QSortFilterProxyModel *>(cppSelf)->filterCaseSensitivity();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CaseSensitivity_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_filterKeyColumn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filterKeyColumn()const
        int cppResult = const_cast<const ::QSortFilterProxyModel *>(cppSelf)->filterKeyColumn();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_filterRegularExpression(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filterRegularExpression()const
        QRegularExpression cppResult = const_cast<const ::QSortFilterProxyModel *>(cppSelf)->filterRegularExpression();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_filterRole(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filterRole()const
        int cppResult = const_cast<const ::QSortFilterProxyModel *>(cppSelf)->filterRole();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_flags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemModel::flags(QModelIndex)const->QFlags<Qt::ItemFlag>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // flags(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "flags", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // flags(QModelIndex)const
            QFlags<Qt::ItemFlag> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::flags(*cppArg0)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->flags(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ItemFlag_IDX])))->flagsConverter, &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_hasChildren(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "hasChildren", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|O:hasChildren", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::hasChildren(const QModelIndex&=)const->bool
    if (numArgs == 0) {
        overloadId = 0; // hasChildren(QModelIndex)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        overloadId = 0; // hasChildren(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "hasChildren", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "hasChildren", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local = QModelIndex();
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasChildren(QModelIndex)const
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::hasChildren(*cppArg0)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->hasChildren(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_headerData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "headerData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:headerData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::headerData(int,Qt::Orientation,int=)const->QVariant
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // headerData(int,Qt::Orientation,int)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 0; // headerData(int,Qt::Orientation,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "headerData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "headerData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::Orientation cppArg1 = static_cast< ::Qt::Orientation>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = Qt::DisplayRole;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // headerData(int,Qt::Orientation,int)const
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::headerData(cppArg0, cppArg1, cppArg2)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->headerData(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_index(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "index", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:index", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::index(int,int,const QModelIndex&=)const->QModelIndex
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // index(int,int,QModelIndex)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2])))) {
            overloadId = 0; // index(int,int,QModelIndex)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "index", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "index", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QModelIndex cppArg2_local = QModelIndex();
        ::QModelIndex *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // index(int,int,QModelIndex)const
            QModelIndex cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::index(cppArg0, cppArg1, *cppArg2)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->index(cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_insertColumns(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "insertColumns", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:insertColumns", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::insertColumns(int,int,const QModelIndex&=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // insertColumns(int,int,QModelIndex)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2])))) {
            overloadId = 0; // insertColumns(int,int,QModelIndex)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertColumns", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "insertColumns", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QModelIndex cppArg2_local = QModelIndex();
        ::QModelIndex *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertColumns(int,int,QModelIndex)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSortFilterProxyModel::insertColumns(cppArg0, cppArg1, *cppArg2)
                : cppSelf->insertColumns(cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_insertRows(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "insertRows", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:insertRows", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::insertRows(int,int,const QModelIndex&=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // insertRows(int,int,QModelIndex)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2])))) {
            overloadId = 0; // insertRows(int,int,QModelIndex)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertRows", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "insertRows", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QModelIndex cppArg2_local = QModelIndex();
        ::QModelIndex *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertRows(int,int,QModelIndex)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSortFilterProxyModel::insertRows(cppArg0, cppArg1, *cppArg2)
                : cppSelf->insertRows(cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_invalidate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invalidate()
        cppSelf->invalidate();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_invalidateColumnsFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invalidateColumnsFilter()
        cppSelf->invalidateColumnsFilter();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_invalidateFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invalidateFilter()
        cppSelf->invalidateFilter();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_invalidateRowsFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invalidateRowsFilter()
        cppSelf->invalidateRowsFilter();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_isRecursiveFilteringEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRecursiveFilteringEnabled()const
        bool cppResult = const_cast<const ::QSortFilterProxyModel *>(cppSelf)->isRecursiveFilteringEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_isSortLocaleAware(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSortLocaleAware()const
        bool cppResult = const_cast<const ::QSortFilterProxyModel *>(cppSelf)->isSortLocaleAware();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_lessThan(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "lessThan", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSortFilterProxyModel::lessThan(QModelIndex,QModelIndex)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[1])))) {
        overloadId = 0; // lessThan(QModelIndex,QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "lessThan", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QModelIndex cppArg1_local;
        ::QModelIndex *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // lessThan(QModelIndex,QModelIndex)const
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::lessThan(*cppArg0, *cppArg1)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->lessThan(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_mapFromSource(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractProxyModel::mapFromSource(QModelIndex)const->QModelIndex
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // mapFromSource(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mapFromSource", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mapFromSource(QModelIndex)const
            QModelIndex cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::mapFromSource(*cppArg0)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->mapFromSource(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_mapSelectionFromSource(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractProxyModel::mapSelectionFromSource(QItemSelection)const->QItemSelection
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), (pyArg)))) {
        overloadId = 0; // mapSelectionFromSource(QItemSelection)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mapSelectionFromSource", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QItemSelection cppArg0_local;
        ::QItemSelection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mapSelectionFromSource(QItemSelection)const
            QItemSelection cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::mapSelectionFromSource(*cppArg0)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->mapSelectionFromSource(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_mapSelectionToSource(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractProxyModel::mapSelectionToSource(QItemSelection)const->QItemSelection
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), (pyArg)))) {
        overloadId = 0; // mapSelectionToSource(QItemSelection)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mapSelectionToSource", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QItemSelection cppArg0_local;
        ::QItemSelection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mapSelectionToSource(QItemSelection)const
            QItemSelection cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::mapSelectionToSource(*cppArg0)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->mapSelectionToSource(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_mapToSource(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractProxyModel::mapToSource(QModelIndex)const->QModelIndex
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // mapToSource(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mapToSource", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mapToSource(QModelIndex)const
            QModelIndex cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::mapToSource(*cppArg0)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->mapToSource(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_match(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "match", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:match", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::match(QModelIndex,int,QVariant,int=,QFlags<Qt::MatchFlag>=)const->QList<QModelIndex>
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // match(QModelIndex,int,QVariant,int,QFlags<Qt::MatchFlag>)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // match(QModelIndex,int,QVariant,int,QFlags<Qt::MatchFlag>)const
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MatchFlag_IDX])))->flagsConverter, (pyArgs[4])))) {
                overloadId = 0; // match(QModelIndex,int,QVariant,int,QFlags<Qt::MatchFlag>)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "match", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"hits", 3}, {"flags", 4}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                || (pyArgs[4] != nullptr && !(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MatchFlag_IDX])))->flagsConverter, (pyArgs[4]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "match", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QVariant cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3 = 1;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QFlags<Qt::MatchFlag> cppArg4 = Qt::MatchFlags(Qt::MatchStartsWith|Qt::MatchWrap);
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // match(QModelIndex,int,QVariant,int,QFlags<Qt::MatchFlag>)const
            QList<QModelIndex> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::match(*cppArg0, cppArg1, cppArg2, cppArg3, cppArg4)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->match(*cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QModelIndex_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_mimeData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemModel::mimeData(QList<QModelIndex>)const->QMimeData*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QModelIndex_IDX], (pyArg)))) {
        overloadId = 0; // mimeData(QList<QModelIndex>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mimeData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        ::QList<QModelIndex> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mimeData(QList<QModelIndex>)const
            QMimeData * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::mimeData(cppArg0)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->mimeData(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_mimeTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mimeTypes()const
        QStringList cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::mimeTypes()
            : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->mimeTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_parent(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "parent", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::parent(QModelIndex)const->QModelIndex
    // 1: QObject::parent()const->QObject*
    if (numArgs == 0) {
        overloadId = 1; // parent()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        overloadId = 0; // parent(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "parent", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // parent(const QModelIndex &child) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QModelIndex cppArg0_local;
            ::QModelIndex *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // parent(QModelIndex)const
                QModelIndex cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::parent(*cppArg0)
                    : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->parent(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
            }
            break;
        }
        case 1: // parent() const
        {

            // parent()const
            QObject * cppResult = const_cast<const ::QObject *>(reinterpret_cast<QObject *>(cppSelf))->parent();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);

            // Ownership transferences.
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_removeColumns(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "removeColumns", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:removeColumns", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::removeColumns(int,int,const QModelIndex&=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // removeColumns(int,int,QModelIndex)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2])))) {
            overloadId = 0; // removeColumns(int,int,QModelIndex)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "removeColumns", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "removeColumns", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QModelIndex cppArg2_local = QModelIndex();
        ::QModelIndex *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeColumns(int,int,QModelIndex)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSortFilterProxyModel::removeColumns(cppArg0, cppArg1, *cppArg2)
                : cppSelf->removeColumns(cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_removeRows(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "removeRows", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:removeRows", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::removeRows(int,int,const QModelIndex&=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // removeRows(int,int,QModelIndex)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2])))) {
            overloadId = 0; // removeRows(int,int,QModelIndex)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "removeRows", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "removeRows", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QModelIndex cppArg2_local = QModelIndex();
        ::QModelIndex *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeRows(int,int,QModelIndex)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSortFilterProxyModel::removeRows(cppArg0, cppArg1, *cppArg2)
                : cppSelf->removeRows(cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_rowCount(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "rowCount", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|O:rowCount", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::rowCount(const QModelIndex&=)const->int
    if (numArgs == 0) {
        overloadId = 0; // rowCount(QModelIndex)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        overloadId = 0; // rowCount(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rowCount", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "rowCount", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local = QModelIndex();
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // rowCount(QModelIndex)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::rowCount(*cppArg0)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->rowCount(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setAutoAcceptChildRows(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSortFilterProxyModel::setAutoAcceptChildRows(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoAcceptChildRows(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoAcceptChildRows", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoAcceptChildRows(bool)
            cppSelf->setAutoAcceptChildRows(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::setData(QModelIndex,QVariant,int=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setData(QModelIndex,QVariant,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 0; // setData(QModelIndex,QVariant,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = Qt::EditRole;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setData(QModelIndex,QVariant,int)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSortFilterProxyModel::setData(*cppArg0, cppArg1, cppArg2)
                : cppSelf->setData(*cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setDynamicSortFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSortFilterProxyModel::setDynamicSortFilter(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDynamicSortFilter(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDynamicSortFilter", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDynamicSortFilter(bool)
            cppSelf->setDynamicSortFilter(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setFilterCaseSensitivity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSortFilterProxyModel::setFilterCaseSensitivity(Qt::CaseSensitivity)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CaseSensitivity_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFilterCaseSensitivity(Qt::CaseSensitivity)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFilterCaseSensitivity", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        ::Qt::CaseSensitivity cppArg0{Qt::CaseInsensitive};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFilterCaseSensitivity(Qt::CaseSensitivity)
            cppSelf->setFilterCaseSensitivity(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setFilterFixedString(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSortFilterProxyModel::setFilterFixedString(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFilterFixedString(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFilterFixedString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFilterFixedString(QString)
            cppSelf->setFilterFixedString(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setFilterKeyColumn(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSortFilterProxyModel::setFilterKeyColumn(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFilterKeyColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFilterKeyColumn", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFilterKeyColumn(int)
            cppSelf->setFilterKeyColumn(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setFilterRegularExpression(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSortFilterProxyModel::setFilterRegularExpression(QRegularExpression)
    // 1: QSortFilterProxyModel::setFilterRegularExpression(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // setFilterRegularExpression(QString)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
        overloadId = 0; // setFilterRegularExpression(QRegularExpression)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFilterRegularExpression", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setFilterRegularExpression(const QRegularExpression &regularExpression)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QRegularExpression cppArg0_local;
            ::QRegularExpression *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setFilterRegularExpression(QRegularExpression)
                cppSelf->setFilterRegularExpression(*cppArg0);
            }
            break;
        }
        case 1: // setFilterRegularExpression(const QString &pattern)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setFilterRegularExpression(QString)
                cppSelf->setFilterRegularExpression(cppArg0);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setFilterRole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSortFilterProxyModel::setFilterRole(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFilterRole(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFilterRole", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFilterRole(int)
            cppSelf->setFilterRole(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setFilterWildcard(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSortFilterProxyModel::setFilterWildcard(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFilterWildcard(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFilterWildcard", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFilterWildcard(QString)
            cppSelf->setFilterWildcard(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setHeaderData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setHeaderData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:setHeaderData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::setHeaderData(int,Qt::Orientation,QVariant,int=)->bool
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // setHeaderData(int,Qt::Orientation,QVariant,int)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 0; // setHeaderData(int,Qt::Orientation,QVariant,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setHeaderData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 3}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setHeaderData", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::Orientation cppArg1 = static_cast< ::Qt::Orientation>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QVariant cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3 = Qt::EditRole;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeaderData(int,Qt::Orientation,QVariant,int)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSortFilterProxyModel::setHeaderData(cppArg0, cppArg1, cppArg2, cppArg3)
                : cppSelf->setHeaderData(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setRecursiveFilteringEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSortFilterProxyModel::setRecursiveFilteringEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setRecursiveFilteringEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRecursiveFilteringEnabled", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRecursiveFilteringEnabled(bool)
            cppSelf->setRecursiveFilteringEnabled(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setSortCaseSensitivity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSortFilterProxyModel::setSortCaseSensitivity(Qt::CaseSensitivity)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CaseSensitivity_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSortCaseSensitivity(Qt::CaseSensitivity)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSortCaseSensitivity", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        ::Qt::CaseSensitivity cppArg0{Qt::CaseInsensitive};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSortCaseSensitivity(Qt::CaseSensitivity)
            cppSelf->setSortCaseSensitivity(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setSortLocaleAware(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSortFilterProxyModel::setSortLocaleAware(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSortLocaleAware(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSortLocaleAware", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSortLocaleAware(bool)
            cppSelf->setSortLocaleAware(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setSortRole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSortFilterProxyModel::setSortRole(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSortRole(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSortRole", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSortRole(int)
            cppSelf->setSortRole(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_setSourceModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractProxyModel::setSourceModel(QAbstractItemModel*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), (pyArg)))) {
        overloadId = 0; // setSourceModel(QAbstractItemModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSourceModel", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractItemModel *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSourceModel(QAbstractItemModel*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSortFilterProxyModel::setSourceModel(cppArg0)
                : cppSelf->setSourceModel(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "setSourceModel(QAbstractItemModel*)1", pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_sibling(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sibling", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::sibling(int,int,QModelIndex)const->QModelIndex
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2])))) {
        overloadId = 0; // sibling(int,int,QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sibling", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QModelIndex cppArg2_local;
        ::QModelIndex *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // sibling(int,int,QModelIndex)const
            QModelIndex cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::sibling(cppArg0, cppArg1, *cppArg2)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->sibling(cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_sort(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "sort", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|OO:sort", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::sort(int,Qt::SortOrder=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // sort(int,Qt::SortOrder)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // sort(int,Qt::SortOrder)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sort", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"order", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "sort", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::SortOrder cppArg1(Qt::AscendingOrder);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sort(int,Qt::SortOrder)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSortFilterProxyModel::sort(cppArg0, cppArg1)
                : cppSelf->sort(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QSortFilterProxyModelFunc_sortCaseSensitivity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sortCaseSensitivity()const
        Qt::CaseSensitivity cppResult = const_cast<const ::QSortFilterProxyModel *>(cppSelf)->sortCaseSensitivity();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CaseSensitivity_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_sortColumn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sortColumn()const
        int cppResult = const_cast<const ::QSortFilterProxyModel *>(cppSelf)->sortColumn();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_sortOrder(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sortOrder()const
        Qt::SortOrder cppResult = const_cast<const ::QSortFilterProxyModel *>(cppSelf)->sortOrder();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_sortRole(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sortRole()const
        int cppResult = const_cast<const ::QSortFilterProxyModel *>(cppSelf)->sortRole();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_span(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemModel::span(QModelIndex)const->QSize
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // span(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "span", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // span(QModelIndex)const
            QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::span(*cppArg0)
                : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->span(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QSortFilterProxyModelFunc_supportedDropActions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedDropActions()const
        QFlags<Qt::DropAction> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QSortFilterProxyModel *>(cppSelf)->::QSortFilterProxyModel::supportedDropActions()
            : const_cast<const ::QSortFilterProxyModel *>(cppSelf)->supportedDropActions();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_DropAction_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QSortFilterProxyModel_PropertyStrings[] = {
    "autoAcceptChildRows::",
    "dynamicSortFilter::",
    "filterCaseSensitivity::",
    "filterKeyColumn::",
    "filterRegularExpression::",
    "filterRole::",
    "isSortLocaleAware::setSortLocaleAware",
    "recursiveFilteringEnabled:isRecursiveFilteringEnabled:",
    "sortCaseSensitivity::",
    "sortRole::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSortFilterProxyModel_methods[] = {
    {"autoAcceptChildRows", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_autoAcceptChildRows), METH_NOARGS, nullptr},
    {"beginFilterChange", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_beginFilterChange), METH_NOARGS, nullptr},
    {"buddy", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_buddy), METH_O, nullptr},
    {"canFetchMore", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_canFetchMore), METH_O, nullptr},
    {"columnCount", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_columnCount), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_data), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"dropMimeData", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_dropMimeData), METH_VARARGS, nullptr},
    {"dynamicSortFilter", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_dynamicSortFilter), METH_NOARGS, nullptr},
    {"fetchMore", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_fetchMore), METH_O, nullptr},
    {"filterAcceptsColumn", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_filterAcceptsColumn), METH_VARARGS, nullptr},
    {"filterAcceptsRow", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_filterAcceptsRow), METH_VARARGS, nullptr},
    {"filterCaseSensitivity", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_filterCaseSensitivity), METH_NOARGS, nullptr},
    {"filterKeyColumn", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_filterKeyColumn), METH_NOARGS, nullptr},
    {"filterRegularExpression", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_filterRegularExpression), METH_NOARGS, nullptr},
    {"filterRole", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_filterRole), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_flags), METH_O, nullptr},
    {"hasChildren", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_hasChildren), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"headerData", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_headerData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"index", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_index), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"insertColumns", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_insertColumns), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"insertRows", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_insertRows), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"invalidate", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_invalidate), METH_NOARGS, nullptr},
    {"invalidateColumnsFilter", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_invalidateColumnsFilter), METH_NOARGS, nullptr},
    {"invalidateFilter", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_invalidateFilter), METH_NOARGS, nullptr},
    {"invalidateRowsFilter", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_invalidateRowsFilter), METH_NOARGS, nullptr},
    {"isRecursiveFilteringEnabled", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_isRecursiveFilteringEnabled), METH_NOARGS, nullptr},
    {"isSortLocaleAware", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_isSortLocaleAware), METH_NOARGS, nullptr},
    {"lessThan", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_lessThan), METH_VARARGS, nullptr},
    {"mapFromSource", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_mapFromSource), METH_O, nullptr},
    {"mapSelectionFromSource", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_mapSelectionFromSource), METH_O, nullptr},
    {"mapSelectionToSource", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_mapSelectionToSource), METH_O, nullptr},
    {"mapToSource", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_mapToSource), METH_O, nullptr},
    {"match", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_match), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"mimeData", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_mimeData), METH_O, nullptr},
    {"mimeTypes", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_mimeTypes), METH_NOARGS, nullptr},
    {"parent", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_parent), METH_VARARGS, nullptr},
    {"removeColumns", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_removeColumns), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"removeRows", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_removeRows), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"rowCount", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_rowCount), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setAutoAcceptChildRows", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setAutoAcceptChildRows), METH_O, nullptr},
    {"setData", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setDynamicSortFilter", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setDynamicSortFilter), METH_O, nullptr},
    {"setFilterCaseSensitivity", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setFilterCaseSensitivity), METH_O, nullptr},
    {"setFilterFixedString", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setFilterFixedString), METH_O, nullptr},
    {"setFilterKeyColumn", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setFilterKeyColumn), METH_O, nullptr},
    {"setFilterRegularExpression", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setFilterRegularExpression), METH_O, nullptr},
    {"setFilterRole", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setFilterRole), METH_O, nullptr},
    {"setFilterWildcard", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setFilterWildcard), METH_O, nullptr},
    {"setHeaderData", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setHeaderData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setRecursiveFilteringEnabled", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setRecursiveFilteringEnabled), METH_O, nullptr},
    {"setSortCaseSensitivity", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setSortCaseSensitivity), METH_O, nullptr},
    {"setSortLocaleAware", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setSortLocaleAware), METH_O, nullptr},
    {"setSortRole", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setSortRole), METH_O, nullptr},
    {"setSourceModel", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_setSourceModel), METH_O, nullptr},
    {"sibling", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_sibling), METH_VARARGS, nullptr},
    {"sort", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_sort), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"sortCaseSensitivity", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_sortCaseSensitivity), METH_NOARGS, nullptr},
    {"sortColumn", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_sortColumn), METH_NOARGS, nullptr},
    {"sortOrder", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_sortOrder), METH_NOARGS, nullptr},
    {"sortRole", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_sortRole), METH_NOARGS, nullptr},
    {"span", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_span), METH_O, nullptr},
    {"supportedDropActions", reinterpret_cast<PyCFunction>(Sbk_QSortFilterProxyModelFunc_supportedDropActions), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSortFilterProxyModel_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSortFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSortFilterProxyModelWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSortFilterProxyModel_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSortFilterProxyModel_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSortFilterProxyModel_Type = nullptr;
static PyTypeObject *Sbk_QSortFilterProxyModel_TypeF(void)
{
    return _Sbk_QSortFilterProxyModel_Type;
}

static PyType_Slot Sbk_QSortFilterProxyModel_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSortFilterProxyModel_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSortFilterProxyModel_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSortFilterProxyModel_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSortFilterProxyModel_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSortFilterProxyModel_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSortFilterProxyModel_spec = {
    "2:PySide6.QtCore.QSortFilterProxyModel",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSortFilterProxyModel_slots
};

} //extern "C"

static void *Sbk_QSortFilterProxyModel_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSortFilterProxyModel *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSortFilterProxyModel_PythonToCpp_QSortFilterProxyModel_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSortFilterProxyModel_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSortFilterProxyModel_PythonToCpp_QSortFilterProxyModel_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSortFilterProxyModel_TypeF()))
        return QSortFilterProxyModel_PythonToCpp_QSortFilterProxyModel_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSortFilterProxyModel_PTR_CppToPython_QSortFilterProxyModel(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSortFilterProxyModel *>(const_cast<void *>(cppIn)), Sbk_QSortFilterProxyModel_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QSortFilterProxyModel_SignatureStrings[] = {
    "PySide6.QtCore.QSortFilterProxyModel(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,filterRegularExpression:QRegularExpression=None,filterKeyColumn:int=None,dynamicSortFilter:bool=None,filterCaseSensitivity:Qt.CaseSensitivity=None,sortCaseSensitivity:Qt.CaseSensitivity=None,isSortLocaleAware:bool=None,sortRole:int=None,filterRole:int=None,recursiveFilteringEnabled:bool=None,autoAcceptChildRows:bool=None)",
    "PySide6.QtCore.QSortFilterProxyModel.autoAcceptChildRows(self)->bool",
    "PySide6.QtCore.QSortFilterProxyModel.beginFilterChange(self)",
    "PySide6.QtCore.QSortFilterProxyModel.buddy(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.QModelIndex",
    "PySide6.QtCore.QSortFilterProxyModel.canFetchMore(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "PySide6.QtCore.QSortFilterProxyModel.columnCount(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->int",
    "PySide6.QtCore.QSortFilterProxyModel.data(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],role:int=Qt.DisplayRole)->QVariant",
    "PySide6.QtCore.QSortFilterProxyModel.dropMimeData(self,data:PySide6.QtCore.QMimeData,action:PySide6.QtCore.Qt.DropAction,row:int,column:int,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "PySide6.QtCore.QSortFilterProxyModel.dynamicSortFilter(self)->bool",
    "PySide6.QtCore.QSortFilterProxyModel.fetchMore(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "PySide6.QtCore.QSortFilterProxyModel.filterAcceptsColumn(self,source_column:int,source_parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "PySide6.QtCore.QSortFilterProxyModel.filterAcceptsRow(self,source_row:int,source_parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "PySide6.QtCore.QSortFilterProxyModel.filterCaseSensitivity(self)->PySide6.QtCore.Qt.CaseSensitivity",
    "PySide6.QtCore.QSortFilterProxyModel.filterKeyColumn(self)->int",
    "PySide6.QtCore.QSortFilterProxyModel.filterRegularExpression(self)->PySide6.QtCore.QRegularExpression",
    "PySide6.QtCore.QSortFilterProxyModel.filterRole(self)->int",
    "PySide6.QtCore.QSortFilterProxyModel.flags(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.Qt.ItemFlag",
    "PySide6.QtCore.QSortFilterProxyModel.hasChildren(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->bool",
    "PySide6.QtCore.QSortFilterProxyModel.headerData(self,section:int,orientation:PySide6.QtCore.Qt.Orientation,role:int=Qt.DisplayRole)->QVariant",
    "PySide6.QtCore.QSortFilterProxyModel.index(self,row:int,column:int,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->PySide6.QtCore.QModelIndex",
    "PySide6.QtCore.QSortFilterProxyModel.insertColumns(self,column:int,count:int,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->bool",
    "PySide6.QtCore.QSortFilterProxyModel.insertRows(self,row:int,count:int,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->bool",
    "PySide6.QtCore.QSortFilterProxyModel.invalidate(self)",
    "PySide6.QtCore.QSortFilterProxyModel.invalidateColumnsFilter(self)",
    "PySide6.QtCore.QSortFilterProxyModel.invalidateFilter(self)",
    "PySide6.QtCore.QSortFilterProxyModel.invalidateRowsFilter(self)",
    "PySide6.QtCore.QSortFilterProxyModel.isRecursiveFilteringEnabled(self)->bool",
    "PySide6.QtCore.QSortFilterProxyModel.isSortLocaleAware(self)->bool",
    "PySide6.QtCore.QSortFilterProxyModel.lessThan(self,source_left:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],source_right:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "PySide6.QtCore.QSortFilterProxyModel.mapFromSource(self,sourceIndex:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.QModelIndex",
    "PySide6.QtCore.QSortFilterProxyModel.mapSelectionFromSource(self,sourceSelection:PySide6.QtCore.QItemSelection)->PySide6.QtCore.QItemSelection",
    "PySide6.QtCore.QSortFilterProxyModel.mapSelectionToSource(self,proxySelection:PySide6.QtCore.QItemSelection)->PySide6.QtCore.QItemSelection",
    "PySide6.QtCore.QSortFilterProxyModel.mapToSource(self,proxyIndex:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.QModelIndex",
    "PySide6.QtCore.QSortFilterProxyModel.match(self,start:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],role:int,value:QVariant,hits:int=1,flags:PySide6.QtCore.Qt.MatchFlag=Qt.MatchFlags(Qt.MatchStartsWith|Qt.MatchWrap))->QList[PySide6.QtCore.QModelIndex]",
    "PySide6.QtCore.QSortFilterProxyModel.mimeData(self,indexes:QList[PySide6.QtCore.QModelIndex])->PySide6.QtCore.QMimeData",
    "PySide6.QtCore.QSortFilterProxyModel.mimeTypes(self)->QStringList",
    "1:PySide6.QtCore.QSortFilterProxyModel.parent(self,child:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.QModelIndex",
    "0:PySide6.QtCore.QSortFilterProxyModel.parent(self)->PySide6.QtCore.QObject",
    "PySide6.QtCore.QSortFilterProxyModel.removeColumns(self,column:int,count:int,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->bool",
    "PySide6.QtCore.QSortFilterProxyModel.removeRows(self,row:int,count:int,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->bool",
    "PySide6.QtCore.QSortFilterProxyModel.rowCount(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->int",
    "PySide6.QtCore.QSortFilterProxyModel.setAutoAcceptChildRows(self,accept:bool)",
    "PySide6.QtCore.QSortFilterProxyModel.setData(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],value:QVariant,role:int=Qt.EditRole)->bool",
    "PySide6.QtCore.QSortFilterProxyModel.setDynamicSortFilter(self,enable:bool)",
    "PySide6.QtCore.QSortFilterProxyModel.setFilterCaseSensitivity(self,cs:PySide6.QtCore.Qt.CaseSensitivity)",
    "PySide6.QtCore.QSortFilterProxyModel.setFilterFixedString(self,pattern:QString)",
    "PySide6.QtCore.QSortFilterProxyModel.setFilterKeyColumn(self,column:int)",
    "1:PySide6.QtCore.QSortFilterProxyModel.setFilterRegularExpression(self,regularExpression:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "0:PySide6.QtCore.QSortFilterProxyModel.setFilterRegularExpression(self,pattern:QString)",
    "PySide6.QtCore.QSortFilterProxyModel.setFilterRole(self,role:int)",
    "PySide6.QtCore.QSortFilterProxyModel.setFilterWildcard(self,pattern:QString)",
    "PySide6.QtCore.QSortFilterProxyModel.setHeaderData(self,section:int,orientation:PySide6.QtCore.Qt.Orientation,value:QVariant,role:int=Qt.EditRole)->bool",
    "PySide6.QtCore.QSortFilterProxyModel.setRecursiveFilteringEnabled(self,recursive:bool)",
    "PySide6.QtCore.QSortFilterProxyModel.setSortCaseSensitivity(self,cs:PySide6.QtCore.Qt.CaseSensitivity)",
    "PySide6.QtCore.QSortFilterProxyModel.setSortLocaleAware(self,on:bool)",
    "PySide6.QtCore.QSortFilterProxyModel.setSortRole(self,role:int)",
    "PySide6.QtCore.QSortFilterProxyModel.setSourceModel(self,sourceModel:PySide6.QtCore.QAbstractItemModel)",
    "PySide6.QtCore.QSortFilterProxyModel.sibling(self,row:int,column:int,idx:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.QModelIndex",
    "PySide6.QtCore.QSortFilterProxyModel.sort(self,column:int,order:PySide6.QtCore.Qt.SortOrder=Qt.AscendingOrder)",
    "PySide6.QtCore.QSortFilterProxyModel.sortCaseSensitivity(self)->PySide6.QtCore.Qt.CaseSensitivity",
    "PySide6.QtCore.QSortFilterProxyModel.sortColumn(self)->int",
    "PySide6.QtCore.QSortFilterProxyModel.sortOrder(self)->PySide6.QtCore.Qt.SortOrder",
    "PySide6.QtCore.QSortFilterProxyModel.sortRole(self)->int",
    "PySide6.QtCore.QSortFilterProxyModel.span(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.QSize",
    "PySide6.QtCore.QSortFilterProxyModel.supportedDropActions(self)->PySide6.QtCore.Qt.DropAction",
    nullptr}; // Sentinel
#else
static constexpr size_t QSortFilterProxyModel_SignatureByteSize = 1106;
static constexpr uint8_t QSortFilterProxyModel_SignatureBytes[1106] = {
    0x78, 0xda, 0xd5, 0x59, 0x4d, 0x6f, 0xe3, 0x36, 0x10, 0xbd, 0xe7, 0x57, 0xec, 0x31, 0x2e, 0x54,
    0xa3, 0x7b, 0xe9, 0x41, 0x40, 0x0a, 0x18, 0x4e, 0x8c, 0x06, 0xdd, 0x34, 0x76, 0x94, 0x36, 0x87,
    0x22, 0x28, 0x68, 0x69, 0x62, 0xb3, 0xa0, 0x49, 0x81, 0xa4, 0x92, 0xa8, 0xe8, 0x8f, 0xef, 0x90,
    0xd4, 0x97, 0x2d, 0x29, 0x4b, 0xc5, 0xb1, 0xd7, 0x7b, 0x14, 0x39, 0x7c, 0x7c, 0x24, 0x87, 0x6f,
    0x86, 0xa3, 0x79, 0x1e, 0xd1, 0x04, 0x7e, 0x1e, 0x2f, 0xf4, 0x54, 0x48, 0x18, 0x2f, 0x22, 0x21,
    0xf5, 0x8c, 0x32, 0x0d, 0x72, 0x2e, 0xc5, 0x6b, 0x7e, 0x23, 0x12, 0x60, 0xe7, 0x0a, 0xd8, 0x53,
    0x90, 0x12, 0x09, 0x5c, 0x87, 0xf3, 0x9d, 0x01, 0xb7, 0xcb, 0x7f, 0x20, 0xd6, 0x17, 0x3c, 0x63,
    0x2c, 0xd5, 0x32, 0xf8, 0x21, 0xfc, 0x0d, 0xf2, 0x17, 0x21, 0x93, 0x5b, 0xce, 0xf2, 0x8b, 0xdf,
    0x05, 0x87, 0xe0, 0xc9, 0xc2, 0xdd, 0xc1, 0x2a, 0x63, 0x44, 0x5e, 0xbd, 0xa6, 0x12, 0x94, 0xa2,
    0x82, 0x87, 0x8b, 0x56, 0x53, 0xd3, 0x1e, 0x61, 0xa6, 0x82, 0x65, 0x1b, 0x1e, 0x52, 0xae, 0x5d,
    0x47, 0x92, 0x73, 0xb2, 0xa1, 0x71, 0x4d, 0x31, 0x5c, 0x0a, 0xc1, 0x9a, 0x83, 0xa6, 0x44, 0x41,
    0x04, 0x5c, 0x51, 0x4d, 0x9f, 0xa9, 0xce, 0xc3, 0x85, 0x1e, 0xef, 0x34, 0x39, 0x6b, 0x85, 0x10,
    0xbe, 0xb6, 0x54, 0x99, 0x09, 0xbf, 0x88, 0x98, 0x30, 0x98, 0xbc, 0xe0, 0x26, 0x34, 0x66, 0x35,
    0x38, 0x77, 0x82, 0x41, 0xcd, 0xb1, 0x58, 0xec, 0x56, 0x9b, 0x84, 0x38, 0x93, 0x8a, 0x3e, 0x83,
    0x63, 0x4d, 0xf9, 0xea, 0x8a, 0x93, 0x25, 0x83, 0xa4, 0x81, 0x44, 0x32, 0x2d, 0x26, 0x71, 0x0c,
    0xa9, 0x9e, 0xae, 0x29, 0x4b, 0xee, 0xc4, 0x8b, 0xaa, 0x7b, 0x47, 0x67, 0x73, 0x8f, 0x63, 0x1a,
    0x77, 0x60, 0xd8, 0xa3, 0x1b, 0xfd, 0xf8, 0x8b, 0x81, 0xf2, 0x03, 0x59, 0xc2, 0x8a, 0x72, 0xd7,
    0x3a, 0x5d, 0x13, 0xbe, 0x02, 0x07, 0xe1, 0x39, 0x38, 0x4b, 0x92, 0xdc, 0xb9, 0x0b, 0xe5, 0x09,
    0xbc, 0x86, 0x3a, 0x4f, 0x71, 0xb9, 0xe3, 0x3f, 0x38, 0x9e, 0xee, 0x5f, 0xbb, 0x10, 0x76, 0xcc,
    0xb5, 0xb1, 0x0b, 0x3e, 0xed, 0xf6, 0xcd, 0x01, 0x77, 0x4c, 0x69, 0xf4, 0xb8, 0xda, 0xea, 0x11,
    0x17, 0xd2, 0x8f, 0xe1, 0xc7, 0x30, 0x26, 0x7c, 0x06, 0x3a, 0x5e, 0xdf, 0xa0, 0xc9, 0x96, 0x5f,
    0x7f, 0x38, 0x53, 0xff, 0x2d, 0x8f, 0xad, 0x9f, 0x4f, 0x45, 0xc6, 0xf5, 0x01, 0x29, 0x5d, 0x34,
    0x86, 0x9c, 0x8f, 0x90, 0x20, 0xfa, 0xa7, 0x1f, 0xbf, 0x84, 0x68, 0x72, 0xb8, 0x43, 0x0d, 0x64,
    0x79, 0x59, 0xf0, 0x06, 0x5e, 0x52, 0x95, 0x32, 0x92, 0x9b, 0xfb, 0x83, 0x0c, 0x17, 0x7f, 0x12,
    0x49, 0x89, 0x37, 0x4d, 0x29, 0xd2, 0x1b, 0xba, 0x81, 0xcb, 0x8a, 0xae, 0x21, 0xde, 0x12, 0xac,
    0xd2, 0x24, 0x20, 0xb1, 0x36, 0x32, 0xb4, 0xdb, 0x8f, 0x24, 0x10, 0x68, 0x62, 0x3b, 0x91, 0xdb,
    0x8b, 0xa1, 0x16, 0xc4, 0x95, 0x14, 0x9d, 0x80, 0xbf, 0xb4, 0x74, 0x70, 0xf8, 0x2d, 0x7f, 0x3a,
    0xc6, 0x1d, 0xf0, 0xa4, 0x62, 0x1b, 0x9c, 0x6e, 0x29, 0x27, 0xf9, 0x8e, 0x94, 0x12, 0x99, 0x8c,
    0xe1, 0xef, 0xc6, 0xd6, 0x17, 0x2d, 0xdf, 0xfe, 0x04, 0xb6, 0x38, 0xa3, 0xce, 0x6e, 0x11, 0x2e,
    0x7d, 0xe6, 0xc4, 0xd8, 0xee, 0x04, 0xb7, 0xd2, 0x67, 0xda, 0xee, 0xbf, 0x63, 0x38, 0x64, 0x8e,
    0x2a, 0x68, 0x97, 0xe8, 0xde, 0x1a, 0xd3, 0x93, 0x24, 0xf4, 0xb1, 0x6c, 0x19, 0x0e, 0x9a, 0x05,
    0xd5, 0x65, 0x38, 0x41, 0x46, 0x56, 0xea, 0xa8, 0xa1, 0x4d, 0x8f, 0xaf, 0x35, 0x6c, 0x66, 0x38,
    0xaf, 0x1f, 0xc3, 0x35, 0x51, 0x36, 0xee, 0xa3, 0xbb, 0x1d, 0x33, 0x8c, 0xf8, 0xfb, 0xe1, 0x1a,
    0x48, 0x02, 0xb2, 0x96, 0x67, 0x05, 0x4e, 0x81, 0xcd, 0x65, 0x11, 0x92, 0xe2, 0x3c, 0xa4, 0x47,
    0x91, 0x6f, 0xeb, 0xde, 0x0f, 0x0b, 0x17, 0xf6, 0x14, 0x1d, 0x91, 0x63, 0xa9, 0x7c, 0x6b, 0xef,
    0xf6, 0xcd, 0x66, 0x28, 0x57, 0x80, 0x99, 0xac, 0xa5, 0x5d, 0x38, 0x67, 0x63, 0x0d, 0xb1, 0xc9,
    0x28, 0x8e, 0xb8, 0x1a, 0x7f, 0x4f, 0x70, 0xbc, 0xab, 0x04, 0xb5, 0x71, 0x00, 0xa7, 0xcb, 0xf8,
    0x99, 0x30, 0x8a, 0x09, 0xc5, 0xa0, 0x7c, 0xb8, 0x1e, 0x55, 0x9c, 0x51, 0x33, 0x5e, 0x0f, 0x85,
    0xd8, 0x67, 0xac, 0xd9, 0xea, 0x77, 0x8c, 0x57, 0x77, 0x7d, 0x4f, 0x97, 0xe1, 0x29, 0x47, 0xeb,
    0x1d, 0x35, 0x1c, 0x82, 0xa1, 0xd6, 0xdf, 0xe3, 0xa3, 0x64, 0x2b, 0xdc, 0x32, 0x78, 0xfa, 0x68,
    0x3f, 0xa9, 0x22, 0x39, 0x5d, 0xad, 0xbf, 0x69, 0xe4, 0xde, 0x90, 0x74, 0x26, 0xc5, 0x26, 0xb2,
    0x74, 0x9a, 0xab, 0xbe, 0x3e, 0xcd, 0xd7, 0x15, 0xf2, 0x8d, 0x80, 0x39, 0x59, 0xef, 0x26, 0x5e,
    0x75, 0xb7, 0x54, 0xde, 0x04, 0xbb, 0xaa, 0xb7, 0x83, 0xcb, 0x56, 0xff, 0x70, 0x3a, 0xf7, 0xa2,
    0x49, 0x26, 0x35, 0x46, 0xc7, 0xe6, 0xd2, 0x41, 0xe1, 0x64, 0xcf, 0x11, 0x9f, 0x07, 0xc5, 0xb1,
    0x69, 0x22, 0xf5, 0xa1, 0x9e, 0x7c, 0x01, 0xea, 0x53, 0x06, 0x61, 0x19, 0xb8, 0x83, 0x35, 0xd5,
    0xca, 0xc6, 0xf6, 0xcf, 0x81, 0xcd, 0xb7, 0x3a, 0x52, 0x81, 0x1b, 0x43, 0xcd, 0x24, 0x45, 0x17,
    0xcd, 0x0f, 0x75, 0x5e, 0x7e, 0x45, 0x86, 0xaf, 0x7a, 0xa0, 0x7a, 0xfd, 0x5f, 0xd9, 0xf4, 0x20,
    0x49, 0x6a, 0xd4, 0x7e, 0xf1, 0x05, 0x99, 0xbc, 0xc1, 0xfe, 0xd1, 0x73, 0x73, 0xb6, 0xde, 0x98,
    0x36, 0x8d, 0x00, 0x15, 0x7e, 0x15, 0xbc, 0xeb, 0x58, 0x0a, 0x24, 0xff, 0x79, 0xef, 0xf3, 0x14,
    0xaa, 0xa2, 0xce, 0x22, 0xd2, 0x46, 0x91, 0xcd, 0xc4, 0x67, 0x9f, 0x43, 0x2f, 0x0c, 0x17, 0x56,
    0x8b, 0x4c, 0xc1, 0x24, 0x8b, 0x47, 0xf5, 0xbd, 0x9f, 0x06, 0x93, 0xec, 0xc0, 0x73, 0x05, 0x47,
    0xbf, 0x2d, 0x93, 0xb0, 0x11, 0xcf, 0xf0, 0xfd, 0xe5, 0x47, 0x8e, 0xf7, 0xf7, 0x94, 0x1f, 0x21,
    0xc3, 0xd3, 0x2d, 0x60, 0x29, 0xd0, 0x93, 0x9e, 0xda, 0x68, 0x40, 0x6c, 0xa3, 0xad, 0xb5, 0x8e,
    0xbc, 0xd1, 0x2e, 0x0f, 0x5b, 0x11, 0xdb, 0x51, 0xc5, 0xe6, 0x8b, 0xe7, 0x2a, 0xa1, 0xba, 0x78,
    0xee, 0xf8, 0x1f, 0x8e, 0x61, 0xdc, 0x59, 0x33, 0x0a, 0xc0, 0x66, 0x73, 0x03, 0x57, 0x3f, 0xeb,
    0xad, 0x27, 0x04, 0x71, 0x97, 0x64, 0xef, 0x58, 0x0e, 0x9d, 0x68, 0x46, 0x5f, 0x21, 0x71, 0x52,
    0x57, 0x7a, 0x97, 0xc6, 0x66, 0x1e, 0x16, 0xfa, 0x37, 0x14, 0x6f, 0xbb, 0x48, 0xd1, 0x10, 0x84,
    0x91, 0xaf, 0x8a, 0x56, 0x50, 0xdd, 0xf5, 0x8a, 0x40, 0xb6, 0xfe, 0x75, 0xbc, 0xe9, 0x20, 0x2d,
    0x94, 0xe0, 0x53, 0xb1, 0xb4, 0xc7, 0x91, 0xaf, 0x66, 0x7e, 0x8d, 0xd2, 0x9e, 0x7b, 0x56, 0x95,
    0x4c, 0x2a, 0x67, 0x1c, 0x8a, 0xf0, 0x80, 0xb7, 0x2e, 0x26, 0x32, 0xd9, 0x93, 0xce, 0xaf, 0x1f,
    0x52, 0x43, 0x38, 0xc0, 0x05, 0x7b, 0xfb, 0xa5, 0x54, 0xff, 0x03, 0x1a, 0x78, 0xd7, 0xa2, 0xf6,
    0x9f, 0xaa, 0x43, 0xdc, 0xb4, 0xae, 0xa7, 0x59, 0x80, 0xdb, 0x38, 0x9c, 0xec, 0x3e, 0x9e, 0xe2,
    0xd2, 0xe3, 0xc6, 0x3f, 0x47, 0x55, 0x37, 0xb4, 0x56, 0x3b, 0x59, 0x2a, 0x2d, 0x49, 0xac, 0x4d,
    0x2e, 0x6e, 0x2d, 0x7c, 0xe7, 0xa1, 0x4b, 0x56, 0x49, 0x49, 0x47, 0xe5, 0x87, 0x26, 0x27, 0x98,
    0x90, 0x9b, 0x1f, 0x8d, 0xad, 0xfc, 0x45, 0x48, 0xbc, 0x0a, 0x1d, 0x5e, 0x60, 0x10, 0x6e, 0x4d,
    0x9f, 0xf1, 0xe7, 0x89, 0x8a, 0x81, 0x27, 0xb8, 0x1a, 0xdb, 0x32, 0xf2, 0x9f, 0xee, 0xb0, 0xf5,
    0x62, 0x3b, 0xc3, 0xfb, 0x4a, 0xc5, 0xaa, 0x5c, 0x5e, 0x3f, 0xa5, 0x6a, 0x07, 0xfc, 0x11, 0xdf,
    0x55, 0x14, 0x56, 0x69, 0x59, 0x8c, 0x38, 0x52, 0x4d, 0x38, 0xa2, 0xff, 0x82, 0x27, 0xb5, 0x2c,
    0x4d, 0xb1, 0x1d, 0x92, 0xfa, 0x6f, 0x96, 0xea, 0xdf, 0xb0, 0xda, 0xe8, 0xec, 0x7f, 0xb1, 0xd1,
    0xdc, 0x8c
};
#endif

PyTypeObject *init_QSortFilterProxyModel(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX].type;

    Shiboken::AutoDecRef Sbk_QSortFilterProxyModel_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractProxyModel_IDX]))));

    _Sbk_QSortFilterProxyModel_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSortFilterProxyModel",
        "QSortFilterProxyModel*",
        &Sbk_QSortFilterProxyModel_spec,
        &Shiboken::callCppDestructor< QSortFilterProxyModel >,
        Sbk_QSortFilterProxyModel_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSortFilterProxyModel_TypeF(); // references _Sbk_QSortFilterProxyModel_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QSortFilterProxyModel_SignatureStrings);
#else
    InitSignatureBytes(pyType, QSortFilterProxyModel_SignatureBytes, QSortFilterProxyModel_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSortFilterProxyModel_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSortFilterProxyModel_PythonToCpp_QSortFilterProxyModel_PTR,
        is_QSortFilterProxyModel_PythonToCpp_QSortFilterProxyModel_PTR_Convertible,
        QSortFilterProxyModel_PTR_CppToPython_QSortFilterProxyModel);

    Shiboken::Conversions::registerConverterName(converter, "QSortFilterProxyModel");
    Shiboken::Conversions::registerConverterName(converter, "QSortFilterProxyModel*");
    Shiboken::Conversions::registerConverterName(converter, "QSortFilterProxyModel&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSortFilterProxyModel).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSortFilterProxyModelWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSortFilterProxyModel_TypeF(), &Sbk_QSortFilterProxyModel_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QSortFilterProxyModel::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSortFilterProxyModel::staticMetaObject, sizeof(QSortFilterProxyModelWrapper));

    return pyType;
}
