// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qabstractitemview_wrapper.h"

// Wrappers providing overrides
#include "qabstractitemview_wrapper.h"
#include "qlayoutitem_wrapper.h"
#include "qtextedit_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qlineedit_wrapper.h"
#include "qabstractscrollarea_wrapper.h"
#include "qwidget_wrapper.h"
#include "qwizardpage_wrapper.h"
#include "qgraphicsitem_wrapper.h"
#include "qgraphicslayout_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qregion.h>
#include <QtWidgets/qabstractitemdelegate.h>
#include <QtWidgets/qabstractitemview.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qitemselectionmodel.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractItemViewWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractItemViewWrapper::QAbstractItemViewWrapper(::QWidget * parent) : QAbstractItemView(parent)
{
}

void QAbstractItemViewWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QWizardPageWrapper::sbk_o_actionEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::changeEvent(::QEvent * arg__1)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFrame::changeEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_changeEvent("QAbstractItemView", funcName, gil, pyOverride, arg__1);
}

void QAbstractItemViewWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWidgetWrapper::sbk_o_childEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::closeEditor(::QWidget * editor, ::QAbstractItemDelegate::EndEditHint hint)
{
    static const char *funcName = "closeEditor";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::closeEditor(editor, hint);
    }
    sbk_o_closeEditor("QAbstractItemView", funcName, gil, pyOverride, editor, hint);
}

void QAbstractItemViewWrapper::sbk_o_closeEditor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * editor, ::QAbstractItemDelegate::EndEditHint hint)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), editor),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_EndEditHint_IDX])))->converter, &hint)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), editor),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_EndEditHint_IDX])))->converter, &hint)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QAbstractItemViewWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QWizardPageWrapper::sbk_o_closeEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::commitData(::QWidget * editor)
{
    static const char *funcName = "commitData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::commitData(editor);
    }
    sbk_o_commitData("QAbstractItemView", funcName, gil, pyOverride, editor);
}

void QAbstractItemViewWrapper::sbk_o_commitData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWidget * editor)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), editor)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), editor)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QAbstractItemViewWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QAbstractItemView", funcName, gil, pyOverride, signal);
}

void QAbstractItemViewWrapper::contextMenuEvent(::QContextMenuEvent * arg__1)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::contextMenuEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_contextMenuEvent("QAbstractItemView", funcName, gil, pyOverride, arg__1);
}

void QAbstractItemViewWrapper::currentChanged(const ::QModelIndex & current, const ::QModelIndex & previous)
{
    static const char *funcName = "currentChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::currentChanged(current, previous);
    }
    sbk_o_currentChanged("QAbstractItemView", funcName, gil, pyOverride, current, previous);
}

void QAbstractItemViewWrapper::sbk_o_currentChanged(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & current, const ::QModelIndex & previous)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &current),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &previous)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &current),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &previous)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QAbstractItemViewWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::dataChanged(const ::QModelIndex & topLeft, const ::QModelIndex & bottomRight, const ::QList<int> & roles)
{
    static const char *funcName = "dataChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::dataChanged(topLeft, bottomRight, roles);
    }
    sbk_o_dataChanged("QAbstractItemView", funcName, gil, pyOverride, topLeft, bottomRight, roles);
}

void QAbstractItemViewWrapper::sbk_o_dataChanged(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & topLeft, const ::QModelIndex & bottomRight, const ::QList<int> & roles)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &topLeft),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &bottomRight),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_int_IDX], &roles)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &topLeft),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &bottomRight),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_int_IDX], &roles)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

int QAbstractItemViewWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QAbstractItemView", funcName, gil, pyOverride);
}

void QAbstractItemViewWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QAbstractItemView", funcName, gil, pyOverride, signal);
}

void QAbstractItemViewWrapper::doItemsLayout()
{
    static const char *funcName = "doItemsLayout";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::doItemsLayout();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QAbstractItemView", funcName, gil, pyOverride);
}

void QAbstractItemViewWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::dragEnterEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragEnterEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::dragLeaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragLeaveEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::dragMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragMoveEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::dropEvent(event);
    }
    QWizardPageWrapper::sbk_o_dropEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

bool QAbstractItemViewWrapper::edit(const ::QModelIndex & index, ::QAbstractItemView::EditTrigger trigger, ::QEvent * event)
{
    static const char *funcName = "edit";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::edit(index, trigger, event);
    }
    return sbk_o_edit("QAbstractItemView", funcName, gil, pyOverride, index, trigger, event);
}

bool QAbstractItemViewWrapper::sbk_o_edit(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & index, ::QAbstractItemView::EditTrigger trigger, ::QEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_EditTrigger_IDX])))->converter, &trigger),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg3 = Py_REFCNT(pyArgArray[2]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_EditTrigger_IDX])))->converter, &trigger),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg3 = Py_REFCNT(PyTuple_GetItem(pyArgs, 2)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    if (invalidateArg3)
        Shiboken::Object::invalidate(pyArgArray[2]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg3)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 2));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractItemViewWrapper::editorDestroyed(::QObject * editor)
{
    static const char *funcName = "editorDestroyed";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::editorDestroyed(editor);
    }
    sbk_o_editorDestroyed("QAbstractItemView", funcName, gil, pyOverride, editor);
}

void QAbstractItemViewWrapper::sbk_o_editorDestroyed(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QObject * editor)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), editor)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), editor)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QAbstractItemViewWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QWizardPageWrapper::sbk_o_enterEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

bool QAbstractItemViewWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::event(event);
    }
    return QWidgetWrapper::sbk_o_event("QAbstractItemView", funcName, gil, pyOverride, event);
}

bool QAbstractItemViewWrapper::eventFilter(::QObject * object, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::eventFilter(object, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QAbstractItemView", funcName, gil, pyOverride, object, event);
}

void QAbstractItemViewWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::focusInEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusInEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

bool QAbstractItemViewWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::focusNextPrevChild(next);
    }
    return QWidgetWrapper::sbk_o_focusNextPrevChild("QAbstractItemView", funcName, gil, pyOverride, next);
}

void QAbstractItemViewWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::focusOutEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusOutEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

bool QAbstractItemViewWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QAbstractItemView", funcName, gil, pyOverride);
}

int QAbstractItemViewWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QAbstractItemView", funcName, gil, pyOverride, arg__1);
}

void QAbstractItemViewWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QWizardPageWrapper::sbk_o_hideEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

int QAbstractItemViewWrapper::horizontalOffset() const
{
    static const char *funcName = "horizontalOffset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.horizontalOffset");
        return 0;
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QAbstractItemView", funcName, gil, pyOverride);
}

void QAbstractItemViewWrapper::horizontalScrollbarAction(int action)
{
    static const char *funcName = "horizontalScrollbarAction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::horizontalScrollbarAction(action);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QAbstractItemView", funcName, gil, pyOverride, action);
}

void QAbstractItemViewWrapper::horizontalScrollbarValueChanged(int value)
{
    static const char *funcName = "horizontalScrollbarValueChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::horizontalScrollbarValueChanged(value);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QAbstractItemView", funcName, gil, pyOverride, value);
}

::QModelIndex QAbstractItemViewWrapper::indexAt(const ::QPoint & point) const
{
    static const char *funcName = "indexAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.indexAt");
        return {};
    }
    return sbk_o_indexAt("QAbstractItemView", funcName, gil, pyOverride, point);
}

::QModelIndex QAbstractItemViewWrapper::sbk_o_indexAt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QPoint & point)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &point)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &point)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QModelIndex >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QModelIndex cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractItemViewWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QWidgetWrapper::sbk_o_initPainter("QAbstractItemView", funcName, gil, pyOverride, painter);
}

void QAbstractItemViewWrapper::initStyleOption(::QStyleOptionFrame * option) const
{
    static const char *funcName = "initStyleOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFrame::initStyleOption(option);
    }
    QLineEditWrapper::sbk_o_initStyleOption("QAbstractItemView", funcName, gil, pyOverride, option);
}

void QAbstractItemViewWrapper::initViewItemOption(::QStyleOptionViewItem * option) const
{
    static const char *funcName = "initViewItemOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::initViewItemOption(option);
    }
    sbk_o_initViewItemOption("QAbstractItemView", funcName, gil, pyOverride, option);
}

void QAbstractItemViewWrapper::sbk_o_initViewItemOption(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyleOptionViewItem * option)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionViewItem_IDX]), option)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionViewItem_IDX]), option)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QAbstractItemViewWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::inputMethodEvent(event);
    }
    QWizardPageWrapper::sbk_o_inputMethodEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

::QVariant QAbstractItemViewWrapper::inputMethodQuery(::Qt::InputMethodQuery query) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::inputMethodQuery(query);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QAbstractItemView", funcName, gil, pyOverride, query);
}

bool QAbstractItemViewWrapper::isIndexHidden(const ::QModelIndex & index) const
{
    static const char *funcName = "isIndexHidden";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.isIndexHidden");
        return false;
    }
    return sbk_o_isIndexHidden("QAbstractItemView", funcName, gil, pyOverride, index);
}

bool QAbstractItemViewWrapper::sbk_o_isIndexHidden(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & index)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QAbstractItemDelegate * QAbstractItemViewWrapper::itemDelegateForIndex(const ::QModelIndex & index) const
{
    static const char *funcName = "itemDelegateForIndex";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::itemDelegateForIndex(index);
    }
    return sbk_o_itemDelegateForIndex("QAbstractItemView", funcName, gil, pyOverride, index);
}

::QAbstractItemDelegate * QAbstractItemViewWrapper::sbk_o_itemDelegateForIndex(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & index)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QAbstractItemDelegate >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QAbstractItemDelegate *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractItemViewWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::keyPressEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyPressEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyReleaseEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::keyboardSearch(const ::QString & search)
{
    static const char *funcName = "keyboardSearch";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::keyboardSearch(search);
    }
    QAccessibleWidgetWrapper::sbk_o_doAction("QAbstractItemView", funcName, gil, pyOverride, search);
}

void QAbstractItemViewWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_leaveEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

int QAbstractItemViewWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QWidgetWrapper::sbk_o_metric("QAbstractItemView", funcName, gil, pyOverride, arg__1);
}

::QSize QAbstractItemViewWrapper::minimumSizeHint() const
{
    static const char *funcName = "minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::minimumSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QAbstractItemView", funcName, gil, pyOverride);
}

void QAbstractItemViewWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::mouseDoubleClickEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseDoubleClickEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::mouseMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseMoveEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::mousePressEvent(event);
    }
    QWizardPageWrapper::sbk_o_mousePressEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::mouseReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseReleaseEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

::QModelIndex QAbstractItemViewWrapper::moveCursor(::QAbstractItemView::CursorAction cursorAction, ::QFlags<Qt::KeyboardModifier> modifiers)
{
    static const char *funcName = "moveCursor";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.moveCursor");
        return {};
    }
    return sbk_o_moveCursor("QAbstractItemView", funcName, gil, pyOverride, cursorAction, modifiers);
}

::QModelIndex QAbstractItemViewWrapper::sbk_o_moveCursor(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAbstractItemView::CursorAction cursorAction, ::QFlags<Qt::KeyboardModifier> modifiers)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_CursorAction_IDX])))->converter, &cursorAction),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, &modifiers)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_CursorAction_IDX])))->converter, &cursorAction),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, &modifiers)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QModelIndex >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QModelIndex cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractItemViewWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QWizardPageWrapper::sbk_o_moveEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

bool QAbstractItemViewWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[52], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QWizardPageWrapper::sbk_o_nativeEvent("QAbstractItemView", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QAbstractItemViewWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[53], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QWidgetWrapper::sbk_o_paintEngine("QAbstractItemView", funcName, gil, pyOverride);
}

void QAbstractItemViewWrapper::paintEvent(::QPaintEvent * arg__1)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[54], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::paintEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_paintEvent("QAbstractItemView", funcName, gil, pyOverride, arg__1);
}

::QPaintDevice * QAbstractItemViewWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[55], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QWidgetWrapper::sbk_o_redirected("QAbstractItemView", funcName, gil, pyOverride, offset);
}

void QAbstractItemViewWrapper::reset()
{
    static const char *funcName = "reset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[56], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::reset();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QAbstractItemView", funcName, gil, pyOverride);
}

void QAbstractItemViewWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[57], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::resizeEvent(event);
    }
    QWizardPageWrapper::sbk_o_resizeEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::rowsAboutToBeRemoved(const ::QModelIndex & parent, int start, int end)
{
    static const char *funcName = "rowsAboutToBeRemoved";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[58], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::rowsAboutToBeRemoved(parent, start, end);
    }
    sbk_o_rowsAboutToBeRemoved("QAbstractItemView", funcName, gil, pyOverride, parent, start, end);
}

void QAbstractItemViewWrapper::sbk_o_rowsAboutToBeRemoved(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & parent, int start, int end)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &parent),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &start),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &end)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(Nii)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &parent),
        start,
        end
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QAbstractItemViewWrapper::rowsInserted(const ::QModelIndex & parent, int start, int end)
{
    static const char *funcName = "rowsInserted";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[59], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::rowsInserted(parent, start, end);
    }
    QAbstractItemViewWrapper::sbk_o_rowsAboutToBeRemoved("QAbstractItemView", funcName, gil, pyOverride, parent, start, end);
}

void QAbstractItemViewWrapper::scrollContentsBy(int dx, int dy)
{
    static const char *funcName = "scrollContentsBy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[60], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::scrollContentsBy(dx, dy);
    }
    QAbstractScrollAreaWrapper::sbk_o_scrollContentsBy("QAbstractItemView", funcName, gil, pyOverride, dx, dy);
}

void QAbstractItemViewWrapper::scrollTo(const ::QModelIndex & index, ::QAbstractItemView::ScrollHint hint)
{
    static const char *funcName = "scrollTo";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[61], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.scrollTo");
        return;
    }
    sbk_o_scrollTo("QAbstractItemView", funcName, gil, pyOverride, index, hint);
}

void QAbstractItemViewWrapper::sbk_o_scrollTo(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & index, ::QAbstractItemView::ScrollHint hint)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollHint_IDX])))->converter, &hint)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollHint_IDX])))->converter, &hint)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QAbstractItemViewWrapper::selectAll()
{
    static const char *funcName = "selectAll";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[62], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::selectAll();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QAbstractItemView", funcName, gil, pyOverride);
}

::QList<QModelIndex> QAbstractItemViewWrapper::selectedIndexes() const
{
    static const char *funcName = "selectedIndexes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[63], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::selectedIndexes();
    }
    return sbk_o_selectedIndexes("QAbstractItemView", funcName, gil, pyOverride);
}

::QList<QModelIndex> QAbstractItemViewWrapper::sbk_o_selectedIndexes(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QModelIndex_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "list", Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QList<QModelIndex> cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractItemViewWrapper::selectionChanged(const ::QItemSelection & selected, const ::QItemSelection & deselected)
{
    static const char *funcName = "selectionChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[64], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::selectionChanged(selected, deselected);
    }
    sbk_o_selectionChanged("QAbstractItemView", funcName, gil, pyOverride, selected, deselected);
}

void QAbstractItemViewWrapper::sbk_o_selectionChanged(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QItemSelection & selected, const ::QItemSelection & deselected)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), &selected),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), &deselected)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), &selected),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), &deselected)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

::QFlags<QItemSelectionModel::SelectionFlag> QAbstractItemViewWrapper::selectionCommand(const ::QModelIndex & index, const ::QEvent * event) const
{
    static const char *funcName = "selectionCommand";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[65], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::selectionCommand(index, event);
    }
    return sbk_o_selectionCommand("QAbstractItemView", funcName, gil, pyOverride, index, event);
}

::QFlags<QItemSelectionModel::SelectionFlag> QAbstractItemViewWrapper::sbk_o_selectionCommand(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & index, const ::QEvent * event)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return QFlags<QItemSelectionModel::SelectionFlag>(0);
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QItemSelectionModel_SelectionFlag_IDX])))->flagsConverter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QFlags<QItemSelectionModel::SelectionFlag> >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QFlags<QItemSelectionModel::SelectionFlag>(0);
    }
    ::QFlags<QItemSelectionModel::SelectionFlag> cppResult = QFlags<QItemSelectionModel::SelectionFlag>(0);
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractItemViewWrapper::setModel(::QAbstractItemModel * model)
{
    static const char *funcName = "setModel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[66], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::setModel(model);
    }
    sbk_o_setModel("QAbstractItemView", funcName, gil, pyOverride, model);
}

void QAbstractItemViewWrapper::sbk_o_setModel(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAbstractItemModel * model)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), model)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), model)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QAbstractItemViewWrapper::setRootIndex(const ::QModelIndex & index)
{
    static const char *funcName = "setRootIndex";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[67], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::setRootIndex(index);
    }
    sbk_o_setRootIndex("QAbstractItemView", funcName, gil, pyOverride, index);
}

void QAbstractItemViewWrapper::sbk_o_setRootIndex(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & index)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QAbstractItemViewWrapper::setSelection(const ::QRect & rect, ::QFlags<QItemSelectionModel::SelectionFlag> command)
{
    static const char *funcName = "setSelection";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[68], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.setSelection");
        return;
    }
    sbk_o_setSelection("QAbstractItemView", funcName, gil, pyOverride, rect, command);
}

void QAbstractItemViewWrapper::sbk_o_setSelection(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QRect & rect, ::QFlags<QItemSelectionModel::SelectionFlag> command)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &rect),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QItemSelectionModel_SelectionFlag_IDX])))->flagsConverter, &command)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &rect),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QItemSelectionModel_SelectionFlag_IDX])))->flagsConverter, &command)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QAbstractItemViewWrapper::setSelectionModel(::QItemSelectionModel * selectionModel)
{
    static const char *funcName = "setSelectionModel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[69], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::setSelectionModel(selectionModel);
    }
    sbk_o_setSelectionModel("QAbstractItemView", funcName, gil, pyOverride, selectionModel);
}

void QAbstractItemViewWrapper::sbk_o_setSelectionModel(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QItemSelectionModel * selectionModel)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionModel_IDX]), selectionModel)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionModel_IDX]), selectionModel)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QAbstractItemViewWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[70], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QWidgetWrapper::sbk_o_setVisible("QAbstractItemView", funcName, gil, pyOverride, visible);
}

void QAbstractItemViewWrapper::setupViewport(::QWidget * viewport)
{
    static const char *funcName = "setupViewport";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[71], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::setupViewport(viewport);
    }
    QTextEditWrapper::sbk_o_setupViewport("QAbstractItemView", funcName, gil, pyOverride, viewport);
}

::QPainter * QAbstractItemViewWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[72], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QWidgetWrapper::sbk_o_sharedPainter("QAbstractItemView", funcName, gil, pyOverride);
}

void QAbstractItemViewWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[73], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QWizardPageWrapper::sbk_o_showEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

::QSize QAbstractItemViewWrapper::sizeHint() const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[74], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QAbstractItemView", funcName, gil, pyOverride);
}

int QAbstractItemViewWrapper::sizeHintForColumn(int column) const
{
    static const char *funcName = "sizeHintForColumn";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[75], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::sizeHintForColumn(column);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QAbstractItemView", funcName, gil, pyOverride, column);
}

int QAbstractItemViewWrapper::sizeHintForRow(int row) const
{
    static const char *funcName = "sizeHintForRow";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[76], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::sizeHintForRow(row);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QAbstractItemView", funcName, gil, pyOverride, row);
}

void QAbstractItemViewWrapper::startDrag(::QFlags<Qt::DropAction> supportedActions)
{
    static const char *funcName = "startDrag";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[77], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::startDrag(supportedActions);
    }
    sbk_o_startDrag("QAbstractItemView", funcName, gil, pyOverride, supportedActions);
}

void QAbstractItemViewWrapper::sbk_o_startDrag(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QFlags<Qt::DropAction> supportedActions)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_DropAction_IDX])))->flagsConverter, &supportedActions)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_DropAction_IDX])))->flagsConverter, &supportedActions)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QAbstractItemViewWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[78], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QWizardPageWrapper::sbk_o_tabletEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[79], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::timerEvent(event);
    }
    QWidgetWrapper::sbk_o_timerEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

void QAbstractItemViewWrapper::updateEditorData()
{
    static const char *funcName = "updateEditorData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[80], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::updateEditorData();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QAbstractItemView", funcName, gil, pyOverride);
}

void QAbstractItemViewWrapper::updateEditorGeometries()
{
    static const char *funcName = "updateEditorGeometries";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[81], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::updateEditorGeometries();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QAbstractItemView", funcName, gil, pyOverride);
}

void QAbstractItemViewWrapper::updateGeometries()
{
    static const char *funcName = "updateGeometries";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[82], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::updateGeometries();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QAbstractItemView", funcName, gil, pyOverride);
}

int QAbstractItemViewWrapper::verticalOffset() const
{
    static const char *funcName = "verticalOffset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[83], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.verticalOffset");
        return 0;
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QAbstractItemView", funcName, gil, pyOverride);
}

void QAbstractItemViewWrapper::verticalScrollbarAction(int action)
{
    static const char *funcName = "verticalScrollbarAction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[84], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::verticalScrollbarAction(action);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QAbstractItemView", funcName, gil, pyOverride, action);
}

void QAbstractItemViewWrapper::verticalScrollbarValueChanged(int value)
{
    static const char *funcName = "verticalScrollbarValueChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[85], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::verticalScrollbarValueChanged(value);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QAbstractItemView", funcName, gil, pyOverride, value);
}

bool QAbstractItemViewWrapper::viewportEvent(::QEvent * event)
{
    static const char *funcName = "viewportEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[86], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::viewportEvent(event);
    }
    return QTextEditWrapper::sbk_o_viewportEvent("QAbstractItemView", funcName, gil, pyOverride, event);
}

::QSize QAbstractItemViewWrapper::viewportSizeHint() const
{
    static const char *funcName = "viewportSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[87], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::viewportSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QAbstractItemView", funcName, gil, pyOverride);
}

::QRect QAbstractItemViewWrapper::visualRect(const ::QModelIndex & index) const
{
    static const char *funcName = "visualRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[88], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.visualRect");
        return {};
    }
    return sbk_o_visualRect("QAbstractItemView", funcName, gil, pyOverride, index);
}

::QRect QAbstractItemViewWrapper::sbk_o_visualRect(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QModelIndex & index)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QRect >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QRect cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QRegion QAbstractItemViewWrapper::visualRegionForSelection(const ::QItemSelection & selection) const
{
    static const char *funcName = "visualRegionForSelection";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[89], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.visualRegionForSelection");
        return {};
    }
    return sbk_o_visualRegionForSelection("QAbstractItemView", funcName, gil, pyOverride, selection);
}

::QRegion QAbstractItemViewWrapper::sbk_o_visualRegionForSelection(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QItemSelection & selection)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), &selection)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), &selection)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QRegion >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QRegion cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractItemViewWrapper::wheelEvent(::QWheelEvent * arg__1)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[90], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::wheelEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_wheelEvent("QAbstractItemView", funcName, gil, pyOverride, arg__1);
}

const QMetaObject *QAbstractItemViewWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QAbstractItemView::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstractItemViewWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QAbstractItemView::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstractItemViewWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstractItemViewWrapper *>(this));
    return QAbstractItemView::qt_metacast(_clname);
}

QAbstractItemViewWrapper::~QAbstractItemViewWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractItemView_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QAbstractItemView");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstractItemView >()))
        return -1;

    QAbstractItemViewWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QAbstractItemView", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAbstractItemView::QAbstractItemView(QWidget*=)
    if (numArgs == 0) {
        overloadId = 0; // QAbstractItemView(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QAbstractItemView(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemView(QWidget*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QAbstractItemViewWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QAbstractItemViewWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAbstractItemView >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QAbstractItemViewFunc_alternatingRowColors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // alternatingRowColors()const
        bool cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->alternatingRowColors();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_autoScrollMargin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // autoScrollMargin()const
        int cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->autoScrollMargin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_clearSelection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearSelection()
        cppSelf->clearSelection();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_closeEditor(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "closeEditor", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::closeEditor(QWidget*,QAbstractItemDelegate::EndEditHint)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_EndEditHint_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // closeEditor(QWidget*,QAbstractItemDelegate::EndEditHint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "closeEditor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QAbstractItemDelegate::EndEditHint cppArg1{QAbstractItemDelegate::NoHint};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // closeEditor(QWidget*,QAbstractItemDelegate::EndEditHint)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::closeEditor(cppArg0, cppArg1)
                : cppSelf->closeEditor(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_closePersistentEditor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::closePersistentEditor(QModelIndex)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // closePersistentEditor(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "closePersistentEditor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // closePersistentEditor(QModelIndex)
            cppSelf->closePersistentEditor(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_commitData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::commitData(QWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // commitData(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "commitData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // commitData(QWidget*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::commitData(cppArg0)
                : cppSelf->commitData(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_currentChanged(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "currentChanged", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::currentChanged(QModelIndex,QModelIndex)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[1])))) {
        overloadId = 0; // currentChanged(QModelIndex,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "currentChanged", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QModelIndex cppArg1_local;
        ::QModelIndex *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // currentChanged(QModelIndex,QModelIndex)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::currentChanged(*cppArg0, *cppArg1)
                : cppSelf->currentChanged(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_currentIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentIndex()const
        QModelIndex cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->currentIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_dataChanged(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "dataChanged", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:dataChanged", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::dataChanged(QModelIndex,QModelIndex,const QList<int>&=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // dataChanged(QModelIndex,QModelIndex,QList<int>)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_int_IDX], (pyArgs[2])))) {
            overloadId = 0; // dataChanged(QModelIndex,QModelIndex,QList<int>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dataChanged", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"roles", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_int_IDX], (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "dataChanged", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QModelIndex cppArg1_local;
        ::QModelIndex *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        ::QList<int> cppArg2_local = QList<int>();
        ::QList<int> *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // dataChanged(QModelIndex,QModelIndex,QList<int>)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::dataChanged(*cppArg0, *cppArg1, *cppArg2)
                : cppSelf->dataChanged(*cppArg0, *cppArg1, *cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_defaultDropAction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultDropAction()const
        Qt::DropAction cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->defaultDropAction();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DropAction_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_dirtyRegionOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dirtyRegionOffset()const
        QPoint cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->dirtyRegionOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_doAutoScroll(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // doAutoScroll()
        cppSelf->doAutoScroll();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_doItemsLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // doItemsLayout()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QAbstractItemView::doItemsLayout()
            : cppSelf->doItemsLayout();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_dragDropMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dragDropMode()const
        QAbstractItemView::DragDropMode cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->dragDropMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_DragDropMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_dragDropOverwriteMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dragDropOverwriteMode()const
        bool cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->dragDropOverwriteMode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_dragEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dragEnabled()const
        bool cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->dragEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_dragEnterEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::dragEnterEvent(QDragEnterEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dragEnterEvent(QDragEnterEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragEnterEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDragEnterEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragEnterEvent(QDragEnterEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::dragEnterEvent(cppArg0)
                : cppSelf->dragEnterEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_dragLeaveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::dragLeaveEvent(QDragLeaveEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragLeaveEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dragLeaveEvent(QDragLeaveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragLeaveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDragLeaveEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragLeaveEvent(QDragLeaveEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::dragLeaveEvent(cppArg0)
                : cppSelf->dragLeaveEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_dragMoveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::dragMoveEvent(QDragMoveEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dragMoveEvent(QDragMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragMoveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDragMoveEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragMoveEvent(QDragMoveEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::dragMoveEvent(cppArg0)
                : cppSelf->dragMoveEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_dropEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::dropEvent(QDropEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dropEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDropEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dropEvent(QDropEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::dropEvent(cppArg0)
                : cppSelf->dropEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_dropIndicatorPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dropIndicatorPosition()const
        QAbstractItemView::DropIndicatorPosition cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->dropIndicatorPosition();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_DropIndicatorPosition_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_edit(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments(args, "edit", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    if (PyArg_UnpackTuple(args, "edit", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::edit(QModelIndex,QAbstractItemView::EditTrigger,QEvent*)->bool
    // 1: QAbstractItemView::edit(QModelIndex)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // edit(QModelIndex)
        } else if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_EditTrigger_IDX])))->converter, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[2])))) {
            overloadId = 0; // edit(QModelIndex,QAbstractItemView::EditTrigger,QEvent*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "edit", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // edit(const QModelIndex &index, QAbstractItemView::EditTrigger trigger, QEvent *event)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QModelIndex cppArg0_local;
            ::QModelIndex *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QAbstractItemView::EditTrigger cppArg1{QAbstractItemView::NoEditTriggers};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QEvent *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // edit(QModelIndex,QAbstractItemView::EditTrigger,QEvent*)
                bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QAbstractItemView::edit(*cppArg0, cppArg1, cppArg2)
                    : cppSelf->edit(*cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // edit(const QModelIndex &index)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QModelIndex cppArg0_local;
            ::QModelIndex *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // edit(QModelIndex)
                cppSelf->edit(*cppArg0);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_editTriggers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // editTriggers()const
        QFlags<QAbstractItemView::EditTrigger> cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->editTriggers();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QAbstractItemView_EditTrigger_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_editorDestroyed(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::editorDestroyed(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // editorDestroyed(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "editorDestroyed", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // editorDestroyed(QObject*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::editorDestroyed(cppArg0)
                : cppSelf->editorDestroyed(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_eventFilter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "eventFilter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QObject::eventFilter(QObject*,QEvent*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // eventFilter(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "eventFilter", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // eventFilter(QObject*,QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::eventFilter(cppArg0, cppArg1)
                : cppSelf->eventFilter(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_executeDelayedItemsLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // executeDelayedItemsLayout()
        cppSelf->executeDelayedItemsLayout();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_focusInEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::focusInEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusInEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusInEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::focusInEvent(cppArg0)
                : cppSelf->focusInEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_focusNextPrevChild(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::focusNextPrevChild(bool)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusNextPrevChild", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusNextPrevChild(bool)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::focusNextPrevChild(cppArg0)
                : cppSelf->focusNextPrevChild(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_focusOutEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::focusOutEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusOutEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusOutEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::focusOutEvent(cppArg0)
                : cppSelf->focusOutEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_hasAutoScroll(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasAutoScroll()const
        bool cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->hasAutoScroll();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_horizontalOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // horizontalOffset()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.horizontalOffset");
            return {};
        }
        int cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->horizontalOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_horizontalScrollMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // horizontalScrollMode()const
        QAbstractItemView::ScrollMode cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->horizontalScrollMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_horizontalScrollbarAction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::horizontalScrollbarAction(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // horizontalScrollbarAction(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "horizontalScrollbarAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // horizontalScrollbarAction(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::horizontalScrollbarAction(cppArg0)
                : cppSelf->horizontalScrollbarAction(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_horizontalScrollbarValueChanged(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::horizontalScrollbarValueChanged(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // horizontalScrollbarValueChanged(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "horizontalScrollbarValueChanged", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // horizontalScrollbarValueChanged(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::horizontalScrollbarValueChanged(cppArg0)
                : cppSelf->horizontalScrollbarValueChanged(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_iconSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // iconSize()const
        QSize cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->iconSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_indexAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::indexAt(QPoint)const->QModelIndex
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // indexAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "indexAt", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint cppArg0_local;
        ::QPoint *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // indexAt(QPoint)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.indexAt");
                return {};
            }
            QModelIndex cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->indexAt(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_indexWidget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::indexWidget(QModelIndex)const->QWidget*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // indexWidget(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "indexWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // indexWidget(QModelIndex)const
            QWidget * cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->indexWidget(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_initViewItemOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::initViewItemOption(QStyleOptionViewItem*)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionViewItem_IDX]), (pyArg)))) {
        overloadId = 0; // initViewItemOption(QStyleOptionViewItem*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "initViewItemOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QStyleOptionViewItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // initViewItemOption(QStyleOptionViewItem*)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QAbstractItemView *>(cppSelf)->::QAbstractItemView::initViewItemOption(cppArg0)
                : const_cast<const ::QAbstractItemView *>(cppSelf)->initViewItemOption(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_inputMethodEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::inputMethodEvent(QInputMethodEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), (pyArg)))) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "inputMethodEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QInputMethodEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // inputMethodEvent(QInputMethodEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::inputMethodEvent(cppArg0)
                : cppSelf->inputMethodEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_inputMethodQuery(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::inputMethodQuery(Qt::InputMethodQuery)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "inputMethodQuery", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        ::Qt::InputMethodQuery cppArg0 = static_cast< ::Qt::InputMethodQuery>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // inputMethodQuery(Qt::InputMethodQuery)const
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QAbstractItemView *>(cppSelf)->::QAbstractItemView::inputMethodQuery(cppArg0)
                : const_cast<const ::QAbstractItemView *>(cppSelf)->inputMethodQuery(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_isIndexHidden(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::isIndexHidden(QModelIndex)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // isIndexHidden(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isIndexHidden", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isIndexHidden(QModelIndex)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.isIndexHidden");
                return {};
            }
            bool cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->isIndexHidden(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_isPersistentEditorOpen(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::isPersistentEditorOpen(QModelIndex)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // isPersistentEditorOpen(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isPersistentEditorOpen", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isPersistentEditorOpen(QModelIndex)const
            bool cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->isPersistentEditorOpen(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_itemDelegate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "itemDelegate", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::itemDelegate()const->QAbstractItemDelegate*
    // 1: QAbstractItemView::itemDelegate(QModelIndex)const->QAbstractItemDelegate*
    if (numArgs == 0) {
        overloadId = 0; // itemDelegate()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        overloadId = 1; // itemDelegate(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "itemDelegate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // itemDelegate() const
        {

            // itemDelegate()const
            QAbstractItemDelegate * cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->itemDelegate();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
            break;
        }
        case 1: // itemDelegate(const QModelIndex &index) const
        {
            Shiboken::Warnings::warnDeprecated("QAbstractItemView", "itemDelegate(const QModelIndex &index) const");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QModelIndex cppArg0_local;
            ::QModelIndex *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // itemDelegate(QModelIndex)const
                QAbstractItemDelegate * cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->itemDelegate(*cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_itemDelegateForColumn(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::itemDelegateForColumn(int)const->QAbstractItemDelegate*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // itemDelegateForColumn(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "itemDelegateForColumn", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // itemDelegateForColumn(int)const
            QAbstractItemDelegate * cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->itemDelegateForColumn(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_itemDelegateForIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::itemDelegateForIndex(QModelIndex)const->QAbstractItemDelegate*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // itemDelegateForIndex(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "itemDelegateForIndex", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // itemDelegateForIndex(QModelIndex)const
            QAbstractItemDelegate * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QAbstractItemView *>(cppSelf)->::QAbstractItemView::itemDelegateForIndex(*cppArg0)
                : const_cast<const ::QAbstractItemView *>(cppSelf)->itemDelegateForIndex(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_itemDelegateForRow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::itemDelegateForRow(int)const->QAbstractItemDelegate*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // itemDelegateForRow(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "itemDelegateForRow", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // itemDelegateForRow(int)const
            QAbstractItemDelegate * cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->itemDelegateForRow(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_keyPressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::keyPressEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyPressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyPressEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::keyPressEvent(cppArg0)
                : cppSelf->keyPressEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_keyboardSearch(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::keyboardSearch(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // keyboardSearch(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyboardSearch", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyboardSearch(QString)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::keyboardSearch(cppArg0)
                : cppSelf->keyboardSearch(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_model(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // model()const
        QAbstractItemModel * cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->model();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), cppResult);

        // Ownership transferences.
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_mouseDoubleClickEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mouseDoubleClickEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseDoubleClickEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseDoubleClickEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseDoubleClickEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::mouseDoubleClickEvent(cppArg0)
                : cppSelf->mouseDoubleClickEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_mouseMoveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mouseMoveEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseMoveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseMoveEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::mouseMoveEvent(cppArg0)
                : cppSelf->mouseMoveEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_mousePressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mousePressEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mousePressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mousePressEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::mousePressEvent(cppArg0)
                : cppSelf->mousePressEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_mouseReleaseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mouseReleaseEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseReleaseEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseReleaseEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::mouseReleaseEvent(cppArg0)
                : cppSelf->mouseReleaseEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_moveCursor(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "moveCursor", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::moveCursor(QAbstractItemView::CursorAction,QFlags<Qt::KeyboardModifier>)->QModelIndex
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_CursorAction_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[1])))) {
        overloadId = 0; // moveCursor(QAbstractItemView::CursorAction,QFlags<Qt::KeyboardModifier>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "moveCursor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        ::QAbstractItemView::CursorAction cppArg0{QAbstractItemView::MoveUp};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::KeyboardModifier> cppArg1 = QFlags<Qt::KeyboardModifier>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // moveCursor(QAbstractItemView::CursorAction,QFlags<Qt::KeyboardModifier>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.moveCursor");
                return {};
            }
            QModelIndex cppResult = cppSelf->moveCursor(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_openPersistentEditor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::openPersistentEditor(QModelIndex)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // openPersistentEditor(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "openPersistentEditor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // openPersistentEditor(QModelIndex)
            cppSelf->openPersistentEditor(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_reset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reset()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QAbstractItemView::reset()
            : cppSelf->reset();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_resetHorizontalScrollMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetHorizontalScrollMode()
        cppSelf->resetHorizontalScrollMode();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_resetVerticalScrollMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetVerticalScrollMode()
        cppSelf->resetVerticalScrollMode();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_resizeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::resizeEvent(QResizeEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), (pyArg)))) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resizeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QResizeEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeEvent(QResizeEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::resizeEvent(cppArg0)
                : cppSelf->resizeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_rootIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rootIndex()const
        QModelIndex cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->rootIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_rowsAboutToBeRemoved(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "rowsAboutToBeRemoved", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::rowsAboutToBeRemoved(QModelIndex,int,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // rowsAboutToBeRemoved(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rowsAboutToBeRemoved", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rowsAboutToBeRemoved(QModelIndex,int,int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::rowsAboutToBeRemoved(*cppArg0, cppArg1, cppArg2)
                : cppSelf->rowsAboutToBeRemoved(*cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_rowsInserted(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "rowsInserted", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::rowsInserted(QModelIndex,int,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // rowsInserted(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rowsInserted", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rowsInserted(QModelIndex,int,int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::rowsInserted(*cppArg0, cppArg1, cppArg2)
                : cppSelf->rowsInserted(*cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_scheduleDelayedItemsLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scheduleDelayedItemsLayout()
        cppSelf->scheduleDelayedItemsLayout();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_scrollDirtyRegion(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "scrollDirtyRegion", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::scrollDirtyRegion(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // scrollDirtyRegion(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scrollDirtyRegion", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // scrollDirtyRegion(int,int)
            cppSelf->scrollDirtyRegion(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_scrollTo(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "scrollTo", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    if (PyArg_ParseTuple(args, "|OO:scrollTo", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::scrollTo(QModelIndex,QAbstractItemView::ScrollHint=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollHint_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scrollTo", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"hint", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollHint_IDX])))->converter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "scrollTo", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QAbstractItemView::ScrollHint cppArg1(QAbstractItemView::ScrollHint::EnsureVisible);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.scrollTo");
                return {};
            }
            cppSelf->scrollTo(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_scrollToBottom(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scrollToBottom()
        cppSelf->scrollToBottom();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_scrollToTop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scrollToTop()
        cppSelf->scrollToTop();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_selectAll(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectAll()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QAbstractItemView::selectAll()
            : cppSelf->selectAll();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_selectedIndexes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedIndexes()const
        QList<QModelIndex> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QAbstractItemView *>(cppSelf)->::QAbstractItemView::selectedIndexes()
            : const_cast<const ::QAbstractItemView *>(cppSelf)->selectedIndexes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QModelIndex_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_selectionBehavior(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectionBehavior()const
        QAbstractItemView::SelectionBehavior cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->selectionBehavior();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_SelectionBehavior_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_selectionChanged(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "selectionChanged", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::selectionChanged(QItemSelection,QItemSelection)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), (pyArgs[1])))) {
        overloadId = 0; // selectionChanged(QItemSelection,QItemSelection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "selectionChanged", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QItemSelection cppArg0_local;
        ::QItemSelection *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QItemSelection cppArg1_local;
        ::QItemSelection *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // selectionChanged(QItemSelection,QItemSelection)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::selectionChanged(*cppArg0, *cppArg1)
                : cppSelf->selectionChanged(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_selectionCommand(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "selectionCommand", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    if (PyArg_ParseTuple(args, "|OO:selectionCommand", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::selectionCommand(QModelIndex,const QEvent*=)const->QFlags<QItemSelectionModel::SelectionFlag>
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // selectionCommand(QModelIndex,const QEvent*)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
            overloadId = 0; // selectionCommand(QModelIndex,const QEvent*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "selectionCommand", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"event", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "selectionCommand", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectionCommand(QModelIndex,const QEvent*)const
            QFlags<QItemSelectionModel::SelectionFlag> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QAbstractItemView *>(cppSelf)->::QAbstractItemView::selectionCommand(*cppArg0, cppArg1)
                : const_cast<const ::QAbstractItemView *>(cppSelf)->selectionCommand(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QItemSelectionModel_SelectionFlag_IDX])))->flagsConverter, &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_selectionMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectionMode()const
        QAbstractItemView::SelectionMode cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->selectionMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_SelectionMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_selectionModel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectionModel()const
        QItemSelectionModel * cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->selectionModel();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionModel_IDX]), cppResult);

        // Ownership transferences.
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_setAlternatingRowColors(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setAlternatingRowColors(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAlternatingRowColors(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAlternatingRowColors", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAlternatingRowColors(bool)
            cppSelf->setAlternatingRowColors(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setAutoScroll(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setAutoScroll(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoScroll(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoScroll", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoScroll(bool)
            cppSelf->setAutoScroll(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setAutoScrollMargin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setAutoScrollMargin(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setAutoScrollMargin(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoScrollMargin", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoScrollMargin(int)
            cppSelf->setAutoScrollMargin(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setCurrentIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setCurrentIndex(QModelIndex)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // setCurrentIndex(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCurrentIndex", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrentIndex(QModelIndex)
            cppSelf->setCurrentIndex(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setDefaultDropAction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setDefaultDropAction(Qt::DropAction)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DropAction_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDefaultDropAction(Qt::DropAction)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDefaultDropAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        ::Qt::DropAction cppArg0{Qt::IgnoreAction};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultDropAction(Qt::DropAction)
            cppSelf->setDefaultDropAction(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setDirtyRegion(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setDirtyRegion(QRegion)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), (pyArg)))) {
        overloadId = 0; // setDirtyRegion(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDirtyRegion", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegion cppArg0_local;
        ::QRegion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDirtyRegion(QRegion)
            cppSelf->setDirtyRegion(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setDragDropMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setDragDropMode(QAbstractItemView::DragDropMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_DragDropMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDragDropMode(QAbstractItemView::DragDropMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDragDropMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        ::QAbstractItemView::DragDropMode cppArg0{QAbstractItemView::NoDragDrop};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDragDropMode(QAbstractItemView::DragDropMode)
            cppSelf->setDragDropMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setDragDropOverwriteMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setDragDropOverwriteMode(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDragDropOverwriteMode(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDragDropOverwriteMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDragDropOverwriteMode(bool)
            cppSelf->setDragDropOverwriteMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setDragEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setDragEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDragEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDragEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDragEnabled(bool)
            cppSelf->setDragEnabled(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setDropIndicatorShown(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setDropIndicatorShown(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDropIndicatorShown(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDropIndicatorShown", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDropIndicatorShown(bool)
            cppSelf->setDropIndicatorShown(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setEditTriggers(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setEditTriggers(QFlags<QAbstractItemView::EditTrigger>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QAbstractItemView_EditTrigger_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setEditTriggers(QFlags<QAbstractItemView::EditTrigger>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEditTriggers", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        ::QFlags<QAbstractItemView::EditTrigger> cppArg0 = QFlags<QAbstractItemView::EditTrigger>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEditTriggers(QFlags<QAbstractItemView::EditTrigger>)
            cppSelf->setEditTriggers(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setHorizontalScrollMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setHorizontalScrollMode(QAbstractItemView::ScrollMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setHorizontalScrollMode(QAbstractItemView::ScrollMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHorizontalScrollMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        ::QAbstractItemView::ScrollMode cppArg0{QAbstractItemView::ScrollPerItem};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHorizontalScrollMode(QAbstractItemView::ScrollMode)
            cppSelf->setHorizontalScrollMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setIconSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setIconSize(QSize)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
        overloadId = 0; // setIconSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIconSize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSize cppArg0_local;
        ::QSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setIconSize(QSize)
            cppSelf->setIconSize(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setIndexWidget(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setIndexWidget", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::setIndexWidget(QModelIndex,QWidget*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setIndexWidget(QModelIndex,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setIndexWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QWidget *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIndexWidget(QModelIndex,QWidget*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setIndexWidget(*cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[1]);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setItemDelegate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setItemDelegate(QAbstractItemDelegate*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX]), (pyArg)))) {
        overloadId = 0; // setItemDelegate(QAbstractItemDelegate*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItemDelegate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractItemDelegate *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemDelegate(QAbstractItemDelegate*)
            cppSelf->setItemDelegate(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "setItemDelegate(QAbstractItemDelegate*)1", pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setItemDelegateForColumn(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setItemDelegateForColumn", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::setItemDelegateForColumn(int,QAbstractItemDelegate*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setItemDelegateForColumn(int,QAbstractItemDelegate*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setItemDelegateForColumn", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QAbstractItemDelegate *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemDelegateForColumn(int,QAbstractItemDelegate*)
            cppSelf->setItemDelegateForColumn(cppArg0, cppArg1);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "setItemDelegateForColumn(int,QAbstractItemDelegate*)2", pyArgs[1]);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setItemDelegateForRow(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setItemDelegateForRow", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::setItemDelegateForRow(int,QAbstractItemDelegate*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setItemDelegateForRow(int,QAbstractItemDelegate*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setItemDelegateForRow", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QAbstractItemDelegate *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemDelegateForRow(int,QAbstractItemDelegate*)
            cppSelf->setItemDelegateForRow(cppArg0, cppArg1);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "setItemDelegateForRow(int,QAbstractItemDelegate*)2", pyArgs[1]);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setModel(QAbstractItemModel*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), (pyArg)))) {
        overloadId = 0; // setModel(QAbstractItemModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setModel", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractItemModel *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setModel(QAbstractItemModel*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::setModel(cppArg0)
                : cppSelf->setModel(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "setModel(QAbstractItemModel*)1", pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setRootIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setRootIndex(QModelIndex)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // setRootIndex(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRootIndex", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRootIndex(QModelIndex)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::setRootIndex(*cppArg0)
                : cppSelf->setRootIndex(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setSelection(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setSelection", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QItemSelectionModel_SelectionFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
        overloadId = 0; // setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSelection", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRect cppArg0_local;
        ::QRect *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QFlags<QItemSelectionModel::SelectionFlag> cppArg1 = QFlags<QItemSelectionModel::SelectionFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.setSelection");
                return {};
            }
            cppSelf->setSelection(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setSelectionBehavior(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setSelectionBehavior(QAbstractItemView::SelectionBehavior)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_SelectionBehavior_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSelectionBehavior(QAbstractItemView::SelectionBehavior)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelectionBehavior", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        ::QAbstractItemView::SelectionBehavior cppArg0{QAbstractItemView::SelectItems};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectionBehavior(QAbstractItemView::SelectionBehavior)
            cppSelf->setSelectionBehavior(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setSelectionMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setSelectionMode(QAbstractItemView::SelectionMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_SelectionMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSelectionMode(QAbstractItemView::SelectionMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelectionMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        ::QAbstractItemView::SelectionMode cppArg0{QAbstractItemView::NoSelection};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectionMode(QAbstractItemView::SelectionMode)
            cppSelf->setSelectionMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setSelectionModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setSelectionModel(QItemSelectionModel*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionModel_IDX]), (pyArg)))) {
        overloadId = 0; // setSelectionModel(QItemSelectionModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelectionModel", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QItemSelectionModel *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectionModel(QItemSelectionModel*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::setSelectionModel(cppArg0)
                : cppSelf->setSelectionModel(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "setSelectionModel(QItemSelectionModel*)1", pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setState(QAbstractItemView::State)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_State_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setState(QAbstractItemView::State)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setState", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        ::QAbstractItemView::State cppArg0{QAbstractItemView::NoState};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setState(QAbstractItemView::State)
            cppSelf->setState(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setTabKeyNavigation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setTabKeyNavigation(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setTabKeyNavigation(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTabKeyNavigation", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabKeyNavigation(bool)
            cppSelf->setTabKeyNavigation(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setTextElideMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setTextElideMode(Qt::TextElideMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TextElideMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTextElideMode(Qt::TextElideMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextElideMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        ::Qt::TextElideMode cppArg0{Qt::ElideLeft};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextElideMode(Qt::TextElideMode)
            cppSelf->setTextElideMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setUpdateThreshold(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setUpdateThreshold(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setUpdateThreshold(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUpdateThreshold", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUpdateThreshold(int)
            cppSelf->setUpdateThreshold(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_setVerticalScrollMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setVerticalScrollMode(QAbstractItemView::ScrollMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setVerticalScrollMode(QAbstractItemView::ScrollMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVerticalScrollMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        ::QAbstractItemView::ScrollMode cppArg0{QAbstractItemView::ScrollPerItem};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVerticalScrollMode(QAbstractItemView::ScrollMode)
            cppSelf->setVerticalScrollMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_showDropIndicator(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showDropIndicator()const
        bool cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->showDropIndicator();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_sizeHintForColumn(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::sizeHintForColumn(int)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // sizeHintForColumn(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "sizeHintForColumn", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sizeHintForColumn(int)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QAbstractItemView *>(cppSelf)->::QAbstractItemView::sizeHintForColumn(cppArg0)
                : const_cast<const ::QAbstractItemView *>(cppSelf)->sizeHintForColumn(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_sizeHintForIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::sizeHintForIndex(QModelIndex)const->QSize
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // sizeHintForIndex(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "sizeHintForIndex", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // sizeHintForIndex(QModelIndex)const
            QSize cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->sizeHintForIndex(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_sizeHintForRow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::sizeHintForRow(int)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // sizeHintForRow(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "sizeHintForRow", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sizeHintForRow(int)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QAbstractItemView *>(cppSelf)->::QAbstractItemView::sizeHintForRow(cppArg0)
                : const_cast<const ::QAbstractItemView *>(cppSelf)->sizeHintForRow(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_startAutoScroll(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // startAutoScroll()
        cppSelf->startAutoScroll();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_startDrag(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::startDrag(QFlags<Qt::DropAction>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_DropAction_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // startDrag(QFlags<Qt::DropAction>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "startDrag", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        ::QFlags<Qt::DropAction> cppArg0 = QFlags<Qt::DropAction>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // startDrag(QFlags<Qt::DropAction>)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::startDrag(cppArg0)
                : cppSelf->startDrag(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QAbstractItemView::State cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_State_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_stopAutoScroll(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stopAutoScroll()
        cppSelf->stopAutoScroll();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_tabKeyNavigation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tabKeyNavigation()const
        bool cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->tabKeyNavigation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_textElideMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textElideMode()const
        Qt::TextElideMode cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->textElideMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TextElideMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_timerEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::timerEvent(QTimerEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), (pyArg)))) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "timerEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTimerEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // timerEvent(QTimerEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::timerEvent(cppArg0)
                : cppSelf->timerEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_update(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::update(QModelIndex)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // update(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "update", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // update(QModelIndex)
            cppSelf->update(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_updateEditorData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // updateEditorData()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QAbstractItemView::updateEditorData()
            : cppSelf->updateEditorData();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_updateEditorGeometries(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // updateEditorGeometries()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QAbstractItemView::updateEditorGeometries()
            : cppSelf->updateEditorGeometries();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_updateGeometries(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // updateGeometries()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QAbstractItemView::updateGeometries()
            : cppSelf->updateGeometries();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_updateThreshold(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // updateThreshold()const
        int cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->updateThreshold();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_verticalOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // verticalOffset()const
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.verticalOffset");
            return {};
        }
        int cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->verticalOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_verticalScrollMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // verticalScrollMode()const
        QAbstractItemView::ScrollMode cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->verticalScrollMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_verticalScrollbarAction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::verticalScrollbarAction(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // verticalScrollbarAction(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "verticalScrollbarAction", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // verticalScrollbarAction(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::verticalScrollbarAction(cppArg0)
                : cppSelf->verticalScrollbarAction(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_verticalScrollbarValueChanged(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::verticalScrollbarValueChanged(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // verticalScrollbarValueChanged(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "verticalScrollbarValueChanged", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // verticalScrollbarValueChanged(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::verticalScrollbarValueChanged(cppArg0)
                : cppSelf->verticalScrollbarValueChanged(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QAbstractItemViewFunc_viewportEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractScrollArea::viewportEvent(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // viewportEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "viewportEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // viewportEvent(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractItemView::viewportEvent(cppArg0)
                : cppSelf->viewportEvent(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_viewportSizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewportSizeHint()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QAbstractItemView *>(cppSelf)->::QAbstractItemView::viewportSizeHint()
            : const_cast<const ::QAbstractItemView *>(cppSelf)->viewportSizeHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_visualRect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::visualRect(QModelIndex)const->QRect
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // visualRect(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "visualRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // visualRect(QModelIndex)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.visualRect");
                return {};
            }
            QRect cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->visualRect(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QAbstractItemViewFunc_visualRegionForSelection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::visualRegionForSelection(QItemSelection)const->QRegion
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), (pyArg)))) {
        overloadId = 0; // visualRegionForSelection(QItemSelection)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "visualRegionForSelection", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QItemSelection cppArg0_local;
        ::QItemSelection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // visualRegionForSelection(QItemSelection)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractItemView.visualRegionForSelection");
                return {};
            }
            QRegion cppResult = const_cast<const ::QAbstractItemView *>(cppSelf)->visualRegionForSelection(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QAbstractItemView_PropertyStrings[] = {
    "alternatingRowColors::",
    "autoScroll:hasAutoScroll:",
    "autoScrollMargin::",
    "defaultDropAction::",
    "dragDropMode::",
    "dragDropOverwriteMode::",
    "dragEnabled::",
    "editTriggers::",
    "horizontalScrollMode::",
    "iconSize::",
    "selectionBehavior::",
    "selectionMode::",
    "showDropIndicator::setDropIndicatorShown",
    "tabKeyNavigation::",
    "textElideMode::",
    "updateThreshold::",
    "verticalScrollMode::",
    nullptr // Sentinel
};

static const char *Sbk_QAbstractItemView_EnumFlagInfo[] = {
    "CursorAction:Enum",
    "DragDropMode:Enum",
    "DropIndicatorPosition:Enum",
    "EditTrigger:Flag:EditTriggers",
    "ScrollHint:Enum",
    "ScrollMode:Enum",
    "SelectionBehavior:Enum",
    "SelectionMode:Enum",
    "State:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractItemView_methods[] = {
    {"alternatingRowColors", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_alternatingRowColors), METH_NOARGS, nullptr},
    {"autoScrollMargin", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_autoScrollMargin), METH_NOARGS, nullptr},
    {"clearSelection", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_clearSelection), METH_NOARGS, nullptr},
    {"closeEditor", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_closeEditor), METH_VARARGS, nullptr},
    {"closePersistentEditor", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_closePersistentEditor), METH_O, nullptr},
    {"commitData", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_commitData), METH_O, nullptr},
    {"currentChanged", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_currentChanged), METH_VARARGS, nullptr},
    {"currentIndex", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_currentIndex), METH_NOARGS, nullptr},
    {"dataChanged", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_dataChanged), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"defaultDropAction", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_defaultDropAction), METH_NOARGS, nullptr},
    {"dirtyRegionOffset", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_dirtyRegionOffset), METH_NOARGS, nullptr},
    {"doAutoScroll", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_doAutoScroll), METH_NOARGS, nullptr},
    {"doItemsLayout", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_doItemsLayout), METH_NOARGS, nullptr},
    {"dragDropMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_dragDropMode), METH_NOARGS, nullptr},
    {"dragDropOverwriteMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_dragDropOverwriteMode), METH_NOARGS, nullptr},
    {"dragEnabled", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_dragEnabled), METH_NOARGS, nullptr},
    {"dragEnterEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_dragEnterEvent), METH_O, nullptr},
    {"dragLeaveEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_dragLeaveEvent), METH_O, nullptr},
    {"dragMoveEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_dragMoveEvent), METH_O, nullptr},
    {"dropEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_dropEvent), METH_O, nullptr},
    {"dropIndicatorPosition", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_dropIndicatorPosition), METH_NOARGS, nullptr},
    {"edit", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_edit), METH_VARARGS, nullptr},
    {"editTriggers", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_editTriggers), METH_NOARGS, nullptr},
    {"editorDestroyed", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_editorDestroyed), METH_O, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_event), METH_O, nullptr},
    {"eventFilter", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_eventFilter), METH_VARARGS, nullptr},
    {"executeDelayedItemsLayout", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_executeDelayedItemsLayout), METH_NOARGS, nullptr},
    {"focusInEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_focusInEvent), METH_O, nullptr},
    {"focusNextPrevChild", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_focusNextPrevChild), METH_O, nullptr},
    {"focusOutEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_focusOutEvent), METH_O, nullptr},
    {"hasAutoScroll", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_hasAutoScroll), METH_NOARGS, nullptr},
    {"horizontalOffset", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_horizontalOffset), METH_NOARGS, nullptr},
    {"horizontalScrollMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_horizontalScrollMode), METH_NOARGS, nullptr},
    {"horizontalScrollbarAction", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_horizontalScrollbarAction), METH_O, nullptr},
    {"horizontalScrollbarValueChanged", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_horizontalScrollbarValueChanged), METH_O, nullptr},
    {"iconSize", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_iconSize), METH_NOARGS, nullptr},
    {"indexAt", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_indexAt), METH_O, nullptr},
    {"indexWidget", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_indexWidget), METH_O, nullptr},
    {"initViewItemOption", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_initViewItemOption), METH_O, nullptr},
    {"inputMethodEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_inputMethodEvent), METH_O, nullptr},
    {"inputMethodQuery", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_inputMethodQuery), METH_O, nullptr},
    {"isIndexHidden", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_isIndexHidden), METH_O, nullptr},
    {"isPersistentEditorOpen", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_isPersistentEditorOpen), METH_O, nullptr},
    {"itemDelegate", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_itemDelegate), METH_VARARGS, nullptr},
    {"itemDelegateForColumn", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_itemDelegateForColumn), METH_O, nullptr},
    {"itemDelegateForIndex", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_itemDelegateForIndex), METH_O, nullptr},
    {"itemDelegateForRow", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_itemDelegateForRow), METH_O, nullptr},
    {"keyPressEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_keyPressEvent), METH_O, nullptr},
    {"keyboardSearch", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_keyboardSearch), METH_O, nullptr},
    {"model", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_model), METH_NOARGS, nullptr},
    {"mouseDoubleClickEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_mouseDoubleClickEvent), METH_O, nullptr},
    {"mouseMoveEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_mouseMoveEvent), METH_O, nullptr},
    {"mousePressEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_mousePressEvent), METH_O, nullptr},
    {"mouseReleaseEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_mouseReleaseEvent), METH_O, nullptr},
    {"moveCursor", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_moveCursor), METH_VARARGS, nullptr},
    {"openPersistentEditor", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_openPersistentEditor), METH_O, nullptr},
    {"reset", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_reset), METH_NOARGS, nullptr},
    {"resetHorizontalScrollMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_resetHorizontalScrollMode), METH_NOARGS, nullptr},
    {"resetVerticalScrollMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_resetVerticalScrollMode), METH_NOARGS, nullptr},
    {"resizeEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_resizeEvent), METH_O, nullptr},
    {"rootIndex", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_rootIndex), METH_NOARGS, nullptr},
    {"rowsAboutToBeRemoved", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_rowsAboutToBeRemoved), METH_VARARGS, nullptr},
    {"rowsInserted", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_rowsInserted), METH_VARARGS, nullptr},
    {"scheduleDelayedItemsLayout", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_scheduleDelayedItemsLayout), METH_NOARGS, nullptr},
    {"scrollDirtyRegion", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_scrollDirtyRegion), METH_VARARGS, nullptr},
    {"scrollTo", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_scrollTo), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"scrollToBottom", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_scrollToBottom), METH_NOARGS, nullptr},
    {"scrollToTop", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_scrollToTop), METH_NOARGS, nullptr},
    {"selectAll", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_selectAll), METH_NOARGS, nullptr},
    {"selectedIndexes", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_selectedIndexes), METH_NOARGS, nullptr},
    {"selectionBehavior", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_selectionBehavior), METH_NOARGS, nullptr},
    {"selectionChanged", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_selectionChanged), METH_VARARGS, nullptr},
    {"selectionCommand", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_selectionCommand), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"selectionMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_selectionMode), METH_NOARGS, nullptr},
    {"selectionModel", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_selectionModel), METH_NOARGS, nullptr},
    {"setAlternatingRowColors", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setAlternatingRowColors), METH_O, nullptr},
    {"setAutoScroll", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setAutoScroll), METH_O, nullptr},
    {"setAutoScrollMargin", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setAutoScrollMargin), METH_O, nullptr},
    {"setCurrentIndex", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setCurrentIndex), METH_O, nullptr},
    {"setDefaultDropAction", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setDefaultDropAction), METH_O, nullptr},
    {"setDirtyRegion", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setDirtyRegion), METH_O, nullptr},
    {"setDragDropMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setDragDropMode), METH_O, nullptr},
    {"setDragDropOverwriteMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setDragDropOverwriteMode), METH_O, nullptr},
    {"setDragEnabled", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setDragEnabled), METH_O, nullptr},
    {"setDropIndicatorShown", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setDropIndicatorShown), METH_O, nullptr},
    {"setEditTriggers", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setEditTriggers), METH_O, nullptr},
    {"setHorizontalScrollMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setHorizontalScrollMode), METH_O, nullptr},
    {"setIconSize", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setIconSize), METH_O, nullptr},
    {"setIndexWidget", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setIndexWidget), METH_VARARGS, nullptr},
    {"setItemDelegate", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setItemDelegate), METH_O, nullptr},
    {"setItemDelegateForColumn", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setItemDelegateForColumn), METH_VARARGS, nullptr},
    {"setItemDelegateForRow", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setItemDelegateForRow), METH_VARARGS, nullptr},
    {"setModel", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setModel), METH_O, nullptr},
    {"setRootIndex", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setRootIndex), METH_O, nullptr},
    {"setSelection", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setSelection), METH_VARARGS, nullptr},
    {"setSelectionBehavior", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setSelectionBehavior), METH_O, nullptr},
    {"setSelectionMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setSelectionMode), METH_O, nullptr},
    {"setSelectionModel", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setSelectionModel), METH_O, nullptr},
    {"setState", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setState), METH_O, nullptr},
    {"setTabKeyNavigation", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setTabKeyNavigation), METH_O, nullptr},
    {"setTextElideMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setTextElideMode), METH_O, nullptr},
    {"setUpdateThreshold", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setUpdateThreshold), METH_O, nullptr},
    {"setVerticalScrollMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_setVerticalScrollMode), METH_O, nullptr},
    {"showDropIndicator", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_showDropIndicator), METH_NOARGS, nullptr},
    {"sizeHintForColumn", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_sizeHintForColumn), METH_O, nullptr},
    {"sizeHintForIndex", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_sizeHintForIndex), METH_O, nullptr},
    {"sizeHintForRow", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_sizeHintForRow), METH_O, nullptr},
    {"startAutoScroll", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_startAutoScroll), METH_NOARGS, nullptr},
    {"startDrag", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_startDrag), METH_O, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_state), METH_NOARGS, nullptr},
    {"stopAutoScroll", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_stopAutoScroll), METH_NOARGS, nullptr},
    {"tabKeyNavigation", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_tabKeyNavigation), METH_NOARGS, nullptr},
    {"textElideMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_textElideMode), METH_NOARGS, nullptr},
    {"timerEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_timerEvent), METH_O, nullptr},
    {"update", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_update), METH_O, nullptr},
    {"updateEditorData", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_updateEditorData), METH_NOARGS, nullptr},
    {"updateEditorGeometries", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_updateEditorGeometries), METH_NOARGS, nullptr},
    {"updateGeometries", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_updateGeometries), METH_NOARGS, nullptr},
    {"updateThreshold", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_updateThreshold), METH_NOARGS, nullptr},
    {"verticalOffset", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_verticalOffset), METH_NOARGS, nullptr},
    {"verticalScrollMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_verticalScrollMode), METH_NOARGS, nullptr},
    {"verticalScrollbarAction", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_verticalScrollbarAction), METH_O, nullptr},
    {"verticalScrollbarValueChanged", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_verticalScrollbarValueChanged), METH_O, nullptr},
    {"viewportEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_viewportEvent), METH_O, nullptr},
    {"viewportSizeHint", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_viewportSizeHint), METH_NOARGS, nullptr},
    {"visualRect", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_visualRect), METH_O, nullptr},
    {"visualRegionForSelection", reinterpret_cast<PyCFunction>(Sbk_QAbstractItemViewFunc_visualRegionForSelection), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractItemView_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstractItemView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractItemViewWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractItemView_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractItemView_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QAbstractItemViewSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QAbstractItemView *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX]))
        return static_cast< ::QAbstractScrollArea *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX]))
        return static_cast< ::QFrame *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractItemView_Type = nullptr;
static PyTypeObject *Sbk_QAbstractItemView_TypeF(void)
{
    return _Sbk_QAbstractItemView_Type;
}

static PyType_Slot Sbk_QAbstractItemView_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractItemView_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractItemView_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractItemView_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractItemView_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractItemView_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractItemView_spec = {
    "2:PySide6.QtWidgets.QAbstractItemView",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractItemView_slots
};

} //extern "C"

static void *Sbk_QAbstractItemView_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QAbstractItemView *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAbstractItemView *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QAbstractItemView *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAbstractItemView_SelectionMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractItemView::SelectionMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractItemView::SelectionMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractItemView_SelectionMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_SelectionMode_IDX])))
        return Enum_PythonToCpp_QAbstractItemView_SelectionMode;
    return {};
}

static PyObject *QAbstractItemView_SelectionMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractItemView::SelectionMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractItemView::SelectionMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_SelectionMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractItemView_SelectionBehavior(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractItemView::SelectionBehavior>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractItemView::SelectionBehavior *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractItemView_SelectionBehavior_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_SelectionBehavior_IDX])))
        return Enum_PythonToCpp_QAbstractItemView_SelectionBehavior;
    return {};
}

static PyObject *QAbstractItemView_SelectionBehavior_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractItemView::SelectionBehavior>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractItemView::SelectionBehavior *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_SelectionBehavior_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractItemView_ScrollHint(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractItemView::ScrollHint>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractItemView::ScrollHint *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractItemView_ScrollHint_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollHint_IDX])))
        return Enum_PythonToCpp_QAbstractItemView_ScrollHint;
    return {};
}

static PyObject *QAbstractItemView_ScrollHint_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractItemView::ScrollHint>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractItemView::ScrollHint *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollHint_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractItemView_EditTrigger(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractItemView::EditTrigger>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractItemView::EditTrigger *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractItemView_EditTrigger_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_EditTrigger_IDX])))
        return Enum_PythonToCpp_QAbstractItemView_EditTrigger;
    return {};
}

static PyObject *QAbstractItemView_EditTrigger_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractItemView::EditTrigger>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractItemView::EditTrigger *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_EditTrigger_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QAbstractItemView_EditTrigger(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QAbstractItemView::EditTrigger>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QAbstractItemView::EditTrigger> *>(cppOut) = value;

}

static PyObject *QAbstractItemView_EditTrigger_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QAbstractItemView::EditTrigger> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_EditTrigger_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QAbstractItemView_ScrollMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractItemView::ScrollMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractItemView::ScrollMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractItemView_ScrollMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollMode_IDX])))
        return Enum_PythonToCpp_QAbstractItemView_ScrollMode;
    return {};
}

static PyObject *QAbstractItemView_ScrollMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractItemView::ScrollMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractItemView::ScrollMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractItemView_DragDropMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractItemView::DragDropMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractItemView::DragDropMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractItemView_DragDropMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_DragDropMode_IDX])))
        return Enum_PythonToCpp_QAbstractItemView_DragDropMode;
    return {};
}

static PyObject *QAbstractItemView_DragDropMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractItemView::DragDropMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractItemView::DragDropMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_DragDropMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractItemView_CursorAction(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractItemView::CursorAction>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractItemView::CursorAction *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractItemView_CursorAction_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_CursorAction_IDX])))
        return Enum_PythonToCpp_QAbstractItemView_CursorAction;
    return {};
}

static PyObject *QAbstractItemView_CursorAction_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractItemView::CursorAction>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractItemView::CursorAction *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_CursorAction_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractItemView_State(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractItemView::State>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractItemView::State *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractItemView_State_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_State_IDX])))
        return Enum_PythonToCpp_QAbstractItemView_State;
    return {};
}

static PyObject *QAbstractItemView_State_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractItemView::State>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractItemView::State *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_State_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractItemView_DropIndicatorPosition(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractItemView::DropIndicatorPosition>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractItemView::DropIndicatorPosition *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractItemView_DropIndicatorPosition_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_DropIndicatorPosition_IDX])))
        return Enum_PythonToCpp_QAbstractItemView_DropIndicatorPosition;
    return {};
}

static PyObject *QAbstractItemView_DropIndicatorPosition_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractItemView::DropIndicatorPosition>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractItemView::DropIndicatorPosition *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_DropIndicatorPosition_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractItemView_PythonToCpp_QAbstractItemView_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractItemView_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractItemView_PythonToCpp_QAbstractItemView_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractItemView_TypeF()))
        return QAbstractItemView_PythonToCpp_QAbstractItemView_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractItemView_PTR_CppToPython_QAbstractItemView(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAbstractItemView *>(const_cast<void *>(cppIn)), Sbk_QAbstractItemView_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractItemView_SignatureStrings[] = {
    "PySide6.QtWidgets.QAbstractItemView(self,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,autoScroll:bool=None,autoScrollMargin:int=None,editTriggers:PySide6.QtWidgets.QAbstractItemView.EditTrigger=None,tabKeyNavigation:bool=None,showDropIndicator:bool=None,dragEnabled:bool=None,dragDropOverwriteMode:bool=None,dragDropMode:QAbstractItemView.DragDropMode=None,defaultDropAction:Qt.DropAction=None,alternatingRowColors:bool=None,selectionMode:QAbstractItemView.SelectionMode=None,selectionBehavior:QAbstractItemView.SelectionBehavior=None,iconSize:QSize=None,textElideMode:Qt.TextElideMode=None,verticalScrollMode:QAbstractItemView.ScrollMode=None,horizontalScrollMode:QAbstractItemView.ScrollMode=None,updateThreshold:int=None)",
    "PySide6.QtWidgets.QAbstractItemView.alternatingRowColors(self)->bool",
    "PySide6.QtWidgets.QAbstractItemView.autoScrollMargin(self)->int",
    "PySide6.QtWidgets.QAbstractItemView.clearSelection(self)",
    "PySide6.QtWidgets.QAbstractItemView.closeEditor(self,editor:PySide6.QtWidgets.QWidget,hint:PySide6.QtWidgets.QAbstractItemDelegate.EndEditHint)",
    "PySide6.QtWidgets.QAbstractItemView.closePersistentEditor(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "PySide6.QtWidgets.QAbstractItemView.commitData(self,editor:PySide6.QtWidgets.QWidget)",
    "PySide6.QtWidgets.QAbstractItemView.currentChanged(self,current:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],previous:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "PySide6.QtWidgets.QAbstractItemView.currentIndex(self)->PySide6.QtCore.QModelIndex",
    "PySide6.QtWidgets.QAbstractItemView.dataChanged(self,topLeft:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],bottomRight:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],roles:QList[int]=QList<int>())",
    "PySide6.QtWidgets.QAbstractItemView.defaultDropAction(self)->PySide6.QtCore.Qt.DropAction",
    "PySide6.QtWidgets.QAbstractItemView.dirtyRegionOffset(self)->PySide6.QtCore.QPoint",
    "PySide6.QtWidgets.QAbstractItemView.doAutoScroll(self)",
    "PySide6.QtWidgets.QAbstractItemView.doItemsLayout(self)",
    "PySide6.QtWidgets.QAbstractItemView.dragDropMode(self)->PySide6.QtWidgets.QAbstractItemView.DragDropMode",
    "PySide6.QtWidgets.QAbstractItemView.dragDropOverwriteMode(self)->bool",
    "PySide6.QtWidgets.QAbstractItemView.dragEnabled(self)->bool",
    "PySide6.QtWidgets.QAbstractItemView.dragEnterEvent(self,event:PySide6.QtGui.QDragEnterEvent)",
    "PySide6.QtWidgets.QAbstractItemView.dragLeaveEvent(self,event:PySide6.QtGui.QDragLeaveEvent)",
    "PySide6.QtWidgets.QAbstractItemView.dragMoveEvent(self,event:PySide6.QtGui.QDragMoveEvent)",
    "PySide6.QtWidgets.QAbstractItemView.dropEvent(self,event:PySide6.QtGui.QDropEvent)",
    "PySide6.QtWidgets.QAbstractItemView.dropIndicatorPosition(self)->PySide6.QtWidgets.QAbstractItemView.DropIndicatorPosition",
    "1:PySide6.QtWidgets.QAbstractItemView.edit(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],trigger:PySide6.QtWidgets.QAbstractItemView.EditTrigger,event:PySide6.QtCore.QEvent)->bool",
    "0:PySide6.QtWidgets.QAbstractItemView.edit(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "PySide6.QtWidgets.QAbstractItemView.editTriggers(self)->PySide6.QtWidgets.QAbstractItemView.EditTrigger",
    "PySide6.QtWidgets.QAbstractItemView.editorDestroyed(self,editor:PySide6.QtCore.QObject)",
    "PySide6.QtWidgets.QAbstractItemView.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QAbstractItemView.eventFilter(self,object:PySide6.QtCore.QObject,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QAbstractItemView.executeDelayedItemsLayout(self)",
    "PySide6.QtWidgets.QAbstractItemView.focusInEvent(self,event:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtWidgets.QAbstractItemView.focusNextPrevChild(self,next:bool)->bool",
    "PySide6.QtWidgets.QAbstractItemView.focusOutEvent(self,event:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtWidgets.QAbstractItemView.hasAutoScroll(self)->bool",
    "PySide6.QtWidgets.QAbstractItemView.horizontalOffset(self)->int",
    "PySide6.QtWidgets.QAbstractItemView.horizontalScrollMode(self)->PySide6.QtWidgets.QAbstractItemView.ScrollMode",
    "PySide6.QtWidgets.QAbstractItemView.horizontalScrollbarAction(self,action:int)",
    "PySide6.QtWidgets.QAbstractItemView.horizontalScrollbarValueChanged(self,value:int)",
    "PySide6.QtWidgets.QAbstractItemView.iconSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QAbstractItemView.indexAt(self,point:PySide6.QtCore.QPoint)->PySide6.QtCore.QModelIndex",
    "PySide6.QtWidgets.QAbstractItemView.indexWidget(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtWidgets.QWidget",
    "PySide6.QtWidgets.QAbstractItemView.initViewItemOption(self,option:PySide6.QtWidgets.QStyleOptionViewItem)",
    "PySide6.QtWidgets.QAbstractItemView.inputMethodEvent(self,event:PySide6.QtGui.QInputMethodEvent)",
    "PySide6.QtWidgets.QAbstractItemView.inputMethodQuery(self,query:PySide6.QtCore.Qt.InputMethodQuery)->QVariant",
    "PySide6.QtWidgets.QAbstractItemView.isIndexHidden(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "PySide6.QtWidgets.QAbstractItemView.isPersistentEditorOpen(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "1:PySide6.QtWidgets.QAbstractItemView.itemDelegate(self)->PySide6.QtWidgets.QAbstractItemDelegate",
    "0:PySide6.QtWidgets.QAbstractItemView.itemDelegate(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtWidgets.QAbstractItemDelegate",
    "PySide6.QtWidgets.QAbstractItemView.itemDelegateForColumn(self,column:int)->PySide6.QtWidgets.QAbstractItemDelegate",
    "PySide6.QtWidgets.QAbstractItemView.itemDelegateForIndex(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtWidgets.QAbstractItemDelegate",
    "PySide6.QtWidgets.QAbstractItemView.itemDelegateForRow(self,row:int)->PySide6.QtWidgets.QAbstractItemDelegate",
    "PySide6.QtWidgets.QAbstractItemView.keyPressEvent(self,event:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtWidgets.QAbstractItemView.keyboardSearch(self,search:QString)",
    "PySide6.QtWidgets.QAbstractItemView.model(self)->PySide6.QtCore.QAbstractItemModel",
    "PySide6.QtWidgets.QAbstractItemView.mouseDoubleClickEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QAbstractItemView.mouseMoveEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QAbstractItemView.mousePressEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QAbstractItemView.mouseReleaseEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QAbstractItemView.moveCursor(self,cursorAction:PySide6.QtWidgets.QAbstractItemView.CursorAction,modifiers:PySide6.QtCore.Qt.KeyboardModifier)->PySide6.QtCore.QModelIndex",
    "PySide6.QtWidgets.QAbstractItemView.openPersistentEditor(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "PySide6.QtWidgets.QAbstractItemView.reset(self)",
    "PySide6.QtWidgets.QAbstractItemView.resetHorizontalScrollMode(self)",
    "PySide6.QtWidgets.QAbstractItemView.resetVerticalScrollMode(self)",
    "PySide6.QtWidgets.QAbstractItemView.resizeEvent(self,event:PySide6.QtGui.QResizeEvent)",
    "PySide6.QtWidgets.QAbstractItemView.rootIndex(self)->PySide6.QtCore.QModelIndex",
    "PySide6.QtWidgets.QAbstractItemView.rowsAboutToBeRemoved(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],start:int,end:int)",
    "PySide6.QtWidgets.QAbstractItemView.rowsInserted(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],start:int,end:int)",
    "PySide6.QtWidgets.QAbstractItemView.scheduleDelayedItemsLayout(self)",
    "PySide6.QtWidgets.QAbstractItemView.scrollDirtyRegion(self,dx:int,dy:int)",
    "PySide6.QtWidgets.QAbstractItemView.scrollTo(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],hint:PySide6.QtWidgets.QAbstractItemView.ScrollHint=QAbstractItemView.ScrollHint.EnsureVisible)",
    "PySide6.QtWidgets.QAbstractItemView.scrollToBottom(self)",
    "PySide6.QtWidgets.QAbstractItemView.scrollToTop(self)",
    "PySide6.QtWidgets.QAbstractItemView.selectAll(self)",
    "PySide6.QtWidgets.QAbstractItemView.selectedIndexes(self)->QList[PySide6.QtCore.QModelIndex]",
    "PySide6.QtWidgets.QAbstractItemView.selectionBehavior(self)->PySide6.QtWidgets.QAbstractItemView.SelectionBehavior",
    "PySide6.QtWidgets.QAbstractItemView.selectionChanged(self,selected:PySide6.QtCore.QItemSelection,deselected:PySide6.QtCore.QItemSelection)",
    "PySide6.QtWidgets.QAbstractItemView.selectionCommand(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],event:PySide6.QtCore.QEvent=nullptr)->PySide6.QtCore.QItemSelectionModel.SelectionFlag",
    "PySide6.QtWidgets.QAbstractItemView.selectionMode(self)->PySide6.QtWidgets.QAbstractItemView.SelectionMode",
    "PySide6.QtWidgets.QAbstractItemView.selectionModel(self)->PySide6.QtCore.QItemSelectionModel",
    "PySide6.QtWidgets.QAbstractItemView.setAlternatingRowColors(self,enable:bool)",
    "PySide6.QtWidgets.QAbstractItemView.setAutoScroll(self,enable:bool)",
    "PySide6.QtWidgets.QAbstractItemView.setAutoScrollMargin(self,margin:int)",
    "PySide6.QtWidgets.QAbstractItemView.setCurrentIndex(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "PySide6.QtWidgets.QAbstractItemView.setDefaultDropAction(self,dropAction:PySide6.QtCore.Qt.DropAction)",
    "PySide6.QtWidgets.QAbstractItemView.setDirtyRegion(self,region:typing.Union[PySide6.QtGui.QRegion, PySide6.QtGui.QBitmap, PySide6.QtGui.QPolygon, PySide6.QtCore.QRect])",
    "PySide6.QtWidgets.QAbstractItemView.setDragDropMode(self,behavior:PySide6.QtWidgets.QAbstractItemView.DragDropMode)",
    "PySide6.QtWidgets.QAbstractItemView.setDragDropOverwriteMode(self,overwrite:bool)",
    "PySide6.QtWidgets.QAbstractItemView.setDragEnabled(self,enable:bool)",
    "PySide6.QtWidgets.QAbstractItemView.setDropIndicatorShown(self,enable:bool)",
    "PySide6.QtWidgets.QAbstractItemView.setEditTriggers(self,triggers:PySide6.QtWidgets.QAbstractItemView.EditTrigger)",
    "PySide6.QtWidgets.QAbstractItemView.setHorizontalScrollMode(self,mode:PySide6.QtWidgets.QAbstractItemView.ScrollMode)",
    "PySide6.QtWidgets.QAbstractItemView.setIconSize(self,size:PySide6.QtCore.QSize)",
    "PySide6.QtWidgets.QAbstractItemView.setIndexWidget(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],widget:PySide6.QtWidgets.QWidget)",
    "PySide6.QtWidgets.QAbstractItemView.setItemDelegate(self,delegate:PySide6.QtWidgets.QAbstractItemDelegate)",
    "PySide6.QtWidgets.QAbstractItemView.setItemDelegateForColumn(self,column:int,delegate:PySide6.QtWidgets.QAbstractItemDelegate)",
    "PySide6.QtWidgets.QAbstractItemView.setItemDelegateForRow(self,row:int,delegate:PySide6.QtWidgets.QAbstractItemDelegate)",
    "PySide6.QtWidgets.QAbstractItemView.setModel(self,model:Optional[PySide6.QtCore.QAbstractItemModel])",
    "PySide6.QtWidgets.QAbstractItemView.setRootIndex(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "PySide6.QtWidgets.QAbstractItemView.setSelection(self,rect:PySide6.QtCore.QRect,command:PySide6.QtCore.QItemSelectionModel.SelectionFlag)",
    "PySide6.QtWidgets.QAbstractItemView.setSelectionBehavior(self,behavior:PySide6.QtWidgets.QAbstractItemView.SelectionBehavior)",
    "PySide6.QtWidgets.QAbstractItemView.setSelectionMode(self,mode:PySide6.QtWidgets.QAbstractItemView.SelectionMode)",
    "PySide6.QtWidgets.QAbstractItemView.setSelectionModel(self,selectionModel:PySide6.QtCore.QItemSelectionModel)",
    "PySide6.QtWidgets.QAbstractItemView.setState(self,state:PySide6.QtWidgets.QAbstractItemView.State)",
    "PySide6.QtWidgets.QAbstractItemView.setTabKeyNavigation(self,enable:bool)",
    "PySide6.QtWidgets.QAbstractItemView.setTextElideMode(self,mode:PySide6.QtCore.Qt.TextElideMode)",
    "PySide6.QtWidgets.QAbstractItemView.setUpdateThreshold(self,threshold:int)",
    "PySide6.QtWidgets.QAbstractItemView.setVerticalScrollMode(self,mode:PySide6.QtWidgets.QAbstractItemView.ScrollMode)",
    "PySide6.QtWidgets.QAbstractItemView.showDropIndicator(self)->bool",
    "PySide6.QtWidgets.QAbstractItemView.sizeHintForColumn(self,column:int)->int",
    "PySide6.QtWidgets.QAbstractItemView.sizeHintForIndex(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QAbstractItemView.sizeHintForRow(self,row:int)->int",
    "PySide6.QtWidgets.QAbstractItemView.startAutoScroll(self)",
    "PySide6.QtWidgets.QAbstractItemView.startDrag(self,supportedActions:PySide6.QtCore.Qt.DropAction)",
    "PySide6.QtWidgets.QAbstractItemView.state(self)->PySide6.QtWidgets.QAbstractItemView.State",
    "PySide6.QtWidgets.QAbstractItemView.stopAutoScroll(self)",
    "PySide6.QtWidgets.QAbstractItemView.tabKeyNavigation(self)->bool",
    "PySide6.QtWidgets.QAbstractItemView.textElideMode(self)->PySide6.QtCore.Qt.TextElideMode",
    "PySide6.QtWidgets.QAbstractItemView.timerEvent(self,event:PySide6.QtCore.QTimerEvent)",
    "PySide6.QtWidgets.QAbstractItemView.update(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "PySide6.QtWidgets.QAbstractItemView.updateEditorData(self)",
    "PySide6.QtWidgets.QAbstractItemView.updateEditorGeometries(self)",
    "PySide6.QtWidgets.QAbstractItemView.updateGeometries(self)",
    "PySide6.QtWidgets.QAbstractItemView.updateThreshold(self)->int",
    "PySide6.QtWidgets.QAbstractItemView.verticalOffset(self)->int",
    "PySide6.QtWidgets.QAbstractItemView.verticalScrollMode(self)->PySide6.QtWidgets.QAbstractItemView.ScrollMode",
    "PySide6.QtWidgets.QAbstractItemView.verticalScrollbarAction(self,action:int)",
    "PySide6.QtWidgets.QAbstractItemView.verticalScrollbarValueChanged(self,value:int)",
    "PySide6.QtWidgets.QAbstractItemView.viewportEvent(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QAbstractItemView.viewportSizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QAbstractItemView.visualRect(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.QRect",
    "PySide6.QtWidgets.QAbstractItemView.visualRegionForSelection(self,selection:PySide6.QtCore.QItemSelection)->PySide6.QtGui.QRegion",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractItemView_SignatureByteSize = 1902;
static constexpr uint8_t QAbstractItemView_SignatureBytes[1902] = {
    0x78, 0xda, 0xd5, 0x5b, 0x4b, 0x73, 0xdb, 0x36, 0x10, 0xbe, 0xe7, 0x57, 0xf4, 0x18, 0x77, 0x58,
    0x4d, 0x7b, 0xe9, 0x41, 0x53, 0x67, 0xc6, 0x96, 0xe4, 0x44, 0x13, 0x3b, 0xb6, 0x1e, 0x71, 0x0f,
    0x99, 0x1c, 0x20, 0x11, 0x96, 0xd0, 0x50, 0x04, 0x0b, 0x80, 0x52, 0x94, 0x5f, 0xdf, 0x05, 0x40,
    0x8a, 0xe0, 0xcb, 0x5a, 0xe8, 0x61, 0xa7, 0x17, 0x0d, 0x0c, 0x62, 0xbf, 0x5d, 0x2c, 0x80, 0xdd,
    0xc5, 0x2e, 0xfc, 0xb0, 0x9d, 0xb0, 0x90, 0xfe, 0xd9, 0x19, 0xa9, 0xbf, 0x59, 0xb8, 0xa0, 0x4a,
    0x76, 0x46, 0x57, 0x33, 0xa9, 0x04, 0x99, 0xab, 0xa1, 0xa2, 0xab, 0x47, 0x46, 0x37, 0x6f, 0x25,
    0x8d, 0x9e, 0x82, 0x84, 0x08, 0x1a, 0xab, 0xee, 0x43, 0x7d, 0xbc, 0x6d, 0x5c, 0xc6, 0x69, 0x14,
    0x25, 0x4a, 0x04, 0xbf, 0x76, 0x3f, 0xd2, 0xed, 0x86, 0x8b, 0xf0, 0x3e, 0x8e, 0xb6, 0x97, 0x9f,
    0x78, 0x4c, 0x03, 0x92, 0x2a, 0x3e, 0x99, 0x0b, 0x1e, 0x45, 0xdd, 0x19, 0xe7, 0x51, 0xb5, 0xf3,
    0x8e, 0x88, 0x05, 0x8b, 0xbb, 0x2c, 0x56, 0xf6, 0x0b, 0x0d, 0x99, 0x9a, 0x0a, 0xb6, 0x58, 0x50,
    0x21, 0x9b, 0x18, 0x56, 0x05, 0xec, 0x0c, 0x0a, 0x02, 0x8b, 0xa0, 0xc8, 0x0c, 0x84, 0xf8, 0x44,
    0xd6, 0x6c, 0x41, 0x14, 0xe3, 0xb1, 0xc3, 0x56, 0x2e, 0xf9, 0xa6, 0x2f, 0x78, 0x32, 0x8c, 0x43,
    0x36, 0x27, 0x8a, 0x0b, 0xe7, 0x5b, 0x28, 0xc8, 0x62, 0x10, 0x93, 0x59, 0x44, 0xc3, 0x4a, 0xaf,
    0xa6, 0xb8, 0x5f, 0x53, 0xb1, 0x11, 0x4c, 0xd1, 0x3b, 0x1e, 0xd2, 0x86, 0xef, 0xa6, 0xbb, 0x2e,
    0x5c, 0xdf, 0xf9, 0x9c, 0x11, 0xd0, 0x27, 0x92, 0x46, 0x4a, 0x77, 0x5e, 0xcd, 0x8d, 0x78, 0x23,
    0xd5, 0x29, 0xfe, 0xca, 0xd4, 0x13, 0x29, 0x2a, 0x62, 0x90, 0x3e, 0x5e, 0x8c, 0xf9, 0xa6, 0xc7,
    0x23, 0x0e, 0xca, 0x70, 0xa6, 0x41, 0x23, 0x6a, 0x46, 0xb7, 0x70, 0x9d, 0xb8, 0xdf, 0x2b, 0x24,
    0xd7, 0x74, 0x09, 0x9a, 0x81, 0x99, 0x3f, 0x43, 0x96, 0x8f, 0xb1, 0xa4, 0x6c, 0xce, 0xe3, 0x09,
    0xfb, 0x01, 0x8c, 0xf4, 0x6f, 0xa6, 0x63, 0xfa, 0x5d, 0x0d, 0x22, 0x58, 0x1b, 0x2b, 0x81, 0xea,
    0x4c, 0xdd, 0x0e, 0x3b, 0x06, 0x34, 0xa6, 0x40, 0xcb, 0x51, 0xb6, 0xce, 0x2d, 0xa2, 0xee, 0x3e,
    0x5a, 0xa2, 0x25, 0x17, 0xec, 0x07, 0x8f, 0x95, 0x27, 0x59, 0x9a, 0x84, 0x44, 0xd1, 0xe9, 0x52,
    0x50, 0x58, 0xe2, 0x28, 0xdc, 0x6d, 0xa7, 0x8b, 0x37, 0x98, 0x2d, 0xd4, 0xa4, 0x6e, 0xb3, 0xf1,
    0x2f, 0x7e, 0x7b, 0xa7, 0xb5, 0x8e, 0x03, 0xa9, 0x6c, 0xe9, 0x1c, 0x00, 0x44, 0x41, 0xd1, 0xcf,
    0x23, 0x4a, 0xc4, 0x6e, 0x09, 0x2c, 0x35, 0x92, 0x90, 0x4b, 0xaa, 0x4f, 0x01, 0x17, 0xf6, 0xb4,
    0x52, 0xd3, 0x6e, 0x3f, 0xad, 0xc1, 0x92, 0x35, 0x1f, 0x66, 0x17, 0xba, 0x0f, 0x92, 0xc0, 0xf9,
    0xa1, 0x9d, 0x41, 0x1c, 0x6a, 0xf0, 0x0f, 0x40, 0xe3, 0x21, 0xcf, 0x03, 0x1c, 0x5f, 0x26, 0x15,
    0x58, 0x0d, 0x57, 0x32, 0x16, 0x87, 0xf4, 0x7b, 0x57, 0x6d, 0x13, 0xd0, 0x74, 0xe7, 0x73, 0x0c,
    0xf3, 0xfc, 0x52, 0x20, 0xf6, 0xb8, 0xa0, 0x9d, 0x91, 0x5e, 0xd3, 0x68, 0xa8, 0xc7, 0x05, 0xbf,
    0x54, 0xbf, 0x15, 0xa0, 0xc5, 0xa8, 0xaf, 0x48, 0xa1, 0xf8, 0x6a, 0xc5, 0x54, 0x9f, 0x28, 0x82,
    0xd3, 0x11, 0x12, 0x35, 0x15, 0xda, 0x30, 0xf6, 0x96, 0x24, 0x5e, 0xd0, 0xd0, 0x22, 0x67, 0x7d,
    0x27, 0x9e, 0x65, 0x90, 0x08, 0x0a, 0x47, 0x32, 0x95, 0xaf, 0xa3, 0x3d, 0x3b, 0x27, 0x43, 0x92,
    0xef, 0xeb, 0x76, 0xd6, 0x28, 0x48, 0x38, 0xaf, 0xa4, 0xa4, 0x37, 0xc5, 0x93, 0x5b, 0xfa, 0x74,
    0x72, 0xbd, 0xcd, 0xb8, 0x52, 0x7c, 0x35, 0x66, 0x8b, 0xe5, 0xc9, 0xa1, 0xe1, 0xac, 0x53, 0xd9,
    0x1d, 0xdd, 0xc2, 0x97, 0x2f, 0x70, 0x3a, 0xbe, 0x5e, 0x9a, 0xe6, 0x5f, 0xd0, 0x7c, 0xf7, 0xf6,
    0x02, 0xa7, 0xd8, 0x9a, 0x37, 0x68, 0xd3, 0xae, 0xeb, 0x23, 0x70, 0xc8, 0x4c, 0xa8, 0xed, 0x98,
    0x2e, 0x60, 0xfc, 0xfd, 0xd3, 0x93, 0xa4, 0xaa, 0x0d, 0xf9, 0x81, 0x63, 0x2d, 0x54, 0xc8, 0xaf,
    0x76, 0x36, 0xce, 0xc3, 0x3e, 0x85, 0x5c, 0x37, 0xe5, 0x2d, 0xd9, 0xf2, 0x54, 0xf9, 0xd0, 0x39,
    0xbe, 0xb3, 0x2e, 0x7c, 0x3b, 0x9d, 0xeb, 0x73, 0xbd, 0x18, 0x95, 0x7c, 0xbc, 0xb7, 0xfd, 0x77,
    0xe2, 0x87, 0x03, 0x69, 0xc1, 0x09, 0x0d, 0xd6, 0xb0, 0xc7, 0x32, 0x0b, 0xb5, 0x2e, 0x87, 0x5c,
    0xef, 0x53, 0xd6, 0x19, 0xf5, 0x4b, 0x03, 0xf1, 0x7a, 0xbc, 0xa5, 0x64, 0x4d, 0x31, 0xe0, 0xc5,
    0x40, 0x3c, 0xf8, 0x1d, 0xc7, 0x61, 0xef, 0xc6, 0x61, 0xa1, 0x79, 0xb2, 0x1f, 0x36, 0x1b, 0x83,
    0x87, 0xdc, 0xc5, 0x7e, 0x0f, 0x5c, 0xb2, 0xe6, 0x23, 0xf7, 0xdc, 0xde, 0x6a, 0x00, 0x78, 0xf3,
    0x07, 0x2a, 0x50, 0xd5, 0x2e, 0xe7, 0x7c, 0x6e, 0x30, 0x50, 0x36, 0x06, 0xf6, 0x8d, 0x99, 0x6b,
    0x7a, 0xb5, 0x3c, 0xac, 0x52, 0xb3, 0x2d, 0xfc, 0xfb, 0x4f, 0x30, 0x3f, 0xdc, 0x02, 0xbb, 0xb7,
    0x07, 0x9f, 0x75, 0x75, 0x14, 0x82, 0xe6, 0xc3, 0x45, 0x9f, 0x42, 0x37, 0xdf, 0xe6, 0x1e, 0xac,
    0x16, 0x53, 0xd8, 0xe9, 0xdc, 0xcf, 0xfe, 0x81, 0x98, 0x0e, 0x29, 0x7f, 0xfb, 0x7e, 0x6f, 0x58,
    0x17, 0x34, 0xe2, 0x0d, 0xd3, 0x11, 0xae, 0xc5, 0xe5, 0x46, 0x9c, 0x16, 0x29, 0x4f, 0xc6, 0xf5,
    0x3b, 0x9d, 0xa7, 0x8a, 0x42, 0x10, 0x49, 0x40, 0x3d, 0x87, 0xd9, 0xff, 0x27, 0x3e, 0x4f, 0xe5,
    0x30, 0xde, 0x67, 0x02, 0x6e, 0xf4, 0x30, 0x0f, 0x1b, 0x60, 0x60, 0x3f, 0xc1, 0x75, 0xe5, 0x01,
    0x22, 0xaa, 0xde, 0x92, 0x45, 0xd9, 0xea, 0xc5, 0xd0, 0x65, 0xee, 0x58, 0x3e, 0xf3, 0x34, 0x60,
    0xf7, 0xa9, 0x3a, 0xb5, 0x90, 0x4b, 0x22, 0xab, 0xbe, 0xd6, 0x43, 0xaa, 0xe2, 0x12, 0x55, 0x76,
    0xfd, 0x58, 0x47, 0xdf, 0x74, 0x09, 0xf3, 0x39, 0x4d, 0x05, 0xd5, 0x41, 0xec, 0x66, 0x44, 0x38,
    0xc1, 0x50, 0x40, 0xec, 0x35, 0x19, 0x7d, 0xff, 0x68, 0x80, 0x7b, 0x24, 0x51, 0x4a, 0x4b, 0xd1,
    0xe6, 0x5a, 0xf7, 0xe0, 0x31, 0xf3, 0x3b, 0x70, 0x5b, 0x10, 0xa5, 0xbf, 0xe1, 0x80, 0xb4, 0x31,
    0xbb, 0xca, 0xb6, 0x4a, 0xc2, 0x59, 0xc3, 0x61, 0x33, 0x01, 0xd9, 0xf1, 0x01, 0xb6, 0xe1, 0x64,
    0x3f, 0x9f, 0xd1, 0x2a, 0x37, 0x6e, 0x08, 0xdb, 0x40, 0x4a, 0xc9, 0x94, 0x6e, 0xe8, 0x8e, 0xfb,
    0xa4, 0x58, 0x74, 0x6e, 0xda, 0x4d, 0x7e, 0x67, 0xa2, 0xb6, 0x11, 0xb5, 0x43, 0x73, 0x42, 0xe4,
    0x1a, 0xc6, 0x49, 0xaa, 0xee, 0xa8, 0x5a, 0xf2, 0x70, 0xdf, 0x71, 0x1d, 0x56, 0x86, 0x7a, 0x33,
    0x18, 0xa5, 0x54, 0x6c, 0x2d, 0x83, 0x7f, 0x75, 0xb3, 0x5b, 0x8f, 0xe7, 0x87, 0x95, 0xd1, 0xa0,
    0xca, 0xd1, 0x23, 0x11, 0x8c, 0x20, 0x0f, 0x29, 0x93, 0x66, 0x09, 0x3e, 0xb0, 0x30, 0xa4, 0xf1,
    0x59, 0x57, 0x18, 0x6d, 0x77, 0x98, 0xac, 0x5e, 0xfb, 0xef, 0x93, 0x97, 0x90, 0x0d, 0x17, 0x7f,
    0x31, 0x27, 0xab, 0x81, 0xb4, 0x66, 0xf9, 0x70, 0x64, 0x04, 0x54, 0xe3, 0xf0, 0x82, 0x67, 0xae,
    0x51, 0x6c, 0x5f, 0xa1, 0x6f, 0xb8, 0xe8, 0xf1, 0x28, 0x5d, 0x65, 0x6b, 0x36, 0x37, 0xed, 0x6e,
    0xd5, 0x1c, 0x9d, 0x9c, 0x67, 0x91, 0x57, 0xf8, 0x1f, 0x2a, 0x6c, 0xcc, 0xb3, 0x24, 0xb9, 0xe0,
    0x9b, 0x33, 0xa8, 0xea, 0x1b, 0xdd, 0x42, 0xa0, 0x22, 0xe5, 0x3e, 0x93, 0xf5, 0x91, 0x6e, 0x3d,
    0x4c, 0x15, 0xa0, 0xce, 0x38, 0x11, 0xe1, 0x84, 0x12, 0x31, 0x5f, 0x5a, 0x58, 0x69, 0xda, 0x5d,
    0x30, 0xb0, 0x02, 0x94, 0x8f, 0xc3, 0x59, 0x69, 0x2d, 0xb7, 0x39, 0x45, 0x77, 0xb4, 0x59, 0x0e,
    0x24, 0x64, 0x2a, 0x69, 0x9f, 0xa7, 0x70, 0x91, 0xee, 0x45, 0x6c, 0xfe, 0x6d, 0xdf, 0xc4, 0xef,
    0xf4, 0x78, 0x8f, 0xa9, 0x1b, 0x7c, 0xcc, 0x95, 0xf5, 0x20, 0x60, 0xd4, 0x5a, 0x1d, 0x84, 0x3c,
    0x86, 0x5d, 0x43, 0xe4, 0x19, 0xa4, 0x5e, 0xd3, 0x5e, 0x2a, 0x64, 0x9e, 0xa2, 0x9d, 0x9b, 0x76,
    0x56, 0x9a, 0xc0, 0x00, 0xf4, 0x1c, 0x82, 0x00, 0xf6, 0x03, 0x7b, 0x62, 0xe5, 0xd2, 0x4d, 0xee,
    0xf0, 0x3e, 0x66, 0x7b, 0xee, 0x2e, 0x1b, 0x73, 0x7c, 0x88, 0xc3, 0xc1, 0xbb, 0xfc, 0x6c, 0x89,
    0x66, 0x58, 0x7f, 0xea, 0x73, 0xcb, 0x31, 0xe3, 0x3f, 0xb4, 0x06, 0xdc, 0x78, 0x8c, 0xc7, 0x5a,
    0xb9, 0xc5, 0x0f, 0x01, 0x22, 0xd8, 0x7d, 0x7b, 0x6b, 0x5c, 0x8c, 0x42, 0xc2, 0x72, 0x7e, 0xd2,
    0xa4, 0x31, 0x98, 0x58, 0x79, 0x35, 0x83, 0x6b, 0xe4, 0x94, 0x5f, 0xc3, 0x81, 0xd0, 0x7b, 0x37,
    0x2c, 0x55, 0x28, 0x4f, 0x9c, 0x53, 0x91, 0x8a, 0x08, 0xa5, 0x8d, 0x7a, 0x40, 0xe3, 0x10, 0x7f,
    0x5b, 0xd0, 0x62, 0x0e, 0x63, 0x09, 0x0b, 0xf2, 0x53, 0x8a, 0x27, 0xe7, 0x4b, 0x1a, 0xa6, 0xd1,
    0x71, 0xb7, 0x73, 0x69, 0xb6, 0x59, 0xbf, 0xc8, 0x32, 0xdb, 0x89, 0x86, 0xdf, 0x8d, 0x3c, 0xe1,
    0xd6, 0x47, 0x1c, 0x8d, 0x34, 0xe5, 0x67, 0xcc, 0x8d, 0x61, 0x0a, 0x5e, 0xce, 0xcd, 0x55, 0xd7,
    0xba, 0x2e, 0x9f, 0xfb, 0xd8, 0x19, 0xc4, 0x32, 0x15, 0xf4, 0x91, 0x49, 0x06, 0x6e, 0xca, 0x6f,
    0x9a, 0xd7, 0xa6, 0x20, 0xe1, 0xad, 0xe9, 0x29, 0x9f, 0xf2, 0xc4, 0x87, 0xca, 0x54, 0x12, 0xaf,
    0xbc, 0x32, 0xf5, 0x96, 0x06, 0x76, 0x84, 0xd6, 0x1a, 0xdd, 0x25, 0xd0, 0x6c, 0x85, 0xa3, 0x7d,
    0x15, 0xbe, 0x7a, 0x80, 0x3b, 0xd5, 0x65, 0xaf, 0x8c, 0x42, 0x95, 0xd8, 0x8f, 0x65, 0xe9, 0xea,
    0x9f, 0xcf, 0xb2, 0xe6, 0xa2, 0x34, 0xdd, 0x8e, 0x51, 0x10, 0x52, 0xdc, 0xc0, 0x0b, 0x4f, 0x51,
    0xf8, 0x6a, 0x45, 0xe2, 0xf0, 0x8c, 0x9b, 0xfd, 0x99, 0x14, 0x5e, 0xfe, 0x4e, 0xa3, 0xc1, 0x12,
    0x97, 0xe6, 0x64, 0xe0, 0x0a, 0xa5, 0xdf, 0x44, 0x64, 0xe1, 0x37, 0x4b, 0xef, 0x8c, 0x91, 0x4b,
    0xe8, 0xcf, 0xaa, 0x35, 0x04, 0xad, 0xcf, 0x0a, 0x09, 0x0e, 0x27, 0xa7, 0xe5, 0x4d, 0x00, 0xd8,
    0x5a, 0x5d, 0xe4, 0xb1, 0xa9, 0x42, 0x34, 0x5a, 0x39, 0x99, 0x77, 0x24, 0x86, 0xf3, 0xc0, 0x20,
    0x58, 0xed, 0xde, 0xcf, 0xa0, 0x81, 0x7a, 0xd5, 0x6a, 0xee, 0x2b, 0x86, 0x4b, 0x20, 0x4e, 0xbf,
    0xb1, 0x06, 0x1a, 0x84, 0xc5, 0x0b, 0x99, 0xe7, 0x8a, 0xa1, 0x78, 0x36, 0x55, 0x57, 0x25, 0x4c,
    0xbb, 0x6d, 0xd6, 0x59, 0xc0, 0xa3, 0x87, 0xb8, 0x13, 0x36, 0xdd, 0xd7, 0x4c, 0xad, 0x48, 0x52,
    0xeb, 0x7e, 0xe0, 0xd1, 0x76, 0x51, 0x1e, 0x6e, 0xe5, 0x1d, 0xc3, 0xfe, 0xf3, 0xd0, 0x47, 0xb5,
    0xee, 0x19, 0xcc, 0xf2, 0x37, 0x3b, 0xbe, 0xe5, 0x4f, 0x6f, 0x9e, 0xf5, 0x12, 0x68, 0xc0, 0xf3,
    0x2e, 0xbf, 0xdd, 0xda, 0xaf, 0x94, 0x43, 0x0f, 0xda, 0xf2, 0xa5, 0x72, 0xdb, 0x64, 0xc9, 0x37,
    0xf1, 0xe1, 0x58, 0x83, 0x6a, 0x69, 0x28, 0xaf, 0x98, 0x79, 0x3f, 0x33, 0x43, 0xb3, 0x6c, 0x0d,
    0xeb, 0xf5, 0x3d, 0x89, 0x76, 0xfd, 0x52, 0xe9, 0x68, 0xae, 0x43, 0x37, 0x57, 0x1d, 0xe8, 0x88,
    0xbd, 0xdb, 0x94, 0xae, 0xc6, 0xe3, 0xbd, 0x44, 0x22, 0x39, 0xd8, 0x18, 0x06, 0xc7, 0x3e, 0xc8,
    0xd1, 0xe2, 0xd6, 0x92, 0x70, 0x61, 0xf6, 0x17, 0xf6, 0xc9, 0xd3, 0x41, 0xac, 0x5a, 0x53, 0x67,
    0x2f, 0xc6, 0xbe, 0x9a, 0x88, 0x3a, 0x1f, 0xe3, 0xc2, 0xe5, 0x9a, 0x8d, 0x1c, 0x75, 0x6d, 0x3a,
    0x9e, 0x44, 0x5f, 0xf6, 0xa6, 0x80, 0xf0, 0x66, 0x70, 0x5c, 0xba, 0x3b, 0xbe, 0xae, 0x8b, 0x2a,
    0x3f, 0xcb, 0x03, 0xcf, 0xd1, 0x50, 0x40, 0xd5, 0x46, 0x3e, 0x98, 0xdb, 0xe8, 0xae, 0xeb, 0x1b,
    0x5d, 0xf9, 0x4b, 0x52, 0x8a, 0xa2, 0xfd, 0x3c, 0x44, 0x0d, 0xc3, 0x9f, 0xfb, 0x21, 0x96, 0xcc,
    0xa5, 0x3d, 0x8c, 0x63, 0xe4, 0x06, 0xf0, 0x79, 0x1f, 0x42, 0xd7, 0x78, 0x6e, 0x6a, 0x67, 0x34,
    0xa4, 0x42, 0x9c, 0x1c, 0x3b, 0x31, 0xe5, 0x73, 0x76, 0xa6, 0x95, 0xd7, 0xc9, 0x87, 0x3b, 0xb4,
    0xd2, 0x93, 0xdb, 0xc6, 0xc5, 0xc8, 0xa3, 0xa5, 0xd2, 0x48, 0x34, 0xfe, 0xe7, 0xf2, 0x9b, 0xda,
    0xcc, 0x67, 0xba, 0x4f, 0x6c, 0xd1, 0x50, 0x2d, 0xb9, 0xa9, 0x33, 0xba, 0xc1, 0xea, 0x43, 0x6f,
    0xef, 0x1a, 0xba, 0xf6, 0x9b, 0xfa, 0xaa, 0xff, 0x5c, 0x49, 0x04, 0x5b, 0x4f, 0x77, 0xb0, 0x5e,
    0xb2, 0xd4, 0xe1, 0x59, 0x9a, 0x76, 0xa4, 0x6c, 0xa8, 0x69, 0xa0, 0xe7, 0xaa, 0x73, 0x52, 0x07,
    0xbd, 0x13, 0x34, 0x94, 0x3a, 0x6c, 0xcc, 0x0e, 0x60, 0x9a, 0x24, 0x5c, 0x67, 0xd0, 0x6c, 0x9c,
    0x2f, 0x4f, 0x71, 0x0b, 0x50, 0xf8, 0xd2, 0x5f, 0x71, 0xb4, 0x91, 0xd0, 0x20, 0xca, 0x21, 0xb3,
    0x56, 0x4d, 0xf6, 0xc0, 0x67, 0xa3, 0xaa, 0x9a, 0x19, 0x68, 0x7c, 0x3e, 0x5a, 0xb2, 0x01, 0x38,
    0x60, 0xb6, 0x7a, 0xf6, 0x41, 0xa2, 0x45, 0x9e, 0xee, 0x46, 0xe1, 0xe6, 0x6b, 0x5f, 0xea, 0xbf,
    0xb6, 0x4f, 0xb7, 0x52, 0xd8, 0x8a, 0xc1, 0xee, 0x51, 0xb8, 0x3f, 0xe9, 0x7b, 0xca, 0x57, 0x14,
    0xae, 0x11, 0x79, 0xae, 0xcc, 0x03, 0xe0, 0x08, 0xd2, 0xb2, 0x49, 0xf6, 0x38, 0x9b, 0xf9, 0x7f,
    0x64, 0x1c, 0xf6, 0x2a, 0x68, 0xdd, 0x52, 0x60, 0x38, 0xcb, 0x9b, 0xa0, 0x32, 0xb3, 0x23, 0x5f,
    0x04, 0xd5, 0xc0, 0x8e, 0x7e, 0x0f, 0xb4, 0x86, 0x1f, 0x6d, 0x9d, 0x06, 0x27, 0x7f, 0xaf, 0x97,
    0x23, 0x4f, 0x32, 0x6b, 0x7c, 0xf4, 0x8b, 0xa3, 0x35, 0x93, 0x29, 0x89, 0x74, 0x74, 0xfa, 0xa2,
    0x6e, 0x47, 0x33, 0xf4, 0x92, 0x4f, 0x67, 0x5a, 0xc0, 0xf5, 0x54, 0x42, 0xed, 0x5d, 0xac, 0xb7,
    0x27, 0x09, 0xeb, 0x0a, 0xe0, 0xa4, 0x6e, 0xde, 0xfc, 0x07, 0xa3, 0xfb, 0x49, 0xbc
};
#endif

PyTypeObject *init_QAbstractItemView(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractItemView_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX]))));

    _Sbk_QAbstractItemView_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractItemView",
        "QAbstractItemView*",
        &Sbk_QAbstractItemView_spec,
        &Shiboken::callCppDestructor< QAbstractItemView >,
        Sbk_QAbstractItemView_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QAbstractItemView_TypeF(); // references _Sbk_QAbstractItemView_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractItemView_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractItemView_SignatureBytes, QAbstractItemView_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractItemView_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractItemView_PythonToCpp_QAbstractItemView_PTR,
        is_QAbstractItemView_PythonToCpp_QAbstractItemView_PTR_Convertible,
        QAbstractItemView_PTR_CppToPython_QAbstractItemView);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractItemView");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractItemView*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractItemView&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractItemView).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractItemViewWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QAbstractItemView_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QAbstractItemView_TypeF(), &Sbk_QAbstractItemViewSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAbstractItemView_TypeF(), &Sbk_QAbstractItemView_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAbstractItemView_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SelectionMode'.
    const char *SelectionMode_Initializer[] = {
        "NoSelection",
        "SingleSelection",
        "MultiSelection",
        "ExtendedSelection",
        "ContiguousSelection",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SelectionMode_InitializerValues[] = {
        uint8_t(QAbstractItemView::SelectionMode::NoSelection),        //  0x00  0
        uint8_t(QAbstractItemView::SelectionMode::SingleSelection),    //  0x01  1
        uint8_t(QAbstractItemView::SelectionMode::MultiSelection),     //  0x02  2
        uint8_t(QAbstractItemView::SelectionMode::ExtendedSelection),  //  0x03  3
        uint8_t(QAbstractItemView::SelectionMode::ContiguousSelection) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractItemView_TypeF(),
        "2:PySide6.QtWidgets.QAbstractItemView.SelectionMode",
        SelectionMode_Initializer, SelectionMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_SelectionMode_IDX].type = EType;
    // Register converter for enum 'QAbstractItemView::SelectionMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractItemView_SelectionMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractItemView_SelectionMode,
            is_Enum_PythonToCpp_QAbstractItemView_SelectionMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractItemView::SelectionMode");
        Shiboken::Conversions::registerConverterAlias(converter, "SelectionMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SelectionMode' enum.

    // Initialization of enum 'SelectionBehavior'.
    const char *SelectionBehavior_Initializer[] = {
        "SelectItems",
        "SelectRows",
        "SelectColumns",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SelectionBehavior_InitializerValues[] = {
        uint8_t(QAbstractItemView::SelectionBehavior::SelectItems),  //  0x00  0
        uint8_t(QAbstractItemView::SelectionBehavior::SelectRows),   //  0x01  1
        uint8_t(QAbstractItemView::SelectionBehavior::SelectColumns) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractItemView_TypeF(),
        "2:PySide6.QtWidgets.QAbstractItemView.SelectionBehavior",
        SelectionBehavior_Initializer, SelectionBehavior_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_SelectionBehavior_IDX].type = EType;
    // Register converter for enum 'QAbstractItemView::SelectionBehavior'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractItemView_SelectionBehavior_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractItemView_SelectionBehavior,
            is_Enum_PythonToCpp_QAbstractItemView_SelectionBehavior_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractItemView::SelectionBehavior");
        Shiboken::Conversions::registerConverterAlias(converter, "SelectionBehavior");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SelectionBehavior' enum.

    // Initialization of enum 'ScrollHint'.
    const char *ScrollHint_Initializer[] = {
        "EnsureVisible",
        "PositionAtTop",
        "PositionAtBottom",
        "PositionAtCenter",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ScrollHint_InitializerValues[] = {
        uint8_t(QAbstractItemView::ScrollHint::EnsureVisible),    //  0x00  0
        uint8_t(QAbstractItemView::ScrollHint::PositionAtTop),    //  0x01  1
        uint8_t(QAbstractItemView::ScrollHint::PositionAtBottom), //  0x02  2
        uint8_t(QAbstractItemView::ScrollHint::PositionAtCenter)  //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractItemView_TypeF(),
        "2:PySide6.QtWidgets.QAbstractItemView.ScrollHint",
        ScrollHint_Initializer, ScrollHint_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollHint_IDX].type = EType;
    // Register converter for enum 'QAbstractItemView::ScrollHint'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractItemView_ScrollHint_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractItemView_ScrollHint,
            is_Enum_PythonToCpp_QAbstractItemView_ScrollHint_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractItemView::ScrollHint");
        Shiboken::Conversions::registerConverterAlias(converter, "ScrollHint");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ScrollHint' enum.

    // Initialization of enum 'EditTrigger'.
    const char *EditTrigger_Initializer[] = {
        "NoEditTriggers",
        "CurrentChanged",
        "DoubleClicked",
        "SelectedClicked",
        "EditKeyPressed",
        "AnyKeyPressed",
        "AllEditTriggers",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t EditTrigger_InitializerValues[] = {
        uint8_t(QAbstractItemView::EditTrigger::NoEditTriggers),  //  0x00  0
        uint8_t(QAbstractItemView::EditTrigger::CurrentChanged),  //  0x01  1
        uint8_t(QAbstractItemView::EditTrigger::DoubleClicked),   //  0x02  2
        uint8_t(QAbstractItemView::EditTrigger::SelectedClicked), //  0x04  4
        uint8_t(QAbstractItemView::EditTrigger::EditKeyPressed),  //  0x08  8
        uint8_t(QAbstractItemView::EditTrigger::AnyKeyPressed),   //  0x10  16
        uint8_t(QAbstractItemView::EditTrigger::AllEditTriggers)  //  0x1f  31
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractItemView_TypeF(),
        "2:PySide6.QtWidgets.QAbstractItemView.EditTrigger",
        EditTrigger_Initializer, EditTrigger_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_EditTrigger_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QAbstractItemView_EditTrigger_IDX].type =
        EType;
    // Register converter for enum 'QAbstractItemView::EditTrigger'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractItemView_EditTrigger_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractItemView_EditTrigger,
            is_Enum_PythonToCpp_QAbstractItemView_EditTrigger_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractItemView::EditTrigger");
        Shiboken::Conversions::registerConverterAlias(converter, "EditTrigger");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QAbstractItemView_EditTrigger_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QAbstractItemView_EditTrigger,
            is_Enum_PythonToCpp_QAbstractItemView_EditTrigger_Convertible);
        // Register converter for flag 'QFlags<QAbstractItemView::EditTrigger>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QAbstractItemView::EditTrigger>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QAbstractItemView::EditTriggers");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'EditTrigger' enum/flags.

    // Initialization of enum 'ScrollMode'.
    const char *ScrollMode_Initializer[] = {
        "ScrollPerItem",
        "ScrollPerPixel",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ScrollMode_InitializerValues[] = {
        uint8_t(QAbstractItemView::ScrollMode::ScrollPerItem), //  0x00  0
        uint8_t(QAbstractItemView::ScrollMode::ScrollPerPixel) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractItemView_TypeF(),
        "2:PySide6.QtWidgets.QAbstractItemView.ScrollMode",
        ScrollMode_Initializer, ScrollMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollMode_IDX].type = EType;
    // Register converter for enum 'QAbstractItemView::ScrollMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractItemView_ScrollMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractItemView_ScrollMode,
            is_Enum_PythonToCpp_QAbstractItemView_ScrollMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractItemView::ScrollMode");
        Shiboken::Conversions::registerConverterAlias(converter, "ScrollMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ScrollMode' enum.

    // Initialization of enum 'DragDropMode'.
    const char *DragDropMode_Initializer[] = {
        "NoDragDrop",
        "DragOnly",
        "DropOnly",
        "DragDrop",
        "InternalMove",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DragDropMode_InitializerValues[] = {
        uint8_t(QAbstractItemView::DragDropMode::NoDragDrop),  //  0x00  0
        uint8_t(QAbstractItemView::DragDropMode::DragOnly),    //  0x01  1
        uint8_t(QAbstractItemView::DragDropMode::DropOnly),    //  0x02  2
        uint8_t(QAbstractItemView::DragDropMode::DragDrop),    //  0x03  3
        uint8_t(QAbstractItemView::DragDropMode::InternalMove) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractItemView_TypeF(),
        "2:PySide6.QtWidgets.QAbstractItemView.DragDropMode",
        DragDropMode_Initializer, DragDropMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_DragDropMode_IDX].type = EType;
    // Register converter for enum 'QAbstractItemView::DragDropMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractItemView_DragDropMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractItemView_DragDropMode,
            is_Enum_PythonToCpp_QAbstractItemView_DragDropMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractItemView::DragDropMode");
        Shiboken::Conversions::registerConverterAlias(converter, "DragDropMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DragDropMode' enum.

    // Initialization of enum 'CursorAction'.
    const char *CursorAction_Initializer[] = {
        "MoveUp",
        "MoveDown",
        "MoveLeft",
        "MoveRight",
        "MoveHome",
        "MoveEnd",
        "MovePageUp",
        "MovePageDown",
        "MoveNext",
        "MovePrevious",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CursorAction_InitializerValues[] = {
        uint8_t(QAbstractItemView::CursorAction::MoveUp),       //  0x00  0
        uint8_t(QAbstractItemView::CursorAction::MoveDown),     //  0x01  1
        uint8_t(QAbstractItemView::CursorAction::MoveLeft),     //  0x02  2
        uint8_t(QAbstractItemView::CursorAction::MoveRight),    //  0x03  3
        uint8_t(QAbstractItemView::CursorAction::MoveHome),     //  0x04  4
        uint8_t(QAbstractItemView::CursorAction::MoveEnd),      //  0x05  5
        uint8_t(QAbstractItemView::CursorAction::MovePageUp),   //  0x06  6
        uint8_t(QAbstractItemView::CursorAction::MovePageDown), //  0x07  7
        uint8_t(QAbstractItemView::CursorAction::MoveNext),     //  0x08  8
        uint8_t(QAbstractItemView::CursorAction::MovePrevious)  //  0x09  9
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractItemView_TypeF(),
        "2:PySide6.QtWidgets.QAbstractItemView.CursorAction",
        CursorAction_Initializer, CursorAction_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_CursorAction_IDX].type = EType;
    // Register converter for enum 'QAbstractItemView::CursorAction'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractItemView_CursorAction_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractItemView_CursorAction,
            is_Enum_PythonToCpp_QAbstractItemView_CursorAction_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractItemView::CursorAction");
        Shiboken::Conversions::registerConverterAlias(converter, "CursorAction");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CursorAction' enum.

    // Initialization of enum 'State'.
    const char *State_Initializer[] = {
        "NoState",
        "DraggingState",
        "DragSelectingState",
        "EditingState",
        "ExpandingState",
        "CollapsingState",
        "AnimatingState",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t State_InitializerValues[] = {
        uint8_t(QAbstractItemView::State::NoState),            //  0x00  0
        uint8_t(QAbstractItemView::State::DraggingState),      //  0x01  1
        uint8_t(QAbstractItemView::State::DragSelectingState), //  0x02  2
        uint8_t(QAbstractItemView::State::EditingState),       //  0x03  3
        uint8_t(QAbstractItemView::State::ExpandingState),     //  0x04  4
        uint8_t(QAbstractItemView::State::CollapsingState),    //  0x05  5
        uint8_t(QAbstractItemView::State::AnimatingState)      //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractItemView_TypeF(),
        "2:PySide6.QtWidgets.QAbstractItemView.State",
        State_Initializer, State_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_State_IDX].type = EType;
    // Register converter for enum 'QAbstractItemView::State'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractItemView_State_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractItemView_State,
            is_Enum_PythonToCpp_QAbstractItemView_State_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractItemView::State");
        Shiboken::Conversions::registerConverterAlias(converter, "State");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'State' enum.

    // Initialization of enum 'DropIndicatorPosition'.
    const char *DropIndicatorPosition_Initializer[] = {
        "OnItem",
        "AboveItem",
        "BelowItem",
        "OnViewport",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DropIndicatorPosition_InitializerValues[] = {
        uint8_t(QAbstractItemView::DropIndicatorPosition::OnItem),    //  0x00  0
        uint8_t(QAbstractItemView::DropIndicatorPosition::AboveItem), //  0x01  1
        uint8_t(QAbstractItemView::DropIndicatorPosition::BelowItem), //  0x02  2
        uint8_t(QAbstractItemView::DropIndicatorPosition::OnViewport) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractItemView_TypeF(),
        "2:PySide6.QtWidgets.QAbstractItemView.DropIndicatorPosition",
        DropIndicatorPosition_Initializer, DropIndicatorPosition_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_DropIndicatorPosition_IDX].type = EType;
    // Register converter for enum 'QAbstractItemView::DropIndicatorPosition'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractItemView_DropIndicatorPosition_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractItemView_DropIndicatorPosition,
            is_Enum_PythonToCpp_QAbstractItemView_DropIndicatorPosition_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractItemView::DropIndicatorPosition");
        Shiboken::Conversions::registerConverterAlias(converter, "DropIndicatorPosition");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DropIndicatorPosition' enum.

    PySide::Signal::registerSignals(pyType, &::QAbstractItemView::staticMetaObject);
    qRegisterMetaType< ::QAbstractItemView::SelectionMode >("QAbstractItemView::SelectionMode");
    qRegisterMetaType< ::QAbstractItemView::SelectionBehavior >("QAbstractItemView::SelectionBehavior");
    qRegisterMetaType< ::QAbstractItemView::ScrollHint >("QAbstractItemView::ScrollHint");
    qRegisterMetaType< ::QAbstractItemView::EditTrigger >("QAbstractItemView::EditTrigger");
    qRegisterMetaType< ::QAbstractItemView::ScrollMode >("QAbstractItemView::ScrollMode");
    qRegisterMetaType< ::QAbstractItemView::DragDropMode >("QAbstractItemView::DragDropMode");
    qRegisterMetaType< ::QAbstractItemView::CursorAction >("QAbstractItemView::CursorAction");
    qRegisterMetaType< ::QAbstractItemView::State >("QAbstractItemView::State");
    qRegisterMetaType< ::QAbstractItemView::DropIndicatorPosition >("QAbstractItemView::DropIndicatorPosition");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAbstractItemView::staticMetaObject, sizeof(QAbstractItemViewWrapper));

    return pyType;
}
