// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qcombobox_wrapper.h"

// Wrappers providing overrides
#include "qlayoutitem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qwidget_wrapper.h"
#include "qwizardpage_wrapper.h"
#include "qgraphicsitem_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <QtGui/qevent.h>
#include <QtGui/qicon.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qvalidator.h>
#include <QtWidgets/qabstractitemdelegate.h>
#include <QtWidgets/qabstractitemview.h>
#include <QtWidgets/qcombobox.h>
#include <QtWidgets/qcompleter.h>
#include <QtWidgets/qlineedit.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QComboBoxWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QComboBoxWrapper::QComboBoxWrapper(::QWidget * parent) : QComboBox(parent)
{
}

void QComboBoxWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QWizardPageWrapper::sbk_o_actionEvent("QComboBox", funcName, gil, pyOverride, event);
}

void QComboBoxWrapper::changeEvent(::QEvent * e)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::changeEvent(e);
    }
    QWizardPageWrapper::sbk_o_changeEvent("QComboBox", funcName, gil, pyOverride, e);
}

void QComboBoxWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWidgetWrapper::sbk_o_childEvent("QComboBox", funcName, gil, pyOverride, event);
}

void QComboBoxWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QWizardPageWrapper::sbk_o_closeEvent("QComboBox", funcName, gil, pyOverride, event);
}

void QComboBoxWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QComboBox", funcName, gil, pyOverride, signal);
}

void QComboBoxWrapper::contextMenuEvent(::QContextMenuEvent * e)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::contextMenuEvent(e);
    }
    QWizardPageWrapper::sbk_o_contextMenuEvent("QComboBox", funcName, gil, pyOverride, e);
}

void QComboBoxWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QComboBox", funcName, gil, pyOverride, event);
}

int QComboBoxWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QComboBox", funcName, gil, pyOverride);
}

void QComboBoxWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QComboBox", funcName, gil, pyOverride, signal);
}

void QComboBoxWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragEnterEvent("QComboBox", funcName, gil, pyOverride, event);
}

void QComboBoxWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragLeaveEvent("QComboBox", funcName, gil, pyOverride, event);
}

void QComboBoxWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragMoveEvent("QComboBox", funcName, gil, pyOverride, event);
}

void QComboBoxWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QWizardPageWrapper::sbk_o_dropEvent("QComboBox", funcName, gil, pyOverride, event);
}

void QComboBoxWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QWizardPageWrapper::sbk_o_enterEvent("QComboBox", funcName, gil, pyOverride, event);
}

bool QComboBoxWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::event(event);
    }
    return QWidgetWrapper::sbk_o_event("QComboBox", funcName, gil, pyOverride, event);
}

bool QComboBoxWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QComboBox", funcName, gil, pyOverride, watched, event);
}

void QComboBoxWrapper::focusInEvent(::QFocusEvent * e)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::focusInEvent(e);
    }
    QWizardPageWrapper::sbk_o_focusInEvent("QComboBox", funcName, gil, pyOverride, e);
}

bool QComboBoxWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QWidgetWrapper::sbk_o_focusNextPrevChild("QComboBox", funcName, gil, pyOverride, next);
}

void QComboBoxWrapper::focusOutEvent(::QFocusEvent * e)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::focusOutEvent(e);
    }
    QWizardPageWrapper::sbk_o_focusOutEvent("QComboBox", funcName, gil, pyOverride, e);
}

bool QComboBoxWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QComboBox", funcName, gil, pyOverride);
}

int QComboBoxWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QComboBox", funcName, gil, pyOverride, arg__1);
}

void QComboBoxWrapper::hideEvent(::QHideEvent * e)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::hideEvent(e);
    }
    QWizardPageWrapper::sbk_o_hideEvent("QComboBox", funcName, gil, pyOverride, e);
}

void QComboBoxWrapper::hidePopup()
{
    static const char *funcName = "hidePopup";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::hidePopup();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QComboBox", funcName, gil, pyOverride);
}

void QComboBoxWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QWidgetWrapper::sbk_o_initPainter("QComboBox", funcName, gil, pyOverride, painter);
}

void QComboBoxWrapper::initStyleOption(::QStyleOptionComboBox * option) const
{
    static const char *funcName = "initStyleOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::initStyleOption(option);
    }
    sbk_o_initStyleOption("QComboBox", funcName, gil, pyOverride, option);
}

void QComboBoxWrapper::sbk_o_initStyleOption(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QStyleOptionComboBox * option)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), option)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), option)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QComboBoxWrapper::inputMethodEvent(::QInputMethodEvent * arg__1)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::inputMethodEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_inputMethodEvent("QComboBox", funcName, gil, pyOverride, arg__1);
}

::QVariant QComboBoxWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::inputMethodQuery(arg__1);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QComboBox", funcName, gil, pyOverride, arg__1);
}

void QComboBoxWrapper::keyPressEvent(::QKeyEvent * e)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::keyPressEvent(e);
    }
    QWizardPageWrapper::sbk_o_keyPressEvent("QComboBox", funcName, gil, pyOverride, e);
}

void QComboBoxWrapper::keyReleaseEvent(::QKeyEvent * e)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::keyReleaseEvent(e);
    }
    QWizardPageWrapper::sbk_o_keyReleaseEvent("QComboBox", funcName, gil, pyOverride, e);
}

void QComboBoxWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_leaveEvent("QComboBox", funcName, gil, pyOverride, event);
}

int QComboBoxWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QWidgetWrapper::sbk_o_metric("QComboBox", funcName, gil, pyOverride, arg__1);
}

::QSize QComboBoxWrapper::minimumSizeHint() const
{
    static const char *funcName = "minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::minimumSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QComboBox", funcName, gil, pyOverride);
}

void QComboBoxWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseDoubleClickEvent("QComboBox", funcName, gil, pyOverride, event);
}

void QComboBoxWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseMoveEvent("QComboBox", funcName, gil, pyOverride, event);
}

void QComboBoxWrapper::mousePressEvent(::QMouseEvent * e)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::mousePressEvent(e);
    }
    QWizardPageWrapper::sbk_o_mousePressEvent("QComboBox", funcName, gil, pyOverride, e);
}

void QComboBoxWrapper::mouseReleaseEvent(::QMouseEvent * e)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::mouseReleaseEvent(e);
    }
    QWizardPageWrapper::sbk_o_mouseReleaseEvent("QComboBox", funcName, gil, pyOverride, e);
}

void QComboBoxWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QWizardPageWrapper::sbk_o_moveEvent("QComboBox", funcName, gil, pyOverride, event);
}

bool QComboBoxWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QWizardPageWrapper::sbk_o_nativeEvent("QComboBox", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QComboBoxWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QWidgetWrapper::sbk_o_paintEngine("QComboBox", funcName, gil, pyOverride);
}

void QComboBoxWrapper::paintEvent(::QPaintEvent * e)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::paintEvent(e);
    }
    QWizardPageWrapper::sbk_o_paintEvent("QComboBox", funcName, gil, pyOverride, e);
}

::QPaintDevice * QComboBoxWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QWidgetWrapper::sbk_o_redirected("QComboBox", funcName, gil, pyOverride, offset);
}

void QComboBoxWrapper::resizeEvent(::QResizeEvent * e)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::resizeEvent(e);
    }
    QWizardPageWrapper::sbk_o_resizeEvent("QComboBox", funcName, gil, pyOverride, e);
}

void QComboBoxWrapper::setModel(::QAbstractItemModel * model)
{
    static const char *funcName = "setModel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::setModel(model);
    }
    sbk_o_setModel("QComboBox", funcName, gil, pyOverride, model);
}

void QComboBoxWrapper::sbk_o_setModel(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QAbstractItemModel * model)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), model)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), model)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QComboBoxWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QWidgetWrapper::sbk_o_setVisible("QComboBox", funcName, gil, pyOverride, visible);
}

::QPainter * QComboBoxWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QWidgetWrapper::sbk_o_sharedPainter("QComboBox", funcName, gil, pyOverride);
}

void QComboBoxWrapper::showEvent(::QShowEvent * e)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::showEvent(e);
    }
    QWizardPageWrapper::sbk_o_showEvent("QComboBox", funcName, gil, pyOverride, e);
}

void QComboBoxWrapper::showPopup()
{
    static const char *funcName = "showPopup";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::showPopup();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QComboBox", funcName, gil, pyOverride);
}

::QSize QComboBoxWrapper::sizeHint() const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QComboBox", funcName, gil, pyOverride);
}

void QComboBoxWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QWizardPageWrapper::sbk_o_tabletEvent("QComboBox", funcName, gil, pyOverride, event);
}

void QComboBoxWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWidgetWrapper::sbk_o_timerEvent("QComboBox", funcName, gil, pyOverride, event);
}

void QComboBoxWrapper::wheelEvent(::QWheelEvent * e)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QComboBox::wheelEvent(e);
    }
    QWizardPageWrapper::sbk_o_wheelEvent("QComboBox", funcName, gil, pyOverride, e);
}

const QMetaObject *QComboBoxWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QComboBox::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QComboBoxWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QComboBox::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QComboBoxWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QComboBoxWrapper *>(this));
    return QComboBox::qt_metacast(_clname);
}

QComboBoxWrapper::~QComboBoxWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QComboBox_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QComboBox >()))
        return -1;

    QComboBoxWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QComboBox", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QComboBox::QComboBox(QWidget*=)
    if (numArgs == 0) {
        overloadId = 0; // QComboBox(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QComboBox(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QComboBox(QWidget*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QComboBoxWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QComboBoxWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QComboBox >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QComboBoxFunc_addItem(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:addItem", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QComboBox::addItem(QIcon,QString,const QVariant&=)
    // 1: QComboBox::addItem(QString,const QVariant&=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // addItem(QString,QVariant)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 1; // addItem(QString,QVariant)
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // addItem(QIcon,QString,QVariant)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[2])))) {
            overloadId = 0; // addItem(QIcon,QString,QVariant)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addItem(const QIcon &icon, const QString &text, const QVariant &userData)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"userData", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QIcon cppArg0_local;
            ::QIcon *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QVariant cppArg2 = QVariant();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addItem(QIcon,QString,QVariant)
                cppSelf->addItem(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // addItem(const QString &text, const QVariant &userData)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"userData", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1 = QVariant();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addItem(QString,QVariant)
                cppSelf->addItem(cppArg0, cppArg1);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_addItems(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::addItems(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // addItems(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addItems", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addItems(QStringList)
            cppSelf->addItems(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_changeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::changeEvent(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "changeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // changeEvent(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::changeEvent(cppArg0)
                : cppSelf->changeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_clearEditText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearEditText()
        cppSelf->clearEditText();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_completer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // completer()const
        QCompleter * cppResult = const_cast<const ::QComboBox *>(cppSelf)->completer();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCompleter_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_contextMenuEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::contextMenuEvent(QContextMenuEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), (pyArg)))) {
        overloadId = 0; // contextMenuEvent(QContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contextMenuEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QContextMenuEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contextMenuEvent(QContextMenuEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::contextMenuEvent(cppArg0)
                : cppSelf->contextMenuEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        int cppResult = const_cast<const ::QComboBox *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_currentData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "currentData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    if (PyArg_ParseTuple(args, "|O:currentData", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QComboBox::currentData(int=)const->QVariant
    if (numArgs == 0) {
        overloadId = 0; // currentData(int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // currentData(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "currentData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "currentData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);
            }
        }
        int cppArg0 = Qt::UserRole;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // currentData(int)const
            QVariant cppResult = const_cast<const ::QComboBox *>(cppSelf)->currentData(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_currentIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentIndex()const
        int cppResult = const_cast<const ::QComboBox *>(cppSelf)->currentIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_currentText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentText()const
        QString cppResult = const_cast<const ::QComboBox *>(cppSelf)->currentText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_duplicatesEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // duplicatesEnabled()const
        bool cppResult = const_cast<const ::QComboBox *>(cppSelf)->duplicatesEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_findData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "findData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:findData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QComboBox::findData(QVariant,int=,QFlags<Qt::MatchFlag>=)const->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // findData(QVariant,int,QFlags<Qt::MatchFlag>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // findData(QVariant,int,QFlags<Qt::MatchFlag>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MatchFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 0; // findData(QVariant,int,QFlags<Qt::MatchFlag>)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "findData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"role", 1}, {"flags", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MatchFlag_IDX])))->flagsConverter, (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "findData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);
            }
        }
        ::QVariant cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = Qt::UserRole;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFlags<Qt::MatchFlag> cppArg2 = static_cast<Qt::MatchFlags>(Qt::MatchExactly|Qt::MatchCaseSensitive);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // findData(QVariant,int,QFlags<Qt::MatchFlag>)const
            int cppResult = const_cast<const ::QComboBox *>(cppSelf)->findData(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_findText(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "findText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    if (PyArg_ParseTuple(args, "|OO:findText", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QComboBox::findText(QString,QFlags<Qt::MatchFlag>=)const->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // findText(QString,QFlags<Qt::MatchFlag>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MatchFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // findText(QString,QFlags<Qt::MatchFlag>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "findText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"flags", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MatchFlag_IDX])))->flagsConverter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "findText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::MatchFlag> cppArg1 = static_cast<Qt::MatchFlags>(Qt::MatchExactly|Qt::MatchCaseSensitive);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // findText(QString,QFlags<Qt::MatchFlag>)const
            int cppResult = const_cast<const ::QComboBox *>(cppSelf)->findText(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_focusInEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::focusInEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusInEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusInEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::focusInEvent(cppArg0)
                : cppSelf->focusInEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_focusOutEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::focusOutEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusOutEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusOutEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::focusOutEvent(cppArg0)
                : cppSelf->focusOutEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_hasFrame(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasFrame()const
        bool cppResult = const_cast<const ::QComboBox *>(cppSelf)->hasFrame();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_hideEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::hideEvent(QHideEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHideEvent_IDX]), (pyArg)))) {
        overloadId = 0; // hideEvent(QHideEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hideEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHideEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hideEvent(QHideEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::hideEvent(cppArg0)
                : cppSelf->hideEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_hidePopup(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hidePopup()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QComboBox::hidePopup()
            : cppSelf->hidePopup();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_iconSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // iconSize()const
        QSize cppResult = const_cast<const ::QComboBox *>(cppSelf)->iconSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_initStyleOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::initStyleOption(QStyleOptionComboBox*)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), (pyArg)))) {
        overloadId = 0; // initStyleOption(QStyleOptionComboBox*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "initStyleOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QStyleOptionComboBox *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // initStyleOption(QStyleOptionComboBox*)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QComboBox *>(cppSelf)->::QComboBox::initStyleOption(cppArg0)
                : const_cast<const ::QComboBox *>(cppSelf)->initStyleOption(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_inputMethodEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::inputMethodEvent(QInputMethodEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), (pyArg)))) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "inputMethodEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QInputMethodEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // inputMethodEvent(QInputMethodEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::inputMethodEvent(cppArg0)
                : cppSelf->inputMethodEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_inputMethodQuery(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "inputMethodQuery", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWidget::inputMethodQuery(Qt::InputMethodQuery)const->QVariant
    // 1: QComboBox::inputMethodQuery(Qt::InputMethodQuery,QVariant)const->QVariant
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 1; // inputMethodQuery(Qt::InputMethodQuery,QVariant)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "inputMethodQuery", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // inputMethodQuery(Qt::InputMethodQuery arg__1) const
        {
            ::Qt::InputMethodQuery cppArg0 = static_cast< ::Qt::InputMethodQuery>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // inputMethodQuery(Qt::InputMethodQuery)const
                QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? const_cast<const ::QComboBox *>(cppSelf)->::QComboBox::inputMethodQuery(cppArg0)
                    : const_cast<const ::QComboBox *>(cppSelf)->inputMethodQuery(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            }
            break;
        }
        case 1: // inputMethodQuery(Qt::InputMethodQuery query, const QVariant &argument) const
        {
            ::Qt::InputMethodQuery cppArg0 = static_cast< ::Qt::InputMethodQuery>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // inputMethodQuery(Qt::InputMethodQuery,QVariant)const
                QVariant cppResult = const_cast<const ::QComboBox *>(cppSelf)->inputMethodQuery(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_insertItem(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "insertItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:insertItem", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QComboBox::insertItem(int,QIcon,QString,const QVariant&=)
    // 1: QComboBox::insertItem(int,QString,const QVariant&=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // insertItem(int,QString,QVariant)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[2])))) {
                overloadId = 1; // insertItem(int,QString,QVariant)
            }
        } else if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // insertItem(int,QIcon,QString,QVariant)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[3])))) {
                overloadId = 0; // insertItem(int,QIcon,QString,QVariant)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // insertItem(int index, const QIcon &icon, const QString &text, const QVariant &userData)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"userData", 3}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[3] != nullptr && !(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[3]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "insertItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QIcon cppArg1_local;
            ::QIcon *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QVariant cppArg3 = QVariant();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insertItem(int,QIcon,QString,QVariant)
                cppSelf->insertItem(cppArg0, *cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 1: // insertItem(int index, const QString &text, const QVariant &userData)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"userData", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "insertItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QVariant cppArg2 = QVariant();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insertItem(int,QString,QVariant)
                cppSelf->insertItem(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_insertItems(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertItems", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QComboBox::insertItems(int,QStringList)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1])))) {
        overloadId = 0; // insertItems(int,QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertItems", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QStringList cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertItems(int,QStringList)
            cppSelf->insertItems(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_insertPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // insertPolicy()const
        QComboBox::InsertPolicy cppResult = const_cast<const ::QComboBox *>(cppSelf)->insertPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_InsertPolicy_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_insertSeparator(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::insertSeparator(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // insertSeparator(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "insertSeparator", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertSeparator(int)
            cppSelf->insertSeparator(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_isEditable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEditable()const
        bool cppResult = const_cast<const ::QComboBox *>(cppSelf)->isEditable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_itemData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "itemData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    if (PyArg_ParseTuple(args, "|OO:itemData", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QComboBox::itemData(int,int=)const->QVariant
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // itemData(int,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // itemData(int,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "itemData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "itemData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = Qt::UserRole;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // itemData(int,int)const
            QVariant cppResult = const_cast<const ::QComboBox *>(cppSelf)->itemData(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_itemDelegate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // itemDelegate()const
        QAbstractItemDelegate * cppResult = const_cast<const ::QComboBox *>(cppSelf)->itemDelegate();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_itemIcon(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::itemIcon(int)const->QIcon
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // itemIcon(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "itemIcon", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // itemIcon(int)const
            QIcon cppResult = const_cast<const ::QComboBox *>(cppSelf)->itemIcon(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_itemText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::itemText(int)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // itemText(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "itemText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // itemText(int)const
            QString cppResult = const_cast<const ::QComboBox *>(cppSelf)->itemText(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_keyPressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::keyPressEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyPressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyPressEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::keyPressEvent(cppArg0)
                : cppSelf->keyPressEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_keyReleaseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::keyReleaseEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyReleaseEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyReleaseEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::keyReleaseEvent(cppArg0)
                : cppSelf->keyReleaseEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_labelDrawingMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelDrawingMode()const
        QComboBox::LabelDrawingMode cppResult = const_cast<const ::QComboBox *>(cppSelf)->labelDrawingMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_LabelDrawingMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_lineEdit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lineEdit()const
        QLineEdit * cppResult = const_cast<const ::QComboBox *>(cppSelf)->lineEdit();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLineEdit_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_maxCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxCount()const
        int cppResult = const_cast<const ::QComboBox *>(cppSelf)->maxCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_maxVisibleItems(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxVisibleItems()const
        int cppResult = const_cast<const ::QComboBox *>(cppSelf)->maxVisibleItems();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_minimumContentsLength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumContentsLength()const
        int cppResult = const_cast<const ::QComboBox *>(cppSelf)->minimumContentsLength();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_minimumSizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumSizeHint()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QComboBox *>(cppSelf)->::QComboBox::minimumSizeHint()
            : const_cast<const ::QComboBox *>(cppSelf)->minimumSizeHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_model(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // model()const
        QAbstractItemModel * cppResult = const_cast<const ::QComboBox *>(cppSelf)->model();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_modelColumn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // modelColumn()const
        int cppResult = const_cast<const ::QComboBox *>(cppSelf)->modelColumn();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_mousePressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mousePressEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mousePressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mousePressEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::mousePressEvent(cppArg0)
                : cppSelf->mousePressEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_mouseReleaseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mouseReleaseEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseReleaseEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseReleaseEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::mouseReleaseEvent(cppArg0)
                : cppSelf->mouseReleaseEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_paintEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::paintEvent(QPaintEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), (pyArg)))) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "paintEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPaintEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paintEvent(QPaintEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::paintEvent(cppArg0)
                : cppSelf->paintEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_placeholderText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // placeholderText()const
        QString cppResult = const_cast<const ::QComboBox *>(cppSelf)->placeholderText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_removeItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::removeItem(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // removeItem(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeItem(int)
            cppSelf->removeItem(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_resizeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::resizeEvent(QResizeEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), (pyArg)))) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resizeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QResizeEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeEvent(QResizeEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::resizeEvent(cppArg0)
                : cppSelf->resizeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_rootModelIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rootModelIndex()const
        QModelIndex cppResult = const_cast<const ::QComboBox *>(cppSelf)->rootModelIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_setCompleter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setCompleter(QCompleter*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCompleter_IDX]), (pyArg)))) {
        overloadId = 0; // setCompleter(QCompleter*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCompleter", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCompleter *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCompleter(QCompleter*)
            cppSelf->setCompleter(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setCurrentIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setCurrentIndex(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCurrentIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCurrentIndex", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrentIndex(int)
            cppSelf->setCurrentIndex(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setCurrentText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setCurrentText(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCurrentText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCurrentText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrentText(QString)
            cppSelf->setCurrentText(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setDuplicatesEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setDuplicatesEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDuplicatesEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDuplicatesEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDuplicatesEnabled(bool)
            cppSelf->setDuplicatesEnabled(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setEditText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setEditText(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setEditText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEditText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEditText(QString)
            cppSelf->setEditText(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setEditable(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setEditable(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setEditable(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEditable", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEditable(bool)
            cppSelf->setEditable(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setFrame(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setFrame(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFrame(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFrame", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFrame(bool)
            cppSelf->setFrame(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setIconSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setIconSize(QSize)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
        overloadId = 0; // setIconSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIconSize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSize cppArg0_local;
        ::QSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setIconSize(QSize)
            cppSelf->setIconSize(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setInsertPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setInsertPolicy(QComboBox::InsertPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_InsertPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setInsertPolicy(QComboBox::InsertPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInsertPolicy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        ::QComboBox::InsertPolicy cppArg0{QComboBox::NoInsert};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInsertPolicy(QComboBox::InsertPolicy)
            cppSelf->setInsertPolicy(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setItemData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setItemData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setItemData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QComboBox::setItemData(int,QVariant,int=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setItemData(int,QVariant,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 0; // setItemData(int,QVariant,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setItemData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setItemData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = Qt::UserRole;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemData(int,QVariant,int)
            cppSelf->setItemData(cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setItemDelegate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setItemDelegate(QAbstractItemDelegate*)
    if ((pyArg != Py_None && (pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX]), (pyArg))))) {
        overloadId = 0; // setItemDelegate(QAbstractItemDelegate*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItemDelegate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractItemDelegate *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemDelegate(QAbstractItemDelegate*)
            cppSelf->setItemDelegate(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "setItemDelegate(QAbstractItemDelegate*)1", pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setItemIcon(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setItemIcon", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QComboBox::setItemIcon(int,QIcon)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setItemIcon(int,QIcon)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setItemIcon", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QIcon cppArg1_local;
        ::QIcon *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemIcon(int,QIcon)
            cppSelf->setItemIcon(cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setItemText(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setItemText", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QComboBox::setItemText(int,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // setItemText(int,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setItemText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemText(int,QString)
            cppSelf->setItemText(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setLabelDrawingMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setLabelDrawingMode(QComboBox::LabelDrawingMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_LabelDrawingMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setLabelDrawingMode(QComboBox::LabelDrawingMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelDrawingMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        ::QComboBox::LabelDrawingMode cppArg0{QComboBox::LabelDrawingMode::UseStyle};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelDrawingMode(QComboBox::LabelDrawingMode)
            cppSelf->setLabelDrawingMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setLineEdit(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setLineEdit(QLineEdit*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QLineEdit_IDX]), (pyArg)))) {
        overloadId = 0; // setLineEdit(QLineEdit*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLineEdit", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLineEdit *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLineEdit(QLineEdit*)
            cppSelf->setLineEdit(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setMaxCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setMaxCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMaxCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxCount", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxCount(int)
            cppSelf->setMaxCount(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setMaxVisibleItems(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setMaxVisibleItems(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMaxVisibleItems(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxVisibleItems", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxVisibleItems(int)
            cppSelf->setMaxVisibleItems(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setMinimumContentsLength(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setMinimumContentsLength(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMinimumContentsLength(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinimumContentsLength", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinimumContentsLength(int)
            cppSelf->setMinimumContentsLength(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setModel(QAbstractItemModel*)
    if ((pyArg != Py_None && (pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), (pyArg))))) {
        overloadId = 0; // setModel(QAbstractItemModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setModel", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractItemModel *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setModel(QAbstractItemModel*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::setModel(cppArg0)
                : cppSelf->setModel(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "setModel(QAbstractItemModel*)1", pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setModelColumn(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setModelColumn(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setModelColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setModelColumn", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setModelColumn(int)
            cppSelf->setModelColumn(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setPlaceholderText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setPlaceholderText(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPlaceholderText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPlaceholderText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPlaceholderText(QString)
            cppSelf->setPlaceholderText(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setRootModelIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setRootModelIndex(QModelIndex)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // setRootModelIndex(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRootModelIndex", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRootModelIndex(QModelIndex)
            cppSelf->setRootModelIndex(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setSizeAdjustPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_SizeAdjustPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSizeAdjustPolicy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        ::QComboBox::SizeAdjustPolicy cppArg0{QComboBox::AdjustToContents};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy)
            cppSelf->setSizeAdjustPolicy(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setValidator(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setValidator(const QValidator*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QValidator_IDX]), (pyArg)))) {
        overloadId = 0; // setValidator(const QValidator*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setValidator", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QValidator *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValidator(const QValidator*)
            cppSelf->setValidator(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_setView(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QComboBox::setView(QAbstractItemView*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), (pyArg)))) {
        overloadId = 0; // setView(QAbstractItemView*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setView", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractItemView *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setView(QAbstractItemView*)
            cppSelf->setView(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_showEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::showEvent(QShowEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), (pyArg)))) {
        overloadId = 0; // showEvent(QShowEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "showEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QShowEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // showEvent(QShowEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::showEvent(cppArg0)
                : cppSelf->showEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_showPopup(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // showPopup()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QComboBox::showPopup()
            : cppSelf->showPopup();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QComboBoxFunc_sizeAdjustPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizeAdjustPolicy()const
        QComboBox::SizeAdjustPolicy cppResult = const_cast<const ::QComboBox *>(cppSelf)->sizeAdjustPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_SizeAdjustPolicy_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_sizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizeHint()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QComboBox *>(cppSelf)->::QComboBox::sizeHint()
            : const_cast<const ::QComboBox *>(cppSelf)->sizeHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_validator(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // validator()const
        const QValidator * cppResult = const_cast<const ::QComboBox *>(cppSelf)->validator();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QValidator_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_view(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // view()const
        QAbstractItemView * cppResult = const_cast<const ::QComboBox *>(cppSelf)->view();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QComboBoxFunc_wheelEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::wheelEvent(QWheelEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), (pyArg)))) {
        overloadId = 0; // wheelEvent(QWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "wheelEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWheelEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wheelEvent(QWheelEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QComboBox::wheelEvent(cppArg0)
                : cppSelf->wheelEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QComboBox_PropertyStrings[] = {
    "count:",
    "currentData:",
    "currentIndex::",
    "currentText::",
    "duplicatesEnabled::",
    "editable:isEditable:",
    "frame:hasFrame:",
    "iconSize::",
    "insertPolicy::",
    "labelDrawingMode::",
    "maxCount::",
    "maxVisibleItems::",
    "minimumContentsLength::",
    "modelColumn::",
    "placeholderText::",
    "sizeAdjustPolicy::",
    nullptr // Sentinel
};

static const char *Sbk_QComboBox_EnumFlagInfo[] = {
    "InsertPolicy:Enum",
    "LabelDrawingMode:Enum",
    "SizeAdjustPolicy:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QComboBox_methods[] = {
    {"addItem", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_addItem), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addItems", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_addItems), METH_O, nullptr},
    {"changeEvent", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_changeEvent), METH_O, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_clear), METH_NOARGS, nullptr},
    {"clearEditText", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_clearEditText), METH_NOARGS, nullptr},
    {"completer", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_completer), METH_NOARGS, nullptr},
    {"contextMenuEvent", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_contextMenuEvent), METH_O, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_count), METH_NOARGS, nullptr},
    {"currentData", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_currentData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"currentIndex", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_currentIndex), METH_NOARGS, nullptr},
    {"currentText", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_currentText), METH_NOARGS, nullptr},
    {"duplicatesEnabled", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_duplicatesEnabled), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_event), METH_O, nullptr},
    {"findData", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_findData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"findText", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_findText), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"focusInEvent", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_focusInEvent), METH_O, nullptr},
    {"focusOutEvent", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_focusOutEvent), METH_O, nullptr},
    {"hasFrame", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_hasFrame), METH_NOARGS, nullptr},
    {"hideEvent", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_hideEvent), METH_O, nullptr},
    {"hidePopup", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_hidePopup), METH_NOARGS, nullptr},
    {"iconSize", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_iconSize), METH_NOARGS, nullptr},
    {"initStyleOption", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_initStyleOption), METH_O, nullptr},
    {"inputMethodEvent", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_inputMethodEvent), METH_O, nullptr},
    {"inputMethodQuery", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_inputMethodQuery), METH_VARARGS, nullptr},
    {"insertItem", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_insertItem), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"insertItems", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_insertItems), METH_VARARGS, nullptr},
    {"insertPolicy", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_insertPolicy), METH_NOARGS, nullptr},
    {"insertSeparator", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_insertSeparator), METH_O, nullptr},
    {"isEditable", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_isEditable), METH_NOARGS, nullptr},
    {"itemData", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_itemData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"itemDelegate", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_itemDelegate), METH_NOARGS, nullptr},
    {"itemIcon", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_itemIcon), METH_O, nullptr},
    {"itemText", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_itemText), METH_O, nullptr},
    {"keyPressEvent", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_keyPressEvent), METH_O, nullptr},
    {"keyReleaseEvent", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_keyReleaseEvent), METH_O, nullptr},
    {"labelDrawingMode", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_labelDrawingMode), METH_NOARGS, nullptr},
    {"lineEdit", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_lineEdit), METH_NOARGS, nullptr},
    {"maxCount", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_maxCount), METH_NOARGS, nullptr},
    {"maxVisibleItems", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_maxVisibleItems), METH_NOARGS, nullptr},
    {"minimumContentsLength", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_minimumContentsLength), METH_NOARGS, nullptr},
    {"minimumSizeHint", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_minimumSizeHint), METH_NOARGS, nullptr},
    {"model", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_model), METH_NOARGS, nullptr},
    {"modelColumn", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_modelColumn), METH_NOARGS, nullptr},
    {"mousePressEvent", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_mousePressEvent), METH_O, nullptr},
    {"mouseReleaseEvent", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_mouseReleaseEvent), METH_O, nullptr},
    {"paintEvent", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_paintEvent), METH_O, nullptr},
    {"placeholderText", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_placeholderText), METH_NOARGS, nullptr},
    {"removeItem", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_removeItem), METH_O, nullptr},
    {"resizeEvent", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_resizeEvent), METH_O, nullptr},
    {"rootModelIndex", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_rootModelIndex), METH_NOARGS, nullptr},
    {"setCompleter", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setCompleter), METH_O, nullptr},
    {"setCurrentIndex", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setCurrentIndex), METH_O, nullptr},
    {"setCurrentText", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setCurrentText), METH_O, nullptr},
    {"setDuplicatesEnabled", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setDuplicatesEnabled), METH_O, nullptr},
    {"setEditText", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setEditText), METH_O, nullptr},
    {"setEditable", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setEditable), METH_O, nullptr},
    {"setFrame", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setFrame), METH_O, nullptr},
    {"setIconSize", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setIconSize), METH_O, nullptr},
    {"setInsertPolicy", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setInsertPolicy), METH_O, nullptr},
    {"setItemData", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setItemData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setItemDelegate", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setItemDelegate), METH_O, nullptr},
    {"setItemIcon", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setItemIcon), METH_VARARGS, nullptr},
    {"setItemText", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setItemText), METH_VARARGS, nullptr},
    {"setLabelDrawingMode", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setLabelDrawingMode), METH_O, nullptr},
    {"setLineEdit", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setLineEdit), METH_O, nullptr},
    {"setMaxCount", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setMaxCount), METH_O, nullptr},
    {"setMaxVisibleItems", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setMaxVisibleItems), METH_O, nullptr},
    {"setMinimumContentsLength", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setMinimumContentsLength), METH_O, nullptr},
    {"setModel", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setModel), METH_O, nullptr},
    {"setModelColumn", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setModelColumn), METH_O, nullptr},
    {"setPlaceholderText", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setPlaceholderText), METH_O, nullptr},
    {"setRootModelIndex", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setRootModelIndex), METH_O, nullptr},
    {"setSizeAdjustPolicy", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setSizeAdjustPolicy), METH_O, nullptr},
    {"setValidator", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setValidator), METH_O, nullptr},
    {"setView", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_setView), METH_O, nullptr},
    {"showEvent", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_showEvent), METH_O, nullptr},
    {"showPopup", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_showPopup), METH_NOARGS, nullptr},
    {"sizeAdjustPolicy", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_sizeAdjustPolicy), METH_NOARGS, nullptr},
    {"sizeHint", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_sizeHint), METH_NOARGS, nullptr},
    {"validator", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_validator), METH_NOARGS, nullptr},
    {"view", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_view), METH_NOARGS, nullptr},
    {"wheelEvent", reinterpret_cast<PyCFunction>(Sbk_QComboBoxFunc_wheelEvent), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QComboBox_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QComboBoxWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QComboBox_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QComboBox_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QComboBoxSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QComboBox *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QComboBox_Type = nullptr;
static PyTypeObject *Sbk_QComboBox_TypeF(void)
{
    return _Sbk_QComboBox_Type;
}

static PyType_Slot Sbk_QComboBox_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QComboBox_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QComboBox_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QComboBox_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QComboBox_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QComboBox_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QComboBox_spec = {
    "2:PySide6.QtWidgets.QComboBox",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QComboBox_slots
};

} //extern "C"

static void *Sbk_QComboBox_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QComboBox *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QComboBox *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QComboBox *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QComboBox_InsertPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QComboBox::InsertPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QComboBox::InsertPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QComboBox_InsertPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_InsertPolicy_IDX])))
        return Enum_PythonToCpp_QComboBox_InsertPolicy;
    return {};
}

static PyObject *QComboBox_InsertPolicy_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QComboBox::InsertPolicy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QComboBox::InsertPolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_InsertPolicy_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QComboBox_SizeAdjustPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QComboBox::SizeAdjustPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QComboBox::SizeAdjustPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QComboBox_SizeAdjustPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_SizeAdjustPolicy_IDX])))
        return Enum_PythonToCpp_QComboBox_SizeAdjustPolicy;
    return {};
}

static PyObject *QComboBox_SizeAdjustPolicy_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QComboBox::SizeAdjustPolicy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QComboBox::SizeAdjustPolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_SizeAdjustPolicy_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QComboBox_LabelDrawingMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QComboBox::LabelDrawingMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QComboBox::LabelDrawingMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QComboBox_LabelDrawingMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_LabelDrawingMode_IDX])))
        return Enum_PythonToCpp_QComboBox_LabelDrawingMode;
    return {};
}

static PyObject *QComboBox_LabelDrawingMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QComboBox::LabelDrawingMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QComboBox::LabelDrawingMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_LabelDrawingMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QComboBox_PythonToCpp_QComboBox_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QComboBox_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QComboBox_PythonToCpp_QComboBox_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QComboBox_TypeF()))
        return QComboBox_PythonToCpp_QComboBox_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QComboBox_PTR_CppToPython_QComboBox(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QComboBox *>(const_cast<void *>(cppIn)), Sbk_QComboBox_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QComboBox_SignatureStrings[] = {
    "PySide6.QtWidgets.QComboBox(self,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,editable:bool=None,count:int=None,currentText:QString=None,currentIndex:int=None,currentData:QVariant=None,maxVisibleItems:int=None,maxCount:int=None,insertPolicy:QComboBox.InsertPolicy=None,sizeAdjustPolicy:QComboBox.SizeAdjustPolicy=None,minimumContentsLength:int=None,iconSize:QSize=None,placeholderText:QString=None,duplicatesEnabled:bool=None,frame:bool=None,modelColumn:int=None,labelDrawingMode:QComboBox.LabelDrawingMode=None)",
    "1:PySide6.QtWidgets.QComboBox.addItem(self,icon:typing.Union[PySide6.QtGui.QIcon, PySide6.QtGui.QPixmap],text:QString,userData:QVariant=QVariant())",
    "0:PySide6.QtWidgets.QComboBox.addItem(self,text:QString,userData:QVariant=QVariant())",
    "PySide6.QtWidgets.QComboBox.addItems(self,texts:QStringList)",
    "PySide6.QtWidgets.QComboBox.changeEvent(self,e:PySide6.QtCore.QEvent)",
    "PySide6.QtWidgets.QComboBox.clear(self)",
    "PySide6.QtWidgets.QComboBox.clearEditText(self)",
    "PySide6.QtWidgets.QComboBox.completer(self)->PySide6.QtWidgets.QCompleter",
    "PySide6.QtWidgets.QComboBox.contextMenuEvent(self,e:PySide6.QtGui.QContextMenuEvent)",
    "PySide6.QtWidgets.QComboBox.count(self)->int",
    "PySide6.QtWidgets.QComboBox.currentData(self,role:int=Qt.UserRole)->QVariant",
    "PySide6.QtWidgets.QComboBox.currentIndex(self)->int",
    "PySide6.QtWidgets.QComboBox.currentText(self)->QString",
    "PySide6.QtWidgets.QComboBox.duplicatesEnabled(self)->bool",
    "PySide6.QtWidgets.QComboBox.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QComboBox.findData(self,data:QVariant,role:int=Qt.UserRole,flags:PySide6.QtCore.Qt.MatchFlag=static_cast<Qt.MatchFlags>(Qt.MatchExactly|Qt.MatchCaseSensitive))->int",
    "PySide6.QtWidgets.QComboBox.findText(self,text:QString,flags:PySide6.QtCore.Qt.MatchFlag=static_cast<Qt.MatchFlags>(Qt.MatchExactly|Qt.MatchCaseSensitive))->int",
    "PySide6.QtWidgets.QComboBox.focusInEvent(self,e:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtWidgets.QComboBox.focusOutEvent(self,e:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtWidgets.QComboBox.hasFrame(self)->bool",
    "PySide6.QtWidgets.QComboBox.hideEvent(self,e:PySide6.QtGui.QHideEvent)",
    "PySide6.QtWidgets.QComboBox.hidePopup(self)",
    "PySide6.QtWidgets.QComboBox.iconSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QComboBox.initStyleOption(self,option:PySide6.QtWidgets.QStyleOptionComboBox)",
    "PySide6.QtWidgets.QComboBox.inputMethodEvent(self,arg__1:PySide6.QtGui.QInputMethodEvent)",
    "1:PySide6.QtWidgets.QComboBox.inputMethodQuery(self,arg__1:PySide6.QtCore.Qt.InputMethodQuery)->QVariant",
    "0:PySide6.QtWidgets.QComboBox.inputMethodQuery(self,query:PySide6.QtCore.Qt.InputMethodQuery,argument:QVariant)->QVariant",
    "1:PySide6.QtWidgets.QComboBox.insertItem(self,index:int,icon:typing.Union[PySide6.QtGui.QIcon, PySide6.QtGui.QPixmap],text:QString,userData:QVariant=QVariant())",
    "0:PySide6.QtWidgets.QComboBox.insertItem(self,index:int,text:QString,userData:QVariant=QVariant())",
    "PySide6.QtWidgets.QComboBox.insertItems(self,index:int,texts:QStringList)",
    "PySide6.QtWidgets.QComboBox.insertPolicy(self)->PySide6.QtWidgets.QComboBox.InsertPolicy",
    "PySide6.QtWidgets.QComboBox.insertSeparator(self,index:int)",
    "PySide6.QtWidgets.QComboBox.isEditable(self)->bool",
    "PySide6.QtWidgets.QComboBox.itemData(self,index:int,role:int=Qt.UserRole)->QVariant",
    "PySide6.QtWidgets.QComboBox.itemDelegate(self)->PySide6.QtWidgets.QAbstractItemDelegate",
    "PySide6.QtWidgets.QComboBox.itemIcon(self,index:int)->PySide6.QtGui.QIcon",
    "PySide6.QtWidgets.QComboBox.itemText(self,index:int)->QString",
    "PySide6.QtWidgets.QComboBox.keyPressEvent(self,e:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtWidgets.QComboBox.keyReleaseEvent(self,e:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtWidgets.QComboBox.labelDrawingMode(self)->PySide6.QtWidgets.QComboBox.LabelDrawingMode",
    "PySide6.QtWidgets.QComboBox.lineEdit(self)->PySide6.QtWidgets.QLineEdit",
    "PySide6.QtWidgets.QComboBox.maxCount(self)->int",
    "PySide6.QtWidgets.QComboBox.maxVisibleItems(self)->int",
    "PySide6.QtWidgets.QComboBox.minimumContentsLength(self)->int",
    "PySide6.QtWidgets.QComboBox.minimumSizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QComboBox.model(self)->PySide6.QtCore.QAbstractItemModel",
    "PySide6.QtWidgets.QComboBox.modelColumn(self)->int",
    "PySide6.QtWidgets.QComboBox.mousePressEvent(self,e:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QComboBox.mouseReleaseEvent(self,e:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QComboBox.paintEvent(self,e:PySide6.QtGui.QPaintEvent)",
    "PySide6.QtWidgets.QComboBox.placeholderText(self)->QString",
    "PySide6.QtWidgets.QComboBox.removeItem(self,index:int)",
    "PySide6.QtWidgets.QComboBox.resizeEvent(self,e:PySide6.QtGui.QResizeEvent)",
    "PySide6.QtWidgets.QComboBox.rootModelIndex(self)->PySide6.QtCore.QModelIndex",
    "PySide6.QtWidgets.QComboBox.setCompleter(self,c:PySide6.QtWidgets.QCompleter)",
    "PySide6.QtWidgets.QComboBox.setCurrentIndex(self,index:int)",
    "PySide6.QtWidgets.QComboBox.setCurrentText(self,text:QString)",
    "PySide6.QtWidgets.QComboBox.setDuplicatesEnabled(self,enable:bool)",
    "PySide6.QtWidgets.QComboBox.setEditText(self,text:QString)",
    "PySide6.QtWidgets.QComboBox.setEditable(self,editable:bool)",
    "PySide6.QtWidgets.QComboBox.setFrame(self,arg__1:bool)",
    "PySide6.QtWidgets.QComboBox.setIconSize(self,size:PySide6.QtCore.QSize)",
    "PySide6.QtWidgets.QComboBox.setInsertPolicy(self,policy:PySide6.QtWidgets.QComboBox.InsertPolicy)",
    "PySide6.QtWidgets.QComboBox.setItemData(self,index:int,value:QVariant,role:int=Qt.UserRole)",
    "PySide6.QtWidgets.QComboBox.setItemDelegate(self,delegate:PySide6.QtWidgets.QAbstractItemDelegate)",
    "PySide6.QtWidgets.QComboBox.setItemIcon(self,index:int,icon:typing.Union[PySide6.QtGui.QIcon, PySide6.QtGui.QPixmap])",
    "PySide6.QtWidgets.QComboBox.setItemText(self,index:int,text:QString)",
    "PySide6.QtWidgets.QComboBox.setLabelDrawingMode(self,labelDrawing:PySide6.QtWidgets.QComboBox.LabelDrawingMode)",
    "PySide6.QtWidgets.QComboBox.setLineEdit(self,edit:PySide6.QtWidgets.QLineEdit)",
    "PySide6.QtWidgets.QComboBox.setMaxCount(self,max:int)",
    "PySide6.QtWidgets.QComboBox.setMaxVisibleItems(self,maxItems:int)",
    "PySide6.QtWidgets.QComboBox.setMinimumContentsLength(self,characters:int)",
    "PySide6.QtWidgets.QComboBox.setModel(self,model:PySide6.QtCore.QAbstractItemModel)",
    "PySide6.QtWidgets.QComboBox.setModelColumn(self,visibleColumn:int)",
    "PySide6.QtWidgets.QComboBox.setPlaceholderText(self,placeholderText:QString)",
    "PySide6.QtWidgets.QComboBox.setRootModelIndex(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "PySide6.QtWidgets.QComboBox.setSizeAdjustPolicy(self,policy:PySide6.QtWidgets.QComboBox.SizeAdjustPolicy)",
    "PySide6.QtWidgets.QComboBox.setValidator(self,v:PySide6.QtGui.QValidator)",
    "PySide6.QtWidgets.QComboBox.setView(self,itemView:PySide6.QtWidgets.QAbstractItemView)",
    "PySide6.QtWidgets.QComboBox.showEvent(self,e:PySide6.QtGui.QShowEvent)",
    "PySide6.QtWidgets.QComboBox.showPopup(self)",
    "PySide6.QtWidgets.QComboBox.sizeAdjustPolicy(self)->PySide6.QtWidgets.QComboBox.SizeAdjustPolicy",
    "PySide6.QtWidgets.QComboBox.sizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QComboBox.validator(self)->PySide6.QtGui.QValidator",
    "PySide6.QtWidgets.QComboBox.view(self)->PySide6.QtWidgets.QAbstractItemView",
    "PySide6.QtWidgets.QComboBox.wheelEvent(self,e:PySide6.QtGui.QWheelEvent)",
    nullptr}; // Sentinel
#else
static constexpr size_t QComboBox_SignatureByteSize = 1260;
static constexpr uint8_t QComboBox_SignatureBytes[1260] = {
    0x78, 0xda, 0xcd, 0x58, 0xcd, 0x72, 0xdb, 0x36, 0x10, 0xbe, 0xfb, 0x29, 0x7a, 0xb4, 0x3a, 0xac,
    0x26, 0xb9, 0xf4, 0xc0, 0xa9, 0x33, 0x93, 0xc8, 0x72, 0xa3, 0xa9, 0x54, 0x4b, 0x56, 0xe3, 0x1c,
    0x32, 0x1d, 0x0f, 0x44, 0xae, 0x25, 0xb4, 0x20, 0xc0, 0x02, 0xa0, 0x2c, 0x75, 0xfa, 0xf0, 0x05,
    0x48, 0x91, 0x04, 0x41, 0x0a, 0x80, 0xe2, 0x1c, 0x72, 0xd1, 0x08, 0xdc, 0xdd, 0x6f, 0x17, 0x8b,
    0xc5, 0xfe, 0x60, 0x79, 0x5c, 0xe3, 0x14, 0x7e, 0x1e, 0xaf, 0xe4, 0x67, 0x9c, 0x6e, 0x41, 0x8a,
    0xf1, 0x6a, 0xc2, 0xb2, 0x0d, 0xfb, 0xc0, 0x0e, 0xd7, 0x02, 0xc8, 0x73, 0x94, 0x23, 0x0e, 0x54,
    0xc6, 0xcb, 0x3e, 0x5f, 0xf5, 0xe7, 0x86, 0x16, 0x84, 0xe4, 0x92, 0x47, 0x3f, 0xc6, 0xbf, 0xc1,
    0xf1, 0x85, 0xf1, 0xf4, 0x9e, 0x92, 0xe3, 0xcd, 0xef, 0x8c, 0x42, 0x04, 0x29, 0x96, 0x68, 0x43,
    0x20, 0xde, 0x30, 0x46, 0xaa, 0x4f, 0x09, 0x2b, 0x14, 0x1a, 0xa6, 0xf2, 0xb4, 0x2c, 0xb8, 0x86,
    0xff, 0x03, 0x0e, 0x32, 0x5e, 0xad, 0x25, 0xc7, 0x74, 0xdb, 0x21, 0xcc, 0x68, 0x0a, 0x87, 0x1e,
    0xfb, 0x2d, 0x92, 0x28, 0x5e, 0x3d, 0x22, 0x8e, 0x51, 0x4d, 0xc9, 0xd0, 0xe1, 0x11, 0x0b, 0xac,
    0x94, 0xcd, 0x24, 0x64, 0xa2, 0x15, 0x51, 0x84, 0x49, 0x57, 0x27, 0xa6, 0x02, 0xb8, 0x5c, 0x32,
    0x82, 0x93, 0x63, 0xdc, 0xec, 0x76, 0x3c, 0x33, 0x3e, 0x57, 0x8c, 0x02, 0xff, 0x0b, 0xef, 0xd3,
    0xbf, 0x0a, 0xd1, 0x67, 0x5e, 0x5b, 0xa4, 0x93, 0x2e, 0x4c, 0x71, 0x56, 0x64, 0x13, 0x46, 0xa5,
    0xb2, 0x52, 0xcc, 0x81, 0x6e, 0xe5, 0xce, 0x50, 0x9c, 0x30, 0xaa, 0x05, 0xd5, 0x4e, 0xd5, 0x6f,
    0xf5, 0x2d, 0x27, 0x28, 0x81, 0x1d, 0x23, 0x29, 0xf0, 0xbe, 0x13, 0xd2, 0x22, 0x57, 0xe0, 0x48,
    0x82, 0x98, 0x52, 0xed, 0xc7, 0xd4, 0x70, 0xe4, 0x33, 0x47, 0x99, 0xe9, 0xd8, 0x8c, 0xa5, 0x40,
    0x26, 0x8c, 0x14, 0x19, 0x6d, 0x35, 0x12, 0xb4, 0x01, 0x72, 0xcb, 0xd1, 0x8b, 0x82, 0x5c, 0x28,
    0x06, 0x63, 0x07, 0x73, 0x8b, 0x54, 0x0a, 0x8c, 0xae, 0xde, 0x0e, 0x9d, 0x74, 0x23, 0x84, 0xd2,
    0x54, 0xbb, 0xb7, 0x8a, 0x0c, 0xbd, 0x9d, 0x58, 0x1e, 0x73, 0x05, 0x30, 0xfe, 0x44, 0x31, 0xa3,
    0x5f, 0x5a, 0xd1, 0x5f, 0x0b, 0x3c, 0x5e, 0xcd, 0x14, 0x43, 0xf4, 0x83, 0xf5, 0x71, 0x89, 0x0f,
    0x19, 0xca, 0xff, 0x8c, 0xa4, 0xb1, 0xdb, 0xa8, 0x50, 0xae, 0xef, 0x1e, 0x6a, 0xfd, 0xe7, 0x7a,
    0x34, 0xba, 0x7a, 0x13, 0x6e, 0xd3, 0x05, 0xa8, 0x01, 0x98, 0xa2, 0x05, 0x15, 0x35, 0xea, 0x1c,
    0x0b, 0xe9, 0x16, 0x4e, 0x76, 0x88, 0x6e, 0x61, 0xba, 0x57, 0x21, 0x50, 0xc9, 0x83, 0x61, 0xff,
    0x84, 0x71, 0x18, 0xaf, 0x4a, 0xa2, 0x07, 0x85, 0x00, 0xe2, 0xa5, 0x7c, 0x00, 0xdf, 0x54, 0x5d,
    0x34, 0x1d, 0x3e, 0x21, 0xfc, 0x2c, 0xcb, 0x09, 0x48, 0x38, 0x61, 0xff, 0xf4, 0x6e, 0x98, 0xb9,
    0xe2, 0xf1, 0x20, 0x51, 0xed, 0x99, 0x05, 0xd0, 0xe2, 0xcc, 0x66, 0xcb, 0x03, 0x9f, 0x58, 0x6c,
    0x3e, 0xf3, 0x8a, 0x13, 0x92, 0x32, 0x4d, 0xc5, 0xb1, 0x9b, 0xb9, 0x4d, 0x07, 0x95, 0x72, 0xce,
    0x54, 0xb2, 0xd1, 0xd1, 0xbf, 0x92, 0xe3, 0x4f, 0xea, 0xf4, 0x1f, 0xd4, 0x5a, 0xe1, 0xd4, 0xc7,
    0x1e, 0x02, 0x56, 0x66, 0x9c, 0x0b, 0x0d, 0x68, 0x5d, 0xaf, 0x74, 0x55, 0x61, 0xe2, 0x14, 0xeb,
    0xdd, 0xeb, 0x5a, 0x58, 0x5f, 0x67, 0xa7, 0x24, 0x18, 0x8e, 0xde, 0x77, 0xf3, 0xb2, 0x19, 0x59,
    0x01, 0x48, 0xcf, 0x98, 0xa6, 0xad, 0xe3, 0x52, 0xf3, 0x9a, 0x0c, 0xba, 0x31, 0x7a, 0x26, 0x68,
    0x2b, 0x7a, 0xfa, 0xe4, 0x78, 0x81, 0x64, 0xb2, 0xbb, 0x53, 0xc4, 0x1b, 0x21, 0x91, 0xc4, 0xc9,
    0x53, 0x82, 0x84, 0xfc, 0xc5, 0x24, 0x88, 0x77, 0xd7, 0xf5, 0x72, 0x7a, 0x40, 0x89, 0x24, 0xc7,
    0xff, 0xea, 0xf5, 0x04, 0x09, 0x58, 0x03, 0x15, 0x58, 0xe2, 0x3d, 0x8c, 0x02, 0x3c, 0xae, 0xcd,
    0x6e, 0xdc, 0xdd, 0xbd, 0xee, 0xdf, 0x89, 0x81, 0x2c, 0x29, 0xc4, 0x8c, 0xba, 0x6e, 0xc4, 0x9d,
    0x66, 0x09, 0xb8, 0x0b, 0x25, 0xd4, 0x7d, 0x21, 0xbf, 0x05, 0xd6, 0x0e, 0x89, 0x3b, 0x5d, 0x31,
    0x82, 0x23, 0x6d, 0xa7, 0x28, 0x2e, 0xc5, 0x1f, 0x6b, 0xfa, 0xc8, 0x0b, 0xb3, 0x64, 0x79, 0x91,
    0x07, 0xa4, 0xa6, 0xba, 0x3e, 0xf6, 0x33, 0x53, 0x75, 0x94, 0x9a, 0xe6, 0x06, 0xa0, 0x58, 0xae,
    0xe5, 0x91, 0xc0, 0x7d, 0x2e, 0x55, 0x3d, 0xaa, 0x2c, 0x67, 0xe5, 0xff, 0xa1, 0x12, 0x62, 0xb0,
    0xd6, 0x10, 0x1e, 0x03, 0x69, 0x5e, 0xa8, 0x44, 0x26, 0x77, 0x2c, 0x35, 0x5c, 0x83, 0xf8, 0xf6,
    0xe9, 0xe9, 0xad, 0xed, 0x9f, 0x99, 0xc5, 0xeb, 0x2b, 0xad, 0x06, 0xf6, 0xaa, 0x00, 0x7e, 0x3c,
    0x83, 0x5d, 0x07, 0xf5, 0xcc, 0x62, 0x37, 0xb3, 0xdc, 0x9b, 0xaf, 0x50, 0xf4, 0x8f, 0xfe, 0x1b,
    0xa0, 0x47, 0x5b, 0x54, 0x64, 0x3a, 0xf3, 0xd4, 0xea, 0x4c, 0xcd, 0xbe, 0x2d, 0xea, 0x0e, 0xcb,
    0x68, 0x20, 0xea, 0xe6, 0xee, 0x7b, 0x69, 0x25, 0xce, 0x1b, 0xf8, 0x8d, 0xfa, 0x8a, 0x56, 0x81,
    0x18, 0xd2, 0x70, 0x41, 0x93, 0x61, 0x36, 0xb1, 0xee, 0x4a, 0xde, 0xef, 0x6e, 0x03, 0x80, 0xd7,
    0xa0, 0xfa, 0x7e, 0x24, 0x19, 0xb7, 0xcc, 0xf4, 0x18, 0x25, 0xa6, 0xa7, 0x8e, 0x3f, 0x38, 0xcd,
    0x60, 0xe5, 0x8b, 0xb6, 0x0c, 0xb5, 0xee, 0x78, 0x4d, 0x25, 0x2f, 0x31, 0x81, 0xc0, 0x56, 0x55,
    0x58, 0x87, 0x6f, 0xde, 0x6f, 0x84, 0xe4, 0x2a, 0xdb, 0xcf, 0x0c, 0x76, 0x2f, 0xae, 0x0e, 0x44,
    0xdb, 0x27, 0x26, 0x7a, 0x13, 0xad, 0x5e, 0xa4, 0xb6, 0x8a, 0x99, 0x48, 0x21, 0xed, 0xc3, 0xdf,
    0x70, 0x5c, 0x72, 0x10, 0xc2, 0x95, 0x9e, 0xd5, 0x2c, 0x16, 0x90, 0x9d, 0x15, 0xd2, 0x83, 0xda,
    0xb9, 0xaa, 0x71, 0xaf, 0xc7, 0xb2, 0x67, 0x8d, 0x90, 0xa8, 0xb4, 0x87, 0x10, 0xb7, 0x02, 0x4c,
    0x41, 0xc7, 0x97, 0x03, 0x78, 0x7e, 0x62, 0x71, 0xe2, 0xd4, 0x13, 0x61, 0x68, 0x93, 0x67, 0x8d,
    0x96, 0xc1, 0x62, 0x43, 0xc3, 0xe0, 0x85, 0xc2, 0xba, 0xe2, 0x7d, 0xc4, 0x54, 0x7e, 0x75, 0x45,
    0x2c, 0xa7, 0xc2, 0x73, 0xd2, 0xe6, 0x05, 0xd0, 0xde, 0x27, 0x7e, 0xa8, 0x6a, 0xc0, 0x0c, 0xde,
    0x05, 0x53, 0xa9, 0xd2, 0x1b, 0xaa, 0x0b, 0xcd, 0x15, 0x10, 0x60, 0x25, 0x5a, 0x40, 0xb8, 0x86,
    0xe2, 0xe5, 0x48, 0xd9, 0xef, 0x02, 0x5a, 0x36, 0x0c, 0x1e, 0xa0, 0xee, 0x0c, 0x7f, 0xc9, 0x24,
    0xc0, 0x21, 0x63, 0x7b, 0x18, 0xa8, 0x38, 0x23, 0x8f, 0x98, 0x7e, 0x9b, 0x70, 0xd9, 0xfe, 0xd0,
    0x72, 0x78, 0xa0, 0x18, 0x93, 0xe5, 0xe1, 0x77, 0x06, 0x1f, 0x3b, 0x54, 0x5a, 0x0e, 0x27, 0x98,
    0x00, 0x39, 0xe9, 0xcc, 0x97, 0x51, 0x12, 0xbb, 0xe6, 0xcb, 0x91, 0x17, 0xcd, 0x1e, 0xca, 0x42,
    0x3d, 0xd4, 0xca, 0x0e, 0x4f, 0x0b, 0x5e, 0xe9, 0xdb, 0xc1, 0x19, 0x2d, 0x02, 0xda, 0x3c, 0x68,
    0x79, 0x21, 0x3a, 0x53, 0xf9, 0x65, 0xda, 0x3b, 0x75, 0xb4, 0xfb, 0x8e, 0xe6, 0x95, 0x6d, 0xfb,
    0xfc, 0xba, 0x7d, 0x0c, 0x12, 0x9b, 0x99, 0xdd, 0x77, 0xf9, 0xf6, 0x15, 0x0f, 0xa5, 0x1b, 0x3f,
    0x8e, 0xdd, 0x99, 0x44, 0x79, 0xf5, 0x7a, 0x16, 0xda, 0x9e, 0xf8, 0x35, 0x9c, 0xe9, 0x19, 0xf6,
    0x88, 0x14, 0xe0, 0x9e, 0x62, 0xc3, 0xb0, 0xcd, 0xde, 0x21, 0x4a, 0x4f, 0xab, 0x38, 0xb0, 0x85,
    0x08, 0x52, 0x31, 0xd0, 0x46, 0xbc, 0xae, 0x09, 0x0e, 0xd2, 0x3a, 0xd0, 0x72, 0x5c, 0x16, 0x96,
    0xf3, 0xa1, 0x1a, 0xdf, 0x79, 0x65, 0x8c, 0x2f, 0x29, 0xf7, 0x7e, 0x7d, 0x66, 0xc9, 0x2f, 0xaf,
    0x41, 0xec, 0xa8, 0xfa, 0x5e, 0xb8, 0x85, 0x59, 0xf9, 0xf5, 0xcb, 0x70, 0x50, 0x1e, 0x59, 0x0c,
    0xd4, 0x7f, 0x2d, 0xdc, 0x3c, 0x34, 0xfb, 0x11, 0xce, 0xb6, 0x02, 0x51, 0xb2, 0x43, 0x3a, 0x80,
    0x80, 0x07, 0x22, 0x35, 0xf5, 0xbc, 0x7a, 0xf0, 0x8d, 0xbd, 0x35, 0x3d, 0x0c, 0xd2, 0xa8, 0xeb,
    0xd1, 0xbe, 0xda, 0x6c, 0xfb, 0x96, 0xec, 0x85, 0x58, 0x0e, 0x14, 0xc0, 0x73, 0x2f, 0xdb, 0x5e,
    0xb0, 0x87, 0x7e, 0x41, 0x3a, 0x85, 0xeb, 0x99, 0xbb, 0x61, 0x57, 0x28, 0xf3, 0x8a, 0x54, 0xb4,
    0xa5, 0x72, 0xaf, 0x9a, 0xa8, 0x94, 0xef, 0x5b, 0x2e, 0xff, 0x8d, 0xb1, 0xdf, 0xf8, 0x83, 0x93,
    0x99, 0x2d, 0xe8, 0xd5, 0xf4, 0x88, 0x08, 0x4e, 0xdb, 0x69, 0x6b, 0x6f, 0x17, 0xf3, 0x86, 0xee,
    0x47, 0xc2, 0xf0, 0x72, 0x72, 0x99, 0x0a, 0x00, 0xbd, 0xf2, 0xa5, 0x2d, 0xcd, 0xe3, 0x81, 0xdd,
    0xb1, 0x17, 0x57, 0xab, 0xb1, 0xae, 0xe9, 0x7e, 0x98, 0xd0, 0x97, 0x20, 0x31, 0xe4, 0x7a, 0xcf,
    0x2c, 0x61, 0x7b, 0xdd, 0xab, 0xe0, 0x55, 0x8d, 0xf5, 0xbe, 0x73, 0x64, 0xfd, 0x11, 0xb0, 0x39,
    0x32, 0x37, 0x4a, 0x7d, 0x5c, 0xfe, 0x09, 0x55, 0x9f, 0x93, 0x13, 0xeb, 0x65, 0x07, 0x40, 0x5c,
    0xe7, 0xf4, 0xb9, 0x61, 0x18, 0x5d, 0xfd, 0x0f, 0x9a, 0x73, 0x2a, 0x64
};
#endif

PyTypeObject *init_QComboBox(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX].type;

    Shiboken::AutoDecRef Sbk_QComboBox_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))));

    _Sbk_QComboBox_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QComboBox",
        "QComboBox*",
        &Sbk_QComboBox_spec,
        &Shiboken::callCppDestructor< QComboBox >,
        Sbk_QComboBox_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QComboBox_TypeF(); // references _Sbk_QComboBox_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QComboBox_SignatureStrings);
#else
    InitSignatureBytes(pyType, QComboBox_SignatureBytes, QComboBox_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QComboBox_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QComboBox_PythonToCpp_QComboBox_PTR,
        is_QComboBox_PythonToCpp_QComboBox_PTR_Convertible,
        QComboBox_PTR_CppToPython_QComboBox);

    Shiboken::Conversions::registerConverterName(converter, "QComboBox");
    Shiboken::Conversions::registerConverterName(converter, "QComboBox*");
    Shiboken::Conversions::registerConverterName(converter, "QComboBox&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QComboBox).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QComboBoxWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QComboBox_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QComboBox_TypeF(), &Sbk_QComboBoxSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QComboBox_TypeF(), &Sbk_QComboBox_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QComboBox_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'InsertPolicy'.
    const char *InsertPolicy_Initializer[] = {
        "NoInsert",
        "InsertAtTop",
        "InsertAtCurrent",
        "InsertAtBottom",
        "InsertAfterCurrent",
        "InsertBeforeCurrent",
        "InsertAlphabetically",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t InsertPolicy_InitializerValues[] = {
        uint8_t(QComboBox::InsertPolicy::NoInsert),            //  0x00  0
        uint8_t(QComboBox::InsertPolicy::InsertAtTop),         //  0x01  1
        uint8_t(QComboBox::InsertPolicy::InsertAtCurrent),     //  0x02  2
        uint8_t(QComboBox::InsertPolicy::InsertAtBottom),      //  0x03  3
        uint8_t(QComboBox::InsertPolicy::InsertAfterCurrent),  //  0x04  4
        uint8_t(QComboBox::InsertPolicy::InsertBeforeCurrent), //  0x05  5
        uint8_t(QComboBox::InsertPolicy::InsertAlphabetically) //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QComboBox_TypeF(),
        "2:PySide6.QtWidgets.QComboBox.InsertPolicy",
        InsertPolicy_Initializer, InsertPolicy_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_InsertPolicy_IDX].type = EType;
    // Register converter for enum 'QComboBox::InsertPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QComboBox_InsertPolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QComboBox_InsertPolicy,
            is_Enum_PythonToCpp_QComboBox_InsertPolicy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QComboBox::InsertPolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "InsertPolicy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'InsertPolicy' enum.

    // Initialization of enum 'SizeAdjustPolicy'.
    const char *SizeAdjustPolicy_Initializer[] = {
        "AdjustToContents",
        "AdjustToContentsOnFirstShow",
        "AdjustToMinimumContentsLengthWithIcon",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SizeAdjustPolicy_InitializerValues[] = {
        uint8_t(QComboBox::SizeAdjustPolicy::AdjustToContents),                     //  0x00  0
        uint8_t(QComboBox::SizeAdjustPolicy::AdjustToContentsOnFirstShow),          //  0x01  1
        uint8_t(QComboBox::SizeAdjustPolicy::AdjustToMinimumContentsLengthWithIcon) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QComboBox_TypeF(),
        "2:PySide6.QtWidgets.QComboBox.SizeAdjustPolicy",
        SizeAdjustPolicy_Initializer, SizeAdjustPolicy_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_SizeAdjustPolicy_IDX].type = EType;
    // Register converter for enum 'QComboBox::SizeAdjustPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QComboBox_SizeAdjustPolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QComboBox_SizeAdjustPolicy,
            is_Enum_PythonToCpp_QComboBox_SizeAdjustPolicy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QComboBox::SizeAdjustPolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "SizeAdjustPolicy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SizeAdjustPolicy' enum.

    // Initialization of enum 'LabelDrawingMode'.
    const char *LabelDrawingMode_Initializer[] = {
        "UseStyle",
        "UseDelegate",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t LabelDrawingMode_InitializerValues[] = {
        int8_t(QComboBox::LabelDrawingMode::UseStyle),   //  0x00  0
        int8_t(QComboBox::LabelDrawingMode::UseDelegate) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QComboBox_TypeF(),
        "2:PySide6.QtWidgets.QComboBox.LabelDrawingMode",
        LabelDrawingMode_Initializer, LabelDrawingMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_LabelDrawingMode_IDX].type = EType;
    // Register converter for enum 'QComboBox::LabelDrawingMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QComboBox_LabelDrawingMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QComboBox_LabelDrawingMode,
            is_Enum_PythonToCpp_QComboBox_LabelDrawingMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QComboBox::LabelDrawingMode");
        Shiboken::Conversions::registerConverterAlias(converter, "LabelDrawingMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'LabelDrawingMode' enum.

    PySide::Signal::registerSignals(pyType, &::QComboBox::staticMetaObject);
    qRegisterMetaType< ::QComboBox::InsertPolicy >("QComboBox::InsertPolicy");
    qRegisterMetaType< ::QComboBox::SizeAdjustPolicy >("QComboBox::SizeAdjustPolicy");
    qRegisterMetaType< ::QComboBox::LabelDrawingMode >("QComboBox::LabelDrawingMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QComboBox::staticMetaObject, sizeof(QComboBoxWrapper));

    return pyType;
}
