// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qdatetimeedit_wrapper.h"

// Wrappers providing overrides
#include "qlayoutitem_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qabstractspinbox_wrapper.h"
#include "qwidget_wrapper.h"
#include "qwizardpage_wrapper.h"
#include "qgraphicsitem_wrapper.h"
#include "qgraphicslayout_wrapper.h"
#include "qspinbox_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qvalidator.h>
#include <QtWidgets/qcalendarwidget.h>
#include <QtWidgets/qdatetimeedit.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcalendar.h>
#include <qcoreevent.h>
#include <qdatetime.h>
#include <qmetaobject.h>
#include <qmetatype.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qtimezone.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDateTimeEditWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDateTimeEditWrapper::QDateTimeEditWrapper(::QDate d, ::QWidget * parent) : QDateTimeEdit(d, parent)
{
}

QDateTimeEditWrapper::QDateTimeEditWrapper(::QTime t, ::QWidget * parent) : QDateTimeEdit(t, parent)
{
}

QDateTimeEditWrapper::QDateTimeEditWrapper(::QWidget * parent) : QDateTimeEdit(parent)
{
}

QDateTimeEditWrapper::QDateTimeEditWrapper(const ::QDateTime & dt, ::QWidget * parent) : QDateTimeEdit(dt, parent)
{
}

QDateTimeEditWrapper::QDateTimeEditWrapper(const ::QVariant & val, ::QMetaType::Type parserType, ::QWidget * parent) : QDateTimeEdit(val, parserType, parent)
{
}

void QDateTimeEditWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QWizardPageWrapper::sbk_o_actionEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::changeEvent(event);
    }
    QWizardPageWrapper::sbk_o_changeEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWidgetWrapper::sbk_o_childEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::clear()
{
    static const char *funcName = "clear";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::clear();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QDateTimeEdit", funcName, gil, pyOverride);
}

void QDateTimeEditWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::closeEvent(event);
    }
    QWizardPageWrapper::sbk_o_closeEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QDateTimeEdit", funcName, gil, pyOverride, signal);
}

void QDateTimeEditWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::contextMenuEvent(event);
    }
    QWizardPageWrapper::sbk_o_contextMenuEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

::QDateTime QDateTimeEditWrapper::dateTimeFromText(const ::QString & text) const
{
    static const char *funcName = "dateTimeFromText";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::dateTimeFromText(text);
    }
    return sbk_o_dateTimeFromText("QDateTimeEdit", funcName, gil, pyOverride, text);
}

::QDateTime QDateTimeEditWrapper::sbk_o_dateTimeFromText(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QString & text)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &text)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &text)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QDateTime >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QDateTime cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QDateTimeEditWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QDateTimeEdit", funcName, gil, pyOverride);
}

void QDateTimeEditWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QDateTimeEdit", funcName, gil, pyOverride, signal);
}

void QDateTimeEditWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragEnterEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragLeaveEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragMoveEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QWizardPageWrapper::sbk_o_dropEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QWizardPageWrapper::sbk_o_enterEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

bool QDateTimeEditWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::event(event);
    }
    return QWidgetWrapper::sbk_o_event("QDateTimeEdit", funcName, gil, pyOverride, event);
}

bool QDateTimeEditWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QDateTimeEdit", funcName, gil, pyOverride, watched, event);
}

void QDateTimeEditWrapper::fixup(::QString & input) const
{
    static const char *funcName = "fixup";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::fixup(input);
    }
    QSpinBoxWrapper::sbk_o_fixup("QDateTimeEdit", funcName, gil, pyOverride, input);
}

void QDateTimeEditWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::focusInEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusInEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

bool QDateTimeEditWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::focusNextPrevChild(next);
    }
    return QWidgetWrapper::sbk_o_focusNextPrevChild("QDateTimeEdit", funcName, gil, pyOverride, next);
}

void QDateTimeEditWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::focusOutEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusOutEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

bool QDateTimeEditWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QDateTimeEdit", funcName, gil, pyOverride);
}

int QDateTimeEditWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QDateTimeEdit", funcName, gil, pyOverride, arg__1);
}

void QDateTimeEditWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::hideEvent(event);
    }
    QWizardPageWrapper::sbk_o_hideEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QWidgetWrapper::sbk_o_initPainter("QDateTimeEdit", funcName, gil, pyOverride, painter);
}

void QDateTimeEditWrapper::initStyleOption(::QStyleOptionSpinBox * option) const
{
    static const char *funcName = "initStyleOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::initStyleOption(option);
    }
    QAbstractSpinBoxWrapper::sbk_o_initStyleOption("QDateTimeEdit", funcName, gil, pyOverride, option);
}

void QDateTimeEditWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QWizardPageWrapper::sbk_o_inputMethodEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

::QVariant QDateTimeEditWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::inputMethodQuery(arg__1);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QDateTimeEdit", funcName, gil, pyOverride, arg__1);
}

void QDateTimeEditWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::keyPressEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyPressEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::keyReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyReleaseEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_leaveEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

int QDateTimeEditWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QWidgetWrapper::sbk_o_metric("QDateTimeEdit", funcName, gil, pyOverride, arg__1);
}

::QSize QDateTimeEditWrapper::minimumSizeHint() const
{
    static const char *funcName = "minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::minimumSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QDateTimeEdit", funcName, gil, pyOverride);
}

void QDateTimeEditWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseDoubleClickEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::mouseMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseMoveEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::mousePressEvent(event);
    }
    QWizardPageWrapper::sbk_o_mousePressEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::mouseReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseReleaseEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QWizardPageWrapper::sbk_o_moveEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

bool QDateTimeEditWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QWizardPageWrapper::sbk_o_nativeEvent("QDateTimeEdit", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QDateTimeEditWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QWidgetWrapper::sbk_o_paintEngine("QDateTimeEdit", funcName, gil, pyOverride);
}

void QDateTimeEditWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::paintEvent(event);
    }
    QWizardPageWrapper::sbk_o_paintEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

::QPaintDevice * QDateTimeEditWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QWidgetWrapper::sbk_o_redirected("QDateTimeEdit", funcName, gil, pyOverride, offset);
}

void QDateTimeEditWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::resizeEvent(event);
    }
    QWizardPageWrapper::sbk_o_resizeEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

void QDateTimeEditWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QWidgetWrapper::sbk_o_setVisible("QDateTimeEdit", funcName, gil, pyOverride, visible);
}

::QPainter * QDateTimeEditWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QWidgetWrapper::sbk_o_sharedPainter("QDateTimeEdit", funcName, gil, pyOverride);
}

void QDateTimeEditWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::showEvent(event);
    }
    QWizardPageWrapper::sbk_o_showEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

::QSize QDateTimeEditWrapper::sizeHint() const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QDateTimeEdit", funcName, gil, pyOverride);
}

void QDateTimeEditWrapper::stepBy(int steps)
{
    static const char *funcName = "stepBy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::stepBy(steps);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QDateTimeEdit", funcName, gil, pyOverride, steps);
}

::QFlags<QAbstractSpinBox::StepEnabledFlag> QDateTimeEditWrapper::stepEnabled() const
{
    static const char *funcName = "stepEnabled";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::stepEnabled();
    }
    return QAbstractSpinBoxWrapper::sbk_o_stepEnabled("QDateTimeEdit", funcName, gil, pyOverride);
}

void QDateTimeEditWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QWizardPageWrapper::sbk_o_tabletEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

::QString QDateTimeEditWrapper::textFromDateTime(const ::QDateTime & dt) const
{
    static const char *funcName = "textFromDateTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::textFromDateTime(dt);
    }
    return sbk_o_textFromDateTime("QDateTimeEdit", funcName, gil, pyOverride, dt);
}

::QString QDateTimeEditWrapper::sbk_o_textFromDateTime(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QDateTime & dt)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &dt)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &dt)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QString();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QString", Py_TYPE(pyResult)->tp_name);
        return ::QString();
    }
    ::QString cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QDateTimeEditWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[52], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractSpinBox::timerEvent(event);
    }
    QWidgetWrapper::sbk_o_timerEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

::QValidator::State QDateTimeEditWrapper::validate(::QString & input, int & pos) const
{
    static const char *funcName = "validate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[53], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::validate(input, pos);
    }
    return QSpinBoxWrapper::sbk_o_validate("QDateTimeEdit", funcName, gil, pyOverride, input, pos);
}

void QDateTimeEditWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[54], nameCache));
    if (pyOverride.isNull()) {
        return this->::QDateTimeEdit::wheelEvent(event);
    }
    QWizardPageWrapper::sbk_o_wheelEvent("QDateTimeEdit", funcName, gil, pyOverride, event);
}

const QMetaObject *QDateTimeEditWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QDateTimeEdit::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QDateTimeEditWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QDateTimeEdit::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QDateTimeEditWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QDateTimeEditWrapper *>(this));
    return QDateTimeEdit::qt_metacast(_clname);
}

QDateTimeEditWrapper::~QDateTimeEditWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDateTimeEdit_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDateTimeEdit >()))
        return -1;

    QDateTimeEditWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOO:QDateTimeEdit", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDateTimeEdit::QDateTimeEdit(QDate,QWidget*=)
    // 1: QDateTimeEdit::QDateTimeEdit(QTime,QWidget*=)
    // 2: QDateTimeEdit::QDateTimeEdit(QWidget*=)
    // 3: QDateTimeEdit::QDateTimeEdit(QDateTime,QWidget*=)
    // 4: QDateTimeEdit::QDateTimeEdit(QVariant,QMetaType::Type,QWidget*=)
    if (numArgs == 0) {
        overloadId = 2; // QDateTimeEdit(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // QDateTimeEdit(QDateTime,QWidget*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))) {
            overloadId = 3; // QDateTimeEdit(QDateTime,QWidget*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QDateTimeEdit(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QDateTimeEdit(QTime,QWidget*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QDateTimeEdit(QTime,QWidget*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QDateTimeEdit(QDate,QWidget*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QDateTimeEdit(QDate,QWidget*)
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_Type_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 4; // QDateTimeEdit(QVariant,QMetaType::Type,QWidget*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
            overloadId = 4; // QDateTimeEdit(QVariant,QMetaType::Type,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDateTimeEdit(QDate d, QWidget *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDate cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QWidget *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDateTimeEdit(QDate,QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QDateTimeEditWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QDateTimeEditWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 1: // QDateTimeEdit(QTime t, QWidget *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTime cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QWidget *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDateTimeEdit(QTime,QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QDateTimeEditWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QDateTimeEditWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 2: // QDateTimeEdit(QWidget *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWidget *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDateTimeEdit(QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QDateTimeEditWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QDateTimeEditWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 3: // QDateTimeEdit(const QDateTime &dt, QWidget *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDateTime cppArg0_local;
            ::QDateTime *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QWidget *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDateTimeEdit(QDateTime,QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QDateTimeEditWrapper(*cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QDateTimeEditWrapper(*cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 4: // QDateTimeEdit(const QVariant &val, QMetaType::Type parserType, QWidget *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 2}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);
                }
            }
            ::QVariant cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QMetaType::Type cppArg1{QMetaType::UnknownType};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QWidget *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDateTimeEdit(QVariant,QMetaType::Type,QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QDateTimeEditWrapper(cppArg0, cppArg1, cppArg2);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QDateTimeEditWrapper(cppArg0, cppArg1, cppArg2);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[2], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QDateTimeEdit >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QDateTimeEditFunc_calendar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // calendar()const
        QCalendar cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->calendar();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_calendarPopup(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // calendarPopup()const
        bool cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->calendarPopup();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_calendarWidget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // calendarWidget()const
        QCalendarWidget * cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->calendarWidget();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QDateTimeEdit::clear()
            : cppSelf->clear();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_clearMaximumDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearMaximumDate()
        cppSelf->clearMaximumDate();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_clearMaximumDateTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearMaximumDateTime()
        cppSelf->clearMaximumDateTime();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_clearMaximumTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearMaximumTime()
        cppSelf->clearMaximumTime();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_clearMinimumDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearMinimumDate()
        cppSelf->clearMinimumDate();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_clearMinimumDateTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearMinimumDateTime()
        cppSelf->clearMinimumDateTime();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_clearMinimumTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearMinimumTime()
        cppSelf->clearMinimumTime();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_currentSection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentSection()const
        QDateTimeEdit::Section cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->currentSection();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_Section_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_currentSectionIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentSectionIndex()const
        int cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->currentSectionIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_date(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // date()const
        QDate cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->date();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_dateTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dateTime()const
        QDateTime cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->dateTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_dateTimeFromText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::dateTimeFromText(QString)const->QDateTime
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // dateTimeFromText(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dateTimeFromText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dateTimeFromText(QString)const
            QDateTime cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QDateTimeEdit *>(cppSelf)->::QDateTimeEdit::dateTimeFromText(cppArg0)
                : const_cast<const ::QDateTimeEdit *>(cppSelf)->dateTimeFromText(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_displayFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // displayFormat()const
        QString cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->displayFormat();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_displayedSections(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // displayedSections()const
        QFlags<QDateTimeEdit::Section> cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->displayedSections();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QDateTimeEdit_Section_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDateTimeEdit::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_fixup(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::fixup(QString&)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // fixup(QString&)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fixup", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fixup(QString&)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QDateTimeEdit *>(cppSelf)->::QDateTimeEdit::fixup(cppArg0)
                : const_cast<const ::QDateTimeEdit *>(cppSelf)->fixup(cppArg0);
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qstring-return)]
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppArg0);
            // END of custom code block [file: ../glue/qtcore.cpp (qstring-return)]
            // ========================================================================
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_focusInEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::focusInEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusInEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusInEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDateTimeEdit::focusInEvent(cppArg0)
                : cppSelf->focusInEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_focusNextPrevChild(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::focusNextPrevChild(bool)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusNextPrevChild", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusNextPrevChild(bool)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDateTimeEdit::focusNextPrevChild(cppArg0)
                : cppSelf->focusNextPrevChild(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_initStyleOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::initStyleOption(QStyleOptionSpinBox*)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_IDX]), (pyArg)))) {
        overloadId = 0; // initStyleOption(QStyleOptionSpinBox*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "initStyleOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QStyleOptionSpinBox *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // initStyleOption(QStyleOptionSpinBox*)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QDateTimeEdit *>(cppSelf)->::QDateTimeEdit::initStyleOption(cppArg0)
                : const_cast<const ::QDateTimeEdit *>(cppSelf)->initStyleOption(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_keyPressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::keyPressEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyPressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyPressEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDateTimeEdit::keyPressEvent(cppArg0)
                : cppSelf->keyPressEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_maximumDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumDate()const
        QDate cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->maximumDate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_maximumDateTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumDateTime()const
        QDateTime cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->maximumDateTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_maximumTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumTime()const
        QTime cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->maximumTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_minimumDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumDate()const
        QDate cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->minimumDate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_minimumDateTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumDateTime()const
        QDateTime cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->minimumDateTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_minimumTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumTime()const
        QTime cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->minimumTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_mousePressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mousePressEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mousePressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mousePressEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDateTimeEdit::mousePressEvent(cppArg0)
                : cppSelf->mousePressEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_paintEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::paintEvent(QPaintEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), (pyArg)))) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "paintEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPaintEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paintEvent(QPaintEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDateTimeEdit::paintEvent(cppArg0)
                : cppSelf->paintEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_sectionAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::sectionAt(int)const->QDateTimeEdit::Section
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // sectionAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "sectionAt", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sectionAt(int)const
            QDateTimeEdit::Section cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->sectionAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_Section_IDX])))->converter, &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_sectionCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sectionCount()const
        int cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->sectionCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_sectionText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::sectionText(QDateTimeEdit::Section)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_Section_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // sectionText(QDateTimeEdit::Section)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "sectionText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        ::QDateTimeEdit::Section cppArg0{QDateTimeEdit::NoSection};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sectionText(QDateTimeEdit::Section)const
            QString cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->sectionText(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_setCalendar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setCalendar(QCalendar)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArg)))) {
        overloadId = 0; // setCalendar(QCalendar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCalendar", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCalendar cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCalendar(QCalendar)
            cppSelf->setCalendar(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setCalendarPopup(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setCalendarPopup(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setCalendarPopup(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCalendarPopup", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCalendarPopup(bool)
            cppSelf->setCalendarPopup(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setCalendarWidget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setCalendarWidget(QCalendarWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), (pyArg)))) {
        overloadId = 0; // setCalendarWidget(QCalendarWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCalendarWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCalendarWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCalendarWidget(QCalendarWidget*)
            cppSelf->setCalendarWidget(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setCurrentSection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setCurrentSection(QDateTimeEdit::Section)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_Section_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setCurrentSection(QDateTimeEdit::Section)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCurrentSection", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        ::QDateTimeEdit::Section cppArg0{QDateTimeEdit::NoSection};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrentSection(QDateTimeEdit::Section)
            cppSelf->setCurrentSection(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setCurrentSectionIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setCurrentSectionIndex(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCurrentSectionIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCurrentSectionIndex", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrentSectionIndex(int)
            cppSelf->setCurrentSectionIndex(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setDate(QDate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // setDate(QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDate(QDate)
            cppSelf->setDate(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setDateRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDateRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDateTimeEdit::setDateRange(QDate,QDate)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setDateRange(QDate,QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDateRange", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDate cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDate cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDateRange(QDate,QDate)
            cppSelf->setDateRange(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setDateTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setDateTime(QDateTime)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // setDateTime(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDateTime", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDateTime(QDateTime)
            cppSelf->setDateTime(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setDateTimeRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDateTimeRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDateTimeEdit::setDateTimeRange(QDateTime,QDateTime)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setDateTimeRange(QDateTime,QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDateTimeRange", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDateTime cppArg1_local;
        ::QDateTime *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDateTimeRange(QDateTime,QDateTime)
            cppSelf->setDateTimeRange(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setDisplayFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setDisplayFormat(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDisplayFormat(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDisplayFormat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDisplayFormat(QString)
            cppSelf->setDisplayFormat(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setMaximumDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setMaximumDate(QDate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // setMaximumDate(QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaximumDate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumDate(QDate)
            cppSelf->setMaximumDate(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setMaximumDateTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setMaximumDateTime(QDateTime)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // setMaximumDateTime(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaximumDateTime", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumDateTime(QDateTime)
            cppSelf->setMaximumDateTime(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setMaximumTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setMaximumTime(QTime)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
        overloadId = 0; // setMaximumTime(QTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaximumTime", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTime cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumTime(QTime)
            cppSelf->setMaximumTime(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setMinimumDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setMinimumDate(QDate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // setMinimumDate(QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinimumDate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinimumDate(QDate)
            cppSelf->setMinimumDate(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setMinimumDateTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setMinimumDateTime(QDateTime)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // setMinimumDateTime(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinimumDateTime", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinimumDateTime(QDateTime)
            cppSelf->setMinimumDateTime(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setMinimumTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setMinimumTime(QTime)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
        overloadId = 0; // setMinimumTime(QTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinimumTime", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTime cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinimumTime(QTime)
            cppSelf->setMinimumTime(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setSelectedSection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setSelectedSection(QDateTimeEdit::Section)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_Section_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSelectedSection(QDateTimeEdit::Section)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelectedSection", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        ::QDateTimeEdit::Section cppArg0{QDateTimeEdit::NoSection};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectedSection(QDateTimeEdit::Section)
            cppSelf->setSelectedSection(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setTime(QTime)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
        overloadId = 0; // setTime(QTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTime", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTime cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTime(QTime)
            cppSelf->setTime(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setTimeRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setTimeRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDateTimeEdit::setTimeRange(QTime,QTime)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setTimeRange(QTime,QTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setTimeRange", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTime cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTime cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTimeRange(QTime,QTime)
            cppSelf->setTimeRange(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setTimeSpec(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setTimeSpec(Qt::TimeSpec)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimeSpec_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTimeSpec(Qt::TimeSpec)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTimeSpec", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QDateTimeEdit", "setTimeSpec(Qt.TimeSpec spec)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        ::Qt::TimeSpec cppArg0{Qt::LocalTime};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTimeSpec(Qt::TimeSpec)
            cppSelf->setTimeSpec(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_setTimeZone(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::setTimeZone(QTimeZone)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArg)))) {
        overloadId = 0; // setTimeZone(QTimeZone)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTimeZone", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTimeZone cppArg0_local;
        ::QTimeZone *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTimeZone(QTimeZone)
            cppSelf->setTimeZone(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_sizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sizeHint()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QDateTimeEdit *>(cppSelf)->::QDateTimeEdit::sizeHint()
            : const_cast<const ::QDateTimeEdit *>(cppSelf)->sizeHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_stepBy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSpinBox::stepBy(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // stepBy(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "stepBy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // stepBy(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDateTimeEdit::stepBy(cppArg0)
                : cppSelf->stepBy(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QDateTimeEditFunc_stepEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stepEnabled()const
        QFlags<QAbstractSpinBox::StepEnabledFlag> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QDateTimeEdit *>(cppSelf)->::QDateTimeEdit::stepEnabled()
            : const_cast<const ::QDateTimeEdit *>(cppSelf)->stepEnabled();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QAbstractSpinBox_StepEnabledFlag_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_textFromDateTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDateTimeEdit::textFromDateTime(QDateTime)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // textFromDateTime(QDateTime)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "textFromDateTime", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // textFromDateTime(QDateTime)const
            QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QDateTimeEdit *>(cppSelf)->::QDateTimeEdit::textFromDateTime(*cppArg0)
                : const_cast<const ::QDateTimeEdit *>(cppSelf)->textFromDateTime(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_time(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // time()const
        QTime cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->time();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_timeSpec(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QDateTimeEdit", "timeSpec() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // timeSpec()const
        Qt::TimeSpec cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->timeSpec();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_TimeSpec_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_timeZone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // timeZone()const
        QTimeZone cppResult = const_cast<const ::QDateTimeEdit *>(cppSelf)->timeZone();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_validate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "validate", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractSpinBox::validate(QString&,int&)const->PyObject
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // validate(QString&,int&)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "validate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // validate(QString&,int&)const
            // Begin code injection
            // TEMPLATE - return_tuple_QValidator_QString_int - START
            ::QValidator::State retval_ = ::QValidator::State((Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QDateTimeEdit::validate(cppArg0, cppArg1) : cppSelf->validate(cppArg0, cppArg1)));
            pyResult = PyTuple_New(3);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QValidator_State_IDX])))->converter, &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppArg0));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppArg1));
            // TEMPLATE - return_tuple_QValidator_QString_int - END
            // End of code injection

        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QDateTimeEditFunc_wheelEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::wheelEvent(QWheelEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), (pyArg)))) {
        overloadId = 0; // wheelEvent(QWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "wheelEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWheelEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wheelEvent(QWheelEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDateTimeEdit::wheelEvent(cppArg0)
                : cppSelf->wheelEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QDateTimeEdit_PropertyStrings[] = {
    "calendarPopup::",
    "currentSection::",
    "currentSectionIndex::",
    "date::",
    "dateTime::",
    "displayFormat::",
    "displayedSections:",
    "maximumDate::",
    "maximumDateTime::",
    "maximumTime::",
    "minimumDate::",
    "minimumDateTime::",
    "minimumTime::",
    "sectionCount:",
    "time::",
    "timeSpec::",
    "timeZone::",
    nullptr // Sentinel
};

static const char *Sbk_QDateTimeEdit_EnumFlagInfo[] = {
    "Section:Flag:Sections",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDateTimeEdit_methods[] = {
    {"calendar", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_calendar), METH_NOARGS, nullptr},
    {"calendarPopup", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_calendarPopup), METH_NOARGS, nullptr},
    {"calendarWidget", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_calendarWidget), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_clear), METH_NOARGS, nullptr},
    {"clearMaximumDate", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_clearMaximumDate), METH_NOARGS, nullptr},
    {"clearMaximumDateTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_clearMaximumDateTime), METH_NOARGS, nullptr},
    {"clearMaximumTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_clearMaximumTime), METH_NOARGS, nullptr},
    {"clearMinimumDate", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_clearMinimumDate), METH_NOARGS, nullptr},
    {"clearMinimumDateTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_clearMinimumDateTime), METH_NOARGS, nullptr},
    {"clearMinimumTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_clearMinimumTime), METH_NOARGS, nullptr},
    {"currentSection", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_currentSection), METH_NOARGS, nullptr},
    {"currentSectionIndex", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_currentSectionIndex), METH_NOARGS, nullptr},
    {"date", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_date), METH_NOARGS, nullptr},
    {"dateTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_dateTime), METH_NOARGS, nullptr},
    {"dateTimeFromText", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_dateTimeFromText), METH_O, nullptr},
    {"displayFormat", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_displayFormat), METH_NOARGS, nullptr},
    {"displayedSections", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_displayedSections), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_event), METH_O, nullptr},
    {"fixup", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_fixup), METH_O, nullptr},
    {"focusInEvent", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_focusInEvent), METH_O, nullptr},
    {"focusNextPrevChild", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_focusNextPrevChild), METH_O, nullptr},
    {"initStyleOption", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_initStyleOption), METH_O, nullptr},
    {"keyPressEvent", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_keyPressEvent), METH_O, nullptr},
    {"maximumDate", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_maximumDate), METH_NOARGS, nullptr},
    {"maximumDateTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_maximumDateTime), METH_NOARGS, nullptr},
    {"maximumTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_maximumTime), METH_NOARGS, nullptr},
    {"minimumDate", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_minimumDate), METH_NOARGS, nullptr},
    {"minimumDateTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_minimumDateTime), METH_NOARGS, nullptr},
    {"minimumTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_minimumTime), METH_NOARGS, nullptr},
    {"mousePressEvent", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_mousePressEvent), METH_O, nullptr},
    {"paintEvent", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_paintEvent), METH_O, nullptr},
    {"sectionAt", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_sectionAt), METH_O, nullptr},
    {"sectionCount", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_sectionCount), METH_NOARGS, nullptr},
    {"sectionText", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_sectionText), METH_O, nullptr},
    {"setCalendar", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setCalendar), METH_O, nullptr},
    {"setCalendarPopup", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setCalendarPopup), METH_O, nullptr},
    {"setCalendarWidget", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setCalendarWidget), METH_O, nullptr},
    {"setCurrentSection", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setCurrentSection), METH_O, nullptr},
    {"setCurrentSectionIndex", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setCurrentSectionIndex), METH_O, nullptr},
    {"setDate", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setDate), METH_O, nullptr},
    {"setDateRange", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setDateRange), METH_VARARGS, nullptr},
    {"setDateTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setDateTime), METH_O, nullptr},
    {"setDateTimeRange", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setDateTimeRange), METH_VARARGS, nullptr},
    {"setDisplayFormat", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setDisplayFormat), METH_O, nullptr},
    {"setMaximumDate", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setMaximumDate), METH_O, nullptr},
    {"setMaximumDateTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setMaximumDateTime), METH_O, nullptr},
    {"setMaximumTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setMaximumTime), METH_O, nullptr},
    {"setMinimumDate", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setMinimumDate), METH_O, nullptr},
    {"setMinimumDateTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setMinimumDateTime), METH_O, nullptr},
    {"setMinimumTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setMinimumTime), METH_O, nullptr},
    {"setSelectedSection", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setSelectedSection), METH_O, nullptr},
    {"setTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setTime), METH_O, nullptr},
    {"setTimeRange", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setTimeRange), METH_VARARGS, nullptr},
    {"setTimeSpec", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setTimeSpec), METH_O, nullptr},
    {"setTimeZone", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_setTimeZone), METH_O, nullptr},
    {"sizeHint", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_sizeHint), METH_NOARGS, nullptr},
    {"stepBy", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_stepBy), METH_O, nullptr},
    {"stepEnabled", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_stepEnabled), METH_NOARGS, nullptr},
    {"textFromDateTime", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_textFromDateTime), METH_O, nullptr},
    {"time", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_time), METH_NOARGS, nullptr},
    {"timeSpec", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_timeSpec), METH_NOARGS, nullptr},
    {"timeZone", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_timeZone), METH_NOARGS, nullptr},
    {"validate", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_validate), METH_VARARGS, nullptr},
    {"wheelEvent", reinterpret_cast<PyCFunction>(Sbk_QDateTimeEditFunc_wheelEvent), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDateTimeEdit_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDateTimeEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDateTimeEditWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDateTimeEdit_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDateTimeEdit_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QDateTimeEditSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QDateTimeEdit *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]))
        return static_cast< ::QAbstractSpinBox *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDateTimeEdit_Type = nullptr;
static PyTypeObject *Sbk_QDateTimeEdit_TypeF(void)
{
    return _Sbk_QDateTimeEdit_Type;
}

static PyType_Slot Sbk_QDateTimeEdit_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDateTimeEdit_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDateTimeEdit_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDateTimeEdit_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDateTimeEdit_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDateTimeEdit_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDateTimeEdit_spec = {
    "2:PySide6.QtWidgets.QDateTimeEdit",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDateTimeEdit_slots
};

} //extern "C"

static void *Sbk_QDateTimeEdit_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QDateTimeEdit *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QDateTimeEdit *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QDateTimeEdit *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDateTimeEdit_Section(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDateTimeEdit::Section>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDateTimeEdit::Section *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDateTimeEdit_Section_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_Section_IDX])))
        return Enum_PythonToCpp_QDateTimeEdit_Section;
    return {};
}

static PyObject *QDateTimeEdit_Section_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDateTimeEdit::Section>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDateTimeEdit::Section *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_Section_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QDateTimeEdit_Section(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QDateTimeEdit::Section>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QDateTimeEdit::Section> *>(cppOut) = value;

}

static PyObject *QDateTimeEdit_Section_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QDateTimeEdit::Section> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_Section_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDateTimeEdit_PythonToCpp_QDateTimeEdit_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDateTimeEdit_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDateTimeEdit_PythonToCpp_QDateTimeEdit_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDateTimeEdit_TypeF()))
        return QDateTimeEdit_PythonToCpp_QDateTimeEdit_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDateTimeEdit_PTR_CppToPython_QDateTimeEdit(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QDateTimeEdit *>(const_cast<void *>(cppIn)), Sbk_QDateTimeEdit_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDateTimeEdit_SignatureStrings[] = {
    "4:PySide6.QtWidgets.QDateTimeEdit(self,d:PySide6.QtCore.QDate,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,dateTime:QDateTime=None,date:QDate=None,time:QTime=None,maximumDateTime:QDateTime=None,minimumDateTime:QDateTime=None,maximumDate:QDate=None,minimumDate:QDate=None,maximumTime:QTime=None,minimumTime:QTime=None,currentSection:QDateTimeEdit.Section=None,displayedSections:PySide6.QtWidgets.QDateTimeEdit.Section=None,displayFormat:QString=None,calendarPopup:bool=None,currentSectionIndex:int=None,sectionCount:int=None,timeSpec:Qt.TimeSpec=None,timeZone:QTimeZone=None)",
    "3:PySide6.QtWidgets.QDateTimeEdit(self,t:PySide6.QtCore.QTime,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,dateTime:QDateTime=None,date:QDate=None,time:QTime=None,maximumDateTime:QDateTime=None,minimumDateTime:QDateTime=None,maximumDate:QDate=None,minimumDate:QDate=None,maximumTime:QTime=None,minimumTime:QTime=None,currentSection:QDateTimeEdit.Section=None,displayedSections:PySide6.QtWidgets.QDateTimeEdit.Section=None,displayFormat:QString=None,calendarPopup:bool=None,currentSectionIndex:int=None,sectionCount:int=None,timeSpec:Qt.TimeSpec=None,timeZone:QTimeZone=None)",
    "2:PySide6.QtWidgets.QDateTimeEdit(self,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,dateTime:QDateTime=None,date:QDate=None,time:QTime=None,maximumDateTime:QDateTime=None,minimumDateTime:QDateTime=None,maximumDate:QDate=None,minimumDate:QDate=None,maximumTime:QTime=None,minimumTime:QTime=None,currentSection:QDateTimeEdit.Section=None,displayedSections:PySide6.QtWidgets.QDateTimeEdit.Section=None,displayFormat:QString=None,calendarPopup:bool=None,currentSectionIndex:int=None,sectionCount:int=None,timeSpec:Qt.TimeSpec=None,timeZone:QTimeZone=None)",
    "1:PySide6.QtWidgets.QDateTimeEdit(self,dt:PySide6.QtCore.QDateTime,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,dateTime:QDateTime=None,date:QDate=None,time:QTime=None,maximumDateTime:QDateTime=None,minimumDateTime:QDateTime=None,maximumDate:QDate=None,minimumDate:QDate=None,maximumTime:QTime=None,minimumTime:QTime=None,currentSection:QDateTimeEdit.Section=None,displayedSections:PySide6.QtWidgets.QDateTimeEdit.Section=None,displayFormat:QString=None,calendarPopup:bool=None,currentSectionIndex:int=None,sectionCount:int=None,timeSpec:Qt.TimeSpec=None,timeZone:QTimeZone=None)",
    "0:PySide6.QtWidgets.QDateTimeEdit(self,val:QVariant,parserType:PySide6.QtCore.QMetaType.Type,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,dateTime:QDateTime=None,date:QDate=None,time:QTime=None,maximumDateTime:QDateTime=None,minimumDateTime:QDateTime=None,maximumDate:QDate=None,minimumDate:QDate=None,maximumTime:QTime=None,minimumTime:QTime=None,currentSection:QDateTimeEdit.Section=None,displayedSections:PySide6.QtWidgets.QDateTimeEdit.Section=None,displayFormat:QString=None,calendarPopup:bool=None,currentSectionIndex:int=None,sectionCount:int=None,timeSpec:Qt.TimeSpec=None,timeZone:QTimeZone=None)",
    "PySide6.QtWidgets.QDateTimeEdit.calendar(self)->PySide6.QtCore.QCalendar",
    "PySide6.QtWidgets.QDateTimeEdit.calendarPopup(self)->bool",
    "PySide6.QtWidgets.QDateTimeEdit.calendarWidget(self)->PySide6.QtWidgets.QCalendarWidget",
    "PySide6.QtWidgets.QDateTimeEdit.clear(self)",
    "PySide6.QtWidgets.QDateTimeEdit.clearMaximumDate(self)",
    "PySide6.QtWidgets.QDateTimeEdit.clearMaximumDateTime(self)",
    "PySide6.QtWidgets.QDateTimeEdit.clearMaximumTime(self)",
    "PySide6.QtWidgets.QDateTimeEdit.clearMinimumDate(self)",
    "PySide6.QtWidgets.QDateTimeEdit.clearMinimumDateTime(self)",
    "PySide6.QtWidgets.QDateTimeEdit.clearMinimumTime(self)",
    "PySide6.QtWidgets.QDateTimeEdit.currentSection(self)->PySide6.QtWidgets.QDateTimeEdit.Section",
    "PySide6.QtWidgets.QDateTimeEdit.currentSectionIndex(self)->int",
    "PySide6.QtWidgets.QDateTimeEdit.date(self)->PySide6.QtCore.QDate",
    "PySide6.QtWidgets.QDateTimeEdit.dateTime(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtWidgets.QDateTimeEdit.dateTimeFromText(self,text:QString)->PySide6.QtCore.QDateTime",
    "PySide6.QtWidgets.QDateTimeEdit.displayFormat(self)->QString",
    "PySide6.QtWidgets.QDateTimeEdit.displayedSections(self)->PySide6.QtWidgets.QDateTimeEdit.Section",
    "PySide6.QtWidgets.QDateTimeEdit.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QDateTimeEdit.fixup(self,input:QString)->QString",
    "PySide6.QtWidgets.QDateTimeEdit.focusInEvent(self,event:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtWidgets.QDateTimeEdit.focusNextPrevChild(self,next:bool)->bool",
    "PySide6.QtWidgets.QDateTimeEdit.initStyleOption(self,option:PySide6.QtWidgets.QStyleOptionSpinBox)",
    "PySide6.QtWidgets.QDateTimeEdit.keyPressEvent(self,event:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtWidgets.QDateTimeEdit.maximumDate(self)->PySide6.QtCore.QDate",
    "PySide6.QtWidgets.QDateTimeEdit.maximumDateTime(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtWidgets.QDateTimeEdit.maximumTime(self)->PySide6.QtCore.QTime",
    "PySide6.QtWidgets.QDateTimeEdit.minimumDate(self)->PySide6.QtCore.QDate",
    "PySide6.QtWidgets.QDateTimeEdit.minimumDateTime(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtWidgets.QDateTimeEdit.minimumTime(self)->PySide6.QtCore.QTime",
    "PySide6.QtWidgets.QDateTimeEdit.mousePressEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QDateTimeEdit.paintEvent(self,event:PySide6.QtGui.QPaintEvent)",
    "PySide6.QtWidgets.QDateTimeEdit.sectionAt(self,index:int)->PySide6.QtWidgets.QDateTimeEdit.Section",
    "PySide6.QtWidgets.QDateTimeEdit.sectionCount(self)->int",
    "PySide6.QtWidgets.QDateTimeEdit.sectionText(self,section:PySide6.QtWidgets.QDateTimeEdit.Section)->QString",
    "PySide6.QtWidgets.QDateTimeEdit.setCalendar(self,calendar:PySide6.QtCore.QCalendar)",
    "PySide6.QtWidgets.QDateTimeEdit.setCalendarPopup(self,enable:bool)",
    "PySide6.QtWidgets.QDateTimeEdit.setCalendarWidget(self,calendarWidget:PySide6.QtWidgets.QCalendarWidget)",
    "PySide6.QtWidgets.QDateTimeEdit.setCurrentSection(self,section:PySide6.QtWidgets.QDateTimeEdit.Section)",
    "PySide6.QtWidgets.QDateTimeEdit.setCurrentSectionIndex(self,index:int)",
    "PySide6.QtWidgets.QDateTimeEdit.setDate(self,date:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QDateTimeEdit.setDateRange(self,min:PySide6.QtCore.QDate,max:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QDateTimeEdit.setDateTime(self,dateTime:PySide6.QtCore.QDateTime)",
    "PySide6.QtWidgets.QDateTimeEdit.setDateTimeRange(self,min:PySide6.QtCore.QDateTime,max:PySide6.QtCore.QDateTime)",
    "PySide6.QtWidgets.QDateTimeEdit.setDisplayFormat(self,format:QString)",
    "PySide6.QtWidgets.QDateTimeEdit.setMaximumDate(self,max:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QDateTimeEdit.setMaximumDateTime(self,dt:PySide6.QtCore.QDateTime)",
    "PySide6.QtWidgets.QDateTimeEdit.setMaximumTime(self,max:PySide6.QtCore.QTime)",
    "PySide6.QtWidgets.QDateTimeEdit.setMinimumDate(self,min:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QDateTimeEdit.setMinimumDateTime(self,dt:PySide6.QtCore.QDateTime)",
    "PySide6.QtWidgets.QDateTimeEdit.setMinimumTime(self,min:PySide6.QtCore.QTime)",
    "PySide6.QtWidgets.QDateTimeEdit.setSelectedSection(self,section:PySide6.QtWidgets.QDateTimeEdit.Section)",
    "PySide6.QtWidgets.QDateTimeEdit.setTime(self,time:PySide6.QtCore.QTime)",
    "PySide6.QtWidgets.QDateTimeEdit.setTimeRange(self,min:PySide6.QtCore.QTime,max:PySide6.QtCore.QTime)",
    "PySide6.QtWidgets.QDateTimeEdit.setTimeSpec(self,spec:PySide6.QtCore.Qt.TimeSpec)",
    "PySide6.QtWidgets.QDateTimeEdit.setTimeZone(self,zone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])",
    "PySide6.QtWidgets.QDateTimeEdit.sizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QDateTimeEdit.stepBy(self,steps:int)",
    "PySide6.QtWidgets.QDateTimeEdit.stepEnabled(self)->PySide6.QtWidgets.QAbstractSpinBox.StepEnabledFlag",
    "PySide6.QtWidgets.QDateTimeEdit.textFromDateTime(self,dt:PySide6.QtCore.QDateTime)->QString",
    "PySide6.QtWidgets.QDateTimeEdit.time(self)->PySide6.QtCore.QTime",
    "PySide6.QtWidgets.QDateTimeEdit.timeSpec(self)->PySide6.QtCore.Qt.TimeSpec",
    "PySide6.QtWidgets.QDateTimeEdit.timeZone(self)->PySide6.QtCore.QTimeZone",
    "PySide6.QtWidgets.QDateTimeEdit.validate(self,input:QString,pos:int)->PyObject",
    "PySide6.QtWidgets.QDateTimeEdit.wheelEvent(self,event:PySide6.QtGui.QWheelEvent)",
    nullptr}; // Sentinel
#else
static constexpr size_t QDateTimeEdit_SignatureByteSize = 982;
static constexpr uint8_t QDateTimeEdit_SignatureBytes[982] = {
    0x78, 0xda, 0xed, 0x58, 0x4b, 0x6f, 0xdb, 0x30, 0x0c, 0xbe, 0xf7, 0x57, 0xec, 0xb8, 0x0c, 0x9e,
    0xb1, 0x17, 0x76, 0x30, 0xd0, 0x01, 0x6d, 0x9a, 0x6c, 0xc5, 0xd0, 0x36, 0x99, 0xb3, 0x15, 0xd8,
    0xb0, 0x83, 0x12, 0x2b, 0xa9, 0x36, 0x59, 0x36, 0x6c, 0x39, 0x8d, 0xfb, 0xeb, 0x27, 0xd9, 0x8a,
    0xe5, 0x87, 0x1c, 0xd3, 0x49, 0x77, 0xf3, 0x25, 0x70, 0x44, 0xf2, 0x13, 0x29, 0x7d, 0xa4, 0x28,
    0x7d, 0x70, 0x66, 0xa9, 0x4b, 0x3c, 0xfc, 0xd1, 0x9e, 0xf3, 0x7b, 0xe2, 0x6d, 0x30, 0x8f, 0xed,
    0xf9, 0x15, 0xe2, 0x78, 0x41, 0x7c, 0x3c, 0xf1, 0x08, 0x7f, 0x19, 0x63, 0xba, 0xb6, 0xbc, 0x92,
    0xda, 0x38, 0x88, 0x70, 0xae, 0x63, 0x85, 0x28, 0xc2, 0x8c, 0x9b, 0x20, 0xf2, 0x8f, 0x73, 0x96,
    0x50, 0x1a, 0xf2, 0xc8, 0x7a, 0xe5, 0x7c, 0xc5, 0xe9, 0x63, 0x10, 0x79, 0x77, 0x8c, 0xa6, 0xe7,
    0xb7, 0x01, 0xc3, 0x96, 0xa7, 0x26, 0x71, 0x8a, 0xe9, 0xf4, 0x78, 0x3e, 0x96, 0xff, 0xe7, 0x99,
    0x8e, 0x96, 0xfb, 0x68, 0x47, 0xfc, 0xc4, 0xbf, 0x6a, 0x31, 0xf7, 0x09, 0x3b, 0x28, 0xd6, 0xd6,
    0xe5, 0x49, 0x4a, 0x56, 0x95, 0xe1, 0x5c, 0x7b, 0x51, 0x77, 0x21, 0xd7, 0xae, 0x0f, 0xaf, 0x92,
    0x48, 0x2e, 0x87, 0x8b, 0x57, 0x9c, 0x04, 0xcc, 0xa9, 0x2c, 0xa3, 0xad, 0x46, 0x55, 0x8c, 0x24,
    0x0e, 0x29, 0x4a, 0xb1, 0xa7, 0x46, 0xe3, 0xae, 0x5d, 0x30, 0x9a, 0x4f, 0x83, 0xc8, 0x47, 0xdc,
    0x99, 0xbb, 0x3c, 0x22, 0x6c, 0xa3, 0x7c, 0x40, 0x14, 0x33, 0x0f, 0x45, 0xb3, 0x20, 0x4c, 0x42,
    0x67, 0x19, 0x04, 0xd4, 0xe4, 0xdb, 0x35, 0xf3, 0xf0, 0xce, 0x21, 0x8c, 0xe7, 0xc2, 0x38, 0x1f,
    0x1d, 0x07, 0x89, 0xd8, 0xcc, 0x62, 0x54, 0x2e, 0xbc, 0x1b, 0xe2, 0x95, 0x33, 0xe7, 0xf6, 0x42,
    0x7d, 0x6b, 0xc9, 0x4f, 0xf1, 0x91, 0x07, 0x2f, 0xbf, 0xb2, 0xf1, 0xd1, 0xd9, 0x7b, 0x18, 0x9b,
    0x78, 0x83, 0x4d, 0x52, 0x3e, 0xb0, 0x69, 0x60, 0x53, 0x85, 0x4d, 0xef, 0x60, 0x6c, 0x1a, 0x68,
    0x33, 0xd0, 0xa6, 0x4c, 0x9b, 0xb7, 0xc0, 0x23, 0x8d, 0x1b, 0xcf, 0xb4, 0xa1, 0x12, 0x0d, 0x94,
    0x6a, 0x50, 0xea, 0x0d, 0x8c, 0x52, 0x5b, 0x44, 0x9d, 0xf9, 0x0f, 0x14, 0x11, 0xc4, 0xb8, 0xe4,
    0x50, 0x8c, 0xa3, 0x45, 0x1a, 0xe2, 0x06, 0xcf, 0x6e, 0x30, 0x47, 0x52, 0x60, 0xcb, 0x9f, 0x81,
    0x6c, 0x03, 0xd9, 0x2a, 0x64, 0xeb, 0x8a, 0x62, 0xef, 0x5d, 0xc6, 0xb9, 0xd1, 0xeb, 0x4f, 0x75,
    0x76, 0x8d, 0x95, 0x1c, 0x0c, 0x94, 0x85, 0xb9, 0x47, 0x93, 0xd1, 0x82, 0x2d, 0x73, 0x69, 0xd3,
    0x91, 0xc2, 0x6a, 0x5c, 0x51, 0xec, 0xc6, 0xa5, 0x78, 0x1f, 0x17, 0x4c, 0xf7, 0x46, 0x33, 0xf1,
    0x48, 0x33, 0x29, 0x38, 0xc2, 0xb4, 0xb7, 0x99, 0xce, 0x8d, 0x23, 0xcd, 0x8e, 0x9c, 0xb1, 0x8f,
    0x59, 0x85, 0xde, 0x07, 0x76, 0xd5, 0x94, 0x54, 0x3d, 0xd1, 0xb3, 0xe4, 0xd9, 0x4f, 0x21, 0xb2,
    0xa5, 0xd3, 0xdc, 0x2b, 0x56, 0xae, 0xc9, 0x78, 0xa9, 0x08, 0x02, 0xd0, 0x8b, 0x61, 0x06, 0x91,
    0x72, 0x30, 0xd0, 0x34, 0x0a, 0xfc, 0x05, 0xde, 0xed, 0xef, 0x34, 0xe2, 0x6b, 0x5f, 0x45, 0x4e,
    0x42, 0x2f, 0x97, 0xa5, 0xbd, 0xaf, 0x0a, 0x17, 0x6a, 0xac, 0x4b, 0xe2, 0x73, 0x6f, 0x22, 0xde,
    0x8a, 0x2d, 0xcc, 0x03, 0xce, 0x3e, 0x1b, 0x47, 0xdb, 0x44, 0x8e, 0x42, 0xcb, 0xc8, 0x9a, 0xec,
    0x54, 0xe1, 0xb1, 0x08, 0x0b, 0x93, 0xf2, 0xfa, 0x41, 0x23, 0x5e, 0x07, 0xab, 0x24, 0xbe, 0x66,
    0x93, 0x76, 0xbf, 0x3e, 0x27, 0xc4, 0x9e, 0x4f, 0xa5, 0x5a, 0xee, 0x1b, 0x0c, 0xf2, 0x56, 0x6c,
    0xe7, 0x2c, 0xc2, 0xdb, 0xf1, 0x03, 0xa1, 0x5e, 0x0e, 0xcc, 0xe4, 0x0e, 0xcb, 0xb8, 0xa0, 0xe1,
    0x89, 0x04, 0xe4, 0x2e, 0x4f, 0x29, 0xbe, 0x0b, 0x8b, 0x84, 0xb2, 0x82, 0xec, 0xdb, 0x74, 0x54,
    0x95, 0x54, 0xdd, 0x90, 0xb0, 0xcb, 0x60, 0xd7, 0xed, 0xeb, 0x5f, 0x9c, 0x0a, 0x2f, 0xe3, 0xb8,
    0x2b, 0x7e, 0xd1, 0x38, 0x00, 0xa3, 0xf7, 0xeb, 0x15, 0xf5, 0xc8, 0x74, 0xf3, 0x4d, 0x25, 0xf6,
    0x84, 0xbc, 0xf0, 0xeb, 0x75, 0xb7, 0x89, 0x05, 0xc3, 0xa9, 0x17, 0xe2, 0x63, 0xe3, 0x33, 0x55,
    0xe6, 0x53, 0xe2, 0xab, 0x97, 0xeb, 0x63, 0xe3, 0x0b, 0x92, 0x18, 0x83, 0x38, 0x71, 0x23, 0x35,
    0x81, 0xac, 0x08, 0x91, 0xa8, 0xd1, 0x5d, 0x80, 0xb3, 0x42, 0xa9, 0x1b, 0x50, 0x75, 0x4b, 0x17,
    0x7c, 0x9f, 0xfe, 0xaa, 0x97, 0x7a, 0xc6, 0x5a, 0x55, 0x6e, 0xc8, 0xfa, 0x9c, 0x34, 0xca, 0x4e,
    0x97, 0x76, 0x35, 0x00, 0x6d, 0x2f, 0x7b, 0x54, 0xaf, 0x18, 0xf3, 0x71, 0xb9, 0x9b, 0x2b, 0x3a,
    0x4f, 0xa7, 0xad, 0xa9, 0x1b, 0xf5, 0xc1, 0xd4, 0x8d, 0x9d, 0x85, 0x19, 0x5a, 0x52, 0x9c, 0x97,
    0xaf, 0x3e, 0x10, 0xa5, 0x0e, 0xcf, 0xaa, 0x76, 0x7d, 0x4e, 0x67, 0xbb, 0x07, 0x9b, 0xa8, 0xd9,
    0x74, 0xf4, 0x5e, 0xf0, 0xfe, 0xf3, 0xe8, 0xf6, 0xa3, 0x44, 0x3d, 0x08, 0x4c, 0x51, 0x37, 0xf2,
    0x2b, 0x96, 0x29, 0xdd, 0xc1, 0x38, 0xdf, 0x10, 0xdb, 0x28, 0x30, 0x91, 0xfd, 0xe6, 0x17, 0x76,
    0x51, 0xf6, 0x4e, 0x9b, 0xa4, 0x28, 0x28, 0xfa, 0xae, 0xd8, 0x56, 0xa3, 0x7a, 0x61, 0x02, 0x9c,
    0xcf, 0x9e, 0x52, 0xda, 0x02, 0x80, 0x4f, 0xd8, 0x68, 0x88, 0xac, 0x75, 0xe5, 0xce, 0x06, 0x42,
    0xa9, 0x5f, 0x14, 0x4e, 0x5b, 0x58, 0xd3, 0xfd, 0xe1, 0xd0, 0x83, 0x52, 0x1f, 0x50, 0x0d, 0x68,
    0x72, 0x11, 0x8e, 0x56, 0x3b, 0xe7, 0x5a, 0x77, 0xa9, 0x2f, 0xda, 0x33, 0x06, 0x5c, 0x3b, 0xf2,
    0x8c, 0x2e, 0x82, 0xd1, 0x5c, 0x4c, 0x45, 0x6e, 0x17, 0xad, 0xef, 0xff, 0xab, 0x24, 0xda, 0x5f,
    0x6e, 0xca, 0x26, 0xb0, 0xc3, 0x80, 0x2c, 0x6a, 0xcd, 0xa0, 0x5e, 0x93, 0xc8, 0x37, 0x07, 0xb5,
    0x1c, 0xf2, 0x25, 0xa2, 0x8e, 0xa5, 0x1f, 0x26, 0xc0, 0x88, 0xf2, 0xb5, 0x22, 0x47, 0x7c, 0x92,
    0x2f, 0x18, 0x3c, 0x15, 0xfd, 0xea, 0xc6, 0xfe, 0xce, 0xc4, 0x12, 0xfe, 0x32, 0xb9, 0x2a, 0xf5,
    0xad, 0x17, 0x6d, 0x12, 0xfb, 0x5a, 0x34, 0xca, 0x04, 0x51, 0xf2, 0x84, 0xe4, 0x26, 0xfc, 0x06,
    0xb8, 0x41, 0x9e, 0xf0, 0x17, 0xc2, 0x78, 0x5b, 0xa7, 0xe4, 0x0a, 0x79, 0x37, 0x08, 0xc7, 0xe1,
    0x65, 0xaa, 0x16, 0x46, 0x7c, 0xc7, 0xc0, 0x43, 0x40, 0xa8, 0x4e, 0xb2, 0xd3, 0xd4, 0x3b, 0x70,
    0xbb, 0xba, 0x58, 0xc6, 0x3c, 0x42, 0x2b, 0xae, 0x3a, 0x79, 0xdb, 0xd5, 0x56, 0x53, 0x8a, 0xba,
    0x3b, 0x03, 0x79, 0x9d, 0x94, 0x17, 0x4c, 0x78, 0xc6, 0xc1, 0xbb, 0x0e, 0x7e, 0x6a, 0x8f, 0xc9,
    0xcb, 0xa4, 0x32, 0x80, 0x68, 0x46, 0x81, 0xa0, 0x0a, 0x36, 0xb5, 0xf8, 0x23, 0xe5, 0x9d, 0x40,
    0x5b, 0xc1, 0x9f, 0xe2, 0x8d, 0xa0, 0x7a, 0x9d, 0xb4, 0xc2, 0x20, 0x2e, 0x7a, 0xcb, 0xbb, 0xe5,
    0x1f, 0x91, 0xeb, 0x9d, 0x70, 0x8f, 0x0f, 0x18, 0xd3, 0xae, 0x86, 0xf7, 0xbe, 0x50, 0x1a, 0x9d,
    0xfd, 0x03, 0xa9, 0x7b, 0x68, 0x87
};
#endif

PyTypeObject *init_QDateTimeEdit(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX].type;

    Shiboken::AutoDecRef Sbk_QDateTimeEdit_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]))));

    _Sbk_QDateTimeEdit_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDateTimeEdit",
        "QDateTimeEdit*",
        &Sbk_QDateTimeEdit_spec,
        &Shiboken::callCppDestructor< QDateTimeEdit >,
        Sbk_QDateTimeEdit_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QDateTimeEdit_TypeF(); // references _Sbk_QDateTimeEdit_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDateTimeEdit_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDateTimeEdit_SignatureBytes, QDateTimeEdit_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDateTimeEdit_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDateTimeEdit_PythonToCpp_QDateTimeEdit_PTR,
        is_QDateTimeEdit_PythonToCpp_QDateTimeEdit_PTR_Convertible,
        QDateTimeEdit_PTR_CppToPython_QDateTimeEdit);

    Shiboken::Conversions::registerConverterName(converter, "QDateTimeEdit");
    Shiboken::Conversions::registerConverterName(converter, "QDateTimeEdit*");
    Shiboken::Conversions::registerConverterName(converter, "QDateTimeEdit&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDateTimeEdit).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDateTimeEditWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QDateTimeEdit_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QDateTimeEdit_TypeF(), &Sbk_QDateTimeEditSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDateTimeEdit_TypeF(), &Sbk_QDateTimeEdit_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDateTimeEdit_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Section'.
    const char *Section_Initializer[] = {
        "NoSection",
        "AmPmSection",
        "MSecSection",
        "SecondSection",
        "MinuteSection",
        "HourSection",
        "DaySection",
        "MonthSection",
        "YearSection",
        "TimeSections_Mask",
        "DateSections_Mask",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Section_InitializerValues[] = {
        uint16_t(QDateTimeEdit::Section::NoSection),         //  0x0000  0
        uint16_t(QDateTimeEdit::Section::AmPmSection),       //  0x0001  1
        uint16_t(QDateTimeEdit::Section::MSecSection),       //  0x0002  2
        uint16_t(QDateTimeEdit::Section::SecondSection),     //  0x0004  4
        uint16_t(QDateTimeEdit::Section::MinuteSection),     //  0x0008  8
        uint16_t(QDateTimeEdit::Section::HourSection),       //  0x0010  16
        uint16_t(QDateTimeEdit::Section::DaySection),        //  0x0100  256
        uint16_t(QDateTimeEdit::Section::MonthSection),      //  0x0200  512
        uint16_t(QDateTimeEdit::Section::YearSection),       //  0x0400  1024
        uint16_t(QDateTimeEdit::Section::TimeSections_Mask), //  0x001f  31
        uint16_t(QDateTimeEdit::Section::DateSections_Mask)  //  0x0700  1792
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDateTimeEdit_TypeF(),
        "2:PySide6.QtWidgets.QDateTimeEdit.Section",
        Section_Initializer, Section_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_Section_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QDateTimeEdit_Section_IDX].type =
        EType;
    // Register converter for enum 'QDateTimeEdit::Section'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDateTimeEdit_Section_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDateTimeEdit_Section,
            is_Enum_PythonToCpp_QDateTimeEdit_Section_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDateTimeEdit::Section");
        Shiboken::Conversions::registerConverterAlias(converter, "Section");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QDateTimeEdit_Section_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QDateTimeEdit_Section,
            is_Enum_PythonToCpp_QDateTimeEdit_Section_Convertible);
        // Register converter for flag 'QFlags<QDateTimeEdit::Section>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QDateTimeEdit::Section>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QDateTimeEdit::Sections");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Section' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QDateTimeEdit::staticMetaObject);
    qRegisterMetaType< ::QDateTimeEdit::Section >("QDateTimeEdit::Section");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QDateTimeEdit::staticMetaObject, sizeof(QDateTimeEditWrapper));

    return pyType;
}
