// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qlistview_wrapper.h"

// Wrappers providing overrides
#include "qabstractitemview_wrapper.h"
#include "qlayoutitem_wrapper.h"
#include "qtextedit_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qlineedit_wrapper.h"
#include "qabstractscrollarea_wrapper.h"
#include "qwidget_wrapper.h"
#include "qwizardpage_wrapper.h"
#include "qgraphicsitem_wrapper.h"
#include "qtreeview_wrapper.h"
#include "qgraphicslayout_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qregion.h>
#include <QtWidgets/qabstractitemdelegate.h>
#include <QtWidgets/qabstractitemview.h>
#include <QtWidgets/qlistview.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qitemselectionmodel.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QListViewWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QListViewWrapper::QListViewWrapper(::QWidget * parent) : QListView(parent)
{
}

void QListViewWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QWizardPageWrapper::sbk_o_actionEvent("QListView", funcName, gil, pyOverride, event);
}

void QListViewWrapper::changeEvent(::QEvent * arg__1)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFrame::changeEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_changeEvent("QListView", funcName, gil, pyOverride, arg__1);
}

void QListViewWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWidgetWrapper::sbk_o_childEvent("QListView", funcName, gil, pyOverride, event);
}

void QListViewWrapper::closeEditor(::QWidget * editor, ::QAbstractItemDelegate::EndEditHint hint)
{
    static const char *funcName = "closeEditor";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::closeEditor(editor, hint);
    }
    QAbstractItemViewWrapper::sbk_o_closeEditor("QListView", funcName, gil, pyOverride, editor, hint);
}

void QListViewWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QWizardPageWrapper::sbk_o_closeEvent("QListView", funcName, gil, pyOverride, event);
}

void QListViewWrapper::commitData(::QWidget * editor)
{
    static const char *funcName = "commitData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::commitData(editor);
    }
    QAbstractItemViewWrapper::sbk_o_commitData("QListView", funcName, gil, pyOverride, editor);
}

void QListViewWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QListView", funcName, gil, pyOverride, signal);
}

void QListViewWrapper::contextMenuEvent(::QContextMenuEvent * arg__1)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::contextMenuEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_contextMenuEvent("QListView", funcName, gil, pyOverride, arg__1);
}

void QListViewWrapper::currentChanged(const ::QModelIndex & current, const ::QModelIndex & previous)
{
    static const char *funcName = "currentChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::currentChanged(current, previous);
    }
    QAbstractItemViewWrapper::sbk_o_currentChanged("QListView", funcName, gil, pyOverride, current, previous);
}

void QListViewWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QListView", funcName, gil, pyOverride, event);
}

void QListViewWrapper::dataChanged(const ::QModelIndex & topLeft, const ::QModelIndex & bottomRight, const ::QList<int> & roles)
{
    static const char *funcName = "dataChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::dataChanged(topLeft, bottomRight, roles);
    }
    QAbstractItemViewWrapper::sbk_o_dataChanged("QListView", funcName, gil, pyOverride, topLeft, bottomRight, roles);
}

int QListViewWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QListView", funcName, gil, pyOverride);
}

void QListViewWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QListView", funcName, gil, pyOverride, signal);
}

void QListViewWrapper::doItemsLayout()
{
    static const char *funcName = "doItemsLayout";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::doItemsLayout();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QListView", funcName, gil, pyOverride);
}

void QListViewWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::dragEnterEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragEnterEvent("QListView", funcName, gil, pyOverride, event);
}

void QListViewWrapper::dragLeaveEvent(::QDragLeaveEvent * e)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::dragLeaveEvent(e);
    }
    QWizardPageWrapper::sbk_o_dragLeaveEvent("QListView", funcName, gil, pyOverride, e);
}

void QListViewWrapper::dragMoveEvent(::QDragMoveEvent * e)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::dragMoveEvent(e);
    }
    QWizardPageWrapper::sbk_o_dragMoveEvent("QListView", funcName, gil, pyOverride, e);
}

void QListViewWrapper::dropEvent(::QDropEvent * e)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::dropEvent(e);
    }
    QWizardPageWrapper::sbk_o_dropEvent("QListView", funcName, gil, pyOverride, e);
}

bool QListViewWrapper::edit(const ::QModelIndex & index, ::QAbstractItemView::EditTrigger trigger, ::QEvent * event)
{
    static const char *funcName = "edit";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::edit(index, trigger, event);
    }
    return QTreeViewWrapper::sbk_o_edit("QListView", funcName, gil, pyOverride, index, trigger, event);
}

void QListViewWrapper::editorDestroyed(::QObject * editor)
{
    static const char *funcName = "editorDestroyed";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::editorDestroyed(editor);
    }
    QAbstractItemViewWrapper::sbk_o_editorDestroyed("QListView", funcName, gil, pyOverride, editor);
}

void QListViewWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QWizardPageWrapper::sbk_o_enterEvent("QListView", funcName, gil, pyOverride, event);
}

bool QListViewWrapper::event(::QEvent * e)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::event(e);
    }
    return QWidgetWrapper::sbk_o_event("QListView", funcName, gil, pyOverride, e);
}

bool QListViewWrapper::eventFilter(::QObject * object, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::eventFilter(object, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QListView", funcName, gil, pyOverride, object, event);
}

void QListViewWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::focusInEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusInEvent("QListView", funcName, gil, pyOverride, event);
}

bool QListViewWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::focusNextPrevChild(next);
    }
    return QWidgetWrapper::sbk_o_focusNextPrevChild("QListView", funcName, gil, pyOverride, next);
}

void QListViewWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::focusOutEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusOutEvent("QListView", funcName, gil, pyOverride, event);
}

bool QListViewWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QListView", funcName, gil, pyOverride);
}

int QListViewWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QListView", funcName, gil, pyOverride, arg__1);
}

void QListViewWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QWizardPageWrapper::sbk_o_hideEvent("QListView", funcName, gil, pyOverride, event);
}

int QListViewWrapper::horizontalOffset() const
{
    static const char *funcName = "horizontalOffset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::horizontalOffset();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QListView", funcName, gil, pyOverride);
}

void QListViewWrapper::horizontalScrollbarAction(int action)
{
    static const char *funcName = "horizontalScrollbarAction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::horizontalScrollbarAction(action);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QListView", funcName, gil, pyOverride, action);
}

void QListViewWrapper::horizontalScrollbarValueChanged(int value)
{
    static const char *funcName = "horizontalScrollbarValueChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::horizontalScrollbarValueChanged(value);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QListView", funcName, gil, pyOverride, value);
}

::QModelIndex QListViewWrapper::indexAt(const ::QPoint & p) const
{
    static const char *funcName = "indexAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::indexAt(p);
    }
    return QAbstractItemViewWrapper::sbk_o_indexAt("QListView", funcName, gil, pyOverride, p);
}

void QListViewWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QWidgetWrapper::sbk_o_initPainter("QListView", funcName, gil, pyOverride, painter);
}

void QListViewWrapper::initStyleOption(::QStyleOptionFrame * option) const
{
    static const char *funcName = "initStyleOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFrame::initStyleOption(option);
    }
    QLineEditWrapper::sbk_o_initStyleOption("QListView", funcName, gil, pyOverride, option);
}

void QListViewWrapper::initViewItemOption(::QStyleOptionViewItem * option) const
{
    static const char *funcName = "initViewItemOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::initViewItemOption(option);
    }
    QAbstractItemViewWrapper::sbk_o_initViewItemOption("QListView", funcName, gil, pyOverride, option);
}

void QListViewWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::inputMethodEvent(event);
    }
    QWizardPageWrapper::sbk_o_inputMethodEvent("QListView", funcName, gil, pyOverride, event);
}

::QVariant QListViewWrapper::inputMethodQuery(::Qt::InputMethodQuery query) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::inputMethodQuery(query);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QListView", funcName, gil, pyOverride, query);
}

bool QListViewWrapper::isIndexHidden(const ::QModelIndex & index) const
{
    static const char *funcName = "isIndexHidden";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::isIndexHidden(index);
    }
    return QAbstractItemViewWrapper::sbk_o_isIndexHidden("QListView", funcName, gil, pyOverride, index);
}

::QAbstractItemDelegate * QListViewWrapper::itemDelegateForIndex(const ::QModelIndex & index) const
{
    static const char *funcName = "itemDelegateForIndex";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::itemDelegateForIndex(index);
    }
    return QAbstractItemViewWrapper::sbk_o_itemDelegateForIndex("QListView", funcName, gil, pyOverride, index);
}

void QListViewWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::keyPressEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyPressEvent("QListView", funcName, gil, pyOverride, event);
}

void QListViewWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyReleaseEvent("QListView", funcName, gil, pyOverride, event);
}

void QListViewWrapper::keyboardSearch(const ::QString & search)
{
    static const char *funcName = "keyboardSearch";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::keyboardSearch(search);
    }
    QAccessibleWidgetWrapper::sbk_o_doAction("QListView", funcName, gil, pyOverride, search);
}

void QListViewWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_leaveEvent("QListView", funcName, gil, pyOverride, event);
}

int QListViewWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QWidgetWrapper::sbk_o_metric("QListView", funcName, gil, pyOverride, arg__1);
}

::QSize QListViewWrapper::minimumSizeHint() const
{
    static const char *funcName = "minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::minimumSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QListView", funcName, gil, pyOverride);
}

void QListViewWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::mouseDoubleClickEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseDoubleClickEvent("QListView", funcName, gil, pyOverride, event);
}

void QListViewWrapper::mouseMoveEvent(::QMouseEvent * e)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::mouseMoveEvent(e);
    }
    QWizardPageWrapper::sbk_o_mouseMoveEvent("QListView", funcName, gil, pyOverride, e);
}

void QListViewWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::mousePressEvent(event);
    }
    QWizardPageWrapper::sbk_o_mousePressEvent("QListView", funcName, gil, pyOverride, event);
}

void QListViewWrapper::mouseReleaseEvent(::QMouseEvent * e)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::mouseReleaseEvent(e);
    }
    QWizardPageWrapper::sbk_o_mouseReleaseEvent("QListView", funcName, gil, pyOverride, e);
}

::QModelIndex QListViewWrapper::moveCursor(::QAbstractItemView::CursorAction cursorAction, ::QFlags<Qt::KeyboardModifier> modifiers)
{
    static const char *funcName = "moveCursor";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::moveCursor(cursorAction, modifiers);
    }
    return QAbstractItemViewWrapper::sbk_o_moveCursor("QListView", funcName, gil, pyOverride, cursorAction, modifiers);
}

void QListViewWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QWizardPageWrapper::sbk_o_moveEvent("QListView", funcName, gil, pyOverride, event);
}

bool QListViewWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[52], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QWizardPageWrapper::sbk_o_nativeEvent("QListView", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QListViewWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[53], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QWidgetWrapper::sbk_o_paintEngine("QListView", funcName, gil, pyOverride);
}

void QListViewWrapper::paintEvent(::QPaintEvent * e)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[54], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::paintEvent(e);
    }
    QWizardPageWrapper::sbk_o_paintEvent("QListView", funcName, gil, pyOverride, e);
}

::QPaintDevice * QListViewWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[55], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QWidgetWrapper::sbk_o_redirected("QListView", funcName, gil, pyOverride, offset);
}

void QListViewWrapper::reset()
{
    static const char *funcName = "reset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[56], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::reset();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QListView", funcName, gil, pyOverride);
}

void QListViewWrapper::resizeEvent(::QResizeEvent * e)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[57], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::resizeEvent(e);
    }
    QWizardPageWrapper::sbk_o_resizeEvent("QListView", funcName, gil, pyOverride, e);
}

void QListViewWrapper::rowsAboutToBeRemoved(const ::QModelIndex & parent, int start, int end)
{
    static const char *funcName = "rowsAboutToBeRemoved";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[58], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::rowsAboutToBeRemoved(parent, start, end);
    }
    QAbstractItemViewWrapper::sbk_o_rowsAboutToBeRemoved("QListView", funcName, gil, pyOverride, parent, start, end);
}

void QListViewWrapper::rowsInserted(const ::QModelIndex & parent, int start, int end)
{
    static const char *funcName = "rowsInserted";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[59], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::rowsInserted(parent, start, end);
    }
    QAbstractItemViewWrapper::sbk_o_rowsAboutToBeRemoved("QListView", funcName, gil, pyOverride, parent, start, end);
}

void QListViewWrapper::scrollContentsBy(int dx, int dy)
{
    static const char *funcName = "scrollContentsBy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[60], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::scrollContentsBy(dx, dy);
    }
    QAbstractScrollAreaWrapper::sbk_o_scrollContentsBy("QListView", funcName, gil, pyOverride, dx, dy);
}

void QListViewWrapper::scrollTo(const ::QModelIndex & index, ::QAbstractItemView::ScrollHint hint)
{
    static const char *funcName = "scrollTo";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[61], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::scrollTo(index, hint);
    }
    QAbstractItemViewWrapper::sbk_o_scrollTo("QListView", funcName, gil, pyOverride, index, hint);
}

void QListViewWrapper::selectAll()
{
    static const char *funcName = "selectAll";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[62], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::selectAll();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QListView", funcName, gil, pyOverride);
}

::QList<QModelIndex> QListViewWrapper::selectedIndexes() const
{
    static const char *funcName = "selectedIndexes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[63], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::selectedIndexes();
    }
    return QAbstractItemViewWrapper::sbk_o_selectedIndexes("QListView", funcName, gil, pyOverride);
}

void QListViewWrapper::selectionChanged(const ::QItemSelection & selected, const ::QItemSelection & deselected)
{
    static const char *funcName = "selectionChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[64], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::selectionChanged(selected, deselected);
    }
    QAbstractItemViewWrapper::sbk_o_selectionChanged("QListView", funcName, gil, pyOverride, selected, deselected);
}

::QFlags<QItemSelectionModel::SelectionFlag> QListViewWrapper::selectionCommand(const ::QModelIndex & index, const ::QEvent * event) const
{
    static const char *funcName = "selectionCommand";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[65], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::selectionCommand(index, event);
    }
    return QTreeViewWrapper::sbk_o_selectionCommand("QListView", funcName, gil, pyOverride, index, event);
}

void QListViewWrapper::setModel(::QAbstractItemModel * model)
{
    static const char *funcName = "setModel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[66], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::setModel(model);
    }
    QTreeViewWrapper::sbk_o_setModel("QListView", funcName, gil, pyOverride, model);
}

void QListViewWrapper::setRootIndex(const ::QModelIndex & index)
{
    static const char *funcName = "setRootIndex";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[67], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::setRootIndex(index);
    }
    QAbstractItemViewWrapper::sbk_o_setRootIndex("QListView", funcName, gil, pyOverride, index);
}

void QListViewWrapper::setSelection(const ::QRect & rect, ::QFlags<QItemSelectionModel::SelectionFlag> command)
{
    static const char *funcName = "setSelection";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[68], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::setSelection(rect, command);
    }
    QAbstractItemViewWrapper::sbk_o_setSelection("QListView", funcName, gil, pyOverride, rect, command);
}

void QListViewWrapper::setSelectionModel(::QItemSelectionModel * selectionModel)
{
    static const char *funcName = "setSelectionModel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[69], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::setSelectionModel(selectionModel);
    }
    QTreeViewWrapper::sbk_o_setSelectionModel("QListView", funcName, gil, pyOverride, selectionModel);
}

void QListViewWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[70], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QWidgetWrapper::sbk_o_setVisible("QListView", funcName, gil, pyOverride, visible);
}

void QListViewWrapper::setupViewport(::QWidget * viewport)
{
    static const char *funcName = "setupViewport";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[71], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::setupViewport(viewport);
    }
    QTextEditWrapper::sbk_o_setupViewport("QListView", funcName, gil, pyOverride, viewport);
}

::QPainter * QListViewWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[72], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QWidgetWrapper::sbk_o_sharedPainter("QListView", funcName, gil, pyOverride);
}

void QListViewWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[73], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QWizardPageWrapper::sbk_o_showEvent("QListView", funcName, gil, pyOverride, event);
}

::QSize QListViewWrapper::sizeHint() const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[74], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QListView", funcName, gil, pyOverride);
}

int QListViewWrapper::sizeHintForColumn(int column) const
{
    static const char *funcName = "sizeHintForColumn";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[75], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::sizeHintForColumn(column);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QListView", funcName, gil, pyOverride, column);
}

int QListViewWrapper::sizeHintForRow(int row) const
{
    static const char *funcName = "sizeHintForRow";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[76], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::sizeHintForRow(row);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QListView", funcName, gil, pyOverride, row);
}

void QListViewWrapper::startDrag(::QFlags<Qt::DropAction> supportedActions)
{
    static const char *funcName = "startDrag";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[77], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::startDrag(supportedActions);
    }
    QAbstractItemViewWrapper::sbk_o_startDrag("QListView", funcName, gil, pyOverride, supportedActions);
}

void QListViewWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[78], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QWizardPageWrapper::sbk_o_tabletEvent("QListView", funcName, gil, pyOverride, event);
}

void QListViewWrapper::timerEvent(::QTimerEvent * e)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[79], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::timerEvent(e);
    }
    QWidgetWrapper::sbk_o_timerEvent("QListView", funcName, gil, pyOverride, e);
}

void QListViewWrapper::updateEditorData()
{
    static const char *funcName = "updateEditorData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[80], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::updateEditorData();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QListView", funcName, gil, pyOverride);
}

void QListViewWrapper::updateEditorGeometries()
{
    static const char *funcName = "updateEditorGeometries";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[81], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::updateEditorGeometries();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QListView", funcName, gil, pyOverride);
}

void QListViewWrapper::updateGeometries()
{
    static const char *funcName = "updateGeometries";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[82], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::updateGeometries();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QListView", funcName, gil, pyOverride);
}

int QListViewWrapper::verticalOffset() const
{
    static const char *funcName = "verticalOffset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[83], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::verticalOffset();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QListView", funcName, gil, pyOverride);
}

void QListViewWrapper::verticalScrollbarAction(int action)
{
    static const char *funcName = "verticalScrollbarAction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[84], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::verticalScrollbarAction(action);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QListView", funcName, gil, pyOverride, action);
}

void QListViewWrapper::verticalScrollbarValueChanged(int value)
{
    static const char *funcName = "verticalScrollbarValueChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[85], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::verticalScrollbarValueChanged(value);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QListView", funcName, gil, pyOverride, value);
}

bool QListViewWrapper::viewportEvent(::QEvent * event)
{
    static const char *funcName = "viewportEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[86], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::viewportEvent(event);
    }
    return QTextEditWrapper::sbk_o_viewportEvent("QListView", funcName, gil, pyOverride, event);
}

::QSize QListViewWrapper::viewportSizeHint() const
{
    static const char *funcName = "viewportSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[87], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::viewportSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QListView", funcName, gil, pyOverride);
}

::QRect QListViewWrapper::visualRect(const ::QModelIndex & index) const
{
    static const char *funcName = "visualRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[88], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::visualRect(index);
    }
    return QAbstractItemViewWrapper::sbk_o_visualRect("QListView", funcName, gil, pyOverride, index);
}

::QRegion QListViewWrapper::visualRegionForSelection(const ::QItemSelection & selection) const
{
    static const char *funcName = "visualRegionForSelection";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[89], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::visualRegionForSelection(selection);
    }
    return QAbstractItemViewWrapper::sbk_o_visualRegionForSelection("QListView", funcName, gil, pyOverride, selection);
}

void QListViewWrapper::wheelEvent(::QWheelEvent * e)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[90], nameCache));
    if (pyOverride.isNull()) {
        return this->::QListView::wheelEvent(e);
    }
    QWizardPageWrapper::sbk_o_wheelEvent("QListView", funcName, gil, pyOverride, e);
}

const QMetaObject *QListViewWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QListView::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QListViewWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QListView::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QListViewWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QListViewWrapper *>(this));
    return QListView::qt_metacast(_clname);
}

QListViewWrapper::~QListViewWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QListView_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QListView >()))
        return -1;

    QListViewWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QListView", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QListView::QListView(QWidget*=)
    if (numArgs == 0) {
        overloadId = 0; // QListView(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QListView(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QListView(QWidget*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QListViewWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QListViewWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QListView >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QListViewFunc_batchSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // batchSize()const
        int cppResult = const_cast<const ::QListView *>(cppSelf)->batchSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_clearPropertyFlags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearPropertyFlags()
        cppSelf->clearPropertyFlags();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_contentsSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contentsSize()const
        QSize cppResult = const_cast<const ::QListView *>(cppSelf)->contentsSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_currentChanged(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "currentChanged", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::currentChanged(QModelIndex,QModelIndex)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[1])))) {
        overloadId = 0; // currentChanged(QModelIndex,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "currentChanged", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QModelIndex cppArg1_local;
        ::QModelIndex *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // currentChanged(QModelIndex,QModelIndex)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::currentChanged(*cppArg0, *cppArg1)
                : cppSelf->currentChanged(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_dataChanged(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "dataChanged", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:dataChanged", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::dataChanged(QModelIndex,QModelIndex,const QList<int>&=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // dataChanged(QModelIndex,QModelIndex,QList<int>)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_int_IDX], (pyArgs[2])))) {
            overloadId = 0; // dataChanged(QModelIndex,QModelIndex,QList<int>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dataChanged", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"roles", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_int_IDX], (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "dataChanged", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QModelIndex cppArg1_local;
        ::QModelIndex *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        ::QList<int> cppArg2_local = QList<int>();
        ::QList<int> *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // dataChanged(QModelIndex,QModelIndex,QList<int>)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::dataChanged(*cppArg0, *cppArg1, *cppArg2)
                : cppSelf->dataChanged(*cppArg0, *cppArg1, *cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_doItemsLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // doItemsLayout()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QListView::doItemsLayout()
            : cppSelf->doItemsLayout();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_dragLeaveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::dragLeaveEvent(QDragLeaveEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragLeaveEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dragLeaveEvent(QDragLeaveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragLeaveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDragLeaveEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragLeaveEvent(QDragLeaveEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::dragLeaveEvent(cppArg0)
                : cppSelf->dragLeaveEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_dragMoveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::dragMoveEvent(QDragMoveEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dragMoveEvent(QDragMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragMoveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDragMoveEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragMoveEvent(QDragMoveEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::dragMoveEvent(cppArg0)
                : cppSelf->dragMoveEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_dropEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::dropEvent(QDropEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dropEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDropEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dropEvent(QDropEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::dropEvent(cppArg0)
                : cppSelf->dropEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_flow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flow()const
        QListView::Flow cppResult = const_cast<const ::QListView *>(cppSelf)->flow();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_Flow_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_gridSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // gridSize()const
        QSize cppResult = const_cast<const ::QListView *>(cppSelf)->gridSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_horizontalOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // horizontalOffset()const
        int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QListView *>(cppSelf)->::QListView::horizontalOffset()
            : const_cast<const ::QListView *>(cppSelf)->horizontalOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_indexAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::indexAt(QPoint)const->QModelIndex
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // indexAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "indexAt", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint cppArg0_local;
        ::QPoint *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // indexAt(QPoint)const
            QModelIndex cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QListView *>(cppSelf)->::QListView::indexAt(*cppArg0)
                : const_cast<const ::QListView *>(cppSelf)->indexAt(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_initViewItemOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::initViewItemOption(QStyleOptionViewItem*)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionViewItem_IDX]), (pyArg)))) {
        overloadId = 0; // initViewItemOption(QStyleOptionViewItem*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "initViewItemOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QStyleOptionViewItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // initViewItemOption(QStyleOptionViewItem*)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QListView *>(cppSelf)->::QListView::initViewItemOption(cppArg0)
                : const_cast<const ::QListView *>(cppSelf)->initViewItemOption(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_isIndexHidden(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::isIndexHidden(QModelIndex)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // isIndexHidden(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isIndexHidden", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isIndexHidden(QModelIndex)const
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QListView *>(cppSelf)->::QListView::isIndexHidden(*cppArg0)
                : const_cast<const ::QListView *>(cppSelf)->isIndexHidden(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_isRowHidden(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::isRowHidden(int)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // isRowHidden(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isRowHidden", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isRowHidden(int)const
            bool cppResult = const_cast<const ::QListView *>(cppSelf)->isRowHidden(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_isSelectionRectVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSelectionRectVisible()const
        bool cppResult = const_cast<const ::QListView *>(cppSelf)->isSelectionRectVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_isWrapping(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isWrapping()const
        bool cppResult = const_cast<const ::QListView *>(cppSelf)->isWrapping();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_itemAlignment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // itemAlignment()const
        QFlags<Qt::AlignmentFlag> cppResult = const_cast<const ::QListView *>(cppSelf)->itemAlignment();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_layoutMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // layoutMode()const
        QListView::LayoutMode cppResult = const_cast<const ::QListView *>(cppSelf)->layoutMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_LayoutMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_modelColumn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // modelColumn()const
        int cppResult = const_cast<const ::QListView *>(cppSelf)->modelColumn();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_mouseMoveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mouseMoveEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseMoveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseMoveEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::mouseMoveEvent(cppArg0)
                : cppSelf->mouseMoveEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_mouseReleaseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mouseReleaseEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseReleaseEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseReleaseEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::mouseReleaseEvent(cppArg0)
                : cppSelf->mouseReleaseEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_moveCursor(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "moveCursor", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::moveCursor(QAbstractItemView::CursorAction,QFlags<Qt::KeyboardModifier>)->QModelIndex
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_CursorAction_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[1])))) {
        overloadId = 0; // moveCursor(QAbstractItemView::CursorAction,QFlags<Qt::KeyboardModifier>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "moveCursor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        ::QAbstractItemView::CursorAction cppArg0{QAbstractItemView::MoveUp};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::KeyboardModifier> cppArg1 = QFlags<Qt::KeyboardModifier>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // moveCursor(QAbstractItemView::CursorAction,QFlags<Qt::KeyboardModifier>)
            QModelIndex cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::moveCursor(cppArg0, cppArg1)
                : cppSelf->moveCursor(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_movement(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // movement()const
        QListView::Movement cppResult = const_cast<const ::QListView *>(cppSelf)->movement();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_Movement_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_paintEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::paintEvent(QPaintEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), (pyArg)))) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "paintEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPaintEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paintEvent(QPaintEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::paintEvent(cppArg0)
                : cppSelf->paintEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_rectForIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::rectForIndex(QModelIndex)const->QRect
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // rectForIndex(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rectForIndex", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // rectForIndex(QModelIndex)const
            QRect cppResult = const_cast<const ::QListView *>(cppSelf)->rectForIndex(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_reset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // reset()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QListView::reset()
            : cppSelf->reset();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_resizeContents(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resizeContents", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QListView::resizeContents(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // resizeContents(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "resizeContents", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeContents(int,int)
            cppSelf->resizeContents(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_resizeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::resizeEvent(QResizeEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), (pyArg)))) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resizeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QResizeEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeEvent(QResizeEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::resizeEvent(cppArg0)
                : cppSelf->resizeEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_resizeMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resizeMode()const
        QListView::ResizeMode cppResult = const_cast<const ::QListView *>(cppSelf)->resizeMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_ResizeMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_rowsAboutToBeRemoved(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "rowsAboutToBeRemoved", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::rowsAboutToBeRemoved(QModelIndex,int,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // rowsAboutToBeRemoved(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rowsAboutToBeRemoved", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rowsAboutToBeRemoved(QModelIndex,int,int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::rowsAboutToBeRemoved(*cppArg0, cppArg1, cppArg2)
                : cppSelf->rowsAboutToBeRemoved(*cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_rowsInserted(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "rowsInserted", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::rowsInserted(QModelIndex,int,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // rowsInserted(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rowsInserted", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rowsInserted(QModelIndex,int,int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::rowsInserted(*cppArg0, cppArg1, cppArg2)
                : cppSelf->rowsInserted(*cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_scrollContentsBy(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "scrollContentsBy", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractScrollArea::scrollContentsBy(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // scrollContentsBy(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scrollContentsBy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // scrollContentsBy(int,int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::scrollContentsBy(cppArg0, cppArg1)
                : cppSelf->scrollContentsBy(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_scrollTo(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "scrollTo", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    if (PyArg_ParseTuple(args, "|OO:scrollTo", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::scrollTo(QModelIndex,QAbstractItemView::ScrollHint=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollHint_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scrollTo", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"hint", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollHint_IDX])))->converter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "scrollTo", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QAbstractItemView::ScrollHint cppArg1(QAbstractItemView::ScrollHint::EnsureVisible);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::scrollTo(*cppArg0, cppArg1)
                : cppSelf->scrollTo(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_selectedIndexes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedIndexes()const
        QList<QModelIndex> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QListView *>(cppSelf)->::QListView::selectedIndexes()
            : const_cast<const ::QListView *>(cppSelf)->selectedIndexes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QModelIndex_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_selectionChanged(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "selectionChanged", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::selectionChanged(QItemSelection,QItemSelection)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), (pyArgs[1])))) {
        overloadId = 0; // selectionChanged(QItemSelection,QItemSelection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "selectionChanged", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QItemSelection cppArg0_local;
        ::QItemSelection *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QItemSelection cppArg1_local;
        ::QItemSelection *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // selectionChanged(QItemSelection,QItemSelection)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::selectionChanged(*cppArg0, *cppArg1)
                : cppSelf->selectionChanged(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setBatchSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::setBatchSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setBatchSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBatchSize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBatchSize(int)
            cppSelf->setBatchSize(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setFlow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::setFlow(QListView::Flow)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_Flow_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFlow(QListView::Flow)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlow", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        ::QListView::Flow cppArg0{QListView::LeftToRight};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlow(QListView::Flow)
            cppSelf->setFlow(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setGridSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::setGridSize(QSize)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
        overloadId = 0; // setGridSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGridSize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSize cppArg0_local;
        ::QSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setGridSize(QSize)
            cppSelf->setGridSize(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setItemAlignment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::setItemAlignment(QFlags<Qt::AlignmentFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setItemAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItemAlignment", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        ::QFlags<Qt::AlignmentFlag> cppArg0 = QFlags<Qt::AlignmentFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemAlignment(QFlags<Qt::AlignmentFlag>)
            cppSelf->setItemAlignment(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setLayoutMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::setLayoutMode(QListView::LayoutMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_LayoutMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setLayoutMode(QListView::LayoutMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLayoutMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        ::QListView::LayoutMode cppArg0{QListView::SinglePass};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayoutMode(QListView::LayoutMode)
            cppSelf->setLayoutMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setModelColumn(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::setModelColumn(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setModelColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setModelColumn", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setModelColumn(int)
            cppSelf->setModelColumn(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setMovement(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::setMovement(QListView::Movement)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_Movement_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMovement(QListView::Movement)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMovement", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        ::QListView::Movement cppArg0{QListView::Static};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMovement(QListView::Movement)
            cppSelf->setMovement(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setPositionForIndex(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setPositionForIndex", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QListView::setPositionForIndex(QPoint,QModelIndex)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setPositionForIndex(QPoint,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPositionForIndex", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPoint cppArg0_local;
        ::QPoint *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QModelIndex cppArg1_local;
        ::QModelIndex *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPositionForIndex(QPoint,QModelIndex)
            cppSelf->setPositionForIndex(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setResizeMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::setResizeMode(QListView::ResizeMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_ResizeMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setResizeMode(QListView::ResizeMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setResizeMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        ::QListView::ResizeMode cppArg0{QListView::Fixed};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setResizeMode(QListView::ResizeMode)
            cppSelf->setResizeMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setRootIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setRootIndex(QModelIndex)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // setRootIndex(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRootIndex", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRootIndex(QModelIndex)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::setRootIndex(*cppArg0)
                : cppSelf->setRootIndex(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setRowHidden(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setRowHidden", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QListView::setRowHidden(int,bool)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
        overloadId = 0; // setRowHidden(int,bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRowHidden", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRowHidden(int,bool)
            cppSelf->setRowHidden(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setSelection(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setSelection", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemView::setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QItemSelectionModel_SelectionFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
        overloadId = 0; // setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSelection", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRect cppArg0_local;
        ::QRect *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QFlags<QItemSelectionModel::SelectionFlag> cppArg1 = QFlags<QItemSelectionModel::SelectionFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::setSelection(*cppArg0, cppArg1)
                : cppSelf->setSelection(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setSelectionRectVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::setSelectionRectVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSelectionRectVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelectionRectVisible", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectionRectVisible(bool)
            cppSelf->setSelectionRectVisible(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setSpacing(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::setSpacing(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSpacing(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSpacing", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSpacing(int)
            cppSelf->setSpacing(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setUniformItemSizes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::setUniformItemSizes(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setUniformItemSizes(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUniformItemSizes", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUniformItemSizes(bool)
            cppSelf->setUniformItemSizes(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setViewMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::setViewMode(QListView::ViewMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_ViewMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setViewMode(QListView::ViewMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setViewMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        ::QListView::ViewMode cppArg0{QListView::ListMode};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setViewMode(QListView::ViewMode)
            cppSelf->setViewMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setWordWrap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::setWordWrap(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setWordWrap(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWordWrap", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWordWrap(bool)
            cppSelf->setWordWrap(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_setWrapping(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QListView::setWrapping(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setWrapping(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWrapping", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWrapping(bool)
            cppSelf->setWrapping(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_spacing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // spacing()const
        int cppResult = const_cast<const ::QListView *>(cppSelf)->spacing();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_startDrag(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::startDrag(QFlags<Qt::DropAction>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_DropAction_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // startDrag(QFlags<Qt::DropAction>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "startDrag", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        ::QFlags<Qt::DropAction> cppArg0 = QFlags<Qt::DropAction>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // startDrag(QFlags<Qt::DropAction>)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::startDrag(cppArg0)
                : cppSelf->startDrag(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_timerEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::timerEvent(QTimerEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), (pyArg)))) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "timerEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTimerEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // timerEvent(QTimerEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::timerEvent(cppArg0)
                : cppSelf->timerEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_uniformItemSizes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // uniformItemSizes()const
        bool cppResult = const_cast<const ::QListView *>(cppSelf)->uniformItemSizes();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_updateGeometries(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // updateGeometries()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QListView::updateGeometries()
            : cppSelf->updateGeometries();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_verticalOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // verticalOffset()const
        int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QListView *>(cppSelf)->::QListView::verticalOffset()
            : const_cast<const ::QListView *>(cppSelf)->verticalOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_viewMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewMode()const
        QListView::ViewMode cppResult = const_cast<const ::QListView *>(cppSelf)->viewMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_ViewMode_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_viewportSizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewportSizeHint()const
        QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QListView *>(cppSelf)->::QListView::viewportSizeHint()
            : const_cast<const ::QListView *>(cppSelf)->viewportSizeHint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_visualRect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::visualRect(QModelIndex)const->QRect
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // visualRect(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "visualRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // visualRect(QModelIndex)const
            QRect cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QListView *>(cppSelf)->::QListView::visualRect(*cppArg0)
                : const_cast<const ::QListView *>(cppSelf)->visualRect(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_visualRegionForSelection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::visualRegionForSelection(QItemSelection)const->QRegion
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelection_IDX]), (pyArg)))) {
        overloadId = 0; // visualRegionForSelection(QItemSelection)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "visualRegionForSelection", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QItemSelection cppArg0_local;
        ::QItemSelection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // visualRegionForSelection(QItemSelection)const
            QRegion cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QListView *>(cppSelf)->::QListView::visualRegionForSelection(*cppArg0)
                : const_cast<const ::QListView *>(cppSelf)->visualRegionForSelection(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QListViewFunc_wheelEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::wheelEvent(QWheelEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), (pyArg)))) {
        overloadId = 0; // wheelEvent(QWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "wheelEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWheelEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wheelEvent(QWheelEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QListView::wheelEvent(cppArg0)
                : cppSelf->wheelEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QListViewFunc_wordWrap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wordWrap()const
        bool cppResult = const_cast<const ::QListView *>(cppSelf)->wordWrap();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QListView_PropertyStrings[] = {
    "batchSize::",
    "flow::",
    "gridSize::",
    "isWrapping::setWrapping",
    "itemAlignment::",
    "layoutMode::",
    "modelColumn::",
    "movement::",
    "resizeMode::",
    "selectionRectVisible:isSelectionRectVisible:",
    "spacing::",
    "uniformItemSizes::",
    "viewMode::",
    "wordWrap::",
    nullptr // Sentinel
};

static const char *Sbk_QListView_EnumFlagInfo[] = {
    "Flow:Enum",
    "LayoutMode:Enum",
    "Movement:Enum",
    "ResizeMode:Enum",
    "ViewMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QListView_methods[] = {
    {"batchSize", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_batchSize), METH_NOARGS, nullptr},
    {"clearPropertyFlags", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_clearPropertyFlags), METH_NOARGS, nullptr},
    {"contentsSize", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_contentsSize), METH_NOARGS, nullptr},
    {"currentChanged", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_currentChanged), METH_VARARGS, nullptr},
    {"dataChanged", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_dataChanged), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"doItemsLayout", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_doItemsLayout), METH_NOARGS, nullptr},
    {"dragLeaveEvent", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_dragLeaveEvent), METH_O, nullptr},
    {"dragMoveEvent", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_dragMoveEvent), METH_O, nullptr},
    {"dropEvent", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_dropEvent), METH_O, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_event), METH_O, nullptr},
    {"flow", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_flow), METH_NOARGS, nullptr},
    {"gridSize", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_gridSize), METH_NOARGS, nullptr},
    {"horizontalOffset", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_horizontalOffset), METH_NOARGS, nullptr},
    {"indexAt", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_indexAt), METH_O, nullptr},
    {"initViewItemOption", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_initViewItemOption), METH_O, nullptr},
    {"isIndexHidden", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_isIndexHidden), METH_O, nullptr},
    {"isRowHidden", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_isRowHidden), METH_O, nullptr},
    {"isSelectionRectVisible", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_isSelectionRectVisible), METH_NOARGS, nullptr},
    {"isWrapping", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_isWrapping), METH_NOARGS, nullptr},
    {"itemAlignment", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_itemAlignment), METH_NOARGS, nullptr},
    {"layoutMode", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_layoutMode), METH_NOARGS, nullptr},
    {"modelColumn", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_modelColumn), METH_NOARGS, nullptr},
    {"mouseMoveEvent", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_mouseMoveEvent), METH_O, nullptr},
    {"mouseReleaseEvent", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_mouseReleaseEvent), METH_O, nullptr},
    {"moveCursor", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_moveCursor), METH_VARARGS, nullptr},
    {"movement", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_movement), METH_NOARGS, nullptr},
    {"paintEvent", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_paintEvent), METH_O, nullptr},
    {"rectForIndex", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_rectForIndex), METH_O, nullptr},
    {"reset", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_reset), METH_NOARGS, nullptr},
    {"resizeContents", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_resizeContents), METH_VARARGS, nullptr},
    {"resizeEvent", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_resizeEvent), METH_O, nullptr},
    {"resizeMode", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_resizeMode), METH_NOARGS, nullptr},
    {"rowsAboutToBeRemoved", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_rowsAboutToBeRemoved), METH_VARARGS, nullptr},
    {"rowsInserted", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_rowsInserted), METH_VARARGS, nullptr},
    {"scrollContentsBy", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_scrollContentsBy), METH_VARARGS, nullptr},
    {"scrollTo", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_scrollTo), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"selectedIndexes", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_selectedIndexes), METH_NOARGS, nullptr},
    {"selectionChanged", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_selectionChanged), METH_VARARGS, nullptr},
    {"setBatchSize", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setBatchSize), METH_O, nullptr},
    {"setFlow", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setFlow), METH_O, nullptr},
    {"setGridSize", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setGridSize), METH_O, nullptr},
    {"setItemAlignment", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setItemAlignment), METH_O, nullptr},
    {"setLayoutMode", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setLayoutMode), METH_O, nullptr},
    {"setModelColumn", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setModelColumn), METH_O, nullptr},
    {"setMovement", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setMovement), METH_O, nullptr},
    {"setPositionForIndex", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setPositionForIndex), METH_VARARGS, nullptr},
    {"setResizeMode", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setResizeMode), METH_O, nullptr},
    {"setRootIndex", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setRootIndex), METH_O, nullptr},
    {"setRowHidden", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setRowHidden), METH_VARARGS, nullptr},
    {"setSelection", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setSelection), METH_VARARGS, nullptr},
    {"setSelectionRectVisible", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setSelectionRectVisible), METH_O, nullptr},
    {"setSpacing", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setSpacing), METH_O, nullptr},
    {"setUniformItemSizes", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setUniformItemSizes), METH_O, nullptr},
    {"setViewMode", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setViewMode), METH_O, nullptr},
    {"setWordWrap", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setWordWrap), METH_O, nullptr},
    {"setWrapping", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_setWrapping), METH_O, nullptr},
    {"spacing", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_spacing), METH_NOARGS, nullptr},
    {"startDrag", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_startDrag), METH_O, nullptr},
    {"timerEvent", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_timerEvent), METH_O, nullptr},
    {"uniformItemSizes", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_uniformItemSizes), METH_NOARGS, nullptr},
    {"updateGeometries", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_updateGeometries), METH_NOARGS, nullptr},
    {"verticalOffset", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_verticalOffset), METH_NOARGS, nullptr},
    {"viewMode", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_viewMode), METH_NOARGS, nullptr},
    {"viewportSizeHint", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_viewportSizeHint), METH_NOARGS, nullptr},
    {"visualRect", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_visualRect), METH_O, nullptr},
    {"visualRegionForSelection", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_visualRegionForSelection), METH_O, nullptr},
    {"wheelEvent", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_wheelEvent), METH_O, nullptr},
    {"wordWrap", reinterpret_cast<PyCFunction>(Sbk_QListViewFunc_wordWrap), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QListView_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QListView *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QListViewWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QListView_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QListView_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QListViewSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QListView *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]))
        return static_cast< ::QAbstractItemView *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX]))
        return static_cast< ::QAbstractScrollArea *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX]))
        return static_cast< ::QFrame *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QListView_Type = nullptr;
static PyTypeObject *Sbk_QListView_TypeF(void)
{
    return _Sbk_QListView_Type;
}

static PyType_Slot Sbk_QListView_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QListView_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QListView_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QListView_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QListView_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QListView_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QListView_spec = {
    "2:PySide6.QtWidgets.QListView",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QListView_slots
};

} //extern "C"

static void *Sbk_QListView_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QListView *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QListView *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QListView *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QListView_Movement(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QListView::Movement>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QListView::Movement *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QListView_Movement_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_Movement_IDX])))
        return Enum_PythonToCpp_QListView_Movement;
    return {};
}

static PyObject *QListView_Movement_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QListView::Movement>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QListView::Movement *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_Movement_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QListView_Flow(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QListView::Flow>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QListView::Flow *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QListView_Flow_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_Flow_IDX])))
        return Enum_PythonToCpp_QListView_Flow;
    return {};
}

static PyObject *QListView_Flow_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QListView::Flow>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QListView::Flow *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_Flow_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QListView_ResizeMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QListView::ResizeMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QListView::ResizeMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QListView_ResizeMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_ResizeMode_IDX])))
        return Enum_PythonToCpp_QListView_ResizeMode;
    return {};
}

static PyObject *QListView_ResizeMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QListView::ResizeMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QListView::ResizeMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_ResizeMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QListView_LayoutMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QListView::LayoutMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QListView::LayoutMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QListView_LayoutMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_LayoutMode_IDX])))
        return Enum_PythonToCpp_QListView_LayoutMode;
    return {};
}

static PyObject *QListView_LayoutMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QListView::LayoutMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QListView::LayoutMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_LayoutMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QListView_ViewMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QListView::ViewMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QListView::ViewMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QListView_ViewMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_ViewMode_IDX])))
        return Enum_PythonToCpp_QListView_ViewMode;
    return {};
}

static PyObject *QListView_ViewMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QListView::ViewMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QListView::ViewMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_ViewMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QListView_PythonToCpp_QListView_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QListView_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QListView_PythonToCpp_QListView_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QListView_TypeF()))
        return QListView_PythonToCpp_QListView_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QListView_PTR_CppToPython_QListView(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QListView *>(const_cast<void *>(cppIn)), Sbk_QListView_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QListView_SignatureStrings[] = {
    "PySide6.QtWidgets.QListView(self,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,movement:QListView.Movement=None,flow:QListView.Flow=None,isWrapping:bool=None,resizeMode:QListView.ResizeMode=None,layoutMode:QListView.LayoutMode=None,spacing:int=None,gridSize:QSize=None,viewMode:QListView.ViewMode=None,modelColumn:int=None,uniformItemSizes:bool=None,batchSize:int=None,wordWrap:bool=None,selectionRectVisible:bool=None,itemAlignment:PySide6.QtCore.Qt.AlignmentFlag=None)",
    "PySide6.QtWidgets.QListView.batchSize(self)->int",
    "PySide6.QtWidgets.QListView.clearPropertyFlags(self)",
    "PySide6.QtWidgets.QListView.contentsSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QListView.currentChanged(self,current:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],previous:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "PySide6.QtWidgets.QListView.dataChanged(self,topLeft:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],bottomRight:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],roles:QList[int]=QList<int>())",
    "PySide6.QtWidgets.QListView.doItemsLayout(self)",
    "PySide6.QtWidgets.QListView.dragLeaveEvent(self,e:PySide6.QtGui.QDragLeaveEvent)",
    "PySide6.QtWidgets.QListView.dragMoveEvent(self,e:PySide6.QtGui.QDragMoveEvent)",
    "PySide6.QtWidgets.QListView.dropEvent(self,e:PySide6.QtGui.QDropEvent)",
    "PySide6.QtWidgets.QListView.event(self,e:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QListView.flow(self)->PySide6.QtWidgets.QListView.Flow",
    "PySide6.QtWidgets.QListView.gridSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QListView.horizontalOffset(self)->int",
    "PySide6.QtWidgets.QListView.indexAt(self,p:PySide6.QtCore.QPoint)->PySide6.QtCore.QModelIndex",
    "PySide6.QtWidgets.QListView.initViewItemOption(self,option:PySide6.QtWidgets.QStyleOptionViewItem)",
    "PySide6.QtWidgets.QListView.isIndexHidden(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "PySide6.QtWidgets.QListView.isRowHidden(self,row:int)->bool",
    "PySide6.QtWidgets.QListView.isSelectionRectVisible(self)->bool",
    "PySide6.QtWidgets.QListView.isWrapping(self)->bool",
    "PySide6.QtWidgets.QListView.itemAlignment(self)->PySide6.QtCore.Qt.AlignmentFlag",
    "PySide6.QtWidgets.QListView.layoutMode(self)->PySide6.QtWidgets.QListView.LayoutMode",
    "PySide6.QtWidgets.QListView.modelColumn(self)->int",
    "PySide6.QtWidgets.QListView.mouseMoveEvent(self,e:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QListView.mouseReleaseEvent(self,e:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QListView.moveCursor(self,cursorAction:PySide6.QtWidgets.QAbstractItemView.CursorAction,modifiers:PySide6.QtCore.Qt.KeyboardModifier)->PySide6.QtCore.QModelIndex",
    "PySide6.QtWidgets.QListView.movement(self)->PySide6.QtWidgets.QListView.Movement",
    "PySide6.QtWidgets.QListView.paintEvent(self,e:PySide6.QtGui.QPaintEvent)",
    "PySide6.QtWidgets.QListView.rectForIndex(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.QRect",
    "PySide6.QtWidgets.QListView.reset(self)",
    "PySide6.QtWidgets.QListView.resizeContents(self,width:int,height:int)",
    "PySide6.QtWidgets.QListView.resizeEvent(self,e:PySide6.QtGui.QResizeEvent)",
    "PySide6.QtWidgets.QListView.resizeMode(self)->PySide6.QtWidgets.QListView.ResizeMode",
    "PySide6.QtWidgets.QListView.rowsAboutToBeRemoved(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],start:int,end:int)",
    "PySide6.QtWidgets.QListView.rowsInserted(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],start:int,end:int)",
    "PySide6.QtWidgets.QListView.scrollContentsBy(self,dx:int,dy:int)",
    "PySide6.QtWidgets.QListView.scrollTo(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],hint:PySide6.QtWidgets.QAbstractItemView.ScrollHint=QAbstractItemView.ScrollHint.EnsureVisible)",
    "PySide6.QtWidgets.QListView.selectedIndexes(self)->QList[PySide6.QtCore.QModelIndex]",
    "PySide6.QtWidgets.QListView.selectionChanged(self,selected:PySide6.QtCore.QItemSelection,deselected:PySide6.QtCore.QItemSelection)",
    "PySide6.QtWidgets.QListView.setBatchSize(self,batchSize:int)",
    "PySide6.QtWidgets.QListView.setFlow(self,flow:PySide6.QtWidgets.QListView.Flow)",
    "PySide6.QtWidgets.QListView.setGridSize(self,size:PySide6.QtCore.QSize)",
    "PySide6.QtWidgets.QListView.setItemAlignment(self,alignment:PySide6.QtCore.Qt.AlignmentFlag)",
    "PySide6.QtWidgets.QListView.setLayoutMode(self,mode:PySide6.QtWidgets.QListView.LayoutMode)",
    "PySide6.QtWidgets.QListView.setModelColumn(self,column:int)",
    "PySide6.QtWidgets.QListView.setMovement(self,movement:PySide6.QtWidgets.QListView.Movement)",
    "PySide6.QtWidgets.QListView.setPositionForIndex(self,position:PySide6.QtCore.QPoint,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "PySide6.QtWidgets.QListView.setResizeMode(self,mode:PySide6.QtWidgets.QListView.ResizeMode)",
    "PySide6.QtWidgets.QListView.setRootIndex(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "PySide6.QtWidgets.QListView.setRowHidden(self,row:int,hide:bool)",
    "PySide6.QtWidgets.QListView.setSelection(self,rect:PySide6.QtCore.QRect,command:PySide6.QtCore.QItemSelectionModel.SelectionFlag)",
    "PySide6.QtWidgets.QListView.setSelectionRectVisible(self,show:bool)",
    "PySide6.QtWidgets.QListView.setSpacing(self,space:int)",
    "PySide6.QtWidgets.QListView.setUniformItemSizes(self,enable:bool)",
    "PySide6.QtWidgets.QListView.setViewMode(self,mode:PySide6.QtWidgets.QListView.ViewMode)",
    "PySide6.QtWidgets.QListView.setWordWrap(self,on:bool)",
    "PySide6.QtWidgets.QListView.setWrapping(self,enable:bool)",
    "PySide6.QtWidgets.QListView.spacing(self)->int",
    "PySide6.QtWidgets.QListView.startDrag(self,supportedActions:PySide6.QtCore.Qt.DropAction)",
    "PySide6.QtWidgets.QListView.timerEvent(self,e:PySide6.QtCore.QTimerEvent)",
    "PySide6.QtWidgets.QListView.uniformItemSizes(self)->bool",
    "PySide6.QtWidgets.QListView.updateGeometries(self)",
    "PySide6.QtWidgets.QListView.verticalOffset(self)->int",
    "PySide6.QtWidgets.QListView.viewMode(self)->PySide6.QtWidgets.QListView.ViewMode",
    "PySide6.QtWidgets.QListView.viewportSizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QListView.visualRect(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.QRect",
    "PySide6.QtWidgets.QListView.visualRegionForSelection(self,selection:PySide6.QtCore.QItemSelection)->PySide6.QtGui.QRegion",
    "PySide6.QtWidgets.QListView.wheelEvent(self,e:PySide6.QtGui.QWheelEvent)",
    "PySide6.QtWidgets.QListView.wordWrap(self)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QListView_SignatureByteSize = 1208;
static constexpr uint8_t QListView_SignatureBytes[1208] = {
    0x78, 0xda, 0xcd, 0x58, 0x4b, 0x6f, 0xdb, 0x38, 0x10, 0xbe, 0xef, 0xaf, 0xd8, 0x63, 0xb3, 0x50,
    0x7d, 0xdc, 0x83, 0xb1, 0x09, 0xe0, 0xb8, 0x49, 0x1a, 0xac, 0xbd, 0x71, 0x9c, 0x34, 0x39, 0x14,
    0x39, 0xd0, 0xe6, 0xd8, 0x26, 0x40, 0x91, 0x02, 0x49, 0xd9, 0x75, 0x7f, 0xfd, 0xf2, 0x21, 0xca,
    0x92, 0x2c, 0x93, 0x6c, 0xe0, 0x00, 0xbd, 0x24, 0xb2, 0x34, 0xf3, 0x71, 0x38, 0x9c, 0xc7, 0x37,
    0x9c, 0xed, 0x9f, 0x08, 0x86, 0xbf, 0x07, 0x8f, 0xea, 0x95, 0xe0, 0x35, 0x28, 0x39, 0x78, 0x9c,
    0x10, 0xa9, 0x5e, 0x08, 0xec, 0x3e, 0x49, 0xa0, 0xab, 0xac, 0x40, 0x02, 0x98, 0x1a, 0xce, 0x8e,
    0xe5, 0xdc, 0xc3, 0x25, 0x2b, 0x29, 0x2d, 0x94, 0xc8, 0xfe, 0x1a, 0xfe, 0x0b, 0xfb, 0x1d, 0x17,
    0xf8, 0x81, 0xd1, 0xfd, 0xe5, 0x7f, 0x9c, 0x41, 0x96, 0xf3, 0x2d, 0xe4, 0x46, 0xbb, 0xc6, 0x1c,
    0x4c, 0xab, 0x57, 0x4e, 0x60, 0x45, 0xf9, 0xae, 0xf1, 0xf1, 0x56, 0xff, 0x74, 0x1f, 0x88, 0x7c,
    0x15, 0xa8, 0x28, 0x08, 0x5b, 0x0f, 0x17, 0x9c, 0x53, 0xf7, 0x52, 0x80, 0x24, 0x3f, 0x61, 0xca,
    0x31, 0x34, 0x74, 0xe6, 0xf5, 0x4b, 0x27, 0x44, 0xd1, 0x9e, 0x97, 0xaa, 0x23, 0x34, 0xa9, 0x5f,
    0x3a, 0x21, 0x59, 0xa0, 0xa5, 0xc1, 0x26, 0xde, 0x90, 0xb5, 0x20, 0xf8, 0x49, 0xe3, 0x0c, 0x1f,
    0xcd, 0x5f, 0xf7, 0x6e, 0xab, 0x35, 0x3b, 0x38, 0x2f, 0xd5, 0x2b, 0xbf, 0x3d, 0x0c, 0x74, 0xcc,
    0x69, 0x99, 0xb3, 0x03, 0x52, 0xc9, 0xc8, 0x8a, 0x8b, 0xfc, 0x5e, 0x41, 0x6e, 0xa0, 0x64, 0xc3,
    0xfe, 0x05, 0x52, 0xcb, 0x8d, 0x5d, 0xa5, 0x96, 0x36, 0xfe, 0x32, 0x3b, 0x6d, 0x48, 0x69, 0xaf,
    0xc3, 0x52, 0x11, 0xce, 0xe6, 0xfa, 0xdf, 0x0b, 0x91, 0x64, 0x41, 0xa1, 0xf1, 0x99, 0x68, 0xe0,
    0x11, 0x25, 0x6b, 0x96, 0xb7, 0x8f, 0x65, 0xcc, 0x05, 0xe8, 0x7f, 0x83, 0xfa, 0xdb, 0x2d, 0x45,
    0x6b, 0xab, 0x72, 0xf1, 0xc7, 0xec, 0xf4, 0x21, 0x0f, 0x6a, 0xa3, 0xec, 0x71, 0x5f, 0x7c, 0xbe,
    0xd2, 0xb6, 0x05, 0x15, 0x96, 0x14, 0x90, 0x98, 0x09, 0x5e, 0x80, 0x50, 0x7b, 0xb3, 0x88, 0x74,
    0x9a, 0x61, 0x25, 0xce, 0x94, 0xb6, 0x49, 0x36, 0x17, 0xea, 0xda, 0x6e, 0xbe, 0x85, 0x41, 0x4a,
    0x61, 0x62, 0x71, 0xbc, 0x41, 0x6c, 0x0d, 0xd8, 0x85, 0x67, 0xf5, 0x6e, 0xa8, 0xf6, 0x26, 0x58,
    0x06, 0xdf, 0x98, 0x76, 0xdc, 0xf7, 0x2e, 0xb2, 0x39, 0x32, 0x7a, 0xcf, 0x30, 0xfc, 0xc8, 0xfe,
    0xec, 0x7e, 0x9b, 0x81, 0x90, 0x7a, 0x01, 0x8d, 0x71, 0x90, 0x7a, 0xcb, 0x0a, 0x01, 0x5b, 0xc2,
    0x4b, 0x79, 0x66, 0xdc, 0xb0, 0x93, 0x30, 0x52, 0xa8, 0xb5, 0x39, 0xc5, 0x8b, 0x09, 0xac, 0xce,
    0xbe, 0xb9, 0x05, 0x57, 0x8a, 0xe7, 0x73, 0xb2, 0xde, 0x9c, 0x1d, 0x5a, 0x70, 0xaa, 0x43, 0xde,
    0x6e, 0xe9, 0xbb, 0x0e, 0xa4, 0xb7, 0x4b, 0xfb, 0xf8, 0x8f, 0x7e, 0xbc, 0xfa, 0x74, 0x11, 0xd9,
    0x3d, 0x37, 0x39, 0x23, 0x5d, 0xaa, 0x26, 0x84, 0x14, 0x16, 0x68, 0x3d, 0x01, 0xb4, 0x85, 0x9b,
    0xad, 0x36, 0xc2, 0x39, 0x0c, 0x1a, 0x09, 0x71, 0x57, 0x92, 0xc1, 0xe3, 0x97, 0x96, 0x50, 0x1c,
    0xd0, 0x94, 0xa7, 0x18, 0x5e, 0x2d, 0x13, 0x83, 0xe3, 0x45, 0x18, 0xaa, 0xfa, 0x1e, 0x86, 0x81,
    0x7e, 0x08, 0x77, 0x08, 0x4e, 0xff, 0xf3, 0x95, 0x29, 0x0f, 0x41, 0x14, 0x53, 0x68, 0x8f, 0xf3,
    0xee, 0x58, 0xce, 0x54, 0xe0, 0x20, 0x90, 0x2f, 0x94, 0xef, 0x4e, 0xe2, 0x0d, 0x17, 0xe4, 0xa7,
    0xae, 0x06, 0x88, 0x3e, 0xac, 0x56, 0x12, 0x54, 0x6a, 0xd9, 0x21, 0x26, 0xc0, 0x46, 0x95, 0x27,
    0x8a, 0x23, 0x4f, 0xcc, 0x38, 0xb1, 0x9e, 0x38, 0x1d, 0xc2, 0x11, 0x74, 0x62, 0x1f, 0x4c, 0x08,
    0x3e, 0x14, 0xa6, 0xfa, 0xba, 0x85, 0xb8, 0x7d, 0xee, 0xeb, 0x7e, 0x4f, 0x6a, 0x4f, 0xc1, 0x89,
    0x7a, 0xc5, 0xf0, 0x41, 0x12, 0x69, 0xcd, 0xf8, 0x4a, 0x30, 0x86, 0x0a, 0xdd, 0xee, 0xe9, 0xdc,
    0x25, 0x26, 0x21, 0x1a, 0x88, 0x9c, 0xf3, 0x5d, 0xd3, 0x10, 0xa1, 0xdb, 0x30, 0x49, 0x8b, 0x24,
    0x22, 0x9f, 0x7a, 0x1a, 0x94, 0x3f, 0xc5, 0x04, 0x75, 0xdf, 0xd8, 0xd3, 0x55, 0x9a, 0x1d, 0xef,
    0x54, 0xdc, 0x75, 0x1a, 0x5f, 0x10, 0xf0, 0x40, 0x11, 0x52, 0x52, 0xe2, 0xc0, 0x1d, 0x82, 0xa0,
    0x0d, 0x32, 0x90, 0x1a, 0xd2, 0xb9, 0x6e, 0x30, 0x10, 0xab, 0x38, 0x53, 0x23, 0x94, 0x50, 0x27,
    0x2c, 0xd8, 0x5c, 0x1f, 0x0d, 0x92, 0x67, 0xc2, 0xdb, 0xc2, 0xb8, 0x14, 0x92, 0x8b, 0xba, 0xd1,
    0xea, 0xe7, 0xd1, 0xf2, 0x54, 0x3e, 0x8c, 0x16, 0x52, 0x09, 0xb4, 0x54, 0x26, 0x11, 0x2c, 0xc0,
    0xb8, 0xa1, 0x60, 0xa8, 0x12, 0x59, 0x11, 0x1d, 0xaf, 0x3d, 0x8c, 0x45, 0xd3, 0xc6, 0x05, 0x47,
    0x02, 0x4f, 0x2b, 0x99, 0xf7, 0x67, 0xb1, 0xe7, 0x9b, 0x29, 0xc7, 0xea, 0x89, 0x68, 0x10, 0xb0,
    0x40, 0xfa, 0x0c, 0x43, 0xde, 0x9c, 0xd5, 0x02, 0x61, 0x6f, 0x0a, 0x9d, 0x2a, 0xb7, 0x5c, 0xd8,
    0x2d, 0x7c, 0x68, 0xee, 0x77, 0xe5, 0x4c, 0x8e, 0x46, 0x2c, 0xab, 0x8b, 0x70, 0x4c, 0x4e, 0x97,
    0xf6, 0x71, 0xc5, 0xe3, 0xdc, 0x1e, 0x76, 0x04, 0xab, 0x8d, 0x29, 0x1c, 0xd9, 0x06, 0x2c, 0x9b,
    0x20, 0x71, 0x3f, 0x18, 0x94, 0x90, 0x47, 0xe7, 0x07, 0x89, 0x14, 0xa8, 0xd4, 0x2c, 0x3e, 0x8c,
    0x09, 0x61, 0x50, 0xbe, 0x93, 0xa3, 0x85, 0xce, 0xf7, 0x67, 0x7e, 0xad, 0xb3, 0xc9, 0x04, 0x14,
    0x6e, 0xcd, 0x41, 0x67, 0xe6, 0x4b, 0x52, 0x21, 0x61, 0xdd, 0x96, 0x01, 0xc3, 0x09, 0xee, 0xd3,
    0xe6, 0xdd, 0x33, 0xa9, 0x99, 0xf7, 0x6f, 0x65, 0x96, 0x5c, 0x6a, 0xde, 0x47, 0x7d, 0x6c, 0x5c,
    0xef, 0x9d, 0x69, 0xf8, 0x87, 0x45, 0xc0, 0xfb, 0x54, 0x80, 0x67, 0xfe, 0x71, 0xa9, 0x91, 0x6d,
    0x48, 0xff, 0x14, 0x7b, 0x54, 0xb7, 0x9e, 0xac, 0x2d, 0x5f, 0xcd, 0x88, 0x16, 0xfa, 0x38, 0xb8,
    0x61, 0xb2, 0x14, 0x50, 0xf5, 0xbf, 0xc8, 0xf6, 0x6c, 0xc7, 0x04, 0x6c, 0x4d, 0x01, 0xe9, 0xe3,
    0xd5, 0xd1, 0xe4, 0xd3, 0x5b, 0x7b, 0x4b, 0x00, 0xd5, 0xce, 0x69, 0x8d, 0x0c, 0x7e, 0xa9, 0xa3,
    0x3a, 0x6b, 0x07, 0x52, 0xaf, 0x92, 0x61, 0x48, 0x13, 0x8c, 0xed, 0x4b, 0x5d, 0xb7, 0xc6, 0xc7,
    0xf6, 0x88, 0x1b, 0x55, 0xbe, 0xf5, 0xac, 0xd4, 0x5d, 0x04, 0xc4, 0x88, 0x69, 0x14, 0xef, 0xae,
    0x49, 0x4e, 0x33, 0x93, 0xf0, 0xc3, 0x3e, 0x7e, 0x1a, 0xc5, 0xb9, 0x3f, 0x62, 0x1c, 0x19, 0x4a,
    0x1d, 0xb9, 0xa3, 0xe0, 0x93, 0x36, 0xfb, 0xb0, 0xb7, 0x08, 0xc3, 0x34, 0x02, 0x12, 0xc5, 0x9e,
    0x76, 0x48, 0x48, 0xb6, 0xac, 0x6f, 0x27, 0x12, 0x74, 0x1b, 0xcd, 0xf3, 0x70, 0x75, 0x93, 0xd2,
    0x43, 0xa3, 0xd8, 0x33, 0x2e, 0x89, 0x09, 0xa7, 0x76, 0x0b, 0x2c, 0xaa, 0xb7, 0xfd, 0x64, 0xfe,
    0x63, 0x3a, 0x64, 0xcc, 0xd2, 0x79, 0xbb, 0xab, 0xc4, 0x4f, 0xe7, 0xa0, 0x10, 0xc7, 0xe6, 0x5c,
    0x7d, 0x34, 0x03, 0x88, 0xdb, 0xd0, 0x47, 0xfc, 0x75, 0x75, 0xc4, 0xee, 0x92, 0x29, 0x0a, 0x50,
    0x97, 0x86, 0x0a, 0x40, 0xff, 0x18, 0xf6, 0x91, 0x0e, 0x1d, 0x7a, 0x79, 0x8e, 0x58, 0xa4, 0xbe,
    0x58, 0xd3, 0x07, 0xf5, 0xcf, 0xa4, 0x04, 0x3a, 0x39, 0x7f, 0x64, 0x72, 0xa3, 0xb7, 0x93, 0xb6,
    0x0b, 0x77, 0x01, 0x58, 0xa9, 0xe9, 0x1f, 0x69, 0x05, 0xeb, 0x5b, 0xe7, 0x72, 0xaf, 0xe2, 0x30,
    0x0c, 0xf9, 0x3b, 0xba, 0x28, 0x82, 0xbf, 0x41, 0x4c, 0x8c, 0x2e, 0x2f, 0x1e, 0xc5, 0x7d, 0xad,
    0x2e, 0x12, 0xab, 0xb1, 0x95, 0xa5, 0x59, 0xd3, 0x9a, 0xc5, 0x7e, 0x61, 0x1f, 0x0d, 0xef, 0x25,
    0xcc, 0x39, 0x96, 0x4d, 0x98, 0x9b, 0x93, 0xca, 0xdd, 0x65, 0x51, 0x70, 0xc3, 0x60, 0xdc, 0x6c,
    0xd0, 0x37, 0x12, 0x98, 0xbb, 0x91, 0x51, 0x42, 0x03, 0x52, 0x24, 0x07, 0x71, 0x13, 0xba, 0x21,
    0x79, 0xae, 0x25, 0xc2, 0x48, 0x65, 0xdf, 0xc9, 0xa6, 0x4c, 0xa7, 0x65, 0x81, 0x91, 0x82, 0x3b,
    0xe0, 0x39, 0x28, 0x41, 0x20, 0xe5, 0x32, 0x74, 0xab, 0xf9, 0x1b, 0x59, 0xfe, 0xea, 0x05, 0xc8,
    0xb6, 0x19, 0x39, 0x11, 0xb6, 0xeb, 0xc3, 0x26, 0x0a, 0x68, 0x0e, 0xc2, 0xec, 0xd7, 0x30, 0x9a,
    0x77, 0x5f, 0xe9, 0x6c, 0x89, 0x2c, 0x11, 0x35, 0xd9, 0xf8, 0x7b, 0x8d, 0x36, 0xde, 0xae, 0xb5,
    0xeb, 0x3c, 0x9d, 0xca, 0x55, 0xf3, 0xa7, 0x08, 0x03, 0x6a, 0x2e, 0x5c, 0x4d, 0x28, 0x06, 0x30,
    0xb8, 0xf2, 0x6e, 0x03, 0x40, 0x43, 0x53, 0xce, 0x6b, 0x2d, 0x10, 0x0e, 0x95, 0x5d, 0x33, 0xad,
    0x7d, 0x38, 0xfe, 0x0f, 0x9c, 0x00, 0x67, 0x51
};
#endif

PyTypeObject *init_QListView(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX].type;

    Shiboken::AutoDecRef Sbk_QListView_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]))));

    _Sbk_QListView_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QListView",
        "QListView*",
        &Sbk_QListView_spec,
        &Shiboken::callCppDestructor< QListView >,
        Sbk_QListView_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QListView_TypeF(); // references _Sbk_QListView_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QListView_SignatureStrings);
#else
    InitSignatureBytes(pyType, QListView_SignatureBytes, QListView_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QListView_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QListView_PythonToCpp_QListView_PTR,
        is_QListView_PythonToCpp_QListView_PTR_Convertible,
        QListView_PTR_CppToPython_QListView);

    Shiboken::Conversions::registerConverterName(converter, "QListView");
    Shiboken::Conversions::registerConverterName(converter, "QListView*");
    Shiboken::Conversions::registerConverterName(converter, "QListView&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QListView).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QListViewWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QListView_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QListView_TypeF(), &Sbk_QListViewSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QListView_TypeF(), &Sbk_QListView_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QListView_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Movement'.
    const char *Movement_Initializer[] = {
        "Static",
        "Free",
        "Snap",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Movement_InitializerValues[] = {
        uint8_t(QListView::Movement::Static), //  0x00  0
        uint8_t(QListView::Movement::Free),   //  0x01  1
        uint8_t(QListView::Movement::Snap)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QListView_TypeF(),
        "2:PySide6.QtWidgets.QListView.Movement",
        Movement_Initializer, Movement_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_Movement_IDX].type = EType;
    // Register converter for enum 'QListView::Movement'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QListView_Movement_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QListView_Movement,
            is_Enum_PythonToCpp_QListView_Movement_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QListView::Movement");
        Shiboken::Conversions::registerConverterAlias(converter, "Movement");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Movement' enum.

    // Initialization of enum 'Flow'.
    const char *Flow_Initializer[] = {
        "LeftToRight",
        "TopToBottom",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Flow_InitializerValues[] = {
        uint8_t(QListView::Flow::LeftToRight), //  0x00  0
        uint8_t(QListView::Flow::TopToBottom)  //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QListView_TypeF(),
        "2:PySide6.QtWidgets.QListView.Flow",
        Flow_Initializer, Flow_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_Flow_IDX].type = EType;
    // Register converter for enum 'QListView::Flow'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QListView_Flow_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QListView_Flow,
            is_Enum_PythonToCpp_QListView_Flow_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QListView::Flow");
        Shiboken::Conversions::registerConverterAlias(converter, "Flow");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Flow' enum.

    // Initialization of enum 'ResizeMode'.
    const char *ResizeMode_Initializer[] = {
        "Fixed",
        "Adjust",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ResizeMode_InitializerValues[] = {
        uint8_t(QListView::ResizeMode::Fixed), //  0x00  0
        uint8_t(QListView::ResizeMode::Adjust) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QListView_TypeF(),
        "2:PySide6.QtWidgets.QListView.ResizeMode",
        ResizeMode_Initializer, ResizeMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_ResizeMode_IDX].type = EType;
    // Register converter for enum 'QListView::ResizeMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QListView_ResizeMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QListView_ResizeMode,
            is_Enum_PythonToCpp_QListView_ResizeMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QListView::ResizeMode");
        Shiboken::Conversions::registerConverterAlias(converter, "ResizeMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ResizeMode' enum.

    // Initialization of enum 'LayoutMode'.
    const char *LayoutMode_Initializer[] = {
        "SinglePass",
        "Batched",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t LayoutMode_InitializerValues[] = {
        uint8_t(QListView::LayoutMode::SinglePass), //  0x00  0
        uint8_t(QListView::LayoutMode::Batched)     //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QListView_TypeF(),
        "2:PySide6.QtWidgets.QListView.LayoutMode",
        LayoutMode_Initializer, LayoutMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_LayoutMode_IDX].type = EType;
    // Register converter for enum 'QListView::LayoutMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QListView_LayoutMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QListView_LayoutMode,
            is_Enum_PythonToCpp_QListView_LayoutMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QListView::LayoutMode");
        Shiboken::Conversions::registerConverterAlias(converter, "LayoutMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'LayoutMode' enum.

    // Initialization of enum 'ViewMode'.
    const char *ViewMode_Initializer[] = {
        "ListMode",
        "IconMode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ViewMode_InitializerValues[] = {
        uint8_t(QListView::ViewMode::ListMode), //  0x00  0
        uint8_t(QListView::ViewMode::IconMode)  //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QListView_TypeF(),
        "2:PySide6.QtWidgets.QListView.ViewMode",
        ViewMode_Initializer, ViewMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_ViewMode_IDX].type = EType;
    // Register converter for enum 'QListView::ViewMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QListView_ViewMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QListView_ViewMode,
            is_Enum_PythonToCpp_QListView_ViewMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QListView::ViewMode");
        Shiboken::Conversions::registerConverterAlias(converter, "ViewMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ViewMode' enum.

    PySide::Signal::registerSignals(pyType, &::QListView::staticMetaObject);
    qRegisterMetaType< ::QListView::Movement >("QListView::Movement");
    qRegisterMetaType< ::QListView::Flow >("QListView::Flow");
    qRegisterMetaType< ::QListView::ResizeMode >("QListView::ResizeMode");
    qRegisterMetaType< ::QListView::LayoutMode >("QListView::LayoutMode");
    qRegisterMetaType< ::QListView::ViewMode >("QListView::ViewMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QListView::staticMetaObject, sizeof(QListViewWrapper));

    return pyType;
}
