// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qtreewidget_wrapper.h"

// Wrappers providing overrides
#include "qabstractitemview_wrapper.h"
#include "qlayoutitem_wrapper.h"
#include "qtextedit_wrapper.h"
#include "qaccessiblewidget_wrapper.h"
#include "qlineedit_wrapper.h"
#include "qabstractscrollarea_wrapper.h"
#include "qwidget_wrapper.h"
#include "qwizardpage_wrapper.h"
#include "qgraphicsitem_wrapper.h"
#include "qtreeview_wrapper.h"
#include "qgraphicslayout_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qregion.h>
#include <QtWidgets/qabstractitemdelegate.h>
#include <QtWidgets/qabstractitemview.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qtreewidget.h>
#include <QtWidgets/qwidget.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qitemselectionmodel.h>
#include <qmetaobject.h>
#include <qmimedata.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QTreeWidgetWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QTreeWidgetWrapper::QTreeWidgetWrapper(::QWidget * parent) : QTreeWidget(parent)
{
}

void QTreeWidgetWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QWizardPageWrapper::sbk_o_actionEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::changeEvent(event);
    }
    QWizardPageWrapper::sbk_o_changeEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWidgetWrapper::sbk_o_childEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::closeEditor(::QWidget * editor, ::QAbstractItemDelegate::EndEditHint hint)
{
    static const char *funcName = "closeEditor";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::closeEditor(editor, hint);
    }
    QAbstractItemViewWrapper::sbk_o_closeEditor("QTreeWidget", funcName, gil, pyOverride, editor, hint);
}

void QTreeWidgetWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QWizardPageWrapper::sbk_o_closeEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::commitData(::QWidget * editor)
{
    static const char *funcName = "commitData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::commitData(editor);
    }
    QAbstractItemViewWrapper::sbk_o_commitData("QTreeWidget", funcName, gil, pyOverride, editor);
}

void QTreeWidgetWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QTreeWidget", funcName, gil, pyOverride, signal);
}

void QTreeWidgetWrapper::contextMenuEvent(::QContextMenuEvent * arg__1)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::contextMenuEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_contextMenuEvent("QTreeWidget", funcName, gil, pyOverride, arg__1);
}

void QTreeWidgetWrapper::currentChanged(const ::QModelIndex & current, const ::QModelIndex & previous)
{
    static const char *funcName = "currentChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::currentChanged(current, previous);
    }
    QAbstractItemViewWrapper::sbk_o_currentChanged("QTreeWidget", funcName, gil, pyOverride, current, previous);
}

void QTreeWidgetWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWidgetWrapper::sbk_o_customEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::dataChanged(const ::QModelIndex & topLeft, const ::QModelIndex & bottomRight, const ::QList<int> & roles)
{
    static const char *funcName = "dataChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::dataChanged(topLeft, bottomRight, roles);
    }
    QAbstractItemViewWrapper::sbk_o_dataChanged("QTreeWidget", funcName, gil, pyOverride, topLeft, bottomRight, roles);
}

int QTreeWidgetWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QTreeWidget", funcName, gil, pyOverride);
}

void QTreeWidgetWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWidgetWrapper::sbk_o_connectNotify("QTreeWidget", funcName, gil, pyOverride, signal);
}

void QTreeWidgetWrapper::doItemsLayout()
{
    static const char *funcName = "doItemsLayout";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::doItemsLayout();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QTreeWidget", funcName, gil, pyOverride);
}

void QTreeWidgetWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::dragEnterEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragEnterEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::dragLeaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragLeaveEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::dragMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_dragMoveEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::drawBranches(::QPainter * painter, const ::QRect & rect, const ::QModelIndex & index) const
{
    static const char *funcName = "drawBranches";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::drawBranches(painter, rect, index);
    }
    sbk_o_drawBranches("QTreeWidget", funcName, gil, pyOverride, painter, rect, index);
}

void QTreeWidgetWrapper::sbk_o_drawBranches(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QRect & rect, const ::QModelIndex & index)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &rect),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &rect),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QTreeWidgetWrapper::drawRow(::QPainter * painter, const ::QStyleOptionViewItem & options, const ::QModelIndex & index) const
{
    static const char *funcName = "drawRow";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::drawRow(painter, options, index);
    }
    sbk_o_drawRow("QTreeWidget", funcName, gil, pyOverride, painter, options, index);
}

void QTreeWidgetWrapper::sbk_o_drawRow(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QPainter * painter, const ::QStyleOptionViewItem & options, const ::QModelIndex & index)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionViewItem_IDX]), &options),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionViewItem_IDX]), &options),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QTreeWidgetWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeWidget::dropEvent(event);
    }
    QWizardPageWrapper::sbk_o_dropEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

bool QTreeWidgetWrapper::dropMimeData(::QTreeWidgetItem * parent, int index, const ::QMimeData * data, ::Qt::DropAction action)
{
    static const char *funcName = "dropMimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeWidget::dropMimeData(parent, index, data, action);
    }
    return sbk_o_dropMimeData("QTreeWidget", funcName, gil, pyOverride, parent, index, data, action);
}

bool QTreeWidgetWrapper::sbk_o_dropMimeData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QTreeWidgetItem * parent, int index, const ::QMimeData * data, ::Qt::DropAction action)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), parent),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &index),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), data),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DropAction_IDX])))->converter, &action)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NiNN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), parent),
        index,
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), data),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DropAction_IDX])))->converter, &action)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QTreeWidgetWrapper::edit(const ::QModelIndex & index, ::QAbstractItemView::EditTrigger trigger, ::QEvent * event)
{
    static const char *funcName = "edit";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::edit(index, trigger, event);
    }
    return QTreeViewWrapper::sbk_o_edit("QTreeWidget", funcName, gil, pyOverride, index, trigger, event);
}

void QTreeWidgetWrapper::editorDestroyed(::QObject * editor)
{
    static const char *funcName = "editorDestroyed";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::editorDestroyed(editor);
    }
    QAbstractItemViewWrapper::sbk_o_editorDestroyed("QTreeWidget", funcName, gil, pyOverride, editor);
}

void QTreeWidgetWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QWizardPageWrapper::sbk_o_enterEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

bool QTreeWidgetWrapper::event(::QEvent * e)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeWidget::event(e);
    }
    return QWidgetWrapper::sbk_o_event("QTreeWidget", funcName, gil, pyOverride, e);
}

bool QTreeWidgetWrapper::eventFilter(::QObject * object, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::eventFilter(object, event);
    }
    return QWidgetWrapper::sbk_o_eventFilter("QTreeWidget", funcName, gil, pyOverride, object, event);
}

void QTreeWidgetWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::focusInEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusInEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

bool QTreeWidgetWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::focusNextPrevChild(next);
    }
    return QWidgetWrapper::sbk_o_focusNextPrevChild("QTreeWidget", funcName, gil, pyOverride, next);
}

void QTreeWidgetWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::focusOutEvent(event);
    }
    QWizardPageWrapper::sbk_o_focusOutEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

bool QTreeWidgetWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QLayoutItemWrapper::sbk_o_hasHeightForWidth("QTreeWidget", funcName, gil, pyOverride);
}

int QTreeWidgetWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QTreeWidget", funcName, gil, pyOverride, arg__1);
}

void QTreeWidgetWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QWizardPageWrapper::sbk_o_hideEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

int QTreeWidgetWrapper::horizontalOffset() const
{
    static const char *funcName = "horizontalOffset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::horizontalOffset();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QTreeWidget", funcName, gil, pyOverride);
}

void QTreeWidgetWrapper::horizontalScrollbarAction(int action)
{
    static const char *funcName = "horizontalScrollbarAction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::horizontalScrollbarAction(action);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QTreeWidget", funcName, gil, pyOverride, action);
}

void QTreeWidgetWrapper::horizontalScrollbarValueChanged(int value)
{
    static const char *funcName = "horizontalScrollbarValueChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::horizontalScrollbarValueChanged(value);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QTreeWidget", funcName, gil, pyOverride, value);
}

::QModelIndex QTreeWidgetWrapper::indexAt(const ::QPoint & p) const
{
    static const char *funcName = "indexAt";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::indexAt(p);
    }
    return QAbstractItemViewWrapper::sbk_o_indexAt("QTreeWidget", funcName, gil, pyOverride, p);
}

void QTreeWidgetWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QWidgetWrapper::sbk_o_initPainter("QTreeWidget", funcName, gil, pyOverride, painter);
}

void QTreeWidgetWrapper::initStyleOption(::QStyleOptionFrame * option) const
{
    static const char *funcName = "initStyleOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QFrame::initStyleOption(option);
    }
    QLineEditWrapper::sbk_o_initStyleOption("QTreeWidget", funcName, gil, pyOverride, option);
}

void QTreeWidgetWrapper::initViewItemOption(::QStyleOptionViewItem * option) const
{
    static const char *funcName = "initViewItemOption";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::initViewItemOption(option);
    }
    QAbstractItemViewWrapper::sbk_o_initViewItemOption("QTreeWidget", funcName, gil, pyOverride, option);
}

void QTreeWidgetWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::inputMethodEvent(event);
    }
    QWizardPageWrapper::sbk_o_inputMethodEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

::QVariant QTreeWidgetWrapper::inputMethodQuery(::Qt::InputMethodQuery query) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::inputMethodQuery(query);
    }
    return QGraphicsItemWrapper::sbk_o_inputMethodQuery("QTreeWidget", funcName, gil, pyOverride, query);
}

bool QTreeWidgetWrapper::isIndexHidden(const ::QModelIndex & index) const
{
    static const char *funcName = "isIndexHidden";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::isIndexHidden(index);
    }
    return QAbstractItemViewWrapper::sbk_o_isIndexHidden("QTreeWidget", funcName, gil, pyOverride, index);
}

::QAbstractItemDelegate * QTreeWidgetWrapper::itemDelegateForIndex(const ::QModelIndex & index) const
{
    static const char *funcName = "itemDelegateForIndex";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::itemDelegateForIndex(index);
    }
    return QAbstractItemViewWrapper::sbk_o_itemDelegateForIndex("QTreeWidget", funcName, gil, pyOverride, index);
}

void QTreeWidgetWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::keyPressEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyPressEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_keyReleaseEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::keyboardSearch(const ::QString & search)
{
    static const char *funcName = "keyboardSearch";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::keyboardSearch(search);
    }
    QAccessibleWidgetWrapper::sbk_o_doAction("QTreeWidget", funcName, gil, pyOverride, search);
}

void QTreeWidgetWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QWizardPageWrapper::sbk_o_leaveEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

int QTreeWidgetWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QWidgetWrapper::sbk_o_metric("QTreeWidget", funcName, gil, pyOverride, arg__1);
}

::QMimeData * QTreeWidgetWrapper::mimeData(const ::QList<QTreeWidgetItem*> & items) const
{
    static const char *funcName = "mimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeWidget::mimeData(items);
    }
    return sbk_o_mimeData("QTreeWidget", funcName, gil, pyOverride, items);
}

::QMimeData * QTreeWidgetWrapper::sbk_o_mimeData(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QList<QTreeWidgetItem*> & items)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTreeWidgetItemPTR_IDX], &items)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTreeWidgetItemPTR_IDX], &items)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QMimeData >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QMimeData *cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (Shiboken::Object::checkType(pyResult))
        Shiboken::Object::releaseOwnership(pyResult);
    return cppResult;
}

::QStringList QTreeWidgetWrapper::mimeTypes() const
{
    static const char *funcName = "mimeTypes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeWidget::mimeTypes();
    }
    return QAccessibleWidgetWrapper::sbk_o_actionNames("QTreeWidget", funcName, gil, pyOverride);
}

::QSize QTreeWidgetWrapper::minimumSizeHint() const
{
    static const char *funcName = "minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::minimumSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QTreeWidget", funcName, gil, pyOverride);
}

void QTreeWidgetWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::mouseDoubleClickEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseDoubleClickEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[52], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::mouseMoveEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseMoveEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[53], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::mousePressEvent(event);
    }
    QWizardPageWrapper::sbk_o_mousePressEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[54], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::mouseReleaseEvent(event);
    }
    QWizardPageWrapper::sbk_o_mouseReleaseEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

::QModelIndex QTreeWidgetWrapper::moveCursor(::QAbstractItemView::CursorAction cursorAction, ::QFlags<Qt::KeyboardModifier> modifiers)
{
    static const char *funcName = "moveCursor";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[55], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::moveCursor(cursorAction, modifiers);
    }
    return QAbstractItemViewWrapper::sbk_o_moveCursor("QTreeWidget", funcName, gil, pyOverride, cursorAction, modifiers);
}

void QTreeWidgetWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[56], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QWizardPageWrapper::sbk_o_moveEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

bool QTreeWidgetWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[57], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QWizardPageWrapper::sbk_o_nativeEvent("QTreeWidget", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QTreeWidgetWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[58], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QWidgetWrapper::sbk_o_paintEngine("QTreeWidget", funcName, gil, pyOverride);
}

void QTreeWidgetWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[59], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::paintEvent(event);
    }
    QWizardPageWrapper::sbk_o_paintEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

::QPaintDevice * QTreeWidgetWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[60], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QWidgetWrapper::sbk_o_redirected("QTreeWidget", funcName, gil, pyOverride, offset);
}

void QTreeWidgetWrapper::reset()
{
    static const char *funcName = "reset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[61], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::reset();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QTreeWidget", funcName, gil, pyOverride);
}

void QTreeWidgetWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[62], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::resizeEvent(event);
    }
    QWizardPageWrapper::sbk_o_resizeEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::rowsAboutToBeRemoved(const ::QModelIndex & parent, int start, int end)
{
    static const char *funcName = "rowsAboutToBeRemoved";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[63], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::rowsAboutToBeRemoved(parent, start, end);
    }
    QAbstractItemViewWrapper::sbk_o_rowsAboutToBeRemoved("QTreeWidget", funcName, gil, pyOverride, parent, start, end);
}

void QTreeWidgetWrapper::rowsInserted(const ::QModelIndex & parent, int start, int end)
{
    static const char *funcName = "rowsInserted";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[64], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::rowsInserted(parent, start, end);
    }
    QAbstractItemViewWrapper::sbk_o_rowsAboutToBeRemoved("QTreeWidget", funcName, gil, pyOverride, parent, start, end);
}

void QTreeWidgetWrapper::scrollContentsBy(int dx, int dy)
{
    static const char *funcName = "scrollContentsBy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[65], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::scrollContentsBy(dx, dy);
    }
    QAbstractScrollAreaWrapper::sbk_o_scrollContentsBy("QTreeWidget", funcName, gil, pyOverride, dx, dy);
}

void QTreeWidgetWrapper::scrollTo(const ::QModelIndex & index, ::QAbstractItemView::ScrollHint hint)
{
    static const char *funcName = "scrollTo";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[66], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::scrollTo(index, hint);
    }
    QAbstractItemViewWrapper::sbk_o_scrollTo("QTreeWidget", funcName, gil, pyOverride, index, hint);
}

void QTreeWidgetWrapper::selectAll()
{
    static const char *funcName = "selectAll";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[67], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::selectAll();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QTreeWidget", funcName, gil, pyOverride);
}

::QList<QModelIndex> QTreeWidgetWrapper::selectedIndexes() const
{
    static const char *funcName = "selectedIndexes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[68], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::selectedIndexes();
    }
    return QAbstractItemViewWrapper::sbk_o_selectedIndexes("QTreeWidget", funcName, gil, pyOverride);
}

void QTreeWidgetWrapper::selectionChanged(const ::QItemSelection & selected, const ::QItemSelection & deselected)
{
    static const char *funcName = "selectionChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[69], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::selectionChanged(selected, deselected);
    }
    QAbstractItemViewWrapper::sbk_o_selectionChanged("QTreeWidget", funcName, gil, pyOverride, selected, deselected);
}

::QFlags<QItemSelectionModel::SelectionFlag> QTreeWidgetWrapper::selectionCommand(const ::QModelIndex & index, const ::QEvent * event) const
{
    static const char *funcName = "selectionCommand";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[70], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::selectionCommand(index, event);
    }
    return QTreeViewWrapper::sbk_o_selectionCommand("QTreeWidget", funcName, gil, pyOverride, index, event);
}

void QTreeWidgetWrapper::setRootIndex(const ::QModelIndex & index)
{
    static const char *funcName = "setRootIndex";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[71], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::setRootIndex(index);
    }
    QAbstractItemViewWrapper::sbk_o_setRootIndex("QTreeWidget", funcName, gil, pyOverride, index);
}

void QTreeWidgetWrapper::setSelection(const ::QRect & rect, ::QFlags<QItemSelectionModel::SelectionFlag> command)
{
    static const char *funcName = "setSelection";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[72], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::setSelection(rect, command);
    }
    QAbstractItemViewWrapper::sbk_o_setSelection("QTreeWidget", funcName, gil, pyOverride, rect, command);
}

void QTreeWidgetWrapper::setSelectionModel(::QItemSelectionModel * selectionModel)
{
    static const char *funcName = "setSelectionModel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[73], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeWidget::setSelectionModel(selectionModel);
    }
    QTreeViewWrapper::sbk_o_setSelectionModel("QTreeWidget", funcName, gil, pyOverride, selectionModel);
}

void QTreeWidgetWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[74], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QWidgetWrapper::sbk_o_setVisible("QTreeWidget", funcName, gil, pyOverride, visible);
}

void QTreeWidgetWrapper::setupViewport(::QWidget * viewport)
{
    static const char *funcName = "setupViewport";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[75], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::setupViewport(viewport);
    }
    QTextEditWrapper::sbk_o_setupViewport("QTreeWidget", funcName, gil, pyOverride, viewport);
}

::QPainter * QTreeWidgetWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[76], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QWidgetWrapper::sbk_o_sharedPainter("QTreeWidget", funcName, gil, pyOverride);
}

void QTreeWidgetWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[77], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QWizardPageWrapper::sbk_o_showEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

::QSize QTreeWidgetWrapper::sizeHint() const
{
    static const char *funcName = "sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[78], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::sizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QTreeWidget", funcName, gil, pyOverride);
}

int QTreeWidgetWrapper::sizeHintForColumn(int column) const
{
    static const char *funcName = "sizeHintForColumn";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[79], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::sizeHintForColumn(column);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QTreeWidget", funcName, gil, pyOverride, column);
}

int QTreeWidgetWrapper::sizeHintForRow(int row) const
{
    static const char *funcName = "sizeHintForRow";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[80], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::sizeHintForRow(row);
    }
    return QLayoutItemWrapper::sbk_o_heightForWidth("QTreeWidget", funcName, gil, pyOverride, row);
}

void QTreeWidgetWrapper::startDrag(::QFlags<Qt::DropAction> supportedActions)
{
    static const char *funcName = "startDrag";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[81], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::startDrag(supportedActions);
    }
    QAbstractItemViewWrapper::sbk_o_startDrag("QTreeWidget", funcName, gil, pyOverride, supportedActions);
}

::QFlags<Qt::DropAction> QTreeWidgetWrapper::supportedDropActions() const
{
    static const char *funcName = "supportedDropActions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[82], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeWidget::supportedDropActions();
    }
    return sbk_o_supportedDropActions("QTreeWidget", funcName, gil, pyOverride);
}

::QFlags<Qt::DropAction> QTreeWidgetWrapper::sbk_o_supportedDropActions(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return QFlags<Qt::DropAction>(0);
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_DropAction_IDX])))->flagsConverter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, Shiboken::SbkType< QFlags<Qt::DropAction> >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QFlags<Qt::DropAction>(0);
    }
    ::QFlags<Qt::DropAction> cppResult = QFlags<Qt::DropAction>(0);
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QTreeWidgetWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[83], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QWizardPageWrapper::sbk_o_tabletEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[84], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::timerEvent(event);
    }
    QWidgetWrapper::sbk_o_timerEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

void QTreeWidgetWrapper::updateEditorData()
{
    static const char *funcName = "updateEditorData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[85], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::updateEditorData();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QTreeWidget", funcName, gil, pyOverride);
}

void QTreeWidgetWrapper::updateEditorGeometries()
{
    static const char *funcName = "updateEditorGeometries";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[86], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::updateEditorGeometries();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QTreeWidget", funcName, gil, pyOverride);
}

void QTreeWidgetWrapper::updateGeometries()
{
    static const char *funcName = "updateGeometries";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[87], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::updateGeometries();
    }
    QLayoutItemWrapper::sbk_o_invalidate("QTreeWidget", funcName, gil, pyOverride);
}

int QTreeWidgetWrapper::verticalOffset() const
{
    static const char *funcName = "verticalOffset";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[88], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::verticalOffset();
    }
    return QAccessibleWidgetWrapper::sbk_o_childCount("QTreeWidget", funcName, gil, pyOverride);
}

void QTreeWidgetWrapper::verticalScrollbarAction(int action)
{
    static const char *funcName = "verticalScrollbarAction";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[89], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemView::verticalScrollbarAction(action);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QTreeWidget", funcName, gil, pyOverride, action);
}

void QTreeWidgetWrapper::verticalScrollbarValueChanged(int value)
{
    static const char *funcName = "verticalScrollbarValueChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[90], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::verticalScrollbarValueChanged(value);
    }
    QGraphicsLayoutWrapper::sbk_o_removeAt("QTreeWidget", funcName, gil, pyOverride, value);
}

bool QTreeWidgetWrapper::viewportEvent(::QEvent * event)
{
    static const char *funcName = "viewportEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[91], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::viewportEvent(event);
    }
    return QTextEditWrapper::sbk_o_viewportEvent("QTreeWidget", funcName, gil, pyOverride, event);
}

::QSize QTreeWidgetWrapper::viewportSizeHint() const
{
    static const char *funcName = "viewportSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[92], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::viewportSizeHint();
    }
    return QLayoutItemWrapper::sbk_o_maximumSize("QTreeWidget", funcName, gil, pyOverride);
}

::QRect QTreeWidgetWrapper::visualRect(const ::QModelIndex & index) const
{
    static const char *funcName = "visualRect";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[93], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::visualRect(index);
    }
    return QAbstractItemViewWrapper::sbk_o_visualRect("QTreeWidget", funcName, gil, pyOverride, index);
}

::QRegion QTreeWidgetWrapper::visualRegionForSelection(const ::QItemSelection & selection) const
{
    static const char *funcName = "visualRegionForSelection";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[94], nameCache));
    if (pyOverride.isNull()) {
        return this->::QTreeView::visualRegionForSelection(selection);
    }
    return QAbstractItemViewWrapper::sbk_o_visualRegionForSelection("QTreeWidget", funcName, gil, pyOverride, selection);
}

void QTreeWidgetWrapper::wheelEvent(::QWheelEvent * arg__1)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[95], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractScrollArea::wheelEvent(arg__1);
    }
    QWizardPageWrapper::sbk_o_wheelEvent("QTreeWidget", funcName, gil, pyOverride, arg__1);
}

const QMetaObject *QTreeWidgetWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QTreeWidget::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QTreeWidgetWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QTreeWidget::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QTreeWidgetWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QTreeWidgetWrapper *>(this));
    return QTreeWidget::qt_metacast(_clname);
}

QTreeWidgetWrapper::~QTreeWidgetWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTreeWidget_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTreeWidget >()))
        return -1;

    QTreeWidgetWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QTreeWidget", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTreeWidget::QTreeWidget(QWidget*=)
    if (numArgs == 0) {
        overloadId = 0; // QTreeWidget(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QTreeWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QTreeWidget(QWidget*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QTreeWidgetWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QTreeWidgetWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QTreeWidget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QTreeWidgetFunc_addTopLevelItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::addTopLevelItem(QTreeWidgetItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArg)))) {
        overloadId = 0; // addTopLevelItem(QTreeWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addTopLevelItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addTopLevelItem(QTreeWidgetItem*)
            cppSelf->addTopLevelItem(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_addTopLevelItems(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::addTopLevelItems(QList<QTreeWidgetItem*>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTreeWidgetItemPTR_IDX], (pyArg)))) {
        overloadId = 0; // addTopLevelItems(QList<QTreeWidgetItem*>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addTopLevelItems", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        ::QList<QTreeWidgetItem*> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addTopLevelItems(QList<QTreeWidgetItem*>)
            cppSelf->addTopLevelItems(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtwidgets.cpp (qtreewidget-clear)]
        QTreeWidgetItem *rootItem = cppSelf->invisibleRootItem();
        Shiboken::BindingManager &bm = Shiboken::BindingManager::instance();

        // PYSIDE-1251:
        // Since some objects can be created with a parent and without
        // being saved on a local variable (refcount = 1), they will be
        // deleted when setting the parent to nullptr, so we change the loop
        // to do this from the last child to the first, to avoid the case
        // when the child(1) points to the original child(2) in case the
        // first one was removed.
        for (int i = rootItem->childCount() - 1; i >= 0; --i) {
            QTreeWidgetItem *item = rootItem->child(i);
            if (SbkObject *wrapper = bm.retrieveWrapper(item))
                Shiboken::Object::setParent(nullptr, reinterpret_cast<PyObject *>(wrapper));
        }
        // END of custom code block [file: ../glue/qtwidgets.cpp (qtreewidget-clear)]
        // ========================================================================
        // End of code injection

        cppSelf->clear();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_closePersistentEditor(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "closePersistentEditor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OO:closePersistentEditor", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::closePersistentEditor(QTreeWidgetItem*,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // closePersistentEditor(QTreeWidgetItem*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // closePersistentEditor(QTreeWidgetItem*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "closePersistentEditor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"column", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "closePersistentEditor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // closePersistentEditor(QTreeWidgetItem*,int)
            cppSelf->closePersistentEditor(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_collapseItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::collapseItem(const QTreeWidgetItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArg)))) {
        overloadId = 0; // collapseItem(const QTreeWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "collapseItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // collapseItem(const QTreeWidgetItem*)
            cppSelf->collapseItem(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_columnCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnCount()const
        int cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->columnCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_currentColumn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentColumn()const
        int cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->currentColumn();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_currentItem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentItem()const
        QTreeWidgetItem * cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->currentItem();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_dropEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::dropEvent(QDropEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dropEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDropEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dropEvent(QDropEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QTreeWidget::dropEvent(cppArg0)
                : cppSelf->dropEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_dropMimeData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "dropMimeData", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::dropMimeData(QTreeWidgetItem*,int,const QMimeData*,Qt::DropAction)->bool
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DropAction_IDX])))->converter, (pyArgs[3])))) {
        overloadId = 0; // dropMimeData(QTreeWidgetItem*,int,const QMimeData*,Qt::DropAction)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dropMimeData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QMimeData *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::Qt::DropAction cppArg3{Qt::IgnoreAction};
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dropMimeData(QTreeWidgetItem*,int,const QMimeData*,Qt::DropAction)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QTreeWidget::dropMimeData(cppArg0, cppArg1, cppArg2, cppArg3)
                : cppSelf->dropMimeData(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_editItem(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "editItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OO:editItem", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::editItem(QTreeWidgetItem*,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // editItem(QTreeWidgetItem*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // editItem(QTreeWidgetItem*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "editItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"column", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "editItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // editItem(QTreeWidgetItem*,int)
            cppSelf->editItem(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QTreeWidget::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_expandItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::expandItem(const QTreeWidgetItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArg)))) {
        overloadId = 0; // expandItem(const QTreeWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "expandItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // expandItem(const QTreeWidgetItem*)
            cppSelf->expandItem(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_findItems(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "findItems", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:findItems", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::findItems(QString,QFlags<Qt::MatchFlag>,int=)const->QList<QTreeWidgetItem*>
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MatchFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // findItems(QString,QFlags<Qt::MatchFlag>,int)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 0; // findItems(QString,QFlags<Qt::MatchFlag>,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "findItems", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"column", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "findItems", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::MatchFlag> cppArg1 = QFlags<Qt::MatchFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = 0;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // findItems(QString,QFlags<Qt::MatchFlag>,int)const
            QList<QTreeWidgetItem*> cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->findItems(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTreeWidgetItemPTR_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_headerItem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // headerItem()const
        QTreeWidgetItem * cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->headerItem();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_indexFromItem(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "indexFromItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OO:indexFromItem", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::indexFromItem(const QTreeWidgetItem*,int=)const->QModelIndex
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // indexFromItem(const QTreeWidgetItem*,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // indexFromItem(const QTreeWidgetItem*,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "indexFromItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"column", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "indexFromItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // indexFromItem(const QTreeWidgetItem*,int)const
            QModelIndex cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->indexFromItem(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_indexOfTopLevelItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::indexOfTopLevelItem(QTreeWidgetItem*)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArg)))) {
        overloadId = 0; // indexOfTopLevelItem(QTreeWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "indexOfTopLevelItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // indexOfTopLevelItem(QTreeWidgetItem*)const
            int cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->indexOfTopLevelItem(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_insertTopLevelItem(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertTopLevelItem", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::insertTopLevelItem(int,QTreeWidgetItem*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insertTopLevelItem(int,QTreeWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertTopLevelItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTreeWidgetItem *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertTopLevelItem(int,QTreeWidgetItem*)
            cppSelf->insertTopLevelItem(cppArg0, cppArg1);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[1]);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_insertTopLevelItems(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertTopLevelItems", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::insertTopLevelItems(int,QList<QTreeWidgetItem*>)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTreeWidgetItemPTR_IDX], (pyArgs[1])))) {
        overloadId = 0; // insertTopLevelItems(int,QList<QTreeWidgetItem*>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertTopLevelItems", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QList<QTreeWidgetItem*> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertTopLevelItems(int,QList<QTreeWidgetItem*>)
            cppSelf->insertTopLevelItems(cppArg0, cppArg1);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[1]);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_invisibleRootItem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // invisibleRootItem()const
        QTreeWidgetItem * cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->invisibleRootItem();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_isPersistentEditorOpen(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "isPersistentEditorOpen", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OO:isPersistentEditorOpen", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::isPersistentEditorOpen(QTreeWidgetItem*,int=)const->bool
    // 1: QAbstractItemView::isPersistentEditorOpen(QModelIndex)const->bool
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        overloadId = 1; // isPersistentEditorOpen(QModelIndex)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // isPersistentEditorOpen(QTreeWidgetItem*,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // isPersistentEditorOpen(QTreeWidgetItem*,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isPersistentEditorOpen", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isPersistentEditorOpen(QTreeWidgetItem *item, int column) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"column", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))) {
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "isPersistentEditorOpen", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTreeWidgetItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isPersistentEditorOpen(QTreeWidgetItem*,int)const
                bool cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->isPersistentEditorOpen(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // isPersistentEditorOpen(const QModelIndex &index) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "isPersistentEditorOpen", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QModelIndex cppArg0_local;
            ::QModelIndex *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // isPersistentEditorOpen(QModelIndex)const
                bool cppResult = const_cast<const ::QAbstractItemView *>(reinterpret_cast<QAbstractItemView *>(cppSelf))->isPersistentEditorOpen(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_itemAbove(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::itemAbove(const QTreeWidgetItem*)const->QTreeWidgetItem*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArg)))) {
        overloadId = 0; // itemAbove(const QTreeWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "itemAbove", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // itemAbove(const QTreeWidgetItem*)const
            QTreeWidgetItem * cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->itemAbove(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_itemAt(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "itemAt", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::itemAt(QPoint)const->QTreeWidgetItem*
    // 1: QTreeWidget::itemAt(int,int)const->QTreeWidgetItem*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 1; // itemAt(int,int)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))) {
        overloadId = 0; // itemAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "itemAt", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // itemAt(const QPoint &p) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // itemAt(QPoint)const
                QTreeWidgetItem * cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->itemAt(*cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), cppResult);
            }
            break;
        }
        case 1: // itemAt(int x, int y) const
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // itemAt(int,int)const
                QTreeWidgetItem * cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->itemAt(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_itemBelow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::itemBelow(const QTreeWidgetItem*)const->QTreeWidgetItem*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArg)))) {
        overloadId = 0; // itemBelow(const QTreeWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "itemBelow", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // itemBelow(const QTreeWidgetItem*)const
            QTreeWidgetItem * cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->itemBelow(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_itemFromIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::itemFromIndex(QModelIndex)const->QTreeWidgetItem*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // itemFromIndex(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "itemFromIndex", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // itemFromIndex(QModelIndex)const
            QTreeWidgetItem * cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->itemFromIndex(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_itemWidget(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "itemWidget", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::itemWidget(QTreeWidgetItem*,int)const->QWidget*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // itemWidget(QTreeWidgetItem*,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "itemWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // itemWidget(QTreeWidgetItem*,int)const
            QWidget * cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->itemWidget(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_mimeData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::mimeData(QList<QTreeWidgetItem*>)const->QMimeData*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTreeWidgetItemPTR_IDX], (pyArg)))) {
        overloadId = 0; // mimeData(QList<QTreeWidgetItem*>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mimeData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        ::QList<QTreeWidgetItem*> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mimeData(QList<QTreeWidgetItem*>)const
            QMimeData * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QTreeWidget *>(cppSelf)->::QTreeWidget::mimeData(cppArg0)
                : const_cast<const ::QTreeWidget *>(cppSelf)->mimeData(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_mimeTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mimeTypes()const
        QStringList cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QTreeWidget *>(cppSelf)->::QTreeWidget::mimeTypes()
            : const_cast<const ::QTreeWidget *>(cppSelf)->mimeTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_openPersistentEditor(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "openPersistentEditor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OO:openPersistentEditor", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::openPersistentEditor(QTreeWidgetItem*,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // openPersistentEditor(QTreeWidgetItem*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // openPersistentEditor(QTreeWidgetItem*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "openPersistentEditor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"column", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "openPersistentEditor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // openPersistentEditor(QTreeWidgetItem*,int)
            cppSelf->openPersistentEditor(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_removeItemWidget(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "removeItemWidget", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::removeItemWidget(QTreeWidgetItem*,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // removeItemWidget(QTreeWidgetItem*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "removeItemWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeItemWidget(QTreeWidgetItem*,int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->removeItemWidget(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_scrollToItem(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "scrollToItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    if (PyArg_ParseTuple(args, "|OO:scrollToItem", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::scrollToItem(const QTreeWidgetItem*,QAbstractItemView::ScrollHint=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // scrollToItem(const QTreeWidgetItem*,QAbstractItemView::ScrollHint)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollHint_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // scrollToItem(const QTreeWidgetItem*,QAbstractItemView::ScrollHint)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scrollToItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"hint", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_ScrollHint_IDX])))->converter, (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "scrollToItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QAbstractItemView::ScrollHint cppArg1(QAbstractItemView::ScrollHint::EnsureVisible);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // scrollToItem(const QTreeWidgetItem*,QAbstractItemView::ScrollHint)
            cppSelf->scrollToItem(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_selectedItems(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedItems()const
        QList<QTreeWidgetItem*> cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->selectedItems();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTreeWidgetItemPTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_setColumnCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::setColumnCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setColumnCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColumnCount", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColumnCount(int)
            cppSelf->setColumnCount(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_setCurrentItem(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setCurrentItem", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::setCurrentItem(QTreeWidgetItem*)
    // 1: QTreeWidget::setCurrentItem(QTreeWidgetItem*,int)
    // 2: QTreeWidget::setCurrentItem(QTreeWidgetItem*,int,QFlags<QItemSelectionModel::SelectionFlag>)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setCurrentItem(QTreeWidgetItem*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // setCurrentItem(QTreeWidgetItem*,int)
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QItemSelectionModel_SelectionFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 2; // setCurrentItem(QTreeWidgetItem*,int,QFlags<QItemSelectionModel::SelectionFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCurrentItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setCurrentItem(QTreeWidgetItem *item)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTreeWidgetItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setCurrentItem(QTreeWidgetItem*)
                cppSelf->setCurrentItem(cppArg0);
            }
            break;
        }
        case 1: // setCurrentItem(QTreeWidgetItem *item, int column)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTreeWidgetItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setCurrentItem(QTreeWidgetItem*,int)
                cppSelf->setCurrentItem(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // setCurrentItem(QTreeWidgetItem *item, int column, QFlags<QItemSelectionModel::SelectionFlag> command)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTreeWidgetItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QItemSelectionModel::SelectionFlag> cppArg2 = QFlags<QItemSelectionModel::SelectionFlag>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setCurrentItem(QTreeWidgetItem*,int,QFlags<QItemSelectionModel::SelectionFlag>)
                cppSelf->setCurrentItem(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_setHeaderItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::setHeaderItem(QTreeWidgetItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArg)))) {
        overloadId = 0; // setHeaderItem(QTreeWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeaderItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeaderItem(QTreeWidgetItem*)
            cppSelf->setHeaderItem(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_setHeaderLabel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::setHeaderLabel(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setHeaderLabel(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeaderLabel", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeaderLabel(QString)
            cppSelf->setHeaderLabel(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_setHeaderLabels(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::setHeaderLabels(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setHeaderLabels(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeaderLabels", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeaderLabels(QStringList)
            cppSelf->setHeaderLabels(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_setItemWidget(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setItemWidget", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::setItemWidget(QTreeWidgetItem*,int,QWidget*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
        overloadId = 0; // setItemWidget(QTreeWidgetItem*,int,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setItemWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QWidget *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemWidget(QTreeWidgetItem*,int,QWidget*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setItemWidget(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[2]);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_setModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setModel(QAbstractItemModel*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), (pyArg)))) {
        overloadId = 0; // setModel(QAbstractItemModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setModel", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("setModel(QAbstractItemModel *model)");
        return {};
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_setSelectionModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemView::setSelectionModel(QItemSelectionModel*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionModel_IDX]), (pyArg)))) {
        overloadId = 0; // setSelectionModel(QItemSelectionModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelectionModel", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QItemSelectionModel *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectionModel(QItemSelectionModel*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QTreeWidget::setSelectionModel(cppArg0)
                : cppSelf->setSelectionModel(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "setSelectionModel(QItemSelectionModel*)1", pyArg);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_sortColumn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sortColumn()const
        int cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->sortColumn();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_sortItems(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sortItems", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTreeWidget::sortItems(int,Qt::SortOrder)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // sortItems(int,Qt::SortOrder)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sortItems", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::SortOrder cppArg1{Qt::AscendingOrder};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sortItems(int,Qt::SortOrder)
            cppSelf->sortItems(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QTreeWidgetFunc_supportedDropActions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedDropActions()const
        QFlags<Qt::DropAction> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QTreeWidget *>(cppSelf)->::QTreeWidget::supportedDropActions()
            : const_cast<const ::QTreeWidget *>(cppSelf)->supportedDropActions();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_DropAction_IDX])))->flagsConverter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_takeTopLevelItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::takeTopLevelItem(int)->QTreeWidgetItem*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // takeTopLevelItem(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "takeTopLevelItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // takeTopLevelItem(int)
            QTreeWidgetItem * cppResult = cppSelf->takeTopLevelItem(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), cppResult);

            // Ownership transferences.
            // Ownership transferences.
            Shiboken::Object::setParent(Py_None, pyResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_topLevelItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::topLevelItem(int)const->QTreeWidgetItem*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // topLevelItem(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "topLevelItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // topLevelItem(int)const
            QTreeWidgetItem * cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->topLevelItem(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_topLevelItemCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // topLevelItemCount()const
        int cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->topLevelItemCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QTreeWidgetFunc_visualItemRect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTreeWidget::visualItemRect(const QTreeWidgetItem*)const->QRect
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), (pyArg)))) {
        overloadId = 0; // visualItemRect(const QTreeWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "visualItemRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTreeWidgetItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // visualItemRect(const QTreeWidgetItem*)const
            QRect cppResult = const_cast<const ::QTreeWidget *>(cppSelf)->visualItemRect(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QTreeWidget_PropertyStrings[] = {
    "columnCount::",
    "topLevelItemCount:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTreeWidget_methods[] = {
    {"addTopLevelItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_addTopLevelItem), METH_O, nullptr},
    {"addTopLevelItems", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_addTopLevelItems), METH_O, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_clear), METH_NOARGS, nullptr},
    {"closePersistentEditor", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_closePersistentEditor), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"collapseItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_collapseItem), METH_O, nullptr},
    {"columnCount", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_columnCount), METH_NOARGS, nullptr},
    {"currentColumn", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_currentColumn), METH_NOARGS, nullptr},
    {"currentItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_currentItem), METH_NOARGS, nullptr},
    {"dropEvent", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_dropEvent), METH_O, nullptr},
    {"dropMimeData", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_dropMimeData), METH_VARARGS, nullptr},
    {"editItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_editItem), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_event), METH_O, nullptr},
    {"expandItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_expandItem), METH_O, nullptr},
    {"findItems", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_findItems), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"headerItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_headerItem), METH_NOARGS, nullptr},
    {"indexFromItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_indexFromItem), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"indexOfTopLevelItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_indexOfTopLevelItem), METH_O, nullptr},
    {"insertTopLevelItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_insertTopLevelItem), METH_VARARGS, nullptr},
    {"insertTopLevelItems", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_insertTopLevelItems), METH_VARARGS, nullptr},
    {"invisibleRootItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_invisibleRootItem), METH_NOARGS, nullptr},
    {"isPersistentEditorOpen", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_isPersistentEditorOpen), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"itemAbove", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_itemAbove), METH_O, nullptr},
    {"itemAt", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_itemAt), METH_VARARGS, nullptr},
    {"itemBelow", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_itemBelow), METH_O, nullptr},
    {"itemFromIndex", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_itemFromIndex), METH_O, nullptr},
    {"itemWidget", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_itemWidget), METH_VARARGS, nullptr},
    {"mimeData", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_mimeData), METH_O, nullptr},
    {"mimeTypes", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_mimeTypes), METH_NOARGS, nullptr},
    {"openPersistentEditor", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_openPersistentEditor), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"removeItemWidget", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_removeItemWidget), METH_VARARGS, nullptr},
    {"scrollToItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_scrollToItem), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"selectedItems", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_selectedItems), METH_NOARGS, nullptr},
    {"setColumnCount", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_setColumnCount), METH_O, nullptr},
    {"setCurrentItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_setCurrentItem), METH_VARARGS, nullptr},
    {"setHeaderItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_setHeaderItem), METH_O, nullptr},
    {"setHeaderLabel", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_setHeaderLabel), METH_O, nullptr},
    {"setHeaderLabels", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_setHeaderLabels), METH_O, nullptr},
    {"setItemWidget", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_setItemWidget), METH_VARARGS, nullptr},
    {"setModel", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_setModel), METH_O, nullptr},
    {"setSelectionModel", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_setSelectionModel), METH_O, nullptr},
    {"sortColumn", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_sortColumn), METH_NOARGS, nullptr},
    {"sortItems", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_sortItems), METH_VARARGS, nullptr},
    {"supportedDropActions", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_supportedDropActions), METH_NOARGS, nullptr},
    {"takeTopLevelItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_takeTopLevelItem), METH_O, nullptr},
    {"topLevelItem", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_topLevelItem), METH_O, nullptr},
    {"topLevelItemCount", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_topLevelItemCount), METH_NOARGS, nullptr},
    {"visualItemRect", reinterpret_cast<PyCFunction>(Sbk_QTreeWidgetFunc_visualItemRect), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QTreeWidget_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QTreeWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QTreeWidgetWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QTreeWidget_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTreeWidget_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QTreeWidgetSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QTreeWidget *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeView_IDX]))
        return static_cast< ::QTreeView *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]))
        return static_cast< ::QAbstractItemView *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX]))
        return static_cast< ::QAbstractScrollArea *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX]))
        return static_cast< ::QFrame *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTreeWidget_Type = nullptr;
static PyTypeObject *Sbk_QTreeWidget_TypeF(void)
{
    return _Sbk_QTreeWidget_Type;
}

static PyType_Slot Sbk_QTreeWidget_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QTreeWidget_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTreeWidget_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTreeWidget_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTreeWidget_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTreeWidget_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTreeWidget_spec = {
    "2:PySide6.QtWidgets.QTreeWidget",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTreeWidget_slots
};

} //extern "C"

static void *Sbk_QTreeWidget_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QTreeWidget *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QTreeWidget *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QTreeWidget *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTreeWidget_PythonToCpp_QTreeWidget_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTreeWidget_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTreeWidget_PythonToCpp_QTreeWidget_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTreeWidget_TypeF()))
        return QTreeWidget_PythonToCpp_QTreeWidget_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTreeWidget_PTR_CppToPython_QTreeWidget(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QTreeWidget *>(const_cast<void *>(cppIn)), Sbk_QTreeWidget_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTreeWidget_SignatureStrings[] = {
    "PySide6.QtWidgets.QTreeWidget(self,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,columnCount:int=None,topLevelItemCount:int=None)",
    "PySide6.QtWidgets.QTreeWidget.addTopLevelItem(self,item:PySide6.QtWidgets.QTreeWidgetItem)",
    "PySide6.QtWidgets.QTreeWidget.addTopLevelItems(self,items:QList[PySide6.QtWidgets.QTreeWidgetItem])",
    "PySide6.QtWidgets.QTreeWidget.clear(self)",
    "PySide6.QtWidgets.QTreeWidget.closePersistentEditor(self,item:PySide6.QtWidgets.QTreeWidgetItem,column:int=0)",
    "PySide6.QtWidgets.QTreeWidget.collapseItem(self,item:PySide6.QtWidgets.QTreeWidgetItem)",
    "PySide6.QtWidgets.QTreeWidget.columnCount(self)->int",
    "PySide6.QtWidgets.QTreeWidget.currentColumn(self)->int",
    "PySide6.QtWidgets.QTreeWidget.currentItem(self)->PySide6.QtWidgets.QTreeWidgetItem",
    "PySide6.QtWidgets.QTreeWidget.dropEvent(self,event:PySide6.QtGui.QDropEvent)",
    "PySide6.QtWidgets.QTreeWidget.dropMimeData(self,parent:PySide6.QtWidgets.QTreeWidgetItem,index:int,data:PySide6.QtCore.QMimeData,action:PySide6.QtCore.Qt.DropAction)->bool",
    "PySide6.QtWidgets.QTreeWidget.editItem(self,item:PySide6.QtWidgets.QTreeWidgetItem,column:int=0)",
    "PySide6.QtWidgets.QTreeWidget.event(self,e:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QTreeWidget.expandItem(self,item:PySide6.QtWidgets.QTreeWidgetItem)",
    "PySide6.QtWidgets.QTreeWidget.findItems(self,text:QString,flags:PySide6.QtCore.Qt.MatchFlag,column:int=0)->QList[PySide6.QtWidgets.QTreeWidgetItem]",
    "PySide6.QtWidgets.QTreeWidget.headerItem(self)->PySide6.QtWidgets.QTreeWidgetItem",
    "PySide6.QtWidgets.QTreeWidget.indexFromItem(self,item:PySide6.QtWidgets.QTreeWidgetItem,column:int=0)->PySide6.QtCore.QModelIndex",
    "PySide6.QtWidgets.QTreeWidget.indexOfTopLevelItem(self,item:PySide6.QtWidgets.QTreeWidgetItem)->int",
    "PySide6.QtWidgets.QTreeWidget.insertTopLevelItem(self,index:int,item:PySide6.QtWidgets.QTreeWidgetItem)",
    "PySide6.QtWidgets.QTreeWidget.insertTopLevelItems(self,index:int,items:QList[PySide6.QtWidgets.QTreeWidgetItem])",
    "PySide6.QtWidgets.QTreeWidget.invisibleRootItem(self)->PySide6.QtWidgets.QTreeWidgetItem",
    "1:PySide6.QtWidgets.QTreeWidget.isPersistentEditorOpen(self,item:PySide6.QtWidgets.QTreeWidgetItem,column:int=0)->bool",
    "0:PySide6.QtWidgets.QTreeWidget.isPersistentEditorOpen(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "PySide6.QtWidgets.QTreeWidget.itemAbove(self,item:PySide6.QtWidgets.QTreeWidgetItem)->PySide6.QtWidgets.QTreeWidgetItem",
    "1:PySide6.QtWidgets.QTreeWidget.itemAt(self,p:PySide6.QtCore.QPoint)->PySide6.QtWidgets.QTreeWidgetItem",
    "0:PySide6.QtWidgets.QTreeWidget.itemAt(self,x:int,y:int)->PySide6.QtWidgets.QTreeWidgetItem",
    "PySide6.QtWidgets.QTreeWidget.itemBelow(self,item:PySide6.QtWidgets.QTreeWidgetItem)->PySide6.QtWidgets.QTreeWidgetItem",
    "PySide6.QtWidgets.QTreeWidget.itemFromIndex(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtWidgets.QTreeWidgetItem",
    "PySide6.QtWidgets.QTreeWidget.itemWidget(self,item:PySide6.QtWidgets.QTreeWidgetItem,column:int)->PySide6.QtWidgets.QWidget",
    "PySide6.QtWidgets.QTreeWidget.mimeData(self,items:QList[PySide6.QtWidgets.QTreeWidgetItem])->PySide6.QtCore.QMimeData",
    "PySide6.QtWidgets.QTreeWidget.mimeTypes(self)->QStringList",
    "PySide6.QtWidgets.QTreeWidget.openPersistentEditor(self,item:PySide6.QtWidgets.QTreeWidgetItem,column:int=0)",
    "PySide6.QtWidgets.QTreeWidget.removeItemWidget(self,item:PySide6.QtWidgets.QTreeWidgetItem,column:int)",
    "PySide6.QtWidgets.QTreeWidget.scrollToItem(self,item:PySide6.QtWidgets.QTreeWidgetItem,hint:PySide6.QtWidgets.QAbstractItemView.ScrollHint=QAbstractItemView.ScrollHint.EnsureVisible)",
    "PySide6.QtWidgets.QTreeWidget.selectedItems(self)->QList[PySide6.QtWidgets.QTreeWidgetItem]",
    "PySide6.QtWidgets.QTreeWidget.setColumnCount(self,columns:int)",
    "2:PySide6.QtWidgets.QTreeWidget.setCurrentItem(self,item:PySide6.QtWidgets.QTreeWidgetItem)",
    "1:PySide6.QtWidgets.QTreeWidget.setCurrentItem(self,item:PySide6.QtWidgets.QTreeWidgetItem,column:int)",
    "0:PySide6.QtWidgets.QTreeWidget.setCurrentItem(self,item:PySide6.QtWidgets.QTreeWidgetItem,column:int,command:PySide6.QtCore.QItemSelectionModel.SelectionFlag)",
    "PySide6.QtWidgets.QTreeWidget.setHeaderItem(self,item:PySide6.QtWidgets.QTreeWidgetItem)",
    "PySide6.QtWidgets.QTreeWidget.setHeaderLabel(self,label:QString)",
    "PySide6.QtWidgets.QTreeWidget.setHeaderLabels(self,labels:QStringList)",
    "PySide6.QtWidgets.QTreeWidget.setItemWidget(self,item:PySide6.QtWidgets.QTreeWidgetItem,column:int,widget:Optional[PySide6.QtWidgets.QWidget])",
    "PySide6.QtWidgets.QTreeWidget.setModel(self,model:Optional[PySide6.QtCore.QAbstractItemModel])",
    "PySide6.QtWidgets.QTreeWidget.setSelectionModel(self,selectionModel:PySide6.QtCore.QItemSelectionModel)",
    "PySide6.QtWidgets.QTreeWidget.sortColumn(self)->int",
    "PySide6.QtWidgets.QTreeWidget.sortItems(self,column:int,order:PySide6.QtCore.Qt.SortOrder)",
    "PySide6.QtWidgets.QTreeWidget.supportedDropActions(self)->PySide6.QtCore.Qt.DropAction",
    "PySide6.QtWidgets.QTreeWidget.takeTopLevelItem(self,index:int)->PySide6.QtWidgets.QTreeWidgetItem",
    "PySide6.QtWidgets.QTreeWidget.topLevelItem(self,index:int)->PySide6.QtWidgets.QTreeWidgetItem",
    "PySide6.QtWidgets.QTreeWidget.topLevelItemCount(self)->int",
    "PySide6.QtWidgets.QTreeWidget.visualItemRect(self,item:PySide6.QtWidgets.QTreeWidgetItem)->PySide6.QtCore.QRect",
    nullptr}; // Sentinel
#else
static constexpr size_t QTreeWidget_SignatureByteSize = 830;
static constexpr uint8_t QTreeWidget_SignatureBytes[830] = {
    0x78, 0xda, 0xbd, 0x58, 0x4d, 0x53, 0xdb, 0x30, 0x10, 0xbd, 0xf3, 0x2b, 0x7a, 0x2c, 0x1d, 0xd7,
    0x13, 0x7a, 0xe8, 0xc1, 0x33, 0x30, 0x43, 0xf9, 0x28, 0x4c, 0xa1, 0x49, 0x48, 0x4a, 0x0f, 0x0c,
    0x07, 0x25, 0xda, 0x80, 0xa6, 0xb2, 0xe4, 0x91, 0xe4, 0x84, 0xfc, 0xfb, 0xea, 0xc3, 0x49, 0xec,
    0xd8, 0x44, 0x16, 0x31, 0xdc, 0x14, 0x4b, 0xfb, 0xde, 0x6a, 0x77, 0xb5, 0x7a, 0xca, 0x60, 0x39,
    0x22, 0x18, 0xbe, 0xc7, 0x43, 0xf5, 0x97, 0xe0, 0x27, 0x50, 0x32, 0x1e, 0x8e, 0x05, 0x80, 0xfb,
    0xf1, 0x59, 0x02, 0x9d, 0x45, 0x19, 0x12, 0xc0, 0x54, 0x32, 0xa8, 0xaf, 0x74, 0x83, 0x63, 0x96,
    0x53, 0x9a, 0x29, 0x11, 0x7d, 0x49, 0x7e, 0xc1, 0x72, 0xc1, 0x05, 0xee, 0x33, 0xba, 0x3c, 0xfe,
    0xcd, 0x19, 0x44, 0x53, 0x4e, 0xf3, 0x94, 0x9d, 0xf1, 0x5c, 0x03, 0x10, 0xa6, 0xdc, 0x47, 0xc5,
    0xb3, 0x1b, 0x98, 0x03, 0xbd, 0x56, 0x90, 0x56, 0xa7, 0x0e, 0x0f, 0x06, 0xbb, 0xfc, 0x89, 0x11,
    0xc6, 0xe3, 0x92, 0xb1, 0xf3, 0x8f, 0xe8, 0x51, 0xb2, 0xd3, 0xce, 0xac, 0x0d, 0x84, 0x96, 0x1b,
    0x6c, 0x99, 0x0c, 0x6f, 0x88, 0x54, 0x0f, 0x5e, 0x8a, 0x47, 0x1f, 0xc7, 0x94, 0x02, 0x12, 0x16,
    0xd8, 0xbf, 0x92, 0x4b, 0x18, 0x80, 0x90, 0x9a, 0x58, 0x07, 0xff, 0x02, 0x13, 0xc5, 0x45, 0xc8,
    0x76, 0x8b, 0xc8, 0xdb, 0xc8, 0xf6, 0xbc, 0x6c, 0x9c, 0x52, 0x94, 0x49, 0xe8, 0x3a, 0xa6, 0xa5,
    0xec, 0xbb, 0x5d, 0x7f, 0x3d, 0xd1, 0xfe, 0xf8, 0x8c, 0x72, 0x61, 0xea, 0xed, 0xcc, 0xda, 0x06,
    0x9b, 0xad, 0xb7, 0xa0, 0x8d, 0xbc, 0xfe, 0x7b, 0x20, 0xb1, 0xe0, 0xd9, 0xc5, 0x1c, 0x0a, 0xe7,
    0x23, 0x98, 0x57, 0x8f, 0xc1, 0xcf, 0x9c, 0xc4, 0xc3, 0xf3, 0xd5, 0x9a, 0xc3, 0x16, 0x60, 0xb7,
    0x24, 0x85, 0x73, 0xa4, 0x90, 0xef, 0x5c, 0x6d, 0xa5, 0x92, 0x30, 0x0c, 0x2f, 0x26, 0x93, 0x11,
    0xd6, 0xc6, 0x25, 0x83, 0x33, 0x2e, 0x20, 0x1e, 0xae, 0x50, 0x23, 0x34, 0x55, 0x84, 0xb3, 0xda,
    0xbc, 0x8a, 0x8d, 0x93, 0xa7, 0x76, 0x52, 0x47, 0x65, 0xc2, 0x39, 0xf5, 0xf8, 0x0a, 0xba, 0xdc,
    0x42, 0x6b, 0x21, 0xa8, 0xe0, 0xa0, 0x14, 0xd5, 0x9a, 0xbf, 0x2e, 0x9c, 0xed, 0x1c, 0x7d, 0xc9,
    0x10, 0xc3, 0x5d, 0x97, 0xed, 0x8c, 0x38, 0xcc, 0xa2, 0x07, 0x28, 0x78, 0x51, 0xc9, 0x70, 0xa4,
    0x04, 0x61, 0x4f, 0xd1, 0x8c, 0xa2, 0x27, 0xd9, 0x10, 0xe2, 0x5b, 0xa4, 0xa6, 0xcf, 0x97, 0x7a,
    0xb2, 0x1a, 0x87, 0xaf, 0x27, 0x6d, 0x7b, 0x87, 0xc7, 0xa7, 0x67, 0x40, 0x18, 0x44, 0x97, 0xd5,
    0x6d, 0xab, 0xea, 0x52, 0xf0, 0x74, 0xbf, 0x4c, 0x97, 0x1d, 0x29, 0xea, 0x91, 0x63, 0xdd, 0x43,
    0x0d, 0x7a, 0x1b, 0x0f, 0xfa, 0xb3, 0x37, 0x77, 0xf4, 0x36, 0x6d, 0x81, 0x30, 0x09, 0x42, 0x35,
    0x50, 0xac, 0xcf, 0x54, 0x37, 0x35, 0x53, 0xe7, 0x91, 0x4d, 0x44, 0xdd, 0xdd, 0x25, 0x84, 0xcd,
    0x89, 0x24, 0x13, 0x0a, 0x77, 0x9c, 0x07, 0x76, 0xbd, 0xa3, 0xc4, 0x03, 0x2d, 0xb7, 0x6f, 0x9e,
    0x7e, 0x06, 0x6c, 0x9f, 0x12, 0xb1, 0x47, 0xb9, 0xb7, 0x0f, 0xad, 0x8d, 0xa2, 0x5a, 0x66, 0xfa,
    0x0c, 0xc6, 0x7f, 0x98, 0xee, 0x64, 0x0f, 0xaf, 0x97, 0x5d, 0xf4, 0x69, 0x7b, 0x6e, 0x03, 0xbc,
    0x59, 0xf5, 0xd8, 0xae, 0xc5, 0x98, 0x0d, 0x9f, 0x4e, 0xf8, 0x1c, 0x02, 0x4b, 0xb3, 0x83, 0x34,
    0x18, 0xe6, 0x95, 0x06, 0xab, 0xb5, 0x9c, 0x01, 0x27, 0xb6, 0x4b, 0xfa, 0x79, 0x7a, 0x01, 0x3c,
    0xae, 0x52, 0x97, 0x49, 0x5b, 0x6c, 0x3f, 0xf2, 0x0f, 0xa0, 0x7c, 0xd1, 0x79, 0xec, 0xfc, 0xbc,
    0xb6, 0xb3, 0x99, 0x3c, 0xbf, 0x6b, 0x01, 0x75, 0xe1, 0x69, 0x59, 0x6b, 0x07, 0x1f, 0xaf, 0x66,
    0x1f, 0xdc, 0xc0, 0xc3, 0x9d, 0x56, 0xd4, 0x48, 0x60, 0x77, 0x6a, 0x68, 0xfb, 0x05, 0x5c, 0x0b,
    0xd6, 0xf1, 0x32, 0x03, 0xb9, 0xea, 0x57, 0xc5, 0xcd, 0x6a, 0x88, 0x3d, 0xa6, 0x5c, 0xb7, 0x83,
    0x0f, 0xd3, 0xc4, 0x02, 0x52, 0x7d, 0xe8, 0xaf, 0xf7, 0xce, 0x8f, 0x87, 0x46, 0x4e, 0x85, 0x16,
    0xdf, 0x63, 0x1e, 0x7c, 0x09, 0x3f, 0x93, 0x66, 0xed, 0x78, 0x3a, 0x91, 0x4a, 0x68, 0x25, 0x68,
    0x16, 0xdd, 0x13, 0x58, 0xc4, 0x23, 0xcb, 0x70, 0x65, 0x36, 0xbd, 0x6b, 0x32, 0xbe, 0x60, 0x32,
    0x17, 0x70, 0xef, 0x2e, 0x15, 0xaf, 0xdb, 0x40, 0x61, 0xaa, 0xa0, 0x24, 0x93, 0xba, 0x93, 0x3a,
    0x12, 0x0a, 0xf1, 0xbf, 0x79, 0x38, 0x14, 0x01, 0x95, 0x2e, 0xa2, 0xdf, 0x12, 0x3f, 0xc0, 0xd6,
    0x6b, 0xa0, 0xf5, 0x2d, 0x7f, 0xf4, 0x6e, 0xd8, 0x95, 0xa2, 0xe8, 0x7d, 0x04, 0x8d, 0x1e, 0xa6,
    0xa9, 0xd6, 0xc7, 0xb5, 0xbb, 0xc3, 0xac, 0x1b, 0xd9, 0x0c, 0xea, 0x3e, 0x68, 0x1b, 0x5a, 0xbc,
    0xfe, 0x69, 0x34, 0xac, 0x3f, 0xfb, 0xea, 0xaa, 0xaa, 0x47, 0x3b, 0x52, 0x51, 0x6b, 0xe0, 0x1b,
    0x34, 0x01, 0xea, 0x90, 0xa9, 0x19, 0xae, 0xf4, 0x77, 0x18, 0x80, 0x2c, 0x21, 0xc8, 0xa4, 0xd4,
    0x68, 0x5a, 0xc0, 0xec, 0x7d, 0xf2, 0xa3, 0x85, 0xfd, 0x9a, 0xf4, 0x33, 0x13, 0x56, 0x44, 0x1f,
    0x5e, 0xed, 0xd3, 0x8f, 0x2d, 0xdc, 0xb1, 0x59, 0x72, 0x9e, 0xa4, 0x66, 0xd8, 0x04, 0xeb, 0x92,
    0x5b, 0x3e, 0xe3, 0xd6, 0xaa, 0x0d, 0x7c, 0xb5, 0x1a, 0x1c, 0x8f, 0xac, 0x7c, 0x6b, 0x51, 0x44,
    0x5e, 0x1e, 0x2e, 0x82, 0x9f, 0xf5, 0xc6, 0xa6, 0xa4, 0xa6, 0x4b, 0xe1, 0xe5, 0x42, 0xa7, 0xb9,
    0xe1, 0x25, 0x36, 0xd2, 0x16, 0x7d, 0x33, 0xe7, 0x75, 0x27, 0xcf, 0x32, 0xbd, 0x16, 0xf0, 0xe6,
    0x79, 0x2c, 0xeb, 0x22, 0xba, 0xfe, 0x86, 0xf6, 0xc0, 0x2a, 0xf4, 0x0f, 0x76, 0xbc, 0x37, 0x3a,
    0x10, 0x0d, 0xea, 0xc3, 0xd0, 0x03, 0xff, 0xba, 0xd1, 0x2f, 0x92, 0x1c, 0x59, 0xc3, 0x3b, 0x5d,
    0x16, 0x6f, 0x16, 0x7d, 0x2e, 0xe4, 0x06, 0xe2, 0xe0, 0x3f, 0xd0, 0x07, 0x8a, 0x44
};
#endif

PyTypeObject *init_QTreeWidget(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX].type;

    Shiboken::AutoDecRef Sbk_QTreeWidget_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeView_IDX]))));

    _Sbk_QTreeWidget_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTreeWidget",
        "QTreeWidget*",
        &Sbk_QTreeWidget_spec,
        &Shiboken::callCppDestructor< QTreeWidget >,
        Sbk_QTreeWidget_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QTreeWidget_TypeF(); // references _Sbk_QTreeWidget_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTreeWidget_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTreeWidget_SignatureBytes, QTreeWidget_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTreeWidget_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTreeWidget_PythonToCpp_QTreeWidget_PTR,
        is_QTreeWidget_PythonToCpp_QTreeWidget_PTR_Convertible,
        QTreeWidget_PTR_CppToPython_QTreeWidget);

    Shiboken::Conversions::registerConverterName(converter, "QTreeWidget");
    Shiboken::Conversions::registerConverterName(converter, "QTreeWidget*");
    Shiboken::Conversions::registerConverterName(converter, "QTreeWidget&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTreeWidget).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QTreeWidgetWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QTreeWidget_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QTreeWidget_TypeF(), &Sbk_QTreeWidgetSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QTreeWidget_TypeF(), &Sbk_QTreeWidget_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QTreeWidget::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QTreeWidget::staticMetaObject, sizeof(QTreeWidgetWrapper));

    return pyType;
}
